(()=>{"use strict";var wpcf7_redirect;(function($){function Wpcf7_redirect(){this.init=function(){this.wpcf7_redirect_mailsent_handler()},this.wpcf7_redirect_mailsent_handler=function(){document.addEventListener("wpcf7mailsent",(function(e){if($(document.body).trigger("wpcf7r-mailsent",[e]),void 0!==e.detail.apiResponse&&e.detail.apiResponse){const i=e.detail.apiResponse;let t=0;void 0!==i.api_url_request&&i.api_url_request&&wpcf7_redirect.handle_api_action(i.api_url_request),void 0!==i.api_json_xml_request&&i.api_json_xml_request&&wpcf7_redirect.handle_api_action(i.api_json_xml_request),void 0!==i.FireScript&&i.FireScript&&(t=void 0!==i.FireScript.delay_redirect?i.FireScript.delay_redirect:t,window.setTimeout((function(){wpcf7_redirect.handle_javascript_action(i.FireScript)}),t)),void 0!==i.popup&&i.popup&&wpcf7_redirect.handle_popups(i.popup,e),void 0!==i.redirect_to_paypal&&i.redirect_to_paypal&&(t=void 0!==i.redirect_to_paypal.delay_redirect?i.redirect_to_paypal.delay_redirect:t,window.setTimeout((function(){wpcf7_redirect.handle_redirect_action(i.redirect_to_paypal)}),t)),void 0!==i.redirect&&i.redirect&&(t=void 0!==i.redirect.delay_redirect?i.redirect.delay_redirect:t,window.setTimeout((function(){wpcf7_redirect.handle_redirect_action(i.redirect)}),t))}}),!1),document.addEventListener("wpcf7invalid",(function(e){if($(document.body).trigger("wpcf7r-invalid",[e]),void 0!==e.detail.apiResponse&&e.detail.apiResponse){const i=e.detail.apiResponse;i.invalidFields&&wpcf7_redirect.ninja_multistep_mov_to_invalid_tab(e,i)}}))},this.handle_popups=function(e,i){$(document.body).trigger("wpcf7r-before-open-popup",[i]),$.each(e,(function(e,i){var t=$(i["popup-template"]);$(document.body).append(t),$(document.body).addClass(i["template-name"]),window.setTimeout((function(){$(document.body).addClass("modal-popup-open"),t.addClass("is-open")}),1e3),t.find(".close-button").on("click",(function(){t.removeClass("is-open").addClass("fade"),$(document.body).removeClass("modal-popup-open"),window.setTimeout((function(){$(".wpcf7r-modal").remove(),$(document.body).trigger("wpcf7r-popup-removed",[t])}),4e3)})),$(document.body).trigger("wpcf7r-popup-appended",[t])}))},this.handle_api_action=function(send_to_api_result){$.each(send_to_api_result,(function(k,v){try{if(!v.result_javascript||"string"!=typeof v.result_javascript)return;v.api_response&&"string"==typeof v.api_response&&""!==v.api_response.trim()&&(window.rcf7_response=JSON.parse(v.api_response)),eval(v.result_javascript)}catch(e){console.error("Error handling API action:",e)}}))},this.ninja_multistep_mov_to_invalid_tab=function(e,i){if($(".fieldset-cf7mls-wrapper").length){const t=$(e.target),r=i.invalidFields[0],n=$(r.into).parents("fieldset"),o=t.find(".cf7mls_current_fs"),d=n;t.find(".fieldset-cf7mls").removeClass("cf7mls_current_fs"),n.addClass("cf7mls_current_fs").removeClass("cf7mls_back_fs"),t.find(".cf7mls_progress_bar").length&&(t.find(".cf7mls_progress_bar li").eq(t.find("fieldset.fieldset-cf7mls").index(d)).addClass("current"),t.find(".cf7mls_progress_bar li").eq(t.find("fieldset.fieldset-cf7mls").index(o)).removeClass("active current"))}},this.handle_redirect_action=function(e){$(document.body).trigger("wpcf7r-handle_redirect_action",[e]),$.each(e,(function(e,i){const t=1e3*(i.delay||0);window.setTimeout((function(e){const i=e.redirect_url||"",t=e.type||"";void 0!==e.form&&e.form?($("body").append(e.form),$("#cf7r-result-form").submit()):i&&"redirect"==t?window.location=i:i&&"new_tab"==t&&window.open(i)}),t,i)}))},this.handle_javascript_action=function(scripts){$(document.body).trigger("wpcf7r-handle_javascript_action",[scripts]),$.each(scripts,(function(k,script){eval(script)}))},this.htmlspecialchars_decode=function(e){var i={"&amp;":"&","&#038;":"&","&lt;":"<","&gt;":">","&quot;":'"',"&#039;":"'","&#8217;":"’","&#8216;":"‘","&#8211;":"–","&#8212;":"—","&#8230;":"…","&#8221;":"”"};return e.replace(/\&[\w\d\#]{2,5}\;/g,(function(e){return i[e]}))},this.init()}wpcf7_redirect=new Wpcf7_redirect})(jQuery)})();