#wpadminbar .wpcode-admin-bar-info-separator-top{margin-top:5px;padding-top:5px;border-top:1px solid}#wpadminbar .wpcode-admin-bar-description .ab-item{font-weight:700}#wpadminbar .wpcode-pro-indicator{background:#bbb;color:#333 !important;text-transform:uppercase;padding:4px 7px;border-radius:9px;font-size:8px;line-height:1;display:inline-block;vertical-align:text-top;font-weight:600}#wpadminbar #wp-admin-bar-wpcode-upgrade a{background-color:#59A56D !important;color:#fff !important}#wpadminbar .quicklinks .wpcode-admin-bar-upsell-submenu .ab-empty-item{display:none}#wpadminbar .quicklinks .wpcode-admin-bar-has-upsell-submenu .ab-sub-wrapper{background:transparent;box-shadow:none}#wpadminbar .wpcode-admin-bar-submenu-upsell{min-width:660px;border-radius:8px;box-shadow:0 2px 5px rgba(0,0,0,.2);background:#fff;color:#1d2327;padding:40px;text-align:center}#wpadminbar .wpcode-admin-bar-submenu-upsell .wpcode-heading{font-size:24px;padding:8px 12px;line-height:1.5}#wpadminbar .wpcode-admin-bar-submenu-upsell p{color:#777777;font-size:16px;margin:16px 0;line-height:1.5}#wpadminbar .wpcode-admin-bar-submenu-upsell .wpcode-button{margin-top:6px !important;background-color:#E06B44;color:#fff !important;font-size:16px;display:inline-block;border-radius:4px;padding:10px 36px;font-weight:700;height:auto}#wpadminbar .wpcode-menu-notification-counter{display:inline-block !important;min-width:18px !important;height:18px !important;border-radius:9px !important;margin:7px 0 0 2px !important;vertical-align:top !important;font-size:11px !important;line-height:1.6 !important;text-align:center !important}#wpadminbar .wpcode-admin-bar-info-submenu .wpcode-menu-notification-counter{float:right;margin-top:5px !important}body:not(.wp-admin) .wpcode-menu-notification-counter{background-color:#d63638 !important;color:#ffffff !important}.wpcode-testing-mode #wp-admin-bar-wpcode-admin-bar-info>.ab-item{color:#fff;background-color:#09A347}

