(()=>{var e,t={998(e,t,n){"use strict";var r={};n.r(r),n.d(r,{hasBrowserEnv:()=>Hs,hasStandardBrowserEnv:()=>Gs,hasStandardBrowserWebWorkerEnv:()=>qs,navigator:()=>Vs,origin:()=>Us});var a={};n.r(a),n.d(a,{fetchApiData:()=>pu,saveSettings:()=>fu,setApiData:()=>cu,setLoading:()=>uu,setSaving:()=>du});var o={};n.r(o),n.d(o,{getApiData:()=>mu,getBlockVisibility:()=>gu,getDashboardSettings:()=>vu,getEapShortcodes:()=>bu,getPluginSettings:()=>hu,isLoading:()=>yu,isSaving:()=>wu});const i=window.wp.element,s=window.wp.data,l=window.wp.i18n;var c=n(609),u=n.n(c);let d={data:""},p=e=>{if("object"==typeof window){let t=(e?e.querySelector("#_goober"):window._goober)||Object.assign(document.createElement("style"),{innerHTML:" ",id:"_goober"});return t.nonce=window.__nonce__,t.parentNode||(e||document.head).appendChild(t),t.firstChild}return e||d},f=/(?:([\u0080-\uFFFF\w-%@]+) *:? *([^{;]+?);|([^;}{]*?) *{)|(}\s*)/g,m=/\/\*[^]*?\*\/|  +/g,h=/\n+/g,g=(e,t)=>{let n="",r="",a="";for(let o in e){let i=e[o];"@"==o[0]?"i"==o[1]?n=o+" "+i+";":r+="f"==o[1]?g(i,o):o+"{"+g(i,"k"==o[1]?"":t)+"}":"object"==typeof i?r+=g(i,t?t.replace(/([^,])+/g,e=>o.replace(/([^,]*:\S+\([^)]*\))|([^,])+/g,t=>/&/.test(t)?t.replace(/&/g,e):e?e+" "+t:t)):o):null!=i&&(o=/^--/.test(o)?o:o.replace(/[A-Z]/g,"-$&").toLowerCase(),a+=g.p?g.p(o,i):o+":"+i+";")}return n+(t&&a?t+"{"+a+"}":a)+r},v={},b=e=>{if("object"==typeof e){let t="";for(let n in e)t+=n+b(e[n]);return t}return e},y=(e,t,n,r,a)=>{let o=b(e),i=v[o]||(v[o]=(e=>{let t=0,n=11;for(;t<e.length;)n=101*n+e.charCodeAt(t++)>>>0;return"go"+n})(o));if(!v[i]){let t=o!==e?e:(e=>{let t,n,r=[{}];for(;t=f.exec(e.replace(m,""));)t[4]?r.shift():t[3]?(n=t[3].replace(h," ").trim(),r.unshift(r[0][n]=r[0][n]||{})):r[0][t[1]]=t[2].replace(h," ").trim();return r[0]})(e);v[i]=g(a?{["@keyframes "+i]:t}:t,n?"":"."+i)}let s=n&&v.g?v.g:null;return n&&(v.g=v[i]),((e,t,n,r)=>{r?t.data=t.data.replace(r,e):-1===t.data.indexOf(e)&&(t.data=n?e+t.data:t.data+e)})(v[i],t,r,s),i};function w(e){let t=this||{},n=e.call?e(t.p):e;return y(n.unshift?n.raw?((e,t,n)=>e.reduce((e,r,a)=>{let o=t[a];if(o&&o.call){let e=o(n),t=e&&e.props&&e.props.className||/^go/.test(e)&&e;o=t?"."+t:e&&"object"==typeof e?e.props?"":g(e,""):!1===e?"":e}return e+r+(null==o?"":o)},""))(n,[].slice.call(arguments,1),t.p):n.reduce((e,n)=>Object.assign(e,n&&n.call?n(t.p):n),{}):n,p(t.target),t.g,t.o,t.k)}w.bind({g:1});let E,R,x,A=w.bind({k:1});function C(e,t){let n=this||{};return function(){let r=arguments;function a(o,i){let s=Object.assign({},o),l=s.className||a.className;n.p=Object.assign({theme:R&&R()},s),n.o=/ *go\d+/.test(l),s.className=w.apply(n,r)+(l?" "+l:""),t&&(s.ref=i);let c=e;return e[0]&&(c=s.as||e,delete s.as),x&&c[0]&&x(s),E(c,s)}return t?t(a):a}}var S=(e,t)=>(e=>"function"==typeof e)(e)?e(t):e,k=(()=>{let e=0;return()=>(++e).toString()})(),O=(()=>{let e;return()=>{if(void 0===e&&typeof window<"u"){let t=matchMedia("(prefers-reduced-motion: reduce)");e=!t||t.matches}return e}})(),P="default",M=(e,t)=>{let{toastLimit:n}=e.settings;switch(t.type){case 0:return{...e,toasts:[t.toast,...e.toasts].slice(0,n)};case 1:return{...e,toasts:e.toasts.map(e=>e.id===t.toast.id?{...e,...t.toast}:e)};case 2:let{toast:r}=t;return M(e,{type:e.toasts.find(e=>e.id===r.id)?1:0,toast:r});case 3:let{toastId:a}=t;return{...e,toasts:e.toasts.map(e=>e.id===a||void 0===a?{...e,dismissed:!0,visible:!1}:e)};case 4:return void 0===t.toastId?{...e,toasts:[]}:{...e,toasts:e.toasts.filter(e=>e.id!==t.toastId)};case 5:return{...e,pausedAt:t.time};case 6:let o=t.time-(e.pausedAt||0);return{...e,pausedAt:void 0,toasts:e.toasts.map(e=>({...e,pauseDuration:e.pauseDuration+o}))}}},I=[],T={toasts:[],pausedAt:void 0,settings:{toastLimit:20}},_={},N=(e,t=P)=>{_[t]=M(_[t]||T,e),I.forEach(([e,n])=>{e===t&&n(_[t])})},L=e=>Object.keys(_).forEach(t=>N(e,t)),D=(e=P)=>t=>{N(t,e)},B={blank:4e3,error:4e3,success:2e3,loading:1/0,custom:4e3},F=e=>(t,n)=>{let r=((e,t="blank",n)=>({createdAt:Date.now(),visible:!0,dismissed:!1,type:t,ariaProps:{role:"status","aria-live":"polite"},message:e,pauseDuration:0,...n,id:(null==n?void 0:n.id)||k()}))(t,e,n);return D(r.toasterId||(e=>Object.keys(_).find(t=>_[t].toasts.some(t=>t.id===e)))(r.id))({type:2,toast:r}),r.id},z=(e,t)=>F("blank")(e,t);z.error=F("error"),z.success=F("success"),z.loading=F("loading"),z.custom=F("custom"),z.dismiss=(e,t)=>{let n={type:3,toastId:e};t?D(t)(n):L(n)},z.dismissAll=e=>z.dismiss(void 0,e),z.remove=(e,t)=>{let n={type:4,toastId:e};t?D(t)(n):L(n)},z.removeAll=e=>z.remove(void 0,e),z.promise=(e,t,n)=>{let r=z.loading(t.loading,{...n,...null==n?void 0:n.loading});return"function"==typeof e&&(e=e()),e.then(e=>{let a=t.success?S(t.success,e):void 0;return a?z.success(a,{id:r,...n,...null==n?void 0:n.success}):z.dismiss(r),e}).catch(e=>{let a=t.error?S(t.error,e):void 0;a?z.error(a,{id:r,...n,...null==n?void 0:n.error}):z.dismiss(r)}),e};var j=A`
from {
  transform: scale(0) rotate(45deg);
	opacity: 0;
}
to {
 transform: scale(1) rotate(45deg);
  opacity: 1;
}`,H=A`
from {
  transform: scale(0);
  opacity: 0;
}
to {
  transform: scale(1);
  opacity: 1;
}`,V=A`
from {
  transform: scale(0) rotate(90deg);
	opacity: 0;
}
to {
  transform: scale(1) rotate(90deg);
	opacity: 1;
}`,G=C("div")`
  width: 20px;
  opacity: 0;
  height: 20px;
  border-radius: 10px;
  background: ${e=>e.primary||"#ff4b4b"};
  position: relative;
  transform: rotate(45deg);

  animation: ${j} 0.3s cubic-bezier(0.175, 0.885, 0.32, 1.275)
    forwards;
  animation-delay: 100ms;

  &:after,
  &:before {
    content: '';
    animation: ${H} 0.15s ease-out forwards;
    animation-delay: 150ms;
    position: absolute;
    border-radius: 3px;
    opacity: 0;
    background: ${e=>e.secondary||"#fff"};
    bottom: 9px;
    left: 4px;
    height: 2px;
    width: 12px;
  }

  &:before {
    animation: ${V} 0.15s ease-out forwards;
    animation-delay: 180ms;
    transform: rotate(90deg);
  }
`,q=A`
  from {
    transform: rotate(0deg);
  }
  to {
    transform: rotate(360deg);
  }
`,U=C("div")`
  width: 12px;
  height: 12px;
  box-sizing: border-box;
  border: 2px solid;
  border-radius: 100%;
  border-color: ${e=>e.secondary||"#e0e0e0"};
  border-right-color: ${e=>e.primary||"#616161"};
  animation: ${q} 1s linear infinite;
`,W=A`
from {
  transform: scale(0) rotate(45deg);
	opacity: 0;
}
to {
  transform: scale(1) rotate(45deg);
	opacity: 1;
}`,Q=A`
0% {
	height: 0;
	width: 0;
	opacity: 0;
}
40% {
  height: 0;
	width: 6px;
	opacity: 1;
}
100% {
  opacity: 1;
  height: 10px;
}`,K=C("div")`
  width: 20px;
  opacity: 0;
  height: 20px;
  border-radius: 10px;
  background: ${e=>e.primary||"#61d345"};
  position: relative;
  transform: rotate(45deg);

  animation: ${W} 0.3s cubic-bezier(0.175, 0.885, 0.32, 1.275)
    forwards;
  animation-delay: 100ms;
  &:after {
    content: '';
    box-sizing: border-box;
    animation: ${Q} 0.2s ease-out forwards;
    opacity: 0;
    animation-delay: 200ms;
    position: absolute;
    border-right: 2px solid;
    border-bottom: 2px solid;
    border-color: ${e=>e.secondary||"#fff"};
    bottom: 6px;
    left: 6px;
    height: 10px;
    width: 6px;
  }
`,Z=C("div")`
  position: absolute;
`,J=C("div")`
  position: relative;
  display: flex;
  justify-content: center;
  align-items: center;
  min-width: 20px;
  min-height: 20px;
`,X=A`
from {
  transform: scale(0.6);
  opacity: 0.4;
}
to {
  transform: scale(1);
  opacity: 1;
}`,Y=C("div")`
  position: relative;
  transform: scale(0.6);
  opacity: 0.4;
  min-width: 20px;
  animation: ${X} 0.3s 0.12s cubic-bezier(0.175, 0.885, 0.32, 1.275)
    forwards;
`,$=({toast:e})=>{let{icon:t,type:n,iconTheme:r}=e;return void 0!==t?"string"==typeof t?c.createElement(Y,null,t):t:"blank"===n?null:c.createElement(J,null,c.createElement(U,{...r}),"loading"!==n&&c.createElement(Z,null,"error"===n?c.createElement(G,{...r}):c.createElement(K,{...r})))},ee=e=>`\n0% {transform: translate3d(0,${-200*e}%,0) scale(.6); opacity:.5;}\n100% {transform: translate3d(0,0,0) scale(1); opacity:1;}\n`,te=e=>`\n0% {transform: translate3d(0,0,-1px) scale(1); opacity:1;}\n100% {transform: translate3d(0,${-150*e}%,-1px) scale(.6); opacity:0;}\n`,ne=C("div")`
  display: flex;
  align-items: center;
  background: #fff;
  color: #363636;
  line-height: 1.3;
  will-change: transform;
  box-shadow: 0 3px 10px rgba(0, 0, 0, 0.1), 0 3px 3px rgba(0, 0, 0, 0.05);
  max-width: 350px;
  pointer-events: auto;
  padding: 8px 10px;
  border-radius: 8px;
`,re=C("div")`
  display: flex;
  justify-content: center;
  margin: 4px 10px;
  color: inherit;
  flex: 1 1 auto;
  white-space: pre-line;
`,ae=c.memo(({toast:e,position:t,style:n,children:r})=>{let a=e.height?((e,t)=>{let n=e.includes("top")?1:-1,[r,a]=O()?["0%{opacity:0;} 100%{opacity:1;}","0%{opacity:1;} 100%{opacity:0;}"]:[ee(n),te(n)];return{animation:t?`${A(r)} 0.35s cubic-bezier(.21,1.02,.73,1) forwards`:`${A(a)} 0.4s forwards cubic-bezier(.06,.71,.55,1)`}})(e.position||t||"top-center",e.visible):{opacity:0},o=c.createElement($,{toast:e}),i=c.createElement(re,{...e.ariaProps},S(e.message,e));return c.createElement(ne,{className:e.className,style:{...a,...n,...e.style}},"function"==typeof r?r({icon:o,message:i}):c.createElement(c.Fragment,null,o,i))});!function(e){g.p=void 0,E=e,R=void 0,x=void 0}(c.createElement);var oe=({id:e,className:t,style:n,onHeightUpdate:r,children:a})=>{let o=c.useCallback(t=>{if(t){let n=()=>{let n=t.getBoundingClientRect().height;r(e,n)};n(),new MutationObserver(n).observe(t,{subtree:!0,childList:!0,characterData:!0})}},[e,r]);return c.createElement("div",{ref:o,className:t,style:n},a)},ie=w`
  z-index: 9999;
  > * {
    pointer-events: auto;
  }
`,se=({reverseOrder:e,position:t="top-center",toastOptions:n,gutter:r,children:a,toasterId:o,containerStyle:i,containerClassName:s})=>{let{toasts:l,handlers:u}=((e,t="default")=>{let{toasts:n,pausedAt:r}=((e={},t=P)=>{let[n,r]=(0,c.useState)(_[t]||T),a=(0,c.useRef)(_[t]);(0,c.useEffect)(()=>(a.current!==_[t]&&r(_[t]),I.push([t,r]),()=>{let e=I.findIndex(([e])=>e===t);e>-1&&I.splice(e,1)}),[t]);let o=n.toasts.map(t=>{var n,r,a;return{...e,...e[t.type],...t,removeDelay:t.removeDelay||(null==(n=e[t.type])?void 0:n.removeDelay)||(null==e?void 0:e.removeDelay),duration:t.duration||(null==(r=e[t.type])?void 0:r.duration)||(null==e?void 0:e.duration)||B[t.type],style:{...e.style,...null==(a=e[t.type])?void 0:a.style,...t.style}}});return{...n,toasts:o}})(e,t),a=(0,c.useRef)(new Map).current,o=(0,c.useCallback)((e,t=1e3)=>{if(a.has(e))return;let n=setTimeout(()=>{a.delete(e),i({type:4,toastId:e})},t);a.set(e,n)},[]);(0,c.useEffect)(()=>{if(r)return;let e=Date.now(),a=n.map(n=>{if(n.duration===1/0)return;let r=(n.duration||0)+n.pauseDuration-(e-n.createdAt);if(!(r<0))return setTimeout(()=>z.dismiss(n.id,t),r);n.visible&&z.dismiss(n.id)});return()=>{a.forEach(e=>e&&clearTimeout(e))}},[n,r,t]);let i=(0,c.useCallback)(D(t),[t]),s=(0,c.useCallback)(()=>{i({type:5,time:Date.now()})},[i]),l=(0,c.useCallback)((e,t)=>{i({type:1,toast:{id:e,height:t}})},[i]),u=(0,c.useCallback)(()=>{r&&i({type:6,time:Date.now()})},[r,i]),d=(0,c.useCallback)((e,t)=>{let{reverseOrder:r=!1,gutter:a=8,defaultPosition:o}=t||{},i=n.filter(t=>(t.position||o)===(e.position||o)&&t.height),s=i.findIndex(t=>t.id===e.id),l=i.filter((e,t)=>t<s&&e.visible).length;return i.filter(e=>e.visible).slice(...r?[l+1]:[0,l]).reduce((e,t)=>e+(t.height||0)+a,0)},[n]);return(0,c.useEffect)(()=>{n.forEach(e=>{if(e.dismissed)o(e.id,e.removeDelay);else{let t=a.get(e.id);t&&(clearTimeout(t),a.delete(e.id))}})},[n,o]),{toasts:n,handlers:{updateHeight:l,startPause:s,endPause:u,calculateOffset:d}}})(n,o);return c.createElement("div",{"data-rht-toaster":o||"",style:{position:"fixed",zIndex:9999,top:16,left:16,right:16,bottom:16,pointerEvents:"none",...i},className:s,onMouseEnter:u.startPause,onMouseLeave:u.endPause},l.map(n=>{let o=n.position||t,i=((e,t)=>{let n=e.includes("top"),r=n?{top:0}:{bottom:0},a=e.includes("center")?{justifyContent:"center"}:e.includes("right")?{justifyContent:"flex-end"}:{};return{left:0,right:0,display:"flex",position:"absolute",transition:O()?void 0:"all 230ms cubic-bezier(.21,1.02,.73,1)",transform:`translateY(${t*(n?1:-1)}px)`,...r,...a}})(o,u.calculateOffset(n,{reverseOrder:e,gutter:r,defaultPosition:t}));return c.createElement(oe,{id:n.id,key:n.id,onHeightUpdate:u.updateHeight,className:n.visible?ie:"",style:i},"custom"===n.type?S(n.message,n):a?a(n):c.createElement(ae,{toast:n,position:o}))}))},le=z;function ce(e){var t,n,r="";if("string"==typeof e||"number"==typeof e)r+=e;else if("object"==typeof e)if(Array.isArray(e)){var a=e.length;for(t=0;t<a;t++)e[t]&&(n=ce(e[t]))&&(r&&(r+=" "),r+=n)}else for(n in e)e[n]&&(r&&(r+=" "),r+=n);return r}const ue=function(){for(var e,t,n=0,r="",a=arguments.length;n<a;n++)(e=arguments[n])&&(t=ce(e))&&(r&&(r+=" "),r+=t);return r};function de(e,t,n=void 0){const r={};for(const a in e){const o=e[a];let i="",s=!0;for(let e=0;e<o.length;e+=1){const r=o[e];r&&(i+=(!0===s?"":" ")+t(r),s=!1,n&&n[r]&&(i+=" "+n[r]))}r[a]=i}return r}const pe=window.ReactJSXRuntime,fe=c.createContext();function me(...e){const t=c.useRef(void 0),n=c.useCallback(t=>{const n=e.map(e=>{if(null==e)return null;if("function"==typeof e){const n=e,r=n(t);return"function"==typeof r?r:()=>{n(null)}}return e.current=t,()=>{e.current=null}});return()=>{n.forEach(e=>e?.())}},e);return c.useMemo(()=>e.every(e=>null==e)?null:e=>{t.current&&(t.current(),t.current=void 0),null!=e&&(t.current=n(e))},e)}function he(e){return e&&e.ownerDocument||document}function ge(e){return parseInt(c.version,10)>=19?e?.props?.ref||null:e?.ref||null}const ve=function(e){let t=e.activeElement;for(;null!=t?.shadowRoot?.activeElement;)t=t.shadowRoot.activeElement;return t},be=["input","select","textarea","a[href]","button","[tabindex]","audio[controls]","video[controls]",'[contenteditable]:not([contenteditable="false"])'].join(",");function ye(e){const t=[],n=[];return Array.from(e.querySelectorAll(be)).forEach((e,r)=>{const a=function(e){const t=parseInt(e.getAttribute("tabindex")||"",10);return Number.isNaN(t)?"true"===e.contentEditable||("AUDIO"===e.nodeName||"VIDEO"===e.nodeName||"DETAILS"===e.nodeName)&&null===e.getAttribute("tabindex")?0:e.tabIndex:t}(e);-1!==a&&function(e){return!(e.disabled||"INPUT"===e.tagName&&"hidden"===e.type||function(e){if("INPUT"!==e.tagName||"radio"!==e.type)return!1;if(!e.name)return!1;const t=t=>e.ownerDocument.querySelector(`input[type="radio"]${t}`);let n=t(`[name="${e.name}"]:checked`);return n||(n=t(`[name="${e.name}"]`)),n!==e}(e))}(e)&&(0===a?t.push(e):n.push({documentOrder:r,tabIndex:a,node:e}))}),n.sort((e,t)=>e.tabIndex===t.tabIndex?e.documentOrder-t.documentOrder:e.tabIndex-t.tabIndex).map(e=>e.node).concat(t)}function we(){return!0}const Ee=function(e){const{children:t,disableAutoFocus:n=!1,disableEnforceFocus:r=!1,disableRestoreFocus:a=!1,getTabbable:o=ye,isEnabled:i=we,open:s}=e,l=c.useRef(!1),u=c.useRef(null),d=c.useRef(null),p=c.useRef(null),f=c.useRef(null),m=c.useRef(!1),h=c.useRef(null),g=me(ge(t),h),v=c.useRef(null);c.useEffect(()=>{s&&h.current&&(m.current=!n)},[n,s]),c.useEffect(()=>{if(!s||!h.current)return;const e=he(h.current),t=ve(e);return h.current.contains(t)||(h.current.hasAttribute("tabIndex")||h.current.setAttribute("tabIndex","-1"),m.current&&h.current.focus()),()=>{a||(p.current&&p.current.focus&&(l.current=!0,p.current.focus()),p.current=null)}},[s]),c.useEffect(()=>{if(!s||!h.current)return;const e=he(h.current),t=t=>{v.current=t,!r&&i()&&"Tab"===t.key&&ve(e)===h.current&&t.shiftKey&&(l.current=!0,d.current&&d.current.focus())},n=()=>{const t=h.current;if(null===t)return;const n=ve(e);if(!e.hasFocus()||!i()||l.current)return void(l.current=!1);if(t.contains(n))return;if(r&&n!==u.current&&n!==d.current)return;if(n!==f.current)f.current=null;else if(null!==f.current)return;if(!m.current)return;let a=[];if(n!==u.current&&n!==d.current||(a=o(h.current)),a.length>0){const e=Boolean(v.current?.shiftKey&&"Tab"===v.current?.key),t=a[0],n=a[a.length-1];"string"!=typeof t&&"string"!=typeof n&&(e?n.focus():t.focus())}else t.focus()};e.addEventListener("focusin",n),e.addEventListener("keydown",t,!0);const a=setInterval(()=>{const t=ve(e);t&&"BODY"===t.tagName&&n()},50);return()=>{clearInterval(a),e.removeEventListener("focusin",n),e.removeEventListener("keydown",t,!0)}},[n,r,a,i,s,o]);const b=e=>{null===p.current&&(p.current=e.relatedTarget),m.current=!0};return(0,pe.jsxs)(c.Fragment,{children:[(0,pe.jsx)("div",{tabIndex:s?0:-1,onFocus:b,ref:u,"data-testid":"sentinelStart"}),c.cloneElement(t,{ref:g,onFocus:e=>{null===p.current&&(p.current=e.relatedTarget),m.current=!0,f.current=e.target;const n=t.props.onFocus;n&&n(e)}}),(0,pe.jsx)("div",{tabIndex:s?0:-1,onFocus:b,ref:d,"data-testid":"sentinelEnd"})]})},Re=window.ReactDOM;var xe=n.n(Re);const Ae="undefined"!=typeof window?c.useLayoutEffect:c.useEffect;function Ce(e,t){"function"==typeof e?e(t):e&&(e.current=t)}const Se=c.forwardRef(function(e,t){const{children:n,container:r,disablePortal:a=!1}=e,[o,i]=c.useState(null),s=me(c.isValidElement(n)?ge(n):null,t);if(Ae(()=>{a||i(function(e){return"function"==typeof e?e():e}(r)||document.body)},[r,a]),Ae(()=>{if(o&&!a)return Ce(t,o),()=>{Ce(t,null)}},[t,o,a]),a){if(c.isValidElement(n)){const e={ref:s};return c.cloneElement(n,e)}return n}return o?Re.createPortal(n,o):o});function ke(){return ke=Object.assign?Object.assign.bind():function(e){for(var t=1;t<arguments.length;t++){var n=arguments[t];for(var r in n)({}).hasOwnProperty.call(n,r)&&(e[r]=n[r])}return e},ke.apply(null,arguments)}var Oe=function(){function e(e){var t=this;this._insertTag=function(e){var n;n=0===t.tags.length?t.insertionPoint?t.insertionPoint.nextSibling:t.prepend?t.container.firstChild:t.before:t.tags[t.tags.length-1].nextSibling,t.container.insertBefore(e,n),t.tags.push(e)},this.isSpeedy=void 0===e.speedy||e.speedy,this.tags=[],this.ctr=0,this.nonce=e.nonce,this.key=e.key,this.container=e.container,this.prepend=e.prepend,this.insertionPoint=e.insertionPoint,this.before=null}var t=e.prototype;return t.hydrate=function(e){e.forEach(this._insertTag)},t.insert=function(e){this.ctr%(this.isSpeedy?65e3:1)==0&&this._insertTag(function(e){var t=document.createElement("style");return t.setAttribute("data-emotion",e.key),void 0!==e.nonce&&t.setAttribute("nonce",e.nonce),t.appendChild(document.createTextNode("")),t.setAttribute("data-s",""),t}(this));var t=this.tags[this.tags.length-1];if(this.isSpeedy){var n=function(e){if(e.sheet)return e.sheet;for(var t=0;t<document.styleSheets.length;t++)if(document.styleSheets[t].ownerNode===e)return document.styleSheets[t]}(t);try{n.insertRule(e,n.cssRules.length)}catch(e){}}else t.appendChild(document.createTextNode(e));this.ctr++},t.flush=function(){this.tags.forEach(function(e){var t;return null==(t=e.parentNode)?void 0:t.removeChild(e)}),this.tags=[],this.ctr=0},e}(),Pe=Math.abs,Me=String.fromCharCode,Ie=Object.assign;function Te(e){return e.trim()}function _e(e,t,n){return e.replace(t,n)}function Ne(e,t){return e.indexOf(t)}function Le(e,t){return 0|e.charCodeAt(t)}function De(e,t,n){return e.slice(t,n)}function Be(e){return e.length}function Fe(e){return e.length}function ze(e,t){return t.push(e),e}var je=1,He=1,Ve=0,Ge=0,qe=0,Ue="";function We(e,t,n,r,a,o,i){return{value:e,root:t,parent:n,type:r,props:a,children:o,line:je,column:He,length:i,return:""}}function Qe(e,t){return Ie(We("",null,null,"",null,null,0),e,{length:-e.length},t)}function Ke(){return qe=Ge>0?Le(Ue,--Ge):0,He--,10===qe&&(He=1,je--),qe}function Ze(){return qe=Ge<Ve?Le(Ue,Ge++):0,He++,10===qe&&(He=1,je++),qe}function Je(){return Le(Ue,Ge)}function Xe(){return Ge}function Ye(e,t){return De(Ue,e,t)}function $e(e){switch(e){case 0:case 9:case 10:case 13:case 32:return 5;case 33:case 43:case 44:case 47:case 62:case 64:case 126:case 59:case 123:case 125:return 4;case 58:return 3;case 34:case 39:case 40:case 91:return 2;case 41:case 93:return 1}return 0}function et(e){return je=He=1,Ve=Be(Ue=e),Ge=0,[]}function tt(e){return Ue="",e}function nt(e){return Te(Ye(Ge-1,ot(91===e?e+2:40===e?e+1:e)))}function rt(e){for(;(qe=Je())&&qe<33;)Ze();return $e(e)>2||$e(qe)>3?"":" "}function at(e,t){for(;--t&&Ze()&&!(qe<48||qe>102||qe>57&&qe<65||qe>70&&qe<97););return Ye(e,Xe()+(t<6&&32==Je()&&32==Ze()))}function ot(e){for(;Ze();)switch(qe){case e:return Ge;case 34:case 39:34!==e&&39!==e&&ot(qe);break;case 40:41===e&&ot(e);break;case 92:Ze()}return Ge}function it(e,t){for(;Ze()&&e+qe!==57&&(e+qe!==84||47!==Je()););return"/*"+Ye(t,Ge-1)+"*"+Me(47===e?e:Ze())}function st(e){for(;!$e(Je());)Ze();return Ye(e,Ge)}var lt="-ms-",ct="-moz-",ut="-webkit-",dt="comm",pt="rule",ft="decl",mt="@keyframes";function ht(e,t){for(var n="",r=Fe(e),a=0;a<r;a++)n+=t(e[a],a,e,t)||"";return n}function gt(e,t,n,r){switch(e.type){case"@layer":if(e.children.length)break;case"@import":case ft:return e.return=e.return||e.value;case dt:return"";case mt:return e.return=e.value+"{"+ht(e.children,r)+"}";case pt:e.value=e.props.join(",")}return Be(n=ht(e.children,r))?e.return=e.value+"{"+n+"}":""}function vt(e){return tt(bt("",null,null,null,[""],e=et(e),0,[0],e))}function bt(e,t,n,r,a,o,i,s,l){for(var c=0,u=0,d=i,p=0,f=0,m=0,h=1,g=1,v=1,b=0,y="",w=a,E=o,R=r,x=y;g;)switch(m=b,b=Ze()){case 40:if(108!=m&&58==Le(x,d-1)){-1!=Ne(x+=_e(nt(b),"&","&\f"),"&\f")&&(v=-1);break}case 34:case 39:case 91:x+=nt(b);break;case 9:case 10:case 13:case 32:x+=rt(m);break;case 92:x+=at(Xe()-1,7);continue;case 47:switch(Je()){case 42:case 47:ze(wt(it(Ze(),Xe()),t,n),l);break;default:x+="/"}break;case 123*h:s[c++]=Be(x)*v;case 125*h:case 59:case 0:switch(b){case 0:case 125:g=0;case 59+u:-1==v&&(x=_e(x,/\f/g,"")),f>0&&Be(x)-d&&ze(f>32?Et(x+";",r,n,d-1):Et(_e(x," ","")+";",r,n,d-2),l);break;case 59:x+=";";default:if(ze(R=yt(x,t,n,c,u,a,s,y,w=[],E=[],d),o),123===b)if(0===u)bt(x,t,R,R,w,o,d,s,E);else switch(99===p&&110===Le(x,3)?100:p){case 100:case 108:case 109:case 115:bt(e,R,R,r&&ze(yt(e,R,R,0,0,a,s,y,a,w=[],d),E),a,E,d,s,r?w:E);break;default:bt(x,R,R,R,[""],E,0,s,E)}}c=u=f=0,h=v=1,y=x="",d=i;break;case 58:d=1+Be(x),f=m;default:if(h<1)if(123==b)--h;else if(125==b&&0==h++&&125==Ke())continue;switch(x+=Me(b),b*h){case 38:v=u>0?1:(x+="\f",-1);break;case 44:s[c++]=(Be(x)-1)*v,v=1;break;case 64:45===Je()&&(x+=nt(Ze())),p=Je(),u=d=Be(y=x+=st(Xe())),b++;break;case 45:45===m&&2==Be(x)&&(h=0)}}return o}function yt(e,t,n,r,a,o,i,s,l,c,u){for(var d=a-1,p=0===a?o:[""],f=Fe(p),m=0,h=0,g=0;m<r;++m)for(var v=0,b=De(e,d+1,d=Pe(h=i[m])),y=e;v<f;++v)(y=Te(h>0?p[v]+" "+b:_e(b,/&\f/g,p[v])))&&(l[g++]=y);return We(e,t,n,0===a?pt:s,l,c,u)}function wt(e,t,n){return We(e,t,n,dt,Me(qe),De(e,2,-2),0)}function Et(e,t,n,r){return We(e,t,n,ft,De(e,0,r),De(e,r+1,-1),r)}var Rt=function(e,t,n){for(var r=0,a=0;r=a,a=Je(),38===r&&12===a&&(t[n]=1),!$e(a);)Ze();return Ye(e,Ge)},xt=new WeakMap,At=function(e){if("rule"===e.type&&e.parent&&!(e.length<1)){for(var t=e.value,n=e.parent,r=e.column===n.column&&e.line===n.line;"rule"!==n.type;)if(!(n=n.parent))return;if((1!==e.props.length||58===t.charCodeAt(0)||xt.get(n))&&!r){xt.set(e,!0);for(var a=[],o=function(e,t){return tt(function(e,t){var n=-1,r=44;do{switch($e(r)){case 0:38===r&&12===Je()&&(t[n]=1),e[n]+=Rt(Ge-1,t,n);break;case 2:e[n]+=nt(r);break;case 4:if(44===r){e[++n]=58===Je()?"&\f":"",t[n]=e[n].length;break}default:e[n]+=Me(r)}}while(r=Ze());return e}(et(e),t))}(t,a),i=n.props,s=0,l=0;s<o.length;s++)for(var c=0;c<i.length;c++,l++)e.props[l]=a[s]?o[s].replace(/&\f/g,i[c]):i[c]+" "+o[s]}}},Ct=function(e){if("decl"===e.type){var t=e.value;108===t.charCodeAt(0)&&98===t.charCodeAt(2)&&(e.return="",e.value="")}};function St(e,t){switch(function(e,t){return 45^Le(e,0)?(((t<<2^Le(e,0))<<2^Le(e,1))<<2^Le(e,2))<<2^Le(e,3):0}(e,t)){case 5103:return ut+"print-"+e+e;case 5737:case 4201:case 3177:case 3433:case 1641:case 4457:case 2921:case 5572:case 6356:case 5844:case 3191:case 6645:case 3005:case 6391:case 5879:case 5623:case 6135:case 4599:case 4855:case 4215:case 6389:case 5109:case 5365:case 5621:case 3829:return ut+e+e;case 5349:case 4246:case 4810:case 6968:case 2756:return ut+e+ct+e+lt+e+e;case 6828:case 4268:return ut+e+lt+e+e;case 6165:return ut+e+lt+"flex-"+e+e;case 5187:return ut+e+_e(e,/(\w+).+(:[^]+)/,ut+"box-$1$2"+lt+"flex-$1$2")+e;case 5443:return ut+e+lt+"flex-item-"+_e(e,/flex-|-self/,"")+e;case 4675:return ut+e+lt+"flex-line-pack"+_e(e,/align-content|flex-|-self/,"")+e;case 5548:return ut+e+lt+_e(e,"shrink","negative")+e;case 5292:return ut+e+lt+_e(e,"basis","preferred-size")+e;case 6060:return ut+"box-"+_e(e,"-grow","")+ut+e+lt+_e(e,"grow","positive")+e;case 4554:return ut+_e(e,/([^-])(transform)/g,"$1"+ut+"$2")+e;case 6187:return _e(_e(_e(e,/(zoom-|grab)/,ut+"$1"),/(image-set)/,ut+"$1"),e,"")+e;case 5495:case 3959:return _e(e,/(image-set\([^]*)/,ut+"$1$`$1");case 4968:return _e(_e(e,/(.+:)(flex-)?(.*)/,ut+"box-pack:$3"+lt+"flex-pack:$3"),/s.+-b[^;]+/,"justify")+ut+e+e;case 4095:case 3583:case 4068:case 2532:return _e(e,/(.+)-inline(.+)/,ut+"$1$2")+e;case 8116:case 7059:case 5753:case 5535:case 5445:case 5701:case 4933:case 4677:case 5533:case 5789:case 5021:case 4765:if(Be(e)-1-t>6)switch(Le(e,t+1)){case 109:if(45!==Le(e,t+4))break;case 102:return _e(e,/(.+:)(.+)-([^]+)/,"$1"+ut+"$2-$3$1"+ct+(108==Le(e,t+3)?"$3":"$2-$3"))+e;case 115:return~Ne(e,"stretch")?St(_e(e,"stretch","fill-available"),t)+e:e}break;case 4949:if(115!==Le(e,t+1))break;case 6444:switch(Le(e,Be(e)-3-(~Ne(e,"!important")&&10))){case 107:return _e(e,":",":"+ut)+e;case 101:return _e(e,/(.+:)([^;!]+)(;|!.+)?/,"$1"+ut+(45===Le(e,14)?"inline-":"")+"box$3$1"+ut+"$2$3$1"+lt+"$2box$3")+e}break;case 5936:switch(Le(e,t+11)){case 114:return ut+e+lt+_e(e,/[svh]\w+-[tblr]{2}/,"tb")+e;case 108:return ut+e+lt+_e(e,/[svh]\w+-[tblr]{2}/,"tb-rl")+e;case 45:return ut+e+lt+_e(e,/[svh]\w+-[tblr]{2}/,"lr")+e}return ut+e+lt+e+e}return e}var kt=[function(e,t,n,r){if(e.length>-1&&!e.return)switch(e.type){case ft:e.return=St(e.value,e.length);break;case mt:return ht([Qe(e,{value:_e(e.value,"@","@"+ut)})],r);case pt:if(e.length)return function(e,t){return e.map(t).join("")}(e.props,function(t){switch(function(e){return(e=/(::plac\w+|:read-\w+)/.exec(e))?e[0]:e}(t)){case":read-only":case":read-write":return ht([Qe(e,{props:[_e(t,/:(read-\w+)/,":-moz-$1")]})],r);case"::placeholder":return ht([Qe(e,{props:[_e(t,/:(plac\w+)/,":"+ut+"input-$1")]}),Qe(e,{props:[_e(t,/:(plac\w+)/,":-moz-$1")]}),Qe(e,{props:[_e(t,/:(plac\w+)/,lt+"input-$1")]})],r)}return""})}}],Ot=function(e){var t=e.key;if("css"===t){var n=document.querySelectorAll("style[data-emotion]:not([data-s])");Array.prototype.forEach.call(n,function(e){-1!==e.getAttribute("data-emotion").indexOf(" ")&&(document.head.appendChild(e),e.setAttribute("data-s",""))})}var r,a,o=e.stylisPlugins||kt,i={},s=[];r=e.container||document.head,Array.prototype.forEach.call(document.querySelectorAll('style[data-emotion^="'+t+' "]'),function(e){for(var t=e.getAttribute("data-emotion").split(" "),n=1;n<t.length;n++)i[t[n]]=!0;s.push(e)});var l,c,u,d,p=[gt,(d=function(e){l.insert(e)},function(e){e.root||(e=e.return)&&d(e)})],f=(c=[At,Ct].concat(o,p),u=Fe(c),function(e,t,n,r){for(var a="",o=0;o<u;o++)a+=c[o](e,t,n,r)||"";return a});a=function(e,t,n,r){l=n,function(e){ht(vt(e),f)}(e?e+"{"+t.styles+"}":t.styles),r&&(m.inserted[t.name]=!0)};var m={key:t,sheet:new Oe({key:t,container:r,nonce:e.nonce,speedy:e.speedy,prepend:e.prepend,insertionPoint:e.insertionPoint}),nonce:e.nonce,inserted:i,registered:{},insert:a};return m.sheet.hydrate(s),m};function Pt(e,t,n){var r="";return n.split(" ").forEach(function(n){void 0!==e[n]?t.push(e[n]+";"):n&&(r+=n+" ")}),r}var Mt=function(e,t,n){var r=e.key+"-"+t.name;!1===n&&void 0===e.registered[r]&&(e.registered[r]=t.styles)},It=function(e,t,n){Mt(e,t,n);var r=e.key+"-"+t.name;if(void 0===e.inserted[t.name]){var a=t;do{e.insert(t===a?"."+r:"",a,e.sheet,!0),a=a.next}while(void 0!==a)}},Tt={animationIterationCount:1,aspectRatio:1,borderImageOutset:1,borderImageSlice:1,borderImageWidth:1,boxFlex:1,boxFlexGroup:1,boxOrdinalGroup:1,columnCount:1,columns:1,flex:1,flexGrow:1,flexPositive:1,flexShrink:1,flexNegative:1,flexOrder:1,gridRow:1,gridRowEnd:1,gridRowSpan:1,gridRowStart:1,gridColumn:1,gridColumnEnd:1,gridColumnSpan:1,gridColumnStart:1,msGridRow:1,msGridRowSpan:1,msGridColumn:1,msGridColumnSpan:1,fontWeight:1,lineHeight:1,opacity:1,order:1,orphans:1,scale:1,tabSize:1,widows:1,zIndex:1,zoom:1,WebkitLineClamp:1,fillOpacity:1,floodOpacity:1,stopOpacity:1,strokeDasharray:1,strokeDashoffset:1,strokeMiterlimit:1,strokeOpacity:1,strokeWidth:1};function _t(e){var t=Object.create(null);return function(n){return void 0===t[n]&&(t[n]=e(n)),t[n]}}var Nt=/[A-Z]|^ms/g,Lt=/_EMO_([^_]+?)_([^]*?)_EMO_/g,Dt=function(e){return 45===e.charCodeAt(1)},Bt=function(e){return null!=e&&"boolean"!=typeof e},Ft=_t(function(e){return Dt(e)?e:e.replace(Nt,"-$&").toLowerCase()}),zt=function(e,t){switch(e){case"animation":case"animationName":if("string"==typeof t)return t.replace(Lt,function(e,t,n){return Ht={name:t,styles:n,next:Ht},t})}return 1===Tt[e]||Dt(e)||"number"!=typeof t||0===t?t:t+"px"};function jt(e,t,n){if(null==n)return"";var r=n;if(void 0!==r.__emotion_styles)return r;switch(typeof n){case"boolean":return"";case"object":var a=n;if(1===a.anim)return Ht={name:a.name,styles:a.styles,next:Ht},a.name;var o=n;if(void 0!==o.styles){var i=o.next;if(void 0!==i)for(;void 0!==i;)Ht={name:i.name,styles:i.styles,next:Ht},i=i.next;return o.styles+";"}return function(e,t,n){var r="";if(Array.isArray(n))for(var a=0;a<n.length;a++)r+=jt(e,t,n[a])+";";else for(var o in n){var i=n[o];if("object"!=typeof i){var s=i;null!=t&&void 0!==t[s]?r+=o+"{"+t[s]+"}":Bt(s)&&(r+=Ft(o)+":"+zt(o,s)+";")}else if(!Array.isArray(i)||"string"!=typeof i[0]||null!=t&&void 0!==t[i[0]]){var l=jt(e,t,i);switch(o){case"animation":case"animationName":r+=Ft(o)+":"+l+";";break;default:r+=o+"{"+l+"}"}}else for(var c=0;c<i.length;c++)Bt(i[c])&&(r+=Ft(o)+":"+zt(o,i[c])+";")}return r}(e,t,n);case"function":if(void 0!==e){var s=Ht,l=n(e);return Ht=s,jt(e,t,l)}}var c=n;if(null==t)return c;var u=t[c];return void 0!==u?u:c}var Ht,Vt=/label:\s*([^\s;{]+)\s*(;|$)/g;function Gt(e,t,n){if(1===e.length&&"object"==typeof e[0]&&null!==e[0]&&void 0!==e[0].styles)return e[0];var r=!0,a="";Ht=void 0;var o=e[0];null==o||void 0===o.raw?(r=!1,a+=jt(n,t,o)):a+=o[0];for(var i=1;i<e.length;i++)a+=jt(n,t,e[i]),r&&(a+=o[i]);Vt.lastIndex=0;for(var s,l="";null!==(s=Vt.exec(a));)l+="-"+s[1];var c=function(e){for(var t,n=0,r=0,a=e.length;a>=4;++r,a-=4)t=1540483477*(65535&(t=255&e.charCodeAt(r)|(255&e.charCodeAt(++r))<<8|(255&e.charCodeAt(++r))<<16|(255&e.charCodeAt(++r))<<24))+(59797*(t>>>16)<<16),n=1540483477*(65535&(t^=t>>>24))+(59797*(t>>>16)<<16)^1540483477*(65535&n)+(59797*(n>>>16)<<16);switch(a){case 3:n^=(255&e.charCodeAt(r+2))<<16;case 2:n^=(255&e.charCodeAt(r+1))<<8;case 1:n=1540483477*(65535&(n^=255&e.charCodeAt(r)))+(59797*(n>>>16)<<16)}return(((n=1540483477*(65535&(n^=n>>>13))+(59797*(n>>>16)<<16))^n>>>15)>>>0).toString(36)}(a)+l;return{name:c,styles:a,next:Ht}}var qt=!!c.useInsertionEffect&&c.useInsertionEffect,Ut=qt||function(e){return e()},Wt=(qt||c.useLayoutEffect,c.createContext("undefined"!=typeof HTMLElement?Ot({key:"css"}):null)),Qt=(Wt.Provider,function(e){return(0,c.forwardRef)(function(t,n){var r=(0,c.useContext)(Wt);return e(t,r,n)})}),Kt=c.createContext({}),Zt={}.hasOwnProperty,Jt="__EMOTION_TYPE_PLEASE_DO_NOT_USE__",Xt=function(e){var t=e.cache,n=e.serialized,r=e.isStringTag;return Mt(t,n,r),Ut(function(){return It(t,n,r)}),null},Yt=Qt(function(e,t,n){var r=e.css;"string"==typeof r&&void 0!==t.registered[r]&&(r=t.registered[r]);var a=e[Jt],o=[r],i="";"string"==typeof e.className?i=Pt(t.registered,o,e.className):null!=e.className&&(i=e.className+" ");var s=Gt(o,void 0,c.useContext(Kt));i+=t.key+"-"+s.name;var l={};for(var u in e)Zt.call(e,u)&&"css"!==u&&u!==Jt&&(l[u]=e[u]);return l.className=i,n&&(l.ref=n),c.createElement(c.Fragment,null,c.createElement(Xt,{cache:t,serialized:s,isStringTag:"string"==typeof a}),c.createElement(a,l))}),$t=Yt,en=/^((children|dangerouslySetInnerHTML|key|ref|autoFocus|defaultValue|defaultChecked|innerHTML|suppressContentEditableWarning|suppressHydrationWarning|valueLink|abbr|accept|acceptCharset|accessKey|action|allow|allowUserMedia|allowPaymentRequest|allowFullScreen|allowTransparency|alt|async|autoComplete|autoPlay|capture|cellPadding|cellSpacing|challenge|charSet|checked|cite|classID|className|cols|colSpan|content|contentEditable|contextMenu|controls|controlsList|coords|crossOrigin|data|dateTime|decoding|default|defer|dir|disabled|disablePictureInPicture|disableRemotePlayback|download|draggable|encType|enterKeyHint|fetchpriority|fetchPriority|form|formAction|formEncType|formMethod|formNoValidate|formTarget|frameBorder|headers|height|hidden|high|href|hrefLang|htmlFor|httpEquiv|id|inputMode|integrity|is|keyParams|keyType|kind|label|lang|list|loading|loop|low|marginHeight|marginWidth|max|maxLength|media|mediaGroup|method|min|minLength|multiple|muted|name|nonce|noValidate|open|optimum|pattern|placeholder|playsInline|popover|popoverTarget|popoverTargetAction|poster|preload|profile|radioGroup|readOnly|referrerPolicy|rel|required|reversed|role|rows|rowSpan|sandbox|scope|scoped|scrolling|seamless|selected|shape|size|sizes|slot|span|spellCheck|src|srcDoc|srcLang|srcSet|start|step|style|summary|tabIndex|target|title|translate|type|useMap|value|width|wmode|wrap|about|datatype|inlist|prefix|property|resource|typeof|vocab|autoCapitalize|autoCorrect|autoSave|color|incremental|fallback|inert|itemProp|itemScope|itemType|itemID|itemRef|on|option|results|security|unselectable|accentHeight|accumulate|additive|alignmentBaseline|allowReorder|alphabetic|amplitude|arabicForm|ascent|attributeName|attributeType|autoReverse|azimuth|baseFrequency|baselineShift|baseProfile|bbox|begin|bias|by|calcMode|capHeight|clip|clipPathUnits|clipPath|clipRule|colorInterpolation|colorInterpolationFilters|colorProfile|colorRendering|contentScriptType|contentStyleType|cursor|cx|cy|d|decelerate|descent|diffuseConstant|direction|display|divisor|dominantBaseline|dur|dx|dy|edgeMode|elevation|enableBackground|end|exponent|externalResourcesRequired|fill|fillOpacity|fillRule|filter|filterRes|filterUnits|floodColor|floodOpacity|focusable|fontFamily|fontSize|fontSizeAdjust|fontStretch|fontStyle|fontVariant|fontWeight|format|from|fr|fx|fy|g1|g2|glyphName|glyphOrientationHorizontal|glyphOrientationVertical|glyphRef|gradientTransform|gradientUnits|hanging|horizAdvX|horizOriginX|ideographic|imageRendering|in|in2|intercept|k|k1|k2|k3|k4|kernelMatrix|kernelUnitLength|kerning|keyPoints|keySplines|keyTimes|lengthAdjust|letterSpacing|lightingColor|limitingConeAngle|local|markerEnd|markerMid|markerStart|markerHeight|markerUnits|markerWidth|mask|maskContentUnits|maskUnits|mathematical|mode|numOctaves|offset|opacity|operator|order|orient|orientation|origin|overflow|overlinePosition|overlineThickness|panose1|paintOrder|pathLength|patternContentUnits|patternTransform|patternUnits|pointerEvents|points|pointsAtX|pointsAtY|pointsAtZ|preserveAlpha|preserveAspectRatio|primitiveUnits|r|radius|refX|refY|renderingIntent|repeatCount|repeatDur|requiredExtensions|requiredFeatures|restart|result|rotate|rx|ry|scale|seed|shapeRendering|slope|spacing|specularConstant|specularExponent|speed|spreadMethod|startOffset|stdDeviation|stemh|stemv|stitchTiles|stopColor|stopOpacity|strikethroughPosition|strikethroughThickness|string|stroke|strokeDasharray|strokeDashoffset|strokeLinecap|strokeLinejoin|strokeMiterlimit|strokeOpacity|strokeWidth|surfaceScale|systemLanguage|tableValues|targetX|targetY|textAnchor|textDecoration|textRendering|textLength|to|transform|u1|u2|underlinePosition|underlineThickness|unicode|unicodeBidi|unicodeRange|unitsPerEm|vAlphabetic|vHanging|vIdeographic|vMathematical|values|vectorEffect|version|vertAdvY|vertOriginX|vertOriginY|viewBox|viewTarget|visibility|widths|wordSpacing|writingMode|x|xHeight|x1|x2|xChannelSelector|xlinkActuate|xlinkArcrole|xlinkHref|xlinkRole|xlinkShow|xlinkTitle|xlinkType|xmlBase|xmlns|xmlnsXlink|xmlLang|xmlSpace|y|y1|y2|yChannelSelector|z|zoomAndPan|for|class|autofocus)|(([Dd][Aa][Tt][Aa]|[Aa][Rr][Ii][Aa]|x)-.*))$/,tn=_t(function(e){return en.test(e)||111===e.charCodeAt(0)&&110===e.charCodeAt(1)&&e.charCodeAt(2)<91}),nn=function(e){return"theme"!==e},rn=function(e){return"string"==typeof e&&e.charCodeAt(0)>96?tn:nn},an=function(e,t,n){var r;if(t){var a=t.shouldForwardProp;r=e.__emotion_forwardProp&&a?function(t){return e.__emotion_forwardProp(t)&&a(t)}:a}return"function"!=typeof r&&n&&(r=e.__emotion_forwardProp),r},on=function(e){var t=e.cache,n=e.serialized,r=e.isStringTag;return Mt(t,n,r),Ut(function(){return It(t,n,r)}),null},sn=function e(t,n){var r,a,o=t.__emotion_real===t,i=o&&t.__emotion_base||t;void 0!==n&&(r=n.label,a=n.target);var s=an(t,n,o),l=s||rn(i),u=!l("as");return function(){var d=arguments,p=o&&void 0!==t.__emotion_styles?t.__emotion_styles.slice(0):[];if(void 0!==r&&p.push("label:"+r+";"),null==d[0]||void 0===d[0].raw)p.push.apply(p,d);else{var f=d[0];p.push(f[0]);for(var m=d.length,h=1;h<m;h++)p.push(d[h],f[h])}var g=Qt(function(e,t,n){var r=u&&e.as||i,o="",d=[],f=e;if(null==e.theme){for(var m in f={},e)f[m]=e[m];f.theme=c.useContext(Kt)}"string"==typeof e.className?o=Pt(t.registered,d,e.className):null!=e.className&&(o=e.className+" ");var h=Gt(p.concat(d),t.registered,f);o+=t.key+"-"+h.name,void 0!==a&&(o+=" "+a);var g=u&&void 0===s?rn(r):l,v={};for(var b in e)u&&"as"===b||g(b)&&(v[b]=e[b]);return v.className=o,n&&(v.ref=n),c.createElement(c.Fragment,null,c.createElement(on,{cache:t,serialized:h,isStringTag:"string"==typeof r}),c.createElement(r,v))});return g.displayName=void 0!==r?r:"Styled("+("string"==typeof i?i:i.displayName||i.name||"Component")+")",g.defaultProps=t.defaultProps,g.__emotion_real=g,g.__emotion_base=i,g.__emotion_styles=p,g.__emotion_forwardProp=s,Object.defineProperty(g,"toString",{value:function(){return"."+a}}),g.withComponent=function(t,r){return e(t,ke({},n,r,{shouldForwardProp:an(g,r,!0)})).apply(void 0,p)},g}}.bind(null);["a","abbr","address","area","article","aside","audio","b","base","bdi","bdo","big","blockquote","body","br","button","canvas","caption","cite","code","col","colgroup","data","datalist","dd","del","details","dfn","dialog","div","dl","dt","em","embed","fieldset","figcaption","figure","footer","form","h1","h2","h3","h4","h5","h6","head","header","hgroup","hr","html","i","iframe","img","input","ins","kbd","keygen","label","legend","li","link","main","map","mark","marquee","menu","menuitem","meta","meter","nav","noscript","object","ol","optgroup","option","output","p","param","picture","pre","progress","q","rp","rt","ruby","s","samp","script","section","select","small","source","span","strong","style","sub","summary","sup","table","tbody","td","textarea","tfoot","th","thead","time","title","tr","track","u","ul","var","video","wbr","circle","clipPath","defs","ellipse","foreignObject","g","image","line","linearGradient","mask","path","pattern","polygon","polyline","radialGradient","rect","stop","svg","text","tspan"].forEach(function(e){sn[e]=sn(e)});const ln=[];function cn(e){return ln[0]=e,Gt(ln)}var un=n(405);function dn(e){if("object"!=typeof e||null===e)return!1;const t=Object.getPrototypeOf(e);return!(null!==t&&t!==Object.prototype&&null!==Object.getPrototypeOf(t)||Symbol.toStringTag in e||Symbol.iterator in e)}function pn(e){if(c.isValidElement(e)||(0,un.Hy)(e)||!dn(e))return e;const t={};return Object.keys(e).forEach(n=>{t[n]=pn(e[n])}),t}function fn(e,t,n={clone:!0}){const r=n.clone?{...e}:e;return dn(e)&&dn(t)&&Object.keys(t).forEach(a=>{c.isValidElement(t[a])||(0,un.Hy)(t[a])?r[a]=t[a]:dn(t[a])&&Object.prototype.hasOwnProperty.call(e,a)&&dn(e[a])?r[a]=fn(e[a],t[a],n):n.clone?r[a]=dn(t[a])?pn(t[a]):t[a]:r[a]=t[a]}),r}function mn(e){const{values:t={xs:0,sm:600,md:900,lg:1200,xl:1536},unit:n="px",step:r=5,...a}=e,o=(e=>{const t=Object.keys(e).map(t=>({key:t,val:e[t]}))||[];return t.sort((e,t)=>e.val-t.val),t.reduce((e,t)=>({...e,[t.key]:t.val}),{})})(t),i=Object.keys(o);function s(e){return`@media (min-width:${"number"==typeof t[e]?t[e]:e}${n})`}function l(e){return`@media (max-width:${("number"==typeof t[e]?t[e]:e)-r/100}${n})`}function c(e,a){const o=i.indexOf(a);return`@media (min-width:${"number"==typeof t[e]?t[e]:e}${n}) and (max-width:${(-1!==o&&"number"==typeof t[i[o]]?t[i[o]]:a)-r/100}${n})`}return{keys:i,values:o,up:s,down:l,between:c,only:function(e){return i.indexOf(e)+1<i.length?c(e,i[i.indexOf(e)+1]):s(e)},not:function(e){const t=i.indexOf(e);return 0===t?s(i[1]):t===i.length-1?l(i[t]):c(e,i[i.indexOf(e)+1]).replace("@media","@media not all and")},unit:n,...a}}function hn(e,t){if(!e.containerQueries)return t;const n=Object.keys(t).filter(e=>e.startsWith("@container")).sort((e,t)=>{const n=/min-width:\s*([0-9.]+)/;return+(e.match(n)?.[1]||0)-+(t.match(n)?.[1]||0)});return n.length?n.reduce((e,n)=>{const r=t[n];return delete e[n],e[n]=r,e},{...t}):t}const gn={borderRadius:4},vn={xs:0,sm:600,md:900,lg:1200,xl:1536},bn={keys:["xs","sm","md","lg","xl"],up:e=>`@media (min-width:${vn[e]}px)`},yn={containerQueries:e=>({up:t=>{let n="number"==typeof t?t:vn[t]||t;return"number"==typeof n&&(n=`${n}px`),e?`@container ${e} (min-width:${n})`:`@container (min-width:${n})`}})};function wn(e,t,n){const r=e.theme||{};if(Array.isArray(t)){const e=r.breakpoints||bn;return t.reduce((r,a,o)=>(r[e.up(e.keys[o])]=n(t[o]),r),{})}if("object"==typeof t){const e=r.breakpoints||bn;return Object.keys(t).reduce((a,o)=>{if(i=e.keys,"@"===(s=o)||s.startsWith("@")&&(i.some(e=>s.startsWith(`@${e}`))||s.match(/^@\d/))){const e=function(e,t){const n=t.match(/^@([^/]+)?\/?(.+)?$/);if(!n)return null;const[,r,a]=n,o=Number.isNaN(+r)?r||0:+r;return e.containerQueries(a).up(o)}(r.containerQueries?r:yn,o);e&&(a[e]=n(t[o],o))}else if(Object.keys(e.values||vn).includes(o))a[e.up(o)]=n(t[o],o);else{const e=o;a[e]=t[e]}var i,s;return a},{})}return n(t)}function En(e,t){return e.reduce((e,t)=>{const n=e[t];return(!n||0===Object.keys(n).length)&&delete e[t],e},t)}function Rn(e,...t){const n=new URL(`https://mui.com/production-error/?code=${e}`);return t.forEach(e=>n.searchParams.append("args[]",e)),`Minified MUI error #${e}; visit ${n} for the full message.`}function xn(e){if("string"!=typeof e)throw new Error(Rn(7));return e.charAt(0).toUpperCase()+e.slice(1)}function An(e,t,n=!0){if(!t||"string"!=typeof t)return null;if(e&&e.vars&&n){const n=`vars.${t}`.split(".").reduce((e,t)=>e&&e[t]?e[t]:null,e);if(null!=n)return n}return t.split(".").reduce((e,t)=>e&&null!=e[t]?e[t]:null,e)}function Cn(e,t,n,r=n){let a;return a="function"==typeof e?e(n):Array.isArray(e)?e[n]||r:An(e,n)||r,t&&(a=t(a,r,e)),a}const Sn=function(e){const{prop:t,cssProperty:n=e.prop,themeKey:r,transform:a}=e,o=e=>{if(null==e[t])return null;const o=e[t],i=An(e.theme,r)||{};return wn(e,o,e=>{let r=Cn(i,a,e);return e===r&&"string"==typeof e&&(r=Cn(i,a,`${t}${"default"===e?"":xn(e)}`,e)),!1===n?r:{[n]:r}})};return o.propTypes={},o.filterProps=[t],o},kn=function(e,t){return t?fn(e,t,{clone:!1}):e},On={m:"margin",p:"padding"},Pn={t:"Top",r:"Right",b:"Bottom",l:"Left",x:["Left","Right"],y:["Top","Bottom"]},Mn={marginX:"mx",marginY:"my",paddingX:"px",paddingY:"py"},In=function(){const e={};return t=>(void 0===e[t]&&(e[t]=(e=>{if(e.length>2){if(!Mn[e])return[e];e=Mn[e]}const[t,n]=e.split(""),r=On[t],a=Pn[n]||"";return Array.isArray(a)?a.map(e=>r+e):[r+a]})(t)),e[t])}(),Tn=["m","mt","mr","mb","ml","mx","my","margin","marginTop","marginRight","marginBottom","marginLeft","marginX","marginY","marginInline","marginInlineStart","marginInlineEnd","marginBlock","marginBlockStart","marginBlockEnd"],Nn=["p","pt","pr","pb","pl","px","py","padding","paddingTop","paddingRight","paddingBottom","paddingLeft","paddingX","paddingY","paddingInline","paddingInlineStart","paddingInlineEnd","paddingBlock","paddingBlockStart","paddingBlockEnd"],Ln=[...Tn,...Nn];function Dn(e,t,n,r){const a=An(e,t,!0)??n;return"number"==typeof a||"string"==typeof a?e=>"string"==typeof e?e:"string"==typeof a?a.startsWith("var(")&&0===e?0:a.startsWith("var(")&&1===e?a:`calc(${e} * ${a})`:a*e:Array.isArray(a)?e=>{if("string"==typeof e)return e;const t=Math.abs(e),n=a[t];return e>=0?n:"number"==typeof n?-n:"string"==typeof n&&n.startsWith("var(")?`calc(-1 * ${n})`:`-${n}`}:"function"==typeof a?a:()=>{}}function Bn(e){return Dn(e,"spacing",8)}function Fn(e,t){return"string"==typeof t||null==t?t:e(t)}function zn(e,t){const n=Bn(e.theme);return Object.keys(e).map(r=>function(e,t,n,r){if(!t.includes(n))return null;const a=function(e,t){return n=>e.reduce((e,r)=>(e[r]=Fn(t,n),e),{})}(In(n),r);return wn(e,e[n],a)}(e,t,r,n)).reduce(kn,{})}function jn(e){return zn(e,Tn)}function Hn(e){return zn(e,Nn)}function Vn(e){return zn(e,Ln)}function Gn(e=8,t=Bn({spacing:e})){if(e.mui)return e;const n=(...e)=>(0===e.length?[1]:e).map(e=>{const n=t(e);return"number"==typeof n?`${n}px`:n}).join(" ");return n.mui=!0,n}jn.propTypes={},jn.filterProps=Tn,Hn.propTypes={},Hn.filterProps=Nn,Vn.propTypes={},Vn.filterProps=Ln;const qn=function(...e){const t=e.reduce((e,t)=>(t.filterProps.forEach(n=>{e[n]=t}),e),{}),n=e=>Object.keys(e).reduce((n,r)=>t[r]?kn(n,t[r](e)):n,{});return n.propTypes={},n.filterProps=e.reduce((e,t)=>e.concat(t.filterProps),[]),n};function Un(e){return"number"!=typeof e?e:`${e}px solid`}function Wn(e,t){return Sn({prop:e,themeKey:"borders",transform:t})}const Qn=Wn("border",Un),Kn=Wn("borderTop",Un),Zn=Wn("borderRight",Un),Jn=Wn("borderBottom",Un),Xn=Wn("borderLeft",Un),Yn=Wn("borderColor"),$n=Wn("borderTopColor"),er=Wn("borderRightColor"),tr=Wn("borderBottomColor"),nr=Wn("borderLeftColor"),rr=Wn("outline",Un),ar=Wn("outlineColor"),or=e=>{if(void 0!==e.borderRadius&&null!==e.borderRadius){const t=Dn(e.theme,"shape.borderRadius",4),n=e=>({borderRadius:Fn(t,e)});return wn(e,e.borderRadius,n)}return null};or.propTypes={},or.filterProps=["borderRadius"],qn(Qn,Kn,Zn,Jn,Xn,Yn,$n,er,tr,nr,or,rr,ar);const ir=e=>{if(void 0!==e.gap&&null!==e.gap){const t=Dn(e.theme,"spacing",8),n=e=>({gap:Fn(t,e)});return wn(e,e.gap,n)}return null};ir.propTypes={},ir.filterProps=["gap"];const sr=e=>{if(void 0!==e.columnGap&&null!==e.columnGap){const t=Dn(e.theme,"spacing",8),n=e=>({columnGap:Fn(t,e)});return wn(e,e.columnGap,n)}return null};sr.propTypes={},sr.filterProps=["columnGap"];const lr=e=>{if(void 0!==e.rowGap&&null!==e.rowGap){const t=Dn(e.theme,"spacing",8),n=e=>({rowGap:Fn(t,e)});return wn(e,e.rowGap,n)}return null};function cr(e,t){return"grey"===t?t:e}function ur(e){return e<=1&&0!==e?100*e+"%":e}lr.propTypes={},lr.filterProps=["rowGap"],qn(ir,sr,lr,Sn({prop:"gridColumn"}),Sn({prop:"gridRow"}),Sn({prop:"gridAutoFlow"}),Sn({prop:"gridAutoColumns"}),Sn({prop:"gridAutoRows"}),Sn({prop:"gridTemplateColumns"}),Sn({prop:"gridTemplateRows"}),Sn({prop:"gridTemplateAreas"}),Sn({prop:"gridArea"})),qn(Sn({prop:"color",themeKey:"palette",transform:cr}),Sn({prop:"bgcolor",cssProperty:"backgroundColor",themeKey:"palette",transform:cr}),Sn({prop:"backgroundColor",themeKey:"palette",transform:cr}));const dr=Sn({prop:"width",transform:ur}),pr=e=>{if(void 0!==e.maxWidth&&null!==e.maxWidth){const t=t=>{const n=e.theme?.breakpoints?.values?.[t]||vn[t];return n?"px"!==e.theme?.breakpoints?.unit?{maxWidth:`${n}${e.theme.breakpoints.unit}`}:{maxWidth:n}:{maxWidth:ur(t)}};return wn(e,e.maxWidth,t)}return null};pr.filterProps=["maxWidth"];const fr=Sn({prop:"minWidth",transform:ur}),mr=Sn({prop:"height",transform:ur}),hr=Sn({prop:"maxHeight",transform:ur}),gr=Sn({prop:"minHeight",transform:ur}),vr=(Sn({prop:"size",cssProperty:"width",transform:ur}),Sn({prop:"size",cssProperty:"height",transform:ur}),qn(dr,pr,fr,mr,hr,gr,Sn({prop:"boxSizing"})),{border:{themeKey:"borders",transform:Un},borderTop:{themeKey:"borders",transform:Un},borderRight:{themeKey:"borders",transform:Un},borderBottom:{themeKey:"borders",transform:Un},borderLeft:{themeKey:"borders",transform:Un},borderColor:{themeKey:"palette"},borderTopColor:{themeKey:"palette"},borderRightColor:{themeKey:"palette"},borderBottomColor:{themeKey:"palette"},borderLeftColor:{themeKey:"palette"},outline:{themeKey:"borders",transform:Un},outlineColor:{themeKey:"palette"},borderRadius:{themeKey:"shape.borderRadius",style:or},color:{themeKey:"palette",transform:cr},bgcolor:{themeKey:"palette",cssProperty:"backgroundColor",transform:cr},backgroundColor:{themeKey:"palette",transform:cr},p:{style:Hn},pt:{style:Hn},pr:{style:Hn},pb:{style:Hn},pl:{style:Hn},px:{style:Hn},py:{style:Hn},padding:{style:Hn},paddingTop:{style:Hn},paddingRight:{style:Hn},paddingBottom:{style:Hn},paddingLeft:{style:Hn},paddingX:{style:Hn},paddingY:{style:Hn},paddingInline:{style:Hn},paddingInlineStart:{style:Hn},paddingInlineEnd:{style:Hn},paddingBlock:{style:Hn},paddingBlockStart:{style:Hn},paddingBlockEnd:{style:Hn},m:{style:jn},mt:{style:jn},mr:{style:jn},mb:{style:jn},ml:{style:jn},mx:{style:jn},my:{style:jn},margin:{style:jn},marginTop:{style:jn},marginRight:{style:jn},marginBottom:{style:jn},marginLeft:{style:jn},marginX:{style:jn},marginY:{style:jn},marginInline:{style:jn},marginInlineStart:{style:jn},marginInlineEnd:{style:jn},marginBlock:{style:jn},marginBlockStart:{style:jn},marginBlockEnd:{style:jn},displayPrint:{cssProperty:!1,transform:e=>({"@media print":{display:e}})},display:{},overflow:{},textOverflow:{},visibility:{},whiteSpace:{},flexBasis:{},flexDirection:{},flexWrap:{},justifyContent:{},alignItems:{},alignContent:{},order:{},flex:{},flexGrow:{},flexShrink:{},alignSelf:{},justifyItems:{},justifySelf:{},gap:{style:ir},rowGap:{style:lr},columnGap:{style:sr},gridColumn:{},gridRow:{},gridAutoFlow:{},gridAutoColumns:{},gridAutoRows:{},gridTemplateColumns:{},gridTemplateRows:{},gridTemplateAreas:{},gridArea:{},position:{},zIndex:{themeKey:"zIndex"},top:{},right:{},bottom:{},left:{},boxShadow:{themeKey:"shadows"},width:{transform:ur},maxWidth:{style:pr},minWidth:{transform:ur},height:{transform:ur},maxHeight:{transform:ur},minHeight:{transform:ur},boxSizing:{},font:{themeKey:"font"},fontFamily:{themeKey:"typography"},fontSize:{themeKey:"typography"},fontStyle:{themeKey:"typography"},fontWeight:{themeKey:"typography"},letterSpacing:{},textTransform:{},lineHeight:{},textAlign:{},typography:{cssProperty:!1,themeKey:"typography"}}),br=function(){function e(e,t,n,r){const a={[e]:t,theme:n},o=r[e];if(!o)return{[e]:t};const{cssProperty:i=e,themeKey:s,transform:l,style:c}=o;if(null==t)return null;if("typography"===s&&"inherit"===t)return{[e]:t};const u=An(n,s)||{};return c?c(a):wn(a,t,t=>{let n=Cn(u,l,t);return t===n&&"string"==typeof t&&(n=Cn(u,l,`${e}${"default"===t?"":xn(t)}`,t)),!1===i?n:{[i]:n}})}return function t(n){const{sx:r,theme:a={},nested:o}=n||{};if(!r)return null;const i=a.unstable_sxConfig??vr;function s(n){let r=n;if("function"==typeof n)r=n(a);else if("object"!=typeof n)return n;if(!r)return null;const s=function(e={}){const t=e.keys?.reduce((t,n)=>(t[e.up(n)]={},t),{});return t||{}}(a.breakpoints),l=Object.keys(s);let c=s;return Object.keys(r).forEach(n=>{const o=function(e,t){return"function"==typeof e?e(t):e}(r[n],a);if(null!=o)if("object"==typeof o)if(i[n])c=kn(c,e(n,o,a,i));else{const e=wn({theme:a},o,e=>({[n]:e}));!function(...e){const t=e.reduce((e,t)=>e.concat(Object.keys(t)),[]),n=new Set(t);return e.every(e=>n.size===Object.keys(e).length)}(e,o)?c=kn(c,e):c[n]=t({sx:o,theme:a,nested:!0})}else c=kn(c,e(n,o,a,i))}),!o&&a.modularCssLayers?{"@layer sx":hn(a,En(l,c))}:hn(a,En(l,c))}return Array.isArray(r)?r.map(s):s(r)}}();br.filterProps=["sx"];const yr=br;function wr(e,t){const n=this;if(n.vars){if(!n.colorSchemes?.[e]||"function"!=typeof n.getColorSchemeSelector)return{};let r=n.getColorSchemeSelector(e);return"&"===r?t:((r.includes("data-")||r.includes("."))&&(r=`*:where(${r.replace(/\s*&$/,"")}) &`),{[r]:t})}return n.palette.mode===e?t:{}}const Er=function(e={},...t){const{breakpoints:n={},palette:r={},spacing:a,shape:o={},...i}=e;let s=fn({breakpoints:mn(n),direction:"ltr",components:{},palette:{mode:"light",...r},spacing:Gn(a),shape:{...gn,...o}},i);return s=function(e){const t=(e,t)=>e.replace("@media",t?`@container ${t}`:"@container");function n(n,r){n.up=(...n)=>t(e.breakpoints.up(...n),r),n.down=(...n)=>t(e.breakpoints.down(...n),r),n.between=(...n)=>t(e.breakpoints.between(...n),r),n.only=(...n)=>t(e.breakpoints.only(...n),r),n.not=(...n)=>{const a=t(e.breakpoints.not(...n),r);return a.includes("not all and")?a.replace("not all and ","").replace("min-width:","width<").replace("max-width:","width>").replace("and","or"):a}}const r={},a=e=>(n(r,e),r);return n(a),{...e,containerQueries:a}}(s),s.applyStyles=wr,s=t.reduce((e,t)=>fn(e,t),s),s.unstable_sxConfig={...vr,...i?.unstable_sxConfig},s.unstable_sx=function(e){return yr({sx:e,theme:this})},s};function Rr(e){const{variants:t,...n}=e,r={variants:t,style:cn(n),isProcessed:!0};return r.style===n||t&&t.forEach(e=>{"function"!=typeof e.style&&(e.style=cn(e.style))}),r}const xr=Er();function Ar(e){return"ownerState"!==e&&"theme"!==e&&"sx"!==e&&"as"!==e}function Cr(e,t){return t&&e&&"object"==typeof e&&e.styles&&!e.styles.startsWith("@layer")&&(e.styles=`@layer ${t}{${String(e.styles)}}`),e}function Sr(e){return e?(t,n)=>n[e]:null}function kr(e,t,n){const r="function"==typeof t?t(e):t;if(Array.isArray(r))return r.flatMap(t=>kr(e,t,n));if(Array.isArray(r?.variants)){let t;if(r.isProcessed)t=n?Cr(r.style,n):r.style;else{const{variants:e,...a}=r;t=n?Cr(cn(a),n):a}return Or(e,r.variants,[t],n)}return r?.isProcessed?n?Cr(cn(r.style),n):r.style:n?Cr(cn(r),n):r}function Or(e,t,n=[],r=void 0){let a;e:for(let o=0;o<t.length;o+=1){const i=t[o];if("function"==typeof i.props){if(a??={...e,...e.ownerState,ownerState:e.ownerState},!i.props(a))continue}else for(const t in i.props)if(e[t]!==i.props[t]&&e.ownerState?.[t]!==i.props[t])continue e;"function"==typeof i.style?(a??={...e,...e.ownerState,ownerState:e.ownerState},n.push(r?Cr(cn(i.style(a)),r):i.style(a))):n.push(r?Cr(cn(i.style),r):i.style)}return n}function Pr(e){return e?e.charAt(0).toLowerCase()+e.slice(1):e}function Mr(e,t=0,n=1){return function(e,t=Number.MIN_SAFE_INTEGER,n=Number.MAX_SAFE_INTEGER){return Math.max(t,Math.min(e,n))}(e,t,n)}function Ir(e){if(e.type)return e;if("#"===e.charAt(0))return Ir(function(e){e=e.slice(1);const t=new RegExp(`.{1,${e.length>=6?2:1}}`,"g");let n=e.match(t);return n&&1===n[0].length&&(n=n.map(e=>e+e)),n?`rgb${4===n.length?"a":""}(${n.map((e,t)=>t<3?parseInt(e,16):Math.round(parseInt(e,16)/255*1e3)/1e3).join(", ")})`:""}(e));const t=e.indexOf("("),n=e.substring(0,t);if(!["rgb","rgba","hsl","hsla","color"].includes(n))throw new Error(Rn(9,e));let r,a=e.substring(t+1,e.length-1);if("color"===n){if(a=a.split(" "),r=a.shift(),4===a.length&&"/"===a[3].charAt(0)&&(a[3]=a[3].slice(1)),!["srgb","display-p3","a98-rgb","prophoto-rgb","rec-2020"].includes(r))throw new Error(Rn(10,r))}else a=a.split(",");return a=a.map(e=>parseFloat(e)),{type:n,values:a,colorSpace:r}}const Tr=(e,t)=>{try{return(e=>{const t=Ir(e);return t.values.slice(0,3).map((e,n)=>t.type.includes("hsl")&&0!==n?`${e}%`:e).join(" ")})(e)}catch(t){return e}};function _r(e){const{type:t,colorSpace:n}=e;let{values:r}=e;return t.includes("rgb")?r=r.map((e,t)=>t<3?parseInt(e,10):e):t.includes("hsl")&&(r[1]=`${r[1]}%`,r[2]=`${r[2]}%`),r=t.includes("color")?`${n} ${r.join(" ")}`:`${r.join(", ")}`,`${t}(${r})`}function Nr(e){e=Ir(e);const{values:t}=e,n=t[0],r=t[1]/100,a=t[2]/100,o=r*Math.min(a,1-a),i=(e,t=(e+n/30)%12)=>a-o*Math.max(Math.min(t-3,9-t,1),-1);let s="rgb";const l=[Math.round(255*i(0)),Math.round(255*i(8)),Math.round(255*i(4))];return"hsla"===e.type&&(s+="a",l.push(t[3])),_r({type:s,values:l})}function Lr(e){let t="hsl"===(e=Ir(e)).type||"hsla"===e.type?Ir(Nr(e)).values:e.values;return t=t.map(t=>("color"!==e.type&&(t/=255),t<=.03928?t/12.92:((t+.055)/1.055)**2.4)),Number((.2126*t[0]+.7152*t[1]+.0722*t[2]).toFixed(3))}function Dr(e,t){return e=Ir(e),t=Mr(t),"rgb"!==e.type&&"hsl"!==e.type||(e.type+="a"),"color"===e.type?e.values[3]=`/${t}`:e.values[3]=t,_r(e)}function Br(e,t,n){try{return Dr(e,t)}catch(t){return e}}function Fr(e,t){if(e=Ir(e),t=Mr(t),e.type.includes("hsl"))e.values[2]*=1-t;else if(e.type.includes("rgb")||e.type.includes("color"))for(let n=0;n<3;n+=1)e.values[n]*=1-t;return _r(e)}function zr(e,t,n){try{return Fr(e,t)}catch(t){return e}}function jr(e,t){if(e=Ir(e),t=Mr(t),e.type.includes("hsl"))e.values[2]+=(100-e.values[2])*t;else if(e.type.includes("rgb"))for(let n=0;n<3;n+=1)e.values[n]+=(255-e.values[n])*t;else if(e.type.includes("color"))for(let n=0;n<3;n+=1)e.values[n]+=(1-e.values[n])*t;return _r(e)}function Hr(e,t,n){try{return jr(e,t)}catch(t){return e}}function Vr(e,t,n){try{return function(e,t=.15){return Lr(e)>.5?Fr(e,t):jr(e,t)}(e,t)}catch(t){return e}}const Gr={black:"#000",white:"#fff"},qr={50:"#fafafa",100:"#f5f5f5",200:"#eeeeee",300:"#e0e0e0",400:"#bdbdbd",500:"#9e9e9e",600:"#757575",700:"#616161",800:"#424242",900:"#212121",A100:"#f5f5f5",A200:"#eeeeee",A400:"#bdbdbd",A700:"#616161"},Ur="#f3e5f5",Wr="#ce93d8",Qr="#ba68c8",Kr="#ab47bc",Zr="#9c27b0",Jr="#7b1fa2",Xr="#e57373",Yr="#ef5350",$r="#f44336",ea="#d32f2f",ta="#c62828",na="#ffb74d",ra="#ffa726",aa="#ff9800",oa="#f57c00",ia="#e65100",sa="#e3f2fd",la="#90caf9",ca="#42a5f5",ua="#1976d2",da="#1565c0",pa="#4fc3f7",fa="#29b6f6",ma="#03a9f4",ha="#0288d1",ga="#01579b",va="#81c784",ba="#66bb6a",ya="#4caf50",wa="#388e3c",Ea="#2e7d32",Ra="#1b5e20";function xa(){return{text:{primary:"rgba(0, 0, 0, 0.87)",secondary:"rgba(0, 0, 0, 0.6)",disabled:"rgba(0, 0, 0, 0.38)"},divider:"rgba(0, 0, 0, 0.12)",background:{paper:Gr.white,default:Gr.white},action:{active:"rgba(0, 0, 0, 0.54)",hover:"rgba(0, 0, 0, 0.04)",hoverOpacity:.04,selected:"rgba(0, 0, 0, 0.08)",selectedOpacity:.08,disabled:"rgba(0, 0, 0, 0.26)",disabledBackground:"rgba(0, 0, 0, 0.12)",disabledOpacity:.38,focus:"rgba(0, 0, 0, 0.12)",focusOpacity:.12,activatedOpacity:.12}}}const Aa=xa();function Ca(){return{text:{primary:Gr.white,secondary:"rgba(255, 255, 255, 0.7)",disabled:"rgba(255, 255, 255, 0.5)",icon:"rgba(255, 255, 255, 0.5)"},divider:"rgba(255, 255, 255, 0.12)",background:{paper:"#121212",default:"#121212"},action:{active:Gr.white,hover:"rgba(255, 255, 255, 0.08)",hoverOpacity:.08,selected:"rgba(255, 255, 255, 0.16)",selectedOpacity:.16,disabled:"rgba(255, 255, 255, 0.3)",disabledBackground:"rgba(255, 255, 255, 0.12)",disabledOpacity:.38,focus:"rgba(255, 255, 255, 0.12)",focusOpacity:.12,activatedOpacity:.24}}}const Sa=Ca();function ka(e,t,n,r){const a=r.light||r,o=r.dark||1.5*r;e[t]||(e.hasOwnProperty(n)?e[t]=e[n]:"light"===t?e.light=jr(e.main,a):"dark"===t&&(e.dark=Fr(e.main,o)))}function Oa(e,t,n,r,a){const o=a.light||a,i=a.dark||1.5*a;t[n]||(t.hasOwnProperty(r)?t[n]=t[r]:"light"===n?t.light=`color-mix(in ${e}, ${t.main}, #fff ${(100*o).toFixed(0)}%)`:"dark"===n&&(t.dark=`color-mix(in ${e}, ${t.main}, #000 ${(100*i).toFixed(0)}%)`))}function Pa(e){const{mode:t="light",contrastThreshold:n=3,tonalOffset:r=.2,colorSpace:a,...o}=e,i=e.primary||function(e="light"){return"dark"===e?{main:la,light:sa,dark:ca}:{main:ua,light:ca,dark:da}}(t),s=e.secondary||function(e="light"){return"dark"===e?{main:Wr,light:Ur,dark:Kr}:{main:Zr,light:Qr,dark:Jr}}(t),l=e.error||function(e="light"){return"dark"===e?{main:$r,light:Xr,dark:ea}:{main:ea,light:Yr,dark:ta}}(t),c=e.info||function(e="light"){return"dark"===e?{main:fa,light:pa,dark:ha}:{main:ha,light:ma,dark:ga}}(t),u=e.success||function(e="light"){return"dark"===e?{main:ba,light:va,dark:wa}:{main:Ea,light:ya,dark:Ra}}(t),d=e.warning||function(e="light"){return"dark"===e?{main:ra,light:na,dark:oa}:{main:"#ed6c02",light:aa,dark:ia}}(t);function p(e){if(a)return function(e){return`oklch(from ${e} var(--__l) 0 h / var(--__a))`}(e);const t=function(e,t){const n=Lr(e),r=Lr(t);return(Math.max(n,r)+.05)/(Math.min(n,r)+.05)}(e,Sa.text.primary)>=n?Sa.text.primary:Aa.text.primary;return t}const f=({color:e,name:t,mainShade:n=500,lightShade:o=300,darkShade:i=700})=>{if(!(e={...e}).main&&e[n]&&(e.main=e[n]),!e.hasOwnProperty("main"))throw new Error(Rn(11,t?` (${t})`:"",n));if("string"!=typeof e.main)throw new Error(Rn(12,t?` (${t})`:"",JSON.stringify(e.main)));return a?(Oa(a,e,"light",o,r),Oa(a,e,"dark",i,r)):(ka(e,"light",o,r),ka(e,"dark",i,r)),e.contrastText||(e.contrastText=p(e.main)),e};let m;return"light"===t?m=xa():"dark"===t&&(m=Ca()),fn({common:{...Gr},mode:t,primary:f({color:i,name:"primary"}),secondary:f({color:s,name:"secondary",mainShade:"A400",lightShade:"A200",darkShade:"A700"}),error:f({color:l,name:"error"}),warning:f({color:d,name:"warning"}),info:f({color:c,name:"info"}),success:f({color:u,name:"success"}),grey:qr,contrastThreshold:n,getContrastText:p,augmentColor:f,tonalOffset:r,...m},o)}function Ma(e=""){function t(...n){if(!n.length)return"";const r=n[0];return"string"!=typeof r||r.match(/(#|\(|\)|(-?(\d*\.)?\d+)(px|em|%|ex|ch|rem|vw|vh|vmin|vmax|cm|mm|in|pt|pc))|^(-?(\d*\.)?\d+)$|(\d+ \d+ \d+)/)?`, ${r}`:`, var(--${e?`${e}-`:""}${r}${t(...n.slice(1))})`}return(n,...r)=>`var(--${e?`${e}-`:""}${n}${t(...r)})`}function Ia(e){const t={};return Object.entries(e).forEach(e=>{const[n,r]=e;"object"==typeof r&&(t[n]=`${r.fontStyle?`${r.fontStyle} `:""}${r.fontVariant?`${r.fontVariant} `:""}${r.fontWeight?`${r.fontWeight} `:""}${r.fontStretch?`${r.fontStretch} `:""}${r.fontSize||""}${r.lineHeight?`/${r.lineHeight} `:""}${r.fontFamily||""}`)}),t}const Ta=(e,t,n,r=[])=>{let a=e;t.forEach((e,o)=>{o===t.length-1?Array.isArray(a)?a[Number(e)]=n:a&&"object"==typeof a&&(a[e]=n):a&&"object"==typeof a&&(a[e]||(a[e]=r.includes(e)?[]:{}),a=a[e])})};function _a(e,t){const{prefix:n,shouldSkipGeneratingVar:r}=t||{},a={},o={},i={};var s,l;return s=(e,t,s)=>{if(!("string"!=typeof t&&"number"!=typeof t||r&&r(e,t))){const r=`--${n?`${n}-`:""}${e.join("-")}`,l=((e,t)=>"number"==typeof t?["lineHeight","fontWeight","opacity","zIndex"].some(t=>e.includes(t))||e[e.length-1].toLowerCase().includes("opacity")?t:`${t}px`:t)(e,t);Object.assign(a,{[r]:l}),Ta(o,e,`var(${r})`,s),Ta(i,e,`var(${r}, ${l})`,s)}},l=e=>"vars"===e[0],function e(t,n=[],r=[]){Object.entries(t).forEach(([t,a])=>{(!l||l&&!l([...n,t]))&&null!=a&&("object"==typeof a&&Object.keys(a).length>0?e(a,[...n,t],Array.isArray(a)?[...r,t]:r):s([...n,t],a,r))})}(e),{css:a,vars:o,varsWithDefaults:i}}const Na={textTransform:"uppercase"},La='"Roboto", "Helvetica", "Arial", sans-serif';function Da(e,t){const{fontFamily:n=La,fontSize:r=14,fontWeightLight:a=300,fontWeightRegular:o=400,fontWeightMedium:i=500,fontWeightBold:s=700,htmlFontSize:l=16,allVariants:c,pxToRem:u,...d}="function"==typeof t?t(e):t,p=r/14,f=u||(e=>e/l*p+"rem"),m=(e,t,r,a,o)=>{return{fontFamily:n,fontWeight:e,fontSize:f(t),lineHeight:r,...n===La?{letterSpacing:(i=a/t,Math.round(1e5*i)/1e5+"em")}:{},...o,...c};var i},h={h1:m(a,96,1.167,-1.5),h2:m(a,60,1.2,-.5),h3:m(o,48,1.167,0),h4:m(o,34,1.235,.25),h5:m(o,24,1.334,0),h6:m(i,20,1.6,.15),subtitle1:m(o,16,1.75,.15),subtitle2:m(i,14,1.57,.1),body1:m(o,16,1.5,.15),body2:m(o,14,1.43,.15),button:m(i,14,1.75,.4,Na),caption:m(o,12,1.66,.4),overline:m(o,12,2.66,1,Na),inherit:{fontFamily:"inherit",fontWeight:"inherit",fontSize:"inherit",lineHeight:"inherit",letterSpacing:"inherit"}};return fn({htmlFontSize:l,pxToRem:f,fontFamily:n,fontSize:r,fontWeightLight:a,fontWeightRegular:o,fontWeightMedium:i,fontWeightBold:s,...h},d,{clone:!1})}function Ba(...e){return[`${e[0]}px ${e[1]}px ${e[2]}px ${e[3]}px rgba(0,0,0,0.2)`,`${e[4]}px ${e[5]}px ${e[6]}px ${e[7]}px rgba(0,0,0,0.14)`,`${e[8]}px ${e[9]}px ${e[10]}px ${e[11]}px rgba(0,0,0,0.12)`].join(",")}const Fa=["none",Ba(0,2,1,-1,0,1,1,0,0,1,3,0),Ba(0,3,1,-2,0,2,2,0,0,1,5,0),Ba(0,3,3,-2,0,3,4,0,0,1,8,0),Ba(0,2,4,-1,0,4,5,0,0,1,10,0),Ba(0,3,5,-1,0,5,8,0,0,1,14,0),Ba(0,3,5,-1,0,6,10,0,0,1,18,0),Ba(0,4,5,-2,0,7,10,1,0,2,16,1),Ba(0,5,5,-3,0,8,10,1,0,3,14,2),Ba(0,5,6,-3,0,9,12,1,0,3,16,2),Ba(0,6,6,-3,0,10,14,1,0,4,18,3),Ba(0,6,7,-4,0,11,15,1,0,4,20,3),Ba(0,7,8,-4,0,12,17,2,0,5,22,4),Ba(0,7,8,-4,0,13,19,2,0,5,24,4),Ba(0,7,9,-4,0,14,21,2,0,5,26,4),Ba(0,8,9,-5,0,15,22,2,0,6,28,5),Ba(0,8,10,-5,0,16,24,2,0,6,30,5),Ba(0,8,11,-5,0,17,26,2,0,6,32,5),Ba(0,9,11,-5,0,18,28,2,0,7,34,6),Ba(0,9,12,-6,0,19,29,2,0,7,36,6),Ba(0,10,13,-6,0,20,31,3,0,8,38,7),Ba(0,10,13,-6,0,21,33,3,0,8,40,7),Ba(0,10,14,-6,0,22,35,3,0,8,42,7),Ba(0,11,14,-7,0,23,36,3,0,9,44,8),Ba(0,11,15,-7,0,24,38,3,0,9,46,8)],za={easeInOut:"cubic-bezier(0.4, 0, 0.2, 1)",easeOut:"cubic-bezier(0.0, 0, 0.2, 1)",easeIn:"cubic-bezier(0.4, 0, 1, 1)",sharp:"cubic-bezier(0.4, 0, 0.6, 1)"},ja={shortest:150,shorter:200,short:250,standard:300,complex:375,enteringScreen:225,leavingScreen:195};function Ha(e){return`${Math.round(e)}ms`}function Va(e){if(!e)return 0;const t=e/36;return Math.min(Math.round(10*(4+15*t**.25+t/5)),3e3)}function Ga(e){const t={...za,...e.easing},n={...ja,...e.duration};return{getAutoHeightDuration:Va,create:(e=["all"],r={})=>{const{duration:a=n.standard,easing:o=t.easeInOut,delay:i=0,...s}=r;return(Array.isArray(e)?e:[e]).map(e=>`${e} ${"string"==typeof a?a:Ha(a)} ${o} ${"string"==typeof i?i:Ha(i)}`).join(",")},...e,easing:t,duration:n}}const qa={mobileStepper:1e3,fab:1050,speedDial:1050,appBar:1100,drawer:1200,modal:1300,snackbar:1400,tooltip:1500};function Ua(e){return dn(e)||void 0===e||"string"==typeof e||"boolean"==typeof e||"number"==typeof e||Array.isArray(e)}function Wa(e={}){const t={...e};return function e(t){const n=Object.entries(t);for(let r=0;r<n.length;r++){const[a,o]=n[r];!Ua(o)||a.startsWith("unstable_")?delete t[a]:dn(o)&&(t[a]={...o},e(t[a]))}}(t),`import { unstable_createBreakpoints as createBreakpoints, createTransitions } from '@mui/material/styles';\n\nconst theme = ${JSON.stringify(t,null,2)};\n\ntheme.breakpoints = createBreakpoints(theme.breakpoints || {});\ntheme.transitions = createTransitions(theme.transitions || {});\n\nexport default theme;`}function Qa(e){return"number"==typeof e?`${(100*e).toFixed(0)}%`:`calc((${e}) * 100%)`}const Ka=function(e={},...t){const{breakpoints:n,mixins:r={},spacing:a,palette:o={},transitions:i={},typography:s={},shape:l,colorSpace:c,...u}=e;if(e.vars&&void 0===e.generateThemeVars)throw new Error(Rn(20));const d=Pa({...o,colorSpace:c}),p=Er(e);let f=fn(p,{mixins:(m=p.breakpoints,h=r,{toolbar:{minHeight:56,[m.up("xs")]:{"@media (orientation: landscape)":{minHeight:48}},[m.up("sm")]:{minHeight:64}},...h}),palette:d,shadows:Fa.slice(),typography:Da(d,s),transitions:Ga(i),zIndex:{...qa}});var m,h,g;return f=fn(f,u),f=t.reduce((e,t)=>fn(e,t),f),f.unstable_sxConfig={...vr,...u?.unstable_sxConfig},f.unstable_sx=function(e){return yr({sx:e,theme:this})},f.toRuntimeSource=Wa,g=f,Object.assign(g,{alpha(e,t){const n=this||g;return n.colorSpace?`oklch(from ${e} l c h / ${"string"==typeof t?`calc(${t})`:t})`:n.vars?`rgba(${e.replace(/var\(--([^,\s)]+)(?:,[^)]+)?\)+/g,"var(--$1Channel)")} / ${"string"==typeof t?`calc(${t})`:t})`:Dr(e,(e=>{if(!Number.isNaN(+e))return+e;const t=e.match(/\d*\.?\d+/g);if(!t)return 0;let n=0;for(let e=0;e<t.length;e+=1)n+=+t[e];return n})(t))},lighten(e,t){const n=this||g;return n.colorSpace?`color-mix(in ${n.colorSpace}, ${e}, #fff ${Qa(t)})`:jr(e,t)},darken(e,t){const n=this||g;return n.colorSpace?`color-mix(in ${n.colorSpace}, ${e}, #000 ${Qa(t)})`:Fr(e,t)}}),f};function Za(e){let t;return t=e<1?5.11916*e**2:4.5*Math.log(e+1)+2,Math.round(10*t)/1e3}const Ja=[...Array(25)].map((e,t)=>{if(0===t)return"none";const n=Za(t);return`linear-gradient(rgba(255 255 255 / ${n}), rgba(255 255 255 / ${n}))`});function Xa(e){return{inputPlaceholder:"dark"===e?.5:.42,inputUnderline:"dark"===e?.7:.42,switchTrackDisabled:"dark"===e?.2:.12,switchTrack:"dark"===e?.3:.38}}function Ya(e){return"dark"===e?Ja:[]}function $a(e){return!!e[0].match(/(cssVarPrefix|colorSchemeSelector|modularCssLayers|rootSelector|typography|mixins|breakpoints|direction|transitions)/)||!!e[0].match(/sxConfig$/)||"palette"===e[0]&&!!e[1]?.match(/(mode|contrastThreshold|tonalOffset)/)}const eo=e=>(t,n)=>{const r=e.rootSelector||":root",a=e.colorSchemeSelector;let o=a;if("class"===a&&(o=".%s"),"data"===a&&(o="[data-%s]"),a?.startsWith("data-")&&!a.includes("%s")&&(o=`[${a}="%s"]`),e.defaultColorScheme===t){if("dark"===t){const a={};return(i=e.cssVarPrefix,[...[...Array(25)].map((e,t)=>`--${i?`${i}-`:""}overlays-${t}`),`--${i?`${i}-`:""}palette-AppBar-darkBg`,`--${i?`${i}-`:""}palette-AppBar-darkColor`]).forEach(e=>{a[e]=n[e],delete n[e]}),"media"===o?{[r]:n,"@media (prefers-color-scheme: dark)":{[r]:a}}:o?{[o.replace("%s",t)]:a,[`${r}, ${o.replace("%s",t)}`]:n}:{[r]:{...n,...a}}}if(o&&"media"!==o)return`${r}, ${o.replace("%s",String(t))}`}else if(t){if("media"===o)return{[`@media (prefers-color-scheme: ${String(t)})`]:{[r]:n}};if(o)return o.replace("%s",String(t))}var i;return r};function to(e,t,n){!e[t]&&n&&(e[t]=n)}function no(e){return"string"==typeof e&&e.startsWith("hsl")?Nr(e):e}function ro(e,t){`${t}Channel`in e||(e[`${t}Channel`]=Tr(no(e[t])))}(Object.getOwnPropertyDescriptor(eo,"name")||{}).writable||Object.defineProperty(eo,"name",{value:"default",configurable:!0});const ao=e=>{try{return e()}catch(e){}};function oo(e,t,n,r,a){if(!n)return;n=!0===n?{}:n;const o="dark"===a?"dark":"light";if(!r)return void(t[a]=function(e){const{palette:t={mode:"light"},opacity:n,overlays:r,colorSpace:a,...o}=e,i=Pa({...t,colorSpace:a});return{palette:i,opacity:{...Xa(i.mode),...n},overlays:r||Ya(i.mode),...o}}({...n,palette:{mode:o,...n?.palette},colorSpace:e}));const{palette:i,...s}=Ka({...r,palette:{mode:o,...n?.palette},colorSpace:e});return t[a]={...n,palette:i,opacity:{...Xa(o),...n?.opacity},overlays:n?.overlays||Ya(o)},s}function io(e={},...t){const{colorSchemes:n={light:!0},defaultColorScheme:r,disableCssColorScheme:a=!1,cssVarPrefix:o="mui",nativeColor:i=!1,shouldSkipGeneratingVar:s=$a,colorSchemeSelector:l=(n.light&&n.dark?"media":void 0),rootSelector:c=":root",...u}=e,d=Object.keys(n)[0],p=r||(n.light&&"light"!==d?"light":d),f=((e="mui")=>Ma(e))(o),{[p]:m,light:h,dark:g,...v}=n,b={...v};let y,w=m;if(("dark"===p&&!("dark"in n)||"light"===p&&!("light"in n))&&(w=!0),!w)throw new Error(Rn(21,p));i&&(y="oklch");const E=oo(y,b,w,u,p);h&&!b.light&&oo(y,b,h,void 0,"light"),g&&!b.dark&&oo(y,b,g,void 0,"dark");let R={defaultColorScheme:p,...E,cssVarPrefix:o,colorSchemeSelector:l,rootSelector:c,getCssVar:f,colorSchemes:b,font:{...Ia(E.typography),...E.font},spacing:(x=u.spacing,"number"==typeof x?`${x}px`:"string"==typeof x||"function"==typeof x||Array.isArray(x)?x:"8px")};var x;Object.keys(R.colorSchemes).forEach(e=>{const t=R.colorSchemes[e].palette,n=e=>{const n=e.split("-"),r=n[1],a=n[2];return f(e,t[r][a])};function r(e,t,n){if(y){let r;return e===Br&&(r=`transparent ${(100*(1-n)).toFixed(0)}%`),e===zr&&(r=`#000 ${(100*n).toFixed(0)}%`),e===Hr&&(r=`#fff ${(100*n).toFixed(0)}%`),`color-mix(in ${y}, ${t}, ${r})`}return e(t,n)}var a;if("light"===t.mode&&(to(t.common,"background","#fff"),to(t.common,"onBackground","#000")),"dark"===t.mode&&(to(t.common,"background","#000"),to(t.common,"onBackground","#fff")),a=t,["Alert","AppBar","Avatar","Button","Chip","FilledInput","LinearProgress","Skeleton","Slider","SnackbarContent","SpeedDialAction","StepConnector","StepContent","Switch","TableCell","Tooltip"].forEach(e=>{a[e]||(a[e]={})}),"light"===t.mode){to(t.Alert,"errorColor",r(zr,i?f("palette-error-light"):t.error.light,.6)),to(t.Alert,"infoColor",r(zr,i?f("palette-info-light"):t.info.light,.6)),to(t.Alert,"successColor",r(zr,i?f("palette-success-light"):t.success.light,.6)),to(t.Alert,"warningColor",r(zr,i?f("palette-warning-light"):t.warning.light,.6)),to(t.Alert,"errorFilledBg",n("palette-error-main")),to(t.Alert,"infoFilledBg",n("palette-info-main")),to(t.Alert,"successFilledBg",n("palette-success-main")),to(t.Alert,"warningFilledBg",n("palette-warning-main")),to(t.Alert,"errorFilledColor",ao(()=>t.getContrastText(t.error.main))),to(t.Alert,"infoFilledColor",ao(()=>t.getContrastText(t.info.main))),to(t.Alert,"successFilledColor",ao(()=>t.getContrastText(t.success.main))),to(t.Alert,"warningFilledColor",ao(()=>t.getContrastText(t.warning.main))),to(t.Alert,"errorStandardBg",r(Hr,i?f("palette-error-light"):t.error.light,.9)),to(t.Alert,"infoStandardBg",r(Hr,i?f("palette-info-light"):t.info.light,.9)),to(t.Alert,"successStandardBg",r(Hr,i?f("palette-success-light"):t.success.light,.9)),to(t.Alert,"warningStandardBg",r(Hr,i?f("palette-warning-light"):t.warning.light,.9)),to(t.Alert,"errorIconColor",n("palette-error-main")),to(t.Alert,"infoIconColor",n("palette-info-main")),to(t.Alert,"successIconColor",n("palette-success-main")),to(t.Alert,"warningIconColor",n("palette-warning-main")),to(t.AppBar,"defaultBg",n("palette-grey-100")),to(t.Avatar,"defaultBg",n("palette-grey-400")),to(t.Button,"inheritContainedBg",n("palette-grey-300")),to(t.Button,"inheritContainedHoverBg",n("palette-grey-A100")),to(t.Chip,"defaultBorder",n("palette-grey-400")),to(t.Chip,"defaultAvatarColor",n("palette-grey-700")),to(t.Chip,"defaultIconColor",n("palette-grey-700")),to(t.FilledInput,"bg","rgba(0, 0, 0, 0.06)"),to(t.FilledInput,"hoverBg","rgba(0, 0, 0, 0.09)"),to(t.FilledInput,"disabledBg","rgba(0, 0, 0, 0.12)"),to(t.LinearProgress,"primaryBg",r(Hr,i?f("palette-primary-main"):t.primary.main,.62)),to(t.LinearProgress,"secondaryBg",r(Hr,i?f("palette-secondary-main"):t.secondary.main,.62)),to(t.LinearProgress,"errorBg",r(Hr,i?f("palette-error-main"):t.error.main,.62)),to(t.LinearProgress,"infoBg",r(Hr,i?f("palette-info-main"):t.info.main,.62)),to(t.LinearProgress,"successBg",r(Hr,i?f("palette-success-main"):t.success.main,.62)),to(t.LinearProgress,"warningBg",r(Hr,i?f("palette-warning-light"):t.warning.main,.62)),to(t.Skeleton,"bg",y?r(Br,i?f("palette-text-primary"):t.text.primary,.11):`rgba(${n("palette-text-primaryChannel")} / 0.11)`),to(t.Slider,"primaryTrack",r(Hr,i?f("palette-primary-main"):t.primary.main,.62)),to(t.Slider,"secondaryTrack",r(Hr,i?f("palette-secondary-main"):t.secondary.main,.62)),to(t.Slider,"errorTrack",r(Hr,i?f("palette-error-main"):t.error.main,.62)),to(t.Slider,"infoTrack",r(Hr,i?f("palette-info-main"):t.info.main,.62)),to(t.Slider,"successTrack",r(Hr,i?f("palette-success-main"):t.success.main,.62)),to(t.Slider,"warningTrack",r(Hr,i?f("palette-warning-main"):t.warning.main,.62));const e=y?r(zr,i?f("palette-background-default"):t.background.default,.6825):Vr(t.background.default,.8);to(t.SnackbarContent,"bg",e),to(t.SnackbarContent,"color",ao(()=>y?Sa.text.primary:t.getContrastText(e))),to(t.SpeedDialAction,"fabHoverBg",Vr(t.background.paper,.15)),to(t.StepConnector,"border",n("palette-grey-400")),to(t.StepContent,"border",n("palette-grey-400")),to(t.Switch,"defaultColor",n("palette-common-white")),to(t.Switch,"defaultDisabledColor",n("palette-grey-100")),to(t.Switch,"primaryDisabledColor",r(Hr,i?f("palette-primary-main"):t.primary.main,.62)),to(t.Switch,"secondaryDisabledColor",r(Hr,i?f("palette-secondary-main"):t.secondary.main,.62)),to(t.Switch,"errorDisabledColor",r(Hr,i?f("palette-error-main"):t.error.main,.62)),to(t.Switch,"infoDisabledColor",r(Hr,i?f("palette-info-main"):t.info.main,.62)),to(t.Switch,"successDisabledColor",r(Hr,i?f("palette-success-main"):t.success.main,.62)),to(t.Switch,"warningDisabledColor",r(Hr,i?f("palette-warning-main"):t.warning.main,.62)),to(t.TableCell,"border",r(Hr,Br(i?f("palette-divider"):t.divider,1),.88)),to(t.Tooltip,"bg",r(Br,i?f("palette-grey-700"):t.grey[700],.92))}if("dark"===t.mode){to(t.Alert,"errorColor",r(Hr,i?f("palette-error-light"):t.error.light,.6)),to(t.Alert,"infoColor",r(Hr,i?f("palette-info-light"):t.info.light,.6)),to(t.Alert,"successColor",r(Hr,i?f("palette-success-light"):t.success.light,.6)),to(t.Alert,"warningColor",r(Hr,i?f("palette-warning-light"):t.warning.light,.6)),to(t.Alert,"errorFilledBg",n("palette-error-dark")),to(t.Alert,"infoFilledBg",n("palette-info-dark")),to(t.Alert,"successFilledBg",n("palette-success-dark")),to(t.Alert,"warningFilledBg",n("palette-warning-dark")),to(t.Alert,"errorFilledColor",ao(()=>t.getContrastText(t.error.dark))),to(t.Alert,"infoFilledColor",ao(()=>t.getContrastText(t.info.dark))),to(t.Alert,"successFilledColor",ao(()=>t.getContrastText(t.success.dark))),to(t.Alert,"warningFilledColor",ao(()=>t.getContrastText(t.warning.dark))),to(t.Alert,"errorStandardBg",r(zr,i?f("palette-error-light"):t.error.light,.9)),to(t.Alert,"infoStandardBg",r(zr,i?f("palette-info-light"):t.info.light,.9)),to(t.Alert,"successStandardBg",r(zr,i?f("palette-success-light"):t.success.light,.9)),to(t.Alert,"warningStandardBg",r(zr,i?f("palette-warning-light"):t.warning.light,.9)),to(t.Alert,"errorIconColor",n("palette-error-main")),to(t.Alert,"infoIconColor",n("palette-info-main")),to(t.Alert,"successIconColor",n("palette-success-main")),to(t.Alert,"warningIconColor",n("palette-warning-main")),to(t.AppBar,"defaultBg",n("palette-grey-900")),to(t.AppBar,"darkBg",n("palette-background-paper")),to(t.AppBar,"darkColor",n("palette-text-primary")),to(t.Avatar,"defaultBg",n("palette-grey-600")),to(t.Button,"inheritContainedBg",n("palette-grey-800")),to(t.Button,"inheritContainedHoverBg",n("palette-grey-700")),to(t.Chip,"defaultBorder",n("palette-grey-700")),to(t.Chip,"defaultAvatarColor",n("palette-grey-300")),to(t.Chip,"defaultIconColor",n("palette-grey-300")),to(t.FilledInput,"bg","rgba(255, 255, 255, 0.09)"),to(t.FilledInput,"hoverBg","rgba(255, 255, 255, 0.13)"),to(t.FilledInput,"disabledBg","rgba(255, 255, 255, 0.12)"),to(t.LinearProgress,"primaryBg",r(zr,i?f("palette-primary-main"):t.primary.main,.5)),to(t.LinearProgress,"secondaryBg",r(zr,i?f("palette-secondary-main"):t.secondary.main,.5)),to(t.LinearProgress,"errorBg",r(zr,i?f("palette-error-main"):t.error.main,.5)),to(t.LinearProgress,"infoBg",r(zr,i?f("palette-info-main"):t.info.main,.5)),to(t.LinearProgress,"successBg",r(zr,i?f("palette-success-main"):t.success.main,.5)),to(t.LinearProgress,"warningBg",r(zr,i?f("palette-warning-main"):t.warning.main,.5)),to(t.Skeleton,"bg",y?r(Br,i?f("palette-text-primary"):t.text.primary,.13):`rgba(${n("palette-text-primaryChannel")} / 0.13)`),to(t.Slider,"primaryTrack",r(zr,i?f("palette-primary-main"):t.primary.main,.5)),to(t.Slider,"secondaryTrack",r(zr,i?f("palette-secondary-main"):t.secondary.main,.5)),to(t.Slider,"errorTrack",r(zr,i?f("palette-error-main"):t.error.main,.5)),to(t.Slider,"infoTrack",r(zr,i?f("palette-info-main"):t.info.main,.5)),to(t.Slider,"successTrack",r(zr,i?f("palette-success-main"):t.success.main,.5)),to(t.Slider,"warningTrack",r(zr,i?f("palette-warning-light"):t.warning.main,.5));const e=y?r(Hr,i?f("palette-background-default"):t.background.default,.985):Vr(t.background.default,.98);to(t.SnackbarContent,"bg",e),to(t.SnackbarContent,"color",ao(()=>y?Aa.text.primary:t.getContrastText(e))),to(t.SpeedDialAction,"fabHoverBg",Vr(t.background.paper,.15)),to(t.StepConnector,"border",n("palette-grey-600")),to(t.StepContent,"border",n("palette-grey-600")),to(t.Switch,"defaultColor",n("palette-grey-300")),to(t.Switch,"defaultDisabledColor",n("palette-grey-600")),to(t.Switch,"primaryDisabledColor",r(zr,i?f("palette-primary-main"):t.primary.main,.55)),to(t.Switch,"secondaryDisabledColor",r(zr,i?f("palette-secondary-main"):t.secondary.main,.55)),to(t.Switch,"errorDisabledColor",r(zr,i?f("palette-error-main"):t.error.main,.55)),to(t.Switch,"infoDisabledColor",r(zr,i?f("palette-info-main"):t.info.main,.55)),to(t.Switch,"successDisabledColor",r(zr,i?f("palette-success-main"):t.success.main,.55)),to(t.Switch,"warningDisabledColor",r(zr,i?f("palette-warning-light"):t.warning.main,.55)),to(t.TableCell,"border",r(zr,Br(i?f("palette-divider"):t.divider,1),.68)),to(t.Tooltip,"bg",r(Br,i?f("palette-grey-700"):t.grey[700],.92))}i||(ro(t.background,"default"),ro(t.background,"paper"),ro(t.common,"background"),ro(t.common,"onBackground"),ro(t,"divider")),Object.keys(t).forEach(e=>{const n=t[e];"tonalOffset"!==e&&!i&&n&&"object"==typeof n&&(n.main&&to(t[e],"mainChannel",Tr(no(n.main))),n.light&&to(t[e],"lightChannel",Tr(no(n.light))),n.dark&&to(t[e],"darkChannel",Tr(no(n.dark))),n.contrastText&&to(t[e],"contrastTextChannel",Tr(no(n.contrastText))),"text"===e&&(ro(t[e],"primary"),ro(t[e],"secondary")),"action"===e&&(n.active&&ro(t[e],"active"),n.selected&&ro(t[e],"selected")))})}),R=t.reduce((e,t)=>fn(e,t),R);const A={prefix:o,disableCssColorScheme:a,shouldSkipGeneratingVar:s,getSelector:eo(R),enableContrastVars:i},{vars:C,generateThemeVars:S,generateStyleSheets:k}=function(e,t={}){const{getSelector:n=v,disableCssColorScheme:r,colorSchemeSelector:a,enableContrastVars:o}=t,{colorSchemes:i={},components:s,defaultColorScheme:l="light",...c}=e,{vars:u,css:d,varsWithDefaults:p}=_a(c,t);let f=p;const m={},{[l]:h,...g}=i;if(Object.entries(g||{}).forEach(([e,n])=>{const{vars:r,css:a,varsWithDefaults:o}=_a(n,t);f=fn(f,o),m[e]={css:a,vars:r}}),h){const{css:e,vars:n,varsWithDefaults:r}=_a(h,t);f=fn(f,r),m[l]={css:e,vars:n}}function v(t,n){let r=a;if("class"===a&&(r=".%s"),"data"===a&&(r="[data-%s]"),a?.startsWith("data-")&&!a.includes("%s")&&(r=`[${a}="%s"]`),t){if("media"===r){if(e.defaultColorScheme===t)return":root";const r=i[t]?.palette?.mode||t;return{[`@media (prefers-color-scheme: ${r})`]:{":root":n}}}if(r)return e.defaultColorScheme===t?`:root, ${r.replace("%s",String(t))}`:r.replace("%s",String(t))}return":root"}return{vars:f,generateThemeVars:()=>{let e={...u};return Object.entries(m).forEach(([,{vars:t}])=>{e=fn(e,t)}),e},generateStyleSheets:()=>{const t=[],a=e.defaultColorScheme||"light";function s(e,n){Object.keys(n).length&&t.push("string"==typeof e?{[e]:{...n}}:e)}s(n(void 0,{...d}),d);const{[a]:l,...c}=m;if(l){const{css:e}=l,t=i[a]?.palette?.mode,o=!r&&t?{colorScheme:t,...e}:{...e};s(n(a,{...o}),o)}return Object.entries(c).forEach(([e,{css:t}])=>{const a=i[e]?.palette?.mode,o=!r&&a?{colorScheme:a,...t}:{...t};s(n(e,{...o}),o)}),o&&t.push({":root":{"--__l-threshold":"0.7","--__l":"clamp(0, (l / var(--__l-threshold) - 1) * -infinity, 1)","--__a":"clamp(0.87, (l / var(--__l-threshold) - 1) * -infinity, 1)"}}),t}}}(R,A);return R.vars=C,Object.entries(R.colorSchemes[R.defaultColorScheme]).forEach(([e,t])=>{R[e]=t}),R.generateThemeVars=S,R.generateStyleSheets=k,R.generateSpacing=function(){return Gn(u.spacing,Bn(this))},R.getColorSchemeSelector=function(e){return function(t){return"media"===e?`@media (prefers-color-scheme: ${t})`:e?e.startsWith("data-")&&!e.includes("%s")?`[${e}="${t}"] &`:"class"===e?`.${t} &`:"data"===e?`[data-${t}] &`:`${e.replace("%s",t)} &`:"&"}}(l),R.spacing=R.generateSpacing(),R.shouldSkipGeneratingVar=s,R.unstable_sxConfig={...vr,...u?.unstable_sxConfig},R.unstable_sx=function(e){return yr({sx:e,theme:this})},R.toRuntimeSource=Wa,R}function so(e,t,n){e.colorSchemes&&n&&(e.colorSchemes[t]={...!0!==n&&n,palette:Pa({...!0===n?{}:n.palette,mode:t})})}const lo=function(e={},...t){const{palette:n,cssVariables:r=!1,colorSchemes:a=(n?void 0:{light:!0}),defaultColorScheme:o=n?.mode,...i}=e,s=o||"light",l=a?.[s],c={...a,...n?{[s]:{..."boolean"!=typeof l&&l,palette:n}}:void 0};if(!1===r){if(!("colorSchemes"in e))return Ka(e,...t);let r=n;"palette"in e||c[s]&&(!0!==c[s]?r=c[s].palette:"dark"===s&&(r={mode:"dark"}));const a=Ka({...e,palette:r},...t);return a.defaultColorScheme=s,a.colorSchemes=c,"light"===a.palette.mode&&(a.colorSchemes.light={...!0!==c.light&&c.light,palette:a.palette},so(a,"dark",c.dark)),"dark"===a.palette.mode&&(a.colorSchemes.dark={...!0!==c.dark&&c.dark,palette:a.palette},so(a,"light",c.light)),a}return n||"light"in c||"light"!==s||(c.light=!0),io({...i,colorSchemes:c,defaultColorScheme:s,..."boolean"!=typeof r&&r},...t)}(),co=lo,uo="$$material",po=e=>function(e){return"ownerState"!==e&&"theme"!==e&&"sx"!==e&&"as"!==e}(e)&&"classes"!==e,fo=function(e={}){const{themeId:t,defaultTheme:n=xr,rootShouldForwardProp:r=Ar,slotShouldForwardProp:a=Ar}=e;function o(e){!function(e,t,n){e.theme=function(e){for(const t in e)return!1;return!0}(e.theme)?n:e.theme[t]||e.theme}(e,t,n)}return(e,t={})=>{!function(e){Array.isArray(e.__emotion_styles)&&(e.__emotion_styles=(e=>e.filter(e=>e!==yr))(e.__emotion_styles))}(e);const{name:n,slot:i,skipVariantsResolver:s,skipSx:l,overridesResolver:c=Sr(Pr(i)),...u}=t,d=n&&n.startsWith("Mui")||i?"components":"custom",p=void 0!==s?s:i&&"Root"!==i&&"root"!==i||!1,f=l||!1;let m=Ar;"Root"===i||"root"===i?m=r:i?m=a:function(e){return"string"==typeof e&&e.charCodeAt(0)>96}(e)&&(m=void 0);const h=function(e,t){return sn(e,t)}(e,{shouldForwardProp:m,label:void 0,...u}),g=e=>{if(e.__emotion_real===e)return e;if("function"==typeof e)return function(t){return kr(t,e,t.theme.modularCssLayers?d:void 0)};if(dn(e)){const t=Rr(e);return function(e){return t.variants?kr(e,t,e.theme.modularCssLayers?d:void 0):e.theme.modularCssLayers?Cr(t.style,d):t.style}}return e},v=(...t)=>{const r=[],a=t.map(g),i=[];if(r.push(o),n&&c&&i.push(function(e){const t=e.theme,r=t.components?.[n]?.styleOverrides;if(!r)return null;const a={};for(const t in r)a[t]=kr(e,r[t],e.theme.modularCssLayers?"theme":void 0);return c(e,a)}),n&&!p&&i.push(function(e){const t=e.theme,r=t?.components?.[n]?.variants;return r?Or(e,r,[],e.theme.modularCssLayers?"theme":void 0):null}),f||i.push(yr),Array.isArray(a[0])){const e=a.shift(),t=new Array(r.length).fill(""),n=new Array(i.length).fill("");let o;o=[...t,...e,...n],o.raw=[...t,...e.raw,...n],r.unshift(o)}const s=[...r,...a,...i],l=h(...s);return e.muiName&&(l.muiName=e.muiName),l};return h.withConfig&&(v.withConfig=h.withConfig),v}}({themeId:uo,defaultTheme:co,rootShouldForwardProp:po}),mo=fo,ho={theme:void 0},go=function(e){let t,n;return function(r){let a=t;return void 0!==a&&r.theme===n||(ho.theme=r.theme,a=Rr(e(ho)),t=a,n=r.theme),a}};function vo(e,t,n=!1){const r={...t};for(const a in e)if(Object.prototype.hasOwnProperty.call(e,a)){const o=a;if("components"===o||"slots"===o)r[o]={...e[o],...r[o]};else if("componentsProps"===o||"slotProps"===o){const a=e[o],i=t[o];if(i)if(a){r[o]={...i};for(const e in a)if(Object.prototype.hasOwnProperty.call(a,e)){const t=e;r[o][t]=vo(a[t],i[t],n)}}else r[o]=i;else r[o]=a||{}}else"className"===o&&n&&t.className?r.className=ue(e?.className,t?.className):"style"===o&&n&&t.style?r.style={...e?.style,...t?.style}:void 0===r[o]&&(r[o]=e[o])}return r}const bo=c.createContext(void 0);function yo(e){return function({props:e,name:t}){return function(e){const{theme:t,name:n,props:r}=e;if(!t||!t.components||!t.components[n])return r;const a=t.components[n];return a.defaultProps?vo(a.defaultProps,r,t.components.mergeClassNameAndStyle):a.styleOverrides||a.variants?r:vo(a,r,t.components.mergeClassNameAndStyle)}({props:e,name:t,theme:{components:c.useContext(bo)}})}(e)}const wo=function(e,t,n){return void 0===e||"string"==typeof e?t:{...t,ownerState:{...t.ownerState,...n}}},Eo=function(e,t=[]){if(void 0===e)return{};const n={};return Object.keys(e).filter(n=>n.match(/^on[A-Z]/)&&"function"==typeof e[n]&&!t.includes(n)).forEach(t=>{n[t]=e[t]}),n},Ro=function(e){if(void 0===e)return{};const t={};return Object.keys(e).filter(t=>!(t.match(/^on[A-Z]/)&&"function"==typeof e[t])).forEach(n=>{t[n]=e[n]}),t};function xo(e,t){const{className:n,elementType:r,ownerState:a,externalForwardedProps:o,internalForwardedProps:i,shouldForwardComponentProp:s=!1,...l}=t,{component:c,slots:u={[e]:void 0},slotProps:d={[e]:void 0},...p}=o,f=u[e]||r,m=function(e,t,n){return"function"==typeof e?e(t,n):e}(d[e],a),{props:{component:h,...g},internalRef:v}=function(e){const{getSlotProps:t,additionalProps:n,externalSlotProps:r,externalForwardedProps:a,className:o}=e;if(!t){const e=ue(n?.className,o,a?.className,r?.className),t={...n?.style,...a?.style,...r?.style},i={...n,...a,...r};return e.length>0&&(i.className=e),Object.keys(t).length>0&&(i.style=t),{props:i,internalRef:void 0}}const i=Eo({...a,...r}),s=Ro(r),l=Ro(a),c=t(i),u=ue(c?.className,n?.className,o,a?.className,r?.className),d={...c?.style,...n?.style,...a?.style,...r?.style},p={...c,...n,...l,...s};return u.length>0&&(p.className=u),Object.keys(d).length>0&&(p.style=d),{props:p,internalRef:c.ref}}({className:n,...l,externalForwardedProps:"root"===e?p:void 0,externalSlotProps:m}),b=me(v,m?.ref,t.ref),y="root"===e?h||c:h;return[f,wo(f,{..."root"===e&&!c&&!u[e]&&i,..."root"!==e&&!u[e]&&i,...g,...y&&!s&&{as:y},...y&&s&&{component:y},ref:b},a)]}function Ao(e,t){if(null==e)return{};var n={};for(var r in e)if({}.hasOwnProperty.call(e,r)){if(-1!==t.indexOf(r))continue;n[r]=e[r]}return n}function Co(e,t){return Co=Object.setPrototypeOf?Object.setPrototypeOf.bind():function(e,t){return e.__proto__=t,e},Co(e,t)}const So=u().createContext(null);var ko="unmounted",Oo="exited",Po="entering",Mo="entered",Io="exiting",To=function(e){function t(t,n){var r;r=e.call(this,t,n)||this;var a,o=n&&!n.isMounting?t.enter:t.appear;return r.appearStatus=null,t.in?o?(a=Oo,r.appearStatus=Po):a=Mo:a=t.unmountOnExit||t.mountOnEnter?ko:Oo,r.state={status:a},r.nextCallback=null,r}!function(e,t){e.prototype=Object.create(t.prototype),e.prototype.constructor=e,Co(e,t)}(t,e),t.getDerivedStateFromProps=function(e,t){return e.in&&t.status===ko?{status:Oo}:null};var n=t.prototype;return n.componentDidMount=function(){this.updateStatus(!0,this.appearStatus)},n.componentDidUpdate=function(e){var t=null;if(e!==this.props){var n=this.state.status;this.props.in?n!==Po&&n!==Mo&&(t=Po):n!==Po&&n!==Mo||(t=Io)}this.updateStatus(!1,t)},n.componentWillUnmount=function(){this.cancelNextCallback()},n.getTimeouts=function(){var e,t,n,r=this.props.timeout;return e=t=n=r,null!=r&&"number"!=typeof r&&(e=r.exit,t=r.enter,n=void 0!==r.appear?r.appear:t),{exit:e,enter:t,appear:n}},n.updateStatus=function(e,t){if(void 0===e&&(e=!1),null!==t)if(this.cancelNextCallback(),t===Po){if(this.props.unmountOnExit||this.props.mountOnEnter){var n=this.props.nodeRef?this.props.nodeRef.current:xe().findDOMNode(this);n&&function(e){e.scrollTop}(n)}this.performEnter(e)}else this.performExit();else this.props.unmountOnExit&&this.state.status===Oo&&this.setState({status:ko})},n.performEnter=function(e){var t=this,n=this.props.enter,r=this.context?this.context.isMounting:e,a=this.props.nodeRef?[r]:[xe().findDOMNode(this),r],o=a[0],i=a[1],s=this.getTimeouts(),l=r?s.appear:s.enter;e||n?(this.props.onEnter(o,i),this.safeSetState({status:Po},function(){t.props.onEntering(o,i),t.onTransitionEnd(l,function(){t.safeSetState({status:Mo},function(){t.props.onEntered(o,i)})})})):this.safeSetState({status:Mo},function(){t.props.onEntered(o)})},n.performExit=function(){var e=this,t=this.props.exit,n=this.getTimeouts(),r=this.props.nodeRef?void 0:xe().findDOMNode(this);t?(this.props.onExit(r),this.safeSetState({status:Io},function(){e.props.onExiting(r),e.onTransitionEnd(n.exit,function(){e.safeSetState({status:Oo},function(){e.props.onExited(r)})})})):this.safeSetState({status:Oo},function(){e.props.onExited(r)})},n.cancelNextCallback=function(){null!==this.nextCallback&&(this.nextCallback.cancel(),this.nextCallback=null)},n.safeSetState=function(e,t){t=this.setNextCallback(t),this.setState(e,t)},n.setNextCallback=function(e){var t=this,n=!0;return this.nextCallback=function(r){n&&(n=!1,t.nextCallback=null,e(r))},this.nextCallback.cancel=function(){n=!1},this.nextCallback},n.onTransitionEnd=function(e,t){this.setNextCallback(t);var n=this.props.nodeRef?this.props.nodeRef.current:xe().findDOMNode(this),r=null==e&&!this.props.addEndListener;if(n&&!r){if(this.props.addEndListener){var a=this.props.nodeRef?[this.nextCallback]:[n,this.nextCallback],o=a[0],i=a[1];this.props.addEndListener(o,i)}null!=e&&setTimeout(this.nextCallback,e)}else setTimeout(this.nextCallback,0)},n.render=function(){var e=this.state.status;if(e===ko)return null;var t=this.props,n=t.children,r=(t.in,t.mountOnEnter,t.unmountOnExit,t.appear,t.enter,t.exit,t.timeout,t.addEndListener,t.onEnter,t.onEntering,t.onEntered,t.onExit,t.onExiting,t.onExited,t.nodeRef,Ao(t,["children","in","mountOnEnter","unmountOnExit","appear","enter","exit","timeout","addEndListener","onEnter","onEntering","onEntered","onExit","onExiting","onExited","nodeRef"]));return u().createElement(So.Provider,{value:null},"function"==typeof n?n(e,r):u().cloneElement(u().Children.only(n),r))},t}(u().Component);function _o(){}To.contextType=So,To.propTypes={},To.defaultProps={in:!1,mountOnEnter:!1,unmountOnExit:!1,appear:!1,enter:!0,exit:!0,onEnter:_o,onEntering:_o,onEntered:_o,onExit:_o,onExiting:_o,onExited:_o},To.UNMOUNTED=ko,To.EXITED=Oo,To.ENTERING=Po,To.ENTERED=Mo,To.EXITING=Io;const No=To,Lo=Er(),Do=function(e=Lo){return function(e=null){const t=c.useContext(Kt);return t&&(n=t,0!==Object.keys(n).length)?t:e;var n}(e)};function Bo(){const e=Do(co);return e[uo]||e}const Fo=e=>e.scrollTop;function zo(e,t){return n=>{if(t){const r=e.current;void 0===n?t(r):t(r,n)}}}function jo(e,t){const{timeout:n,easing:r,style:a={}}=e;return{duration:a.transitionDuration??("number"==typeof n?n:n[t.mode]||0),easing:a.transitionTimingFunction??("object"==typeof r?r[t.mode]:r),delay:a.transitionDelay}}const Ho=me,Vo={entering:{opacity:1},entered:{opacity:1},exiting:{opacity:0},exited:{opacity:0}},Go={opacity:0,visibility:"hidden"},qo=c.forwardRef(function(e,t){const n=Bo(),r={enter:n.transitions.duration.enteringScreen,exit:n.transitions.duration.leavingScreen},{addEndListener:a,appear:o=!0,children:i,easing:s,in:l,onEnter:u,onEntered:d,onEntering:p,onExit:f,onExited:m,onExiting:h,style:g,timeout:v=r,...b}=e,y=c.useRef(null),w=Ho(y,ge(i),t),E=zo(y,p),R=zo(y,(e,t)=>{Fo(e);const r=jo({style:g,timeout:v,easing:s},{mode:"enter"});e.style.transition=n.transitions.create("opacity",r),u&&u(e,t)}),x=zo(y,d),A=zo(y,h),C=zo(y,e=>{const t=jo({style:g,timeout:v,easing:s},{mode:"exit"});e.style.transition=n.transitions.create("opacity",t),f&&f(e)}),S=zo(y,e=>{e.style.transition="",m&&m(e)});return(0,pe.jsx)(No,{appear:o,in:l,nodeRef:y,onEnter:R,onEntered:x,onEntering:E,onExit:C,onExited:S,onExiting:A,addEndListener:e=>{a&&a(y.current,e)},timeout:v,...b,children:(e,{ownerState:t,...n})=>{const r=function(e,t,n,r,a,o){const i="exited"!==e||t?n[e]||n.exited:r;return a||o?{...i,...a,...o}:i}(e,l,Vo,Go,g,i.props.style);return c.cloneElement(i,{style:r,ref:w,...n})}})}),Uo=qo,Wo=e=>e,Qo=(()=>{let e=Wo;return{configure(t){e=t},generate:t=>e(t),reset(){e=Wo}}})(),Ko={active:"active",checked:"checked",completed:"completed",disabled:"disabled",error:"error",expanded:"expanded",focused:"focused",focusVisible:"focusVisible",open:"open",readOnly:"readOnly",required:"required",selected:"selected"};function Zo(e,t,n="Mui"){const r=Ko[t];return r?`${n}-${r}`:`${Qo.generate(e)}-${t}`}function Jo(e,t,n="Mui"){const r={};return t.forEach(t=>{r[t]=Zo(e,t,n)}),r}function Xo(e){return Zo("MuiBackdrop",e)}Jo("MuiBackdrop",["root","invisible"]);const Yo=mo("div",{name:"MuiBackdrop",slot:"Root",overridesResolver:(e,t)=>{const{ownerState:n}=e;return[t.root,n.invisible&&t.invisible]}})({position:"fixed",display:"flex",alignItems:"center",justifyContent:"center",right:0,bottom:0,top:0,left:0,backgroundColor:"rgba(0, 0, 0, 0.5)",WebkitTapHighlightColor:"transparent",variants:[{props:{invisible:!0},style:{backgroundColor:"transparent"}}]}),$o=c.forwardRef(function(e,t){const n=yo({props:e,name:"MuiBackdrop"}),{children:r,className:a,component:o="div",invisible:i=!1,open:s,components:l={},componentsProps:c={},slotProps:u={},slots:d={},TransitionComponent:p,transitionDuration:f,...m}=n,h={...n,component:o,invisible:i},g=(e=>{const{classes:t,invisible:n}=e;return de({root:["root",n&&"invisible"]},Xo,t)})(h),v={component:o,slots:{transition:p,root:l.Root,...d},slotProps:{...c,...u}},[b,y]=xo("root",{elementType:Yo,externalForwardedProps:v,className:ue(g.root,a),ownerState:h}),[w,E]=xo("transition",{elementType:Uo,externalForwardedProps:v,ownerState:h});return(0,pe.jsx)(w,{in:s,timeout:f,...m,...E,children:(0,pe.jsx)(b,{"aria-hidden":!0,...y,ref:t,children:r})})}),ei=$o,ti=function(e){const t=c.useRef(e);return Ae(()=>{t.current=e}),c.useRef((...e)=>(0,t.current)(...e)).current};function ni(...e){return e.reduce((e,t)=>null==t?e:function(...n){e.apply(this,n),t.apply(this,n)},()=>{})}function ri(e){return he(e).defaultView||window}function ai(e,t){t?e.setAttribute("aria-hidden","true"):e.removeAttribute("aria-hidden")}function oi(e){return parseFloat(ri(e).getComputedStyle(e).paddingRight)||0}function ii(e,t,n,r,a){const o=[t,n,...r];[].forEach.call(e.children,e=>{const t=!o.includes(e),n=!function(e){const t=["TEMPLATE","SCRIPT","STYLE","LINK","MAP","META","NOSCRIPT","PICTURE","COL","COLGROUP","PARAM","SLOT","SOURCE","TRACK"].includes(e.tagName),n="INPUT"===e.tagName&&"hidden"===e.getAttribute("type");return t||n}(e);t&&n&&ai(e,a)})}function si(e,t){let n=-1;return e.some((e,r)=>!!t(e)&&(n=r,!0)),n}const li=()=>{},ci=new class{constructor(){this.modals=[],this.containers=[]}add(e,t){let n=this.modals.indexOf(e);if(-1!==n)return n;n=this.modals.length,this.modals.push(e),e.modalRef&&ai(e.modalRef,!1);const r=function(e){const t=[];return[].forEach.call(e.children,e=>{"true"===e.getAttribute("aria-hidden")&&t.push(e)}),t}(t);ii(t,e.mount,e.modalRef,r,!0);const a=si(this.containers,e=>e.container===t);return-1!==a?(this.containers[a].modals.push(e),n):(this.containers.push({modals:[e],container:t,restore:null,hiddenSiblings:r}),n)}mount(e,t){const n=si(this.containers,t=>t.modals.includes(e)),r=this.containers[n];r.restore||(r.restore=function(e,t){const n=[],r=e.container;if(!t.disableScrollLock){if(function(e){const t=he(e);return t.body===e?ri(e).innerWidth>t.documentElement.clientWidth:e.scrollHeight>e.clientHeight}(r)){const e=function(e=window){const t=e.document.documentElement.clientWidth;return e.innerWidth-t}(ri(r));n.push({value:r.style.paddingRight,property:"padding-right",el:r}),r.style.paddingRight=`${oi(r)+e}px`;const t=he(r).querySelectorAll(".mui-fixed");[].forEach.call(t,t=>{n.push({value:t.style.paddingRight,property:"padding-right",el:t}),t.style.paddingRight=`${oi(t)+e}px`})}let e;if(r.parentNode instanceof DocumentFragment)e=he(r).body;else{const t=r.parentElement,n=ri(r);e="HTML"===t?.nodeName&&"scroll"===n.getComputedStyle(t).overflowY?t:r}n.push({value:e.style.overflow,property:"overflow",el:e},{value:e.style.overflowX,property:"overflow-x",el:e},{value:e.style.overflowY,property:"overflow-y",el:e}),e.style.overflow="hidden"}return()=>{n.forEach(({value:e,el:t,property:n})=>{e?t.style.setProperty(n,e):t.style.removeProperty(n)})}}(r,t))}remove(e,t=!0){const n=this.modals.indexOf(e);if(-1===n)return n;const r=si(this.containers,t=>t.modals.includes(e)),a=this.containers[r];if(a.modals.splice(a.modals.indexOf(e),1),this.modals.splice(n,1),0===a.modals.length)a.restore&&a.restore(),e.modalRef&&ai(e.modalRef,t),ii(a.container,e.mount,e.modalRef,a.hiddenSiblings,!1),this.containers.splice(r,1);else{const e=a.modals[a.modals.length-1];e.modalRef&&ai(e.modalRef,!1)}return n}isTopModal(e){return this.modals.length>0&&this.modals[this.modals.length-1]===e}};function ui(e){return Zo("MuiModal",e)}Jo("MuiModal",["root","hidden","backdrop"]);const di=mo("div",{name:"MuiModal",slot:"Root",overridesResolver:(e,t)=>{const{ownerState:n}=e;return[t.root,!n.open&&n.exited&&t.hidden]}})(go(({theme:e})=>({position:"fixed",zIndex:(e.vars||e).zIndex.modal,right:0,bottom:0,top:0,left:0,variants:[{props:({ownerState:e})=>!e.open&&e.exited,style:{visibility:"hidden"}}]}))),pi=mo(ei,{name:"MuiModal",slot:"Backdrop"})({zIndex:-1}),fi=c.forwardRef(function(e,t){const n=yo({name:"MuiModal",props:e}),{BackdropComponent:r=pi,BackdropProps:a,classes:o,className:i,closeAfterTransition:s=!1,children:l,container:u,component:d,components:p={},componentsProps:f={},disableAutoFocus:m=!1,disableEnforceFocus:h=!1,disableEscapeKeyDown:g=!1,disablePortal:v=!1,disableRestoreFocus:b=!1,disableScrollLock:y=!1,hideBackdrop:w=!1,keepMounted:E=!1,onClose:R,onTransitionEnter:x,onTransitionExited:A,open:C,slotProps:S={},slots:k={},theme:O,...P}=n,M={...n,closeAfterTransition:s,disableAutoFocus:m,disableEnforceFocus:h,disableEscapeKeyDown:g,disablePortal:v,disableRestoreFocus:b,disableScrollLock:y,hideBackdrop:w,keepMounted:E},{getRootProps:I,getBackdropProps:T,getTransitionProps:_,portalRef:N,isTopModal:L,exited:D,hasTransition:B}=function(e){const{container:t,disableEscapeKeyDown:n=!1,disableScrollLock:r=!1,closeAfterTransition:a=!1,onTransitionEnter:o,onTransitionExited:i,children:s,onClose:l,open:u,rootRef:d}=e,p=c.useRef({}),f=c.useRef(null),m=c.useRef(null),h=me(m,d),[g,v]=c.useState(!u),b=function(e){return!!e&&e.props.hasOwnProperty("in")}(s);let y=!0;"false"!==e["aria-hidden"]&&!1!==e["aria-hidden"]||(y=!1);const w=()=>(p.current.modalRef=m.current,p.current.mount=f.current,p.current),E=()=>{ci.mount(w(),{disableScrollLock:r}),m.current&&(m.current.scrollTop=0)},R=ti(()=>{const e=function(e){return"function"==typeof e?e():e}(t)||he(f.current).body;ci.add(w(),e),m.current&&E()}),x=()=>ci.isTopModal(w()),A=ti(e=>{f.current=e,e&&(u&&x()?E():m.current&&ai(m.current,y))}),C=c.useCallback(()=>{ci.remove(w(),y)},[y]);c.useEffect(()=>()=>{C()},[C]),c.useEffect(()=>{u?R():b&&a||C()},[u,C,b,a,R]);const S=e=>t=>{e.onKeyDown?.(t),"Escape"===t.key&&229!==t.which&&x()&&(n||(t.stopPropagation(),l&&l(t,"escapeKeyDown")))},k=e=>t=>{e.onClick?.(t),t.target===t.currentTarget&&l&&l(t,"backdropClick")};return{getRootProps:(t={})=>{const n=Eo(e);delete n.onTransitionEnter,delete n.onTransitionExited;const r={...n,...t};return{role:"presentation",...r,onKeyDown:S(r),ref:h}},getBackdropProps:(e={})=>{const t=e;return{"aria-hidden":!0,...t,onClick:k(t),open:u}},getTransitionProps:()=>({onEnter:ni(()=>{v(!1),o&&o()},s?.props.onEnter??li),onExited:ni(()=>{v(!0),i&&i(),a&&C()},s?.props.onExited??li)}),rootRef:h,portalRef:A,isTopModal:x,exited:g,hasTransition:b}}({...M,rootRef:t}),F={...M,exited:D},z=(e=>{const{open:t,exited:n,classes:r}=e;return de({root:["root",!t&&n&&"hidden"],backdrop:["backdrop"]},ui,r)})(F),j={};if(void 0===l.props.tabIndex&&(j.tabIndex="-1"),B){const{onEnter:e,onExited:t}=_();j.onEnter=e,j.onExited=t}const H={slots:{root:p.Root,backdrop:p.Backdrop,...k},slotProps:{...f,...S}},[V,G]=xo("root",{ref:t,elementType:di,externalForwardedProps:{...H,...P,component:d},getSlotProps:I,ownerState:F,className:ue(i,z?.root,!F.open&&F.exited&&z?.hidden)}),[q,U]=xo("backdrop",{ref:a?.ref,elementType:r,externalForwardedProps:H,shouldForwardComponentProp:!0,additionalProps:a,getSlotProps:e=>T({...e,onClick:t=>{e?.onClick&&e.onClick(t)}}),className:ue(a?.className,z?.backdrop),ownerState:F});return E||C||B&&!D?(0,pe.jsx)(Se,{ref:N,container:u,disablePortal:v,children:(0,pe.jsxs)(V,{...G,children:[!w&&r?(0,pe.jsx)(q,{...U}):null,(0,pe.jsx)(Ee,{disableEnforceFocus:h,disableAutoFocus:m,disableRestoreFocus:b,isEnabled:L,open:C,children:c.cloneElement(l,j)})]})}):null}),mi=fi,hi=ri,gi={visibility:"hidden"};function vi(e,t,n){var r;const a=function(e,t,n){const r=n&&n.getBoundingClientRect(),a=hi(t),o=t.style.transform,i=t.style.transition;t.style.transition="",t.style.transform="";const s=t.getBoundingClientRect(),l=a.getComputedStyle(t).getPropertyValue("transform");t.style.transform=o,t.style.transition=i;let c=0,u=0;if(l&&"none"!==l&&"string"==typeof l){const e=l.split("(")[1].split(")")[0].split(",");c=parseInt(e[4],10),u=parseInt(e[5],10)}return"left"===e?r?`translateX(${r.right+c-s.left}px)`:`translateX(${a.innerWidth+c-s.left}px)`:"right"===e?r?`translateX(-${s.right-r.left-c}px)`:`translateX(-${s.left+s.width-c}px)`:"up"===e?r?`translateY(${r.bottom+u-s.top}px)`:`translateY(${a.innerHeight+u-s.top}px)`:r?`translateY(-${s.top-r.top+s.height-u}px)`:`translateY(-${s.top+s.height-u}px)`}(e,t,"function"==typeof(r=n)?r():r);a&&(t.style.transform=a)}const bi=c.forwardRef(function(e,t){const n=Bo(),r={enter:n.transitions.easing.easeOut,exit:n.transitions.easing.sharp},a={enter:n.transitions.duration.enteringScreen,exit:n.transitions.duration.leavingScreen},{addEndListener:o,appear:i=!0,children:s,container:l,direction:u="down",easing:d=r,in:p,onEnter:f,onEntered:m,onEntering:h,onExit:g,onExited:v,onExiting:b,style:y,timeout:w=a,...E}=e,R=c.useRef(null),x=Ho(ge(s),R,t),A=zo(R,(e,t)=>{vi(u,e,l),Fo(e),f&&f(e,t)}),C=zo(R,(e,t)=>{const r=jo({timeout:w,style:y,easing:d},{mode:"enter"});e.style.transition=n.transitions.create("transform",r),e.style.transform="none",h&&h(e,t)}),S=zo(R,m),k=zo(R,b),O=zo(R,e=>{const t=jo({timeout:w,style:y,easing:d},{mode:"exit"});e.style.transition=n.transitions.create("transform",t),vi(u,e,l),g&&g(e)}),P=zo(R,e=>{e.style.transition="",v&&v(e)}),M=c.useCallback(()=>{R.current&&vi(u,R.current,l)},[u,l]);return c.useEffect(()=>{if(p||"down"===u||"right"===u)return;const e=function(e,t=166){let n;function r(...r){clearTimeout(n),n=setTimeout(()=>{e.apply(this,r)},t)}return r.clear=()=>{clearTimeout(n)},r}(()=>{R.current&&vi(u,R.current,l)}),t=hi(R.current);return t.addEventListener("resize",e),()=>{e.clear(),t.removeEventListener("resize",e)}},[u,p,l]),c.useEffect(()=>{p||M()},[p,M]),(0,pe.jsx)(No,{nodeRef:R,onEnter:A,onEntered:S,onEntering:C,onExit:O,onExited:P,onExiting:k,addEndListener:e=>{o&&o(R.current,e)},appear:i,in:p,timeout:w,...E,children:(e,{ownerState:t,...n})=>{let r;return r="exited"!==e||p?y&&s.props.style?{...y,...s.props.style}:y||s.props.style:y||s.props.style?{visibility:"hidden",...y,...s.props.style}:gi,c.cloneElement(s,{ref:x,style:r,...n})}})}),yi=bi;function wi(e){return Zo("MuiPaper",e)}Jo("MuiPaper",["root","rounded","outlined","elevation","elevation0","elevation1","elevation2","elevation3","elevation4","elevation5","elevation6","elevation7","elevation8","elevation9","elevation10","elevation11","elevation12","elevation13","elevation14","elevation15","elevation16","elevation17","elevation18","elevation19","elevation20","elevation21","elevation22","elevation23","elevation24"]);const Ei=mo("div",{name:"MuiPaper",slot:"Root",overridesResolver:(e,t)=>{const{ownerState:n}=e;return[t.root,t[n.variant],!n.square&&t.rounded,"elevation"===n.variant&&t[`elevation${n.elevation}`]]}})(go(({theme:e})=>({backgroundColor:(e.vars||e).palette.background.paper,color:(e.vars||e).palette.text.primary,transition:e.transitions.create("box-shadow"),variants:[{props:({ownerState:e})=>!e.square,style:{borderRadius:e.shape.borderRadius}},{props:{variant:"outlined"},style:{border:`1px solid ${(e.vars||e).palette.divider}`}},{props:{variant:"elevation"},style:{boxShadow:"var(--Paper-shadow)",backgroundImage:"var(--Paper-overlay)"}}]}))),Ri=c.forwardRef(function(e,t){const n=yo({props:e,name:"MuiPaper"}),r=Bo(),{className:a,component:o="div",elevation:i=1,square:s=!1,variant:l="elevation",...c}=n,u={...n,component:o,elevation:i,square:s,variant:l},d=(e=>{const{square:t,elevation:n,variant:r,classes:a}=e;return de({root:["root",r,!t&&"rounded","elevation"===r&&`elevation${n}`]},wi,a)})(u);return(0,pe.jsx)(Ei,{as:o,ownerState:u,className:ue(d.root,a),ref:t,...c,style:{..."elevation"===l&&{"--Paper-shadow":(r.vars||r).shadows[i],...r.vars&&{"--Paper-overlay":r.vars.overlays?.[i]},...!r.vars&&"dark"===r.palette.mode&&{"--Paper-overlay":`linear-gradient(${Dr("#fff",Za(i))}, ${Dr("#fff",Za(i))})`}},...c.style}})}),xi=Ri,Ai=xn;function Ci(e){return Zo("MuiDrawer",e)}function Si(e,t){if(!e)return t;function n(e,t){const n={};return Object.keys(t).forEach(r=>{(function(e,t){const n=e.charCodeAt(2);return"o"===e[0]&&"n"===e[1]&&n>=65&&n<=90&&"function"==typeof t})(r,t[r])&&"function"==typeof e[r]&&(n[r]=(...n)=>{e[r](...n),t[r](...n)})}),n}if("function"==typeof e||"function"==typeof t)return r=>{const a="function"==typeof t?t(r):t,o="function"==typeof e?e({...r,...a}):e,i=ue(r?.className,a?.className,o?.className),s=n(o,a);return{...a,...o,...s,...!!i&&{className:i},...a?.style&&o?.style&&{style:{...a.style,...o.style}},...a?.sx&&o?.sx&&{sx:[...Array.isArray(a.sx)?a.sx:[a.sx],...Array.isArray(o.sx)?o.sx:[o.sx]]}}};const r=t,a=n(e,r),o=ue(r?.className,e?.className);return{...t,...e,...a,...!!o&&{className:o},...r?.style&&e?.style&&{style:{...r.style,...e.style}},...r?.sx&&e?.sx&&{sx:[...Array.isArray(r.sx)?r.sx:[r.sx],...Array.isArray(e.sx)?e.sx:[e.sx]]}}}Jo("MuiDrawer",["root","docked","paper","anchorLeft","anchorRight","anchorTop","anchorBottom","paperAnchorLeft","paperAnchorRight","paperAnchorTop","paperAnchorBottom","paperAnchorDockedLeft","paperAnchorDockedRight","paperAnchorDockedTop","paperAnchorDockedBottom","modal"]);const ki=(e,t)=>{const{ownerState:n}=e;return[t.root,("permanent"===n.variant||"persistent"===n.variant)&&t.docked,"temporary"===n.variant&&t.modal]},Oi=mo(mi,{name:"MuiDrawer",slot:"Root",overridesResolver:ki})(go(({theme:e})=>({zIndex:(e.vars||e).zIndex.drawer}))),Pi=mo("div",{shouldForwardProp:po,name:"MuiDrawer",slot:"Docked",skipVariantsResolver:!1,overridesResolver:ki})({flex:"0 0 auto"}),Mi=mo(xi,{name:"MuiDrawer",slot:"Paper",overridesResolver:(e,t)=>{const{ownerState:n}=e;return[t.paper,t[`paperAnchor${Ai(n.anchor)}`],"temporary"!==n.variant&&t[`paperAnchorDocked${Ai(n.anchor)}`]]}})(go(({theme:e})=>({overflowY:"auto",display:"flex",flexDirection:"column",height:"100%",flex:"1 0 auto",zIndex:(e.vars||e).zIndex.drawer,WebkitOverflowScrolling:"touch",position:"fixed",top:0,outline:0,variants:[{props:{anchor:"left"},style:{left:0}},{props:{anchor:"top"},style:{top:0,left:0,right:0,height:"auto",maxHeight:"100%"}},{props:{anchor:"right"},style:{right:0}},{props:{anchor:"bottom"},style:{top:"auto",left:0,bottom:0,right:0,height:"auto",maxHeight:"100%"}},{props:({ownerState:e})=>"left"===e.anchor&&"temporary"!==e.variant,style:{borderRight:`1px solid ${(e.vars||e).palette.divider}`}},{props:({ownerState:e})=>"top"===e.anchor&&"temporary"!==e.variant,style:{borderBottom:`1px solid ${(e.vars||e).palette.divider}`}},{props:({ownerState:e})=>"right"===e.anchor&&"temporary"!==e.variant,style:{borderLeft:`1px solid ${(e.vars||e).palette.divider}`}},{props:({ownerState:e})=>"bottom"===e.anchor&&"temporary"!==e.variant,style:{borderTop:`1px solid ${(e.vars||e).palette.divider}`}}]}))),Ii={left:"right",right:"left",top:"down",bottom:"up"},Ti=c.forwardRef(function(e,t){const n=yo({props:e,name:"MuiDrawer"}),r=Bo(),a=c.useContext(fe)??!1,o={enter:r.transitions.duration.enteringScreen,exit:r.transitions.duration.leavingScreen},{anchor:i="left",BackdropProps:s,children:l,className:u,elevation:d=16,hideBackdrop:p=!1,ModalProps:{BackdropProps:f,...m}={},onClose:h,open:g=!1,PaperProps:v={},SlideProps:b,TransitionComponent:y,transitionDuration:w=o,variant:E="temporary",slots:R={},slotProps:x={},...A}=n,C=c.useRef(!1);c.useEffect(()=>{C.current=!0},[]);const S=function({direction:e},t){return"rtl"===e&&function(e){return["left","right"].includes(e)}(t)?Ii[t]:t}({direction:a?"rtl":"ltr"},i),k=i,O={...n,anchor:k,elevation:d,open:g,variant:E,...A},P=(e=>{const{classes:t,anchor:n,variant:r}=e;return de({root:["root",`anchor${Ai(n)}`],docked:[("permanent"===r||"persistent"===r)&&"docked"],modal:["modal"],paper:["paper",`paperAnchor${Ai(n)}`,"temporary"!==r&&`paperAnchorDocked${Ai(n)}`]},Ci,t)})(O),M={slots:{transition:y,...R},slotProps:{paper:v,transition:b,...x,backdrop:Si(x.backdrop||{...s,...f},{transitionDuration:w})}},[I,T]=xo("root",{ref:t,elementType:Oi,className:ue(P.root,P.modal,u),shouldForwardComponentProp:!0,ownerState:O,externalForwardedProps:{...M,...A,...m},additionalProps:{open:g,onClose:h,hideBackdrop:p,slots:{backdrop:M.slots.backdrop},slotProps:{backdrop:M.slotProps.backdrop}}}),[_,N]=xo("paper",{elementType:Mi,shouldForwardComponentProp:!0,className:ue(P.paper,v.className),ownerState:O,externalForwardedProps:M,additionalProps:{elevation:"temporary"===E?d:0,square:!0,..."temporary"===E&&{role:"dialog","aria-modal":"true"}}}),[L,D]=xo("docked",{elementType:Pi,ref:t,className:ue(P.root,P.docked,u),ownerState:O,externalForwardedProps:M,additionalProps:A}),[B,F]=xo("transition",{elementType:yi,ownerState:O,externalForwardedProps:M,additionalProps:{in:g,direction:Ii[S],timeout:w,appear:C.current}}),z=(0,pe.jsx)(_,{...N,children:l});if("permanent"===E)return(0,pe.jsx)(L,{...D,children:z});const j=(0,pe.jsx)(B,{...F,children:z});return"persistent"===E?(0,pe.jsx)(L,{...D,children:j}):(0,pe.jsx)(I,{...T,children:j})}),_i=Ti;function Ni(e,t){return function(){return e.apply(t,arguments)}}const{toString:Li}=Object.prototype,{getPrototypeOf:Di}=Object,{iterator:Bi,toStringTag:Fi}=Symbol,zi=(ji=Object.create(null),e=>{const t=Li.call(e);return ji[t]||(ji[t]=t.slice(8,-1).toLowerCase())});var ji;const Hi=e=>(e=e.toLowerCase(),t=>zi(t)===e),Vi=e=>t=>typeof t===e,{isArray:Gi}=Array,qi=Vi("undefined");function Ui(e){return null!==e&&!qi(e)&&null!==e.constructor&&!qi(e.constructor)&&Ki(e.constructor.isBuffer)&&e.constructor.isBuffer(e)}const Wi=Hi("ArrayBuffer"),Qi=Vi("string"),Ki=Vi("function"),Zi=Vi("number"),Ji=e=>null!==e&&"object"==typeof e,Xi=e=>{if("object"!==zi(e))return!1;const t=Di(e);return!(null!==t&&t!==Object.prototype&&null!==Object.getPrototypeOf(t)||Fi in e||Bi in e)},Yi=Hi("Date"),$i=Hi("File"),es=Hi("Blob"),ts=Hi("FileList"),ns="undefined"!=typeof globalThis?globalThis:"undefined"!=typeof self?self:"undefined"!=typeof window?window:"undefined"!=typeof globalThis?globalThis:{},rs=void 0!==ns.FormData?ns.FormData:void 0,as=Hi("URLSearchParams"),[os,is,ss,ls]=["ReadableStream","Request","Response","Headers"].map(Hi);function cs(e,t,{allOwnKeys:n=!1}={}){if(null==e)return;let r,a;if("object"!=typeof e&&(e=[e]),Gi(e))for(r=0,a=e.length;r<a;r++)t.call(null,e[r],r,e);else{if(Ui(e))return;const a=n?Object.getOwnPropertyNames(e):Object.keys(e),o=a.length;let i;for(r=0;r<o;r++)i=a[r],t.call(null,e[i],i,e)}}function us(e,t){if(Ui(e))return null;t=t.toLowerCase();const n=Object.keys(e);let r,a=n.length;for(;a-- >0;)if(r=n[a],t===r.toLowerCase())return r;return null}const ds="undefined"!=typeof globalThis?globalThis:"undefined"!=typeof self?self:"undefined"!=typeof window?window:globalThis,ps=e=>!qi(e)&&e!==ds,fs=(ms="undefined"!=typeof Uint8Array&&Di(Uint8Array),e=>ms&&e instanceof ms);var ms;const hs=Hi("HTMLFormElement"),gs=(({hasOwnProperty:e})=>(t,n)=>e.call(t,n))(Object.prototype),vs=Hi("RegExp"),bs=(e,t)=>{const n=Object.getOwnPropertyDescriptors(e),r={};cs(n,(n,a)=>{let o;!1!==(o=t(n,a,e))&&(r[a]=o||n)}),Object.defineProperties(e,r)},ys=Hi("AsyncFunction"),ws=(Es="function"==typeof setImmediate,Rs=Ki(ds.postMessage),Es?setImmediate:Rs?((e,t)=>(ds.addEventListener("message",({source:n,data:r})=>{n===ds&&r===e&&t.length&&t.shift()()},!1),n=>{t.push(n),ds.postMessage(e,"*")}))(`axios@${Math.random()}`,[]):e=>setTimeout(e));var Es,Rs;const xs="undefined"!=typeof queueMicrotask?queueMicrotask.bind(ds):"undefined"!=typeof process&&process.nextTick||ws,As={isArray:Gi,isArrayBuffer:Wi,isBuffer:Ui,isFormData:e=>{if(!e)return!1;if(rs&&e instanceof rs)return!0;const t=Di(e);if(!t||t===Object.prototype)return!1;if(!Ki(e.append))return!1;const n=zi(e);return"formdata"===n||"object"===n&&Ki(e.toString)&&"[object FormData]"===e.toString()},isArrayBufferView:function(e){let t;return t="undefined"!=typeof ArrayBuffer&&ArrayBuffer.isView?ArrayBuffer.isView(e):e&&e.buffer&&Wi(e.buffer),t},isString:Qi,isNumber:Zi,isBoolean:e=>!0===e||!1===e,isObject:Ji,isPlainObject:Xi,isEmptyObject:e=>{if(!Ji(e)||Ui(e))return!1;try{return 0===Object.keys(e).length&&Object.getPrototypeOf(e)===Object.prototype}catch(e){return!1}},isReadableStream:os,isRequest:is,isResponse:ss,isHeaders:ls,isUndefined:qi,isDate:Yi,isFile:$i,isReactNativeBlob:e=>!(!e||void 0===e.uri),isReactNative:e=>e&&void 0!==e.getParts,isBlob:es,isRegExp:vs,isFunction:Ki,isStream:e=>Ji(e)&&Ki(e.pipe),isURLSearchParams:as,isTypedArray:fs,isFileList:ts,forEach:cs,merge:function e(){const{caseless:t,skipUndefined:n}=ps(this)&&this||{},r={},a=(a,o)=>{if("__proto__"===o||"constructor"===o||"prototype"===o)return;const i=t&&us(r,o)||o;Xi(r[i])&&Xi(a)?r[i]=e(r[i],a):Xi(a)?r[i]=e({},a):Gi(a)?r[i]=a.slice():n&&qi(a)||(r[i]=a)};for(let e=0,t=arguments.length;e<t;e++)arguments[e]&&cs(arguments[e],a);return r},extend:(e,t,n,{allOwnKeys:r}={})=>(cs(t,(t,r)=>{n&&Ki(t)?Object.defineProperty(e,r,{value:Ni(t,n),writable:!0,enumerable:!0,configurable:!0}):Object.defineProperty(e,r,{value:t,writable:!0,enumerable:!0,configurable:!0})},{allOwnKeys:r}),e),trim:e=>e.trim?e.trim():e.replace(/^[\s\uFEFF\xA0]+|[\s\uFEFF\xA0]+$/g,""),stripBOM:e=>(65279===e.charCodeAt(0)&&(e=e.slice(1)),e),inherits:(e,t,n,r)=>{e.prototype=Object.create(t.prototype,r),Object.defineProperty(e.prototype,"constructor",{value:e,writable:!0,enumerable:!1,configurable:!0}),Object.defineProperty(e,"super",{value:t.prototype}),n&&Object.assign(e.prototype,n)},toFlatObject:(e,t,n,r)=>{let a,o,i;const s={};if(t=t||{},null==e)return t;do{for(a=Object.getOwnPropertyNames(e),o=a.length;o-- >0;)i=a[o],r&&!r(i,e,t)||s[i]||(t[i]=e[i],s[i]=!0);e=!1!==n&&Di(e)}while(e&&(!n||n(e,t))&&e!==Object.prototype);return t},kindOf:zi,kindOfTest:Hi,endsWith:(e,t,n)=>{e=String(e),(void 0===n||n>e.length)&&(n=e.length),n-=t.length;const r=e.indexOf(t,n);return-1!==r&&r===n},toArray:e=>{if(!e)return null;if(Gi(e))return e;let t=e.length;if(!Zi(t))return null;const n=new Array(t);for(;t-- >0;)n[t]=e[t];return n},forEachEntry:(e,t)=>{const n=(e&&e[Bi]).call(e);let r;for(;(r=n.next())&&!r.done;){const n=r.value;t.call(e,n[0],n[1])}},matchAll:(e,t)=>{let n;const r=[];for(;null!==(n=e.exec(t));)r.push(n);return r},isHTMLForm:hs,hasOwnProperty:gs,hasOwnProp:gs,reduceDescriptors:bs,freezeMethods:e=>{bs(e,(t,n)=>{if(Ki(e)&&-1!==["arguments","caller","callee"].indexOf(n))return!1;const r=e[n];Ki(r)&&(t.enumerable=!1,"writable"in t?t.writable=!1:t.set||(t.set=()=>{throw Error("Can not rewrite read-only method '"+n+"'")}))})},toObjectSet:(e,t)=>{const n={},r=e=>{e.forEach(e=>{n[e]=!0})};return Gi(e)?r(e):r(String(e).split(t)),n},toCamelCase:e=>e.toLowerCase().replace(/[-_\s]([a-z\d])(\w*)/g,function(e,t,n){return t.toUpperCase()+n}),noop:()=>{},toFiniteNumber:(e,t)=>null!=e&&Number.isFinite(e=+e)?e:t,findKey:us,global:ds,isContextDefined:ps,isSpecCompliantForm:function(e){return!!(e&&Ki(e.append)&&"FormData"===e[Fi]&&e[Bi])},toJSONObject:e=>{const t=new Array(10),n=(e,r)=>{if(Ji(e)){if(t.indexOf(e)>=0)return;if(Ui(e))return e;if(!("toJSON"in e)){t[r]=e;const a=Gi(e)?[]:{};return cs(e,(e,t)=>{const o=n(e,r+1);!qi(o)&&(a[t]=o)}),t[r]=void 0,a}}return e};return n(e,0)},isAsyncFn:ys,isThenable:e=>e&&(Ji(e)||Ki(e))&&Ki(e.then)&&Ki(e.catch),setImmediate:ws,asap:xs,isIterable:e=>null!=e&&Ki(e[Bi])};class Cs extends Error{static from(e,t,n,r,a,o){const i=new Cs(e.message,t||e.code,n,r,a);return i.cause=e,i.name=e.name,null!=e.status&&null==i.status&&(i.status=e.status),o&&Object.assign(i,o),i}constructor(e,t,n,r,a){super(e),Object.defineProperty(this,"message",{value:e,enumerable:!0,writable:!0,configurable:!0}),this.name="AxiosError",this.isAxiosError=!0,t&&(this.code=t),n&&(this.config=n),r&&(this.request=r),a&&(this.response=a,this.status=a.status)}toJSON(){return{message:this.message,name:this.name,description:this.description,number:this.number,fileName:this.fileName,lineNumber:this.lineNumber,columnNumber:this.columnNumber,stack:this.stack,config:As.toJSONObject(this.config),code:this.code,status:this.status}}}Cs.ERR_BAD_OPTION_VALUE="ERR_BAD_OPTION_VALUE",Cs.ERR_BAD_OPTION="ERR_BAD_OPTION",Cs.ECONNABORTED="ECONNABORTED",Cs.ETIMEDOUT="ETIMEDOUT",Cs.ERR_NETWORK="ERR_NETWORK",Cs.ERR_FR_TOO_MANY_REDIRECTS="ERR_FR_TOO_MANY_REDIRECTS",Cs.ERR_DEPRECATED="ERR_DEPRECATED",Cs.ERR_BAD_RESPONSE="ERR_BAD_RESPONSE",Cs.ERR_BAD_REQUEST="ERR_BAD_REQUEST",Cs.ERR_CANCELED="ERR_CANCELED",Cs.ERR_NOT_SUPPORT="ERR_NOT_SUPPORT",Cs.ERR_INVALID_URL="ERR_INVALID_URL",Cs.ERR_FORM_DATA_DEPTH_EXCEEDED="ERR_FORM_DATA_DEPTH_EXCEEDED";const Ss=Cs;function ks(e){return As.isPlainObject(e)||As.isArray(e)}function Os(e){return As.endsWith(e,"[]")?e.slice(0,-2):e}function Ps(e,t,n){return e?e.concat(t).map(function(e,t){return e=Os(e),!n&&t?"["+e+"]":e}).join(n?".":""):t}const Ms=As.toFlatObject(As,{},null,function(e){return/^is[A-Z]/.test(e)}),Is=function(e,t,n){if(!As.isObject(e))throw new TypeError("target must be an object");t=t||new FormData;const r=(n=As.toFlatObject(n,{metaTokens:!0,dots:!1,indexes:!1},!1,function(e,t){return!As.isUndefined(t[e])})).metaTokens,a=n.visitor||d,o=n.dots,i=n.indexes,s=n.Blob||"undefined"!=typeof Blob&&Blob,l=void 0===n.maxDepth?100:n.maxDepth,c=s&&As.isSpecCompliantForm(t);if(!As.isFunction(a))throw new TypeError("visitor must be a function");function u(e){if(null===e)return"";if(As.isDate(e))return e.toISOString();if(As.isBoolean(e))return e.toString();if(!c&&As.isBlob(e))throw new Ss("Blob is not supported. Use a Buffer instead.");return As.isArrayBuffer(e)||As.isTypedArray(e)?c&&"function"==typeof Blob?new Blob([e]):Buffer.from(e):e}function d(e,n,a){let s=e;if(As.isReactNative(t)&&As.isReactNativeBlob(e))return t.append(Ps(a,n,o),u(e)),!1;if(e&&!a&&"object"==typeof e)if(As.endsWith(n,"{}"))n=r?n:n.slice(0,-2),e=JSON.stringify(e);else if(As.isArray(e)&&function(e){return As.isArray(e)&&!e.some(ks)}(e)||(As.isFileList(e)||As.endsWith(n,"[]"))&&(s=As.toArray(e)))return n=Os(n),s.forEach(function(e,r){!As.isUndefined(e)&&null!==e&&t.append(!0===i?Ps([n],r,o):null===i?n:n+"[]",u(e))}),!1;return!!ks(e)||(t.append(Ps(a,n,o),u(e)),!1)}const p=[],f=Object.assign(Ms,{defaultVisitor:d,convertValue:u,isVisitable:ks});if(!As.isObject(e))throw new TypeError("data must be an object");return function e(n,r,o=0){if(!As.isUndefined(n)){if(o>l)throw new Ss("Object is too deeply nested ("+o+" levels). Max depth: "+l,Ss.ERR_FORM_DATA_DEPTH_EXCEEDED);if(-1!==p.indexOf(n))throw Error("Circular reference detected in "+r.join("."));p.push(n),As.forEach(n,function(n,i){!0===(!(As.isUndefined(n)||null===n)&&a.call(t,n,As.isString(i)?i.trim():i,r,f))&&e(n,r?r.concat(i):[i],o+1)}),p.pop()}}(e),t};function Ts(e){const t={"!":"%21","'":"%27","(":"%28",")":"%29","~":"%7E","%20":"+"};return encodeURIComponent(e).replace(/[!'()~]|%20/g,function(e){return t[e]})}function _s(e,t){this._pairs=[],e&&Is(e,this,t)}const Ns=_s.prototype;Ns.append=function(e,t){this._pairs.push([e,t])},Ns.toString=function(e){const t=e?function(t){return e.call(this,t,Ts)}:Ts;return this._pairs.map(function(e){return t(e[0])+"="+t(e[1])},"").join("&")};const Ls=_s;function Ds(e){return encodeURIComponent(e).replace(/%3A/gi,":").replace(/%24/g,"$").replace(/%2C/gi,",").replace(/%20/g,"+")}function Bs(e,t,n){if(!t)return e;const r=n&&n.encode||Ds,a=As.isFunction(n)?{serialize:n}:n,o=a&&a.serialize;let i;if(i=o?o(t,a):As.isURLSearchParams(t)?t.toString():new Ls(t,a).toString(r),i){const t=e.indexOf("#");-1!==t&&(e=e.slice(0,t)),e+=(-1===e.indexOf("?")?"?":"&")+i}return e}const Fs=class{constructor(){this.handlers=[]}use(e,t,n){return this.handlers.push({fulfilled:e,rejected:t,synchronous:!!n&&n.synchronous,runWhen:n?n.runWhen:null}),this.handlers.length-1}eject(e){this.handlers[e]&&(this.handlers[e]=null)}clear(){this.handlers&&(this.handlers=[])}forEach(e){As.forEach(this.handlers,function(t){null!==t&&e(t)})}},zs={silentJSONParsing:!0,forcedJSONParsing:!0,clarifyTimeoutError:!1,legacyInterceptorReqResOrdering:!0},js={isBrowser:!0,classes:{URLSearchParams:"undefined"!=typeof URLSearchParams?URLSearchParams:Ls,FormData:"undefined"!=typeof FormData?FormData:null,Blob:"undefined"!=typeof Blob?Blob:null},protocols:["http","https","file","blob","url","data"]},Hs="undefined"!=typeof window&&"undefined"!=typeof document,Vs="object"==typeof navigator&&navigator||void 0,Gs=Hs&&(!Vs||["ReactNative","NativeScript","NS"].indexOf(Vs.product)<0),qs="undefined"!=typeof WorkerGlobalScope&&self instanceof WorkerGlobalScope&&"function"==typeof self.importScripts,Us=Hs&&window.location.href||"http://localhost",Ws={...r,...js},Qs=function(e){function t(e,n,r,a){let o=e[a++];if("__proto__"===o)return!0;const i=Number.isFinite(+o),s=a>=e.length;return o=!o&&As.isArray(r)?r.length:o,s?(As.hasOwnProp(r,o)?r[o]=As.isArray(r[o])?r[o].concat(n):[r[o],n]:r[o]=n,!i):(r[o]&&As.isObject(r[o])||(r[o]=[]),t(e,n,r[o],a)&&As.isArray(r[o])&&(r[o]=function(e){const t={},n=Object.keys(e);let r;const a=n.length;let o;for(r=0;r<a;r++)o=n[r],t[o]=e[o];return t}(r[o])),!i)}if(As.isFormData(e)&&As.isFunction(e.entries)){const n={};return As.forEachEntry(e,(e,r)=>{t(function(e){return As.matchAll(/\w+|\[(\w*)]/g,e).map(e=>"[]"===e[0]?"":e[1]||e[0])}(e),r,n,0)}),n}return null},Ks=(e,t)=>null!=e&&As.hasOwnProp(e,t)?e[t]:void 0,Zs={transitional:zs,adapter:["xhr","http","fetch"],transformRequest:[function(e,t){const n=t.getContentType()||"",r=n.indexOf("application/json")>-1,a=As.isObject(e);if(a&&As.isHTMLForm(e)&&(e=new FormData(e)),As.isFormData(e))return r?JSON.stringify(Qs(e)):e;if(As.isArrayBuffer(e)||As.isBuffer(e)||As.isStream(e)||As.isFile(e)||As.isBlob(e)||As.isReadableStream(e))return e;if(As.isArrayBufferView(e))return e.buffer;if(As.isURLSearchParams(e))return t.setContentType("application/x-www-form-urlencoded;charset=utf-8",!1),e.toString();let o;if(a){const t=Ks(this,"formSerializer");if(n.indexOf("application/x-www-form-urlencoded")>-1)return function(e,t){return Is(e,new Ws.classes.URLSearchParams,{visitor:function(e,t,n,r){return Ws.isNode&&As.isBuffer(e)?(this.append(t,e.toString("base64")),!1):r.defaultVisitor.apply(this,arguments)},...t})}(e,t).toString();if((o=As.isFileList(e))||n.indexOf("multipart/form-data")>-1){const n=Ks(this,"env"),r=n&&n.FormData;return Is(o?{"files[]":e}:e,r&&new r,t)}}return a||r?(t.setContentType("application/json",!1),function(e){if(As.isString(e))try{return(0,JSON.parse)(e),As.trim(e)}catch(e){if("SyntaxError"!==e.name)throw e}return(0,JSON.stringify)(e)}(e)):e}],transformResponse:[function(e){const t=Ks(this,"transitional")||Zs.transitional,n=t&&t.forcedJSONParsing,r=Ks(this,"responseType"),a="json"===r;if(As.isResponse(e)||As.isReadableStream(e))return e;if(e&&As.isString(e)&&(n&&!r||a)){const n=!(t&&t.silentJSONParsing)&&a;try{return JSON.parse(e,Ks(this,"parseReviver"))}catch(e){if(n){if("SyntaxError"===e.name)throw Ss.from(e,Ss.ERR_BAD_RESPONSE,this,null,Ks(this,"response"));throw e}}}return e}],timeout:0,xsrfCookieName:"XSRF-TOKEN",xsrfHeaderName:"X-XSRF-TOKEN",maxContentLength:-1,maxBodyLength:-1,env:{FormData:Ws.classes.FormData,Blob:Ws.classes.Blob},validateStatus:function(e){return e>=200&&e<300},headers:{common:{Accept:"application/json, text/plain, */*","Content-Type":void 0}}};As.forEach(["delete","get","head","post","put","patch"],e=>{Zs.headers[e]={}});const Js=Zs,Xs=As.toObjectSet(["age","authorization","content-length","content-type","etag","expires","from","host","if-modified-since","if-unmodified-since","last-modified","location","max-forwards","proxy-authorization","referer","retry-after","user-agent"]),Ys=e=>{const t={};let n,r,a;return e&&e.split("\n").forEach(function(e){a=e.indexOf(":"),n=e.substring(0,a).trim().toLowerCase(),r=e.substring(a+1).trim(),!n||t[n]&&Xs[n]||("set-cookie"===n?t[n]?t[n].push(r):t[n]=[r]:t[n]=t[n]?t[n]+", "+r:r)}),t};(Object.getOwnPropertyDescriptor(Ys,"name")||{}).writable||Object.defineProperty(Ys,"name",{value:"default",configurable:!0});const $s=Symbol("internals"),el=/[^\x09\x20-\x7E\x80-\xFF]/g;function tl(e){return e&&String(e).trim().toLowerCase()}function nl(e){return!1===e||null==e?e:As.isArray(e)?e.map(nl):function(e){let t=0,n=e.length;for(;t<n;){const n=e.charCodeAt(t);if(9!==n&&32!==n)break;t+=1}for(;n>t;){const t=e.charCodeAt(n-1);if(9!==t&&32!==t)break;n-=1}return 0===t&&n===e.length?e:e.slice(t,n)}(String(e).replace(el,""))}function rl(e,t,n,r,a){return As.isFunction(r)?r.call(this,t,n):(a&&(t=n),As.isString(t)?As.isString(r)?-1!==t.indexOf(r):As.isRegExp(r)?r.test(t):void 0:void 0)}class al{constructor(e){e&&this.set(e)}set(e,t,n){const r=this;function a(e,t,n){const a=tl(t);if(!a)throw new Error("header name must be a non-empty string");const o=As.findKey(r,a);(!o||void 0===r[o]||!0===n||void 0===n&&!1!==r[o])&&(r[o||t]=nl(e))}const o=(e,t)=>As.forEach(e,(e,n)=>a(e,n,t));if(As.isPlainObject(e)||e instanceof this.constructor)o(e,t);else if(As.isString(e)&&(e=e.trim())&&!/^[-_a-zA-Z0-9^`|~,!#$%&'*+.]+$/.test(e.trim()))o(Ys(e),t);else if(As.isObject(e)&&As.isIterable(e)){let n,r,a={};for(const t of e){if(!As.isArray(t))throw TypeError("Object iterator must return a key-value pair");a[r=t[0]]=(n=a[r])?As.isArray(n)?[...n,t[1]]:[n,t[1]]:t[1]}o(a,t)}else null!=e&&a(t,e,n);return this}get(e,t){if(e=tl(e)){const n=As.findKey(this,e);if(n){const e=this[n];if(!t)return e;if(!0===t)return function(e){const t=Object.create(null),n=/([^\s,;=]+)\s*(?:=\s*([^,;]+))?/g;let r;for(;r=n.exec(e);)t[r[1]]=r[2];return t}(e);if(As.isFunction(t))return t.call(this,e,n);if(As.isRegExp(t))return t.exec(e);throw new TypeError("parser must be boolean|regexp|function")}}}has(e,t){if(e=tl(e)){const n=As.findKey(this,e);return!(!n||void 0===this[n]||t&&!rl(0,this[n],n,t))}return!1}delete(e,t){const n=this;let r=!1;function a(e){if(e=tl(e)){const a=As.findKey(n,e);!a||t&&!rl(0,n[a],a,t)||(delete n[a],r=!0)}}return As.isArray(e)?e.forEach(a):a(e),r}clear(e){const t=Object.keys(this);let n=t.length,r=!1;for(;n--;){const a=t[n];e&&!rl(0,this[a],a,e,!0)||(delete this[a],r=!0)}return r}normalize(e){const t=this,n={};return As.forEach(this,(r,a)=>{const o=As.findKey(n,a);if(o)return t[o]=nl(r),void delete t[a];const i=e?function(e){return e.trim().toLowerCase().replace(/([a-z\d])(\w*)/g,(e,t,n)=>t.toUpperCase()+n)}(a):String(a).trim();i!==a&&delete t[a],t[i]=nl(r),n[i]=!0}),this}concat(...e){return this.constructor.concat(this,...e)}toJSON(e){const t=Object.create(null);return As.forEach(this,(n,r)=>{null!=n&&!1!==n&&(t[r]=e&&As.isArray(n)?n.join(", "):n)}),t}[Symbol.iterator](){return Object.entries(this.toJSON())[Symbol.iterator]()}toString(){return Object.entries(this.toJSON()).map(([e,t])=>e+": "+t).join("\n")}getSetCookie(){return this.get("set-cookie")||[]}get[Symbol.toStringTag](){return"AxiosHeaders"}static from(e){return e instanceof this?e:new this(e)}static concat(e,...t){const n=new this(e);return t.forEach(e=>n.set(e)),n}static accessor(e){const t=(this[$s]=this[$s]={accessors:{}}).accessors,n=this.prototype;function r(e){const r=tl(e);t[r]||(function(e,t){const n=As.toCamelCase(" "+t);["get","set","has"].forEach(r=>{Object.defineProperty(e,r+n,{value:function(e,n,a){return this[r].call(this,t,e,n,a)},configurable:!0})})}(n,e),t[r]=!0)}return As.isArray(e)?e.forEach(r):r(e),this}}al.accessor(["Content-Type","Content-Length","Accept","Accept-Encoding","User-Agent","Authorization"]),As.reduceDescriptors(al.prototype,({value:e},t)=>{let n=t[0].toUpperCase()+t.slice(1);return{get:()=>e,set(e){this[n]=e}}}),As.freezeMethods(al);const ol=al;function il(e,t){const n=this||Js,r=t||n,a=ol.from(r.headers);let o=r.data;return As.forEach(e,function(e){o=e.call(n,o,a.normalize(),t?t.status:void 0)}),a.normalize(),o}function sl(e){return!(!e||!e.__CANCEL__)}const ll=class extends Ss{constructor(e,t,n){super(null==e?"canceled":e,Ss.ERR_CANCELED,t,n),this.name="CanceledError",this.__CANCEL__=!0}};function cl(e,t,n){const r=n.config.validateStatus;n.status&&r&&!r(n.status)?t(new Ss("Request failed with status code "+n.status,[Ss.ERR_BAD_REQUEST,Ss.ERR_BAD_RESPONSE][Math.floor(n.status/100)-4],n.config,n.request,n)):e(n)}const ul=(e,t,n=3)=>{let r=0;const a=function(e,t){e=e||10;const n=new Array(e),r=new Array(e);let a,o=0,i=0;return t=void 0!==t?t:1e3,function(s){const l=Date.now(),c=r[i];a||(a=l),n[o]=s,r[o]=l;let u=i,d=0;for(;u!==o;)d+=n[u++],u%=e;if(o=(o+1)%e,o===i&&(i=(i+1)%e),l-a<t)return;const p=c&&l-c;return p?Math.round(1e3*d/p):void 0}}(50,250);return function(e,t){let n,r,a=0,o=1e3/t;const i=(t,o=Date.now())=>{a=o,n=null,r&&(clearTimeout(r),r=null),e(...t)};return[(...e)=>{const t=Date.now(),s=t-a;s>=o?i(e,t):(n=e,r||(r=setTimeout(()=>{r=null,i(n)},o-s)))},()=>n&&i(n)]}(n=>{const o=n.loaded,i=n.lengthComputable?n.total:void 0,s=null!=i?Math.min(o,i):o,l=Math.max(0,s-r),c=a(l);r=Math.max(r,s),e({loaded:s,total:i,progress:i?s/i:void 0,bytes:l,rate:c||void 0,estimated:c&&i?(i-s)/c:void 0,event:n,lengthComputable:null!=i,[t?"download":"upload"]:!0})},n)},dl=(e,t)=>{const n=null!=e;return[r=>t[0]({lengthComputable:n,total:e,loaded:r}),t[1]]},pl=e=>(...t)=>As.asap(()=>e(...t)),fl=Ws.hasStandardBrowserEnv?((e,t)=>n=>(n=new URL(n,Ws.origin),e.protocol===n.protocol&&e.host===n.host&&(t||e.port===n.port)))(new URL(Ws.origin),Ws.navigator&&/(msie|trident)/i.test(Ws.navigator.userAgent)):()=>!0,ml=Ws.hasStandardBrowserEnv?{write(e,t,n,r,a,o,i){if("undefined"==typeof document)return;const s=[`${e}=${encodeURIComponent(t)}`];As.isNumber(n)&&s.push(`expires=${new Date(n).toUTCString()}`),As.isString(r)&&s.push(`path=${r}`),As.isString(a)&&s.push(`domain=${a}`),!0===o&&s.push("secure"),As.isString(i)&&s.push(`SameSite=${i}`),document.cookie=s.join("; ")},read(e){if("undefined"==typeof document)return null;const t=document.cookie.match(new RegExp("(?:^|; )"+e+"=([^;]*)"));return t?decodeURIComponent(t[1]):null},remove(e){this.write(e,"",Date.now()-864e5,"/")}}:{write(){},read:()=>null,remove(){}};function hl(e,t,n){let r=!("string"==typeof(a=t)&&/^([a-z][a-z\d+\-.]*:)?\/\//i.test(a));var a;return e&&(r||!1===n)?function(e,t){return t?e.replace(/\/?\/$/,"")+"/"+t.replace(/^\/+/,""):e}(e,t):t}const gl=e=>e instanceof ol?{...e}:e;function vl(e,t){t=t||{};const n=Object.create(null);function r(e,t,n,r){return As.isPlainObject(e)&&As.isPlainObject(t)?As.merge.call({caseless:r},e,t):As.isPlainObject(t)?As.merge({},t):As.isArray(t)?t.slice():t}function a(e,t,n,a){return As.isUndefined(t)?As.isUndefined(e)?void 0:r(void 0,e,0,a):r(e,t,0,a)}function o(e,t){if(!As.isUndefined(t))return r(void 0,t)}function i(e,t){return As.isUndefined(t)?As.isUndefined(e)?void 0:r(void 0,e):r(void 0,t)}function s(n,a,o){return As.hasOwnProp(t,o)?r(n,a):As.hasOwnProp(e,o)?r(void 0,n):void 0}Object.defineProperty(n,"hasOwnProperty",{value:Object.prototype.hasOwnProperty,enumerable:!1,writable:!0,configurable:!0});const l={url:o,method:o,data:o,baseURL:i,transformRequest:i,transformResponse:i,paramsSerializer:i,timeout:i,timeoutMessage:i,withCredentials:i,withXSRFToken:i,adapter:i,responseType:i,xsrfCookieName:i,xsrfHeaderName:i,onUploadProgress:i,onDownloadProgress:i,decompress:i,maxContentLength:i,maxBodyLength:i,beforeRedirect:i,transport:i,httpAgent:i,httpsAgent:i,cancelToken:i,socketPath:i,allowedSocketPaths:i,responseEncoding:i,validateStatus:s,headers:(e,t,n)=>a(gl(e),gl(t),0,!0)};return As.forEach(Object.keys({...e,...t}),function(r){if("__proto__"===r||"constructor"===r||"prototype"===r)return;const o=As.hasOwnProp(l,r)?l[r]:a,i=o(As.hasOwnProp(e,r)?e[r]:void 0,As.hasOwnProp(t,r)?t[r]:void 0,r);As.isUndefined(i)&&o!==s||(n[r]=i)}),n}const bl=e=>{const t=vl({},e),n=e=>As.hasOwnProp(t,e)?t[e]:void 0,r=n("data");let a=n("withXSRFToken");const o=n("xsrfHeaderName"),i=n("xsrfCookieName");let s=n("headers");const l=n("auth"),c=n("baseURL"),u=n("allowAbsoluteUrls"),d=n("url");if(t.headers=s=ol.from(s),t.url=Bs(hl(c,d,u),e.params,e.paramsSerializer),l&&s.set("Authorization","Basic "+btoa((l.username||"")+":"+(l.password?unescape(encodeURIComponent(l.password)):""))),As.isFormData(r))if(Ws.hasStandardBrowserEnv||Ws.hasStandardBrowserWebWorkerEnv)s.setContentType(void 0);else if(As.isFunction(r.getHeaders)){const e=r.getHeaders(),t=["content-type","content-length"];Object.entries(e).forEach(([e,n])=>{t.includes(e.toLowerCase())&&s.set(e,n)})}if(Ws.hasStandardBrowserEnv&&(As.isFunction(a)&&(a=a(t)),!0===a||null==a&&fl(t.url))){const e=o&&i&&ml.read(i);e&&s.set(o,e)}return t};(Object.getOwnPropertyDescriptor(bl,"name")||{}).writable||Object.defineProperty(bl,"name",{value:"default",configurable:!0});const yl="undefined"!=typeof XMLHttpRequest&&function(e){return new Promise(function(t,n){const r=bl(e);let a=r.data;const o=ol.from(r.headers).normalize();let i,s,l,c,u,{responseType:d,onUploadProgress:p,onDownloadProgress:f}=r;function m(){c&&c(),u&&u(),r.cancelToken&&r.cancelToken.unsubscribe(i),r.signal&&r.signal.removeEventListener("abort",i)}let h=new XMLHttpRequest;function g(){if(!h)return;const r=ol.from("getAllResponseHeaders"in h&&h.getAllResponseHeaders());cl(function(e){t(e),m()},function(e){n(e),m()},{data:d&&"text"!==d&&"json"!==d?h.response:h.responseText,status:h.status,statusText:h.statusText,headers:r,config:e,request:h}),h=null}h.open(r.method.toUpperCase(),r.url,!0),h.timeout=r.timeout,"onloadend"in h?h.onloadend=g:h.onreadystatechange=function(){h&&4===h.readyState&&(0!==h.status||h.responseURL&&0===h.responseURL.indexOf("file:"))&&setTimeout(g)},h.onabort=function(){h&&(n(new Ss("Request aborted",Ss.ECONNABORTED,e,h)),h=null)},h.onerror=function(t){const r=t&&t.message?t.message:"Network Error",a=new Ss(r,Ss.ERR_NETWORK,e,h);a.event=t||null,n(a),h=null},h.ontimeout=function(){let t=r.timeout?"timeout of "+r.timeout+"ms exceeded":"timeout exceeded";const a=r.transitional||zs;r.timeoutErrorMessage&&(t=r.timeoutErrorMessage),n(new Ss(t,a.clarifyTimeoutError?Ss.ETIMEDOUT:Ss.ECONNABORTED,e,h)),h=null},void 0===a&&o.setContentType(null),"setRequestHeader"in h&&As.forEach(o.toJSON(),function(e,t){h.setRequestHeader(t,e)}),As.isUndefined(r.withCredentials)||(h.withCredentials=!!r.withCredentials),d&&"json"!==d&&(h.responseType=r.responseType),f&&([l,u]=ul(f,!0),h.addEventListener("progress",l)),p&&h.upload&&([s,c]=ul(p),h.upload.addEventListener("progress",s),h.upload.addEventListener("loadend",c)),(r.cancelToken||r.signal)&&(i=t=>{h&&(n(!t||t.type?new ll(null,e,h):t),h.abort(),h=null)},r.cancelToken&&r.cancelToken.subscribe(i),r.signal&&(r.signal.aborted?i():r.signal.addEventListener("abort",i)));const v=function(e){const t=/^([-+\w]{1,25})(:?\/\/|:)/.exec(e);return t&&t[1]||""}(r.url);v&&-1===Ws.protocols.indexOf(v)?n(new Ss("Unsupported protocol "+v+":",Ss.ERR_BAD_REQUEST,e)):h.send(a||null)})},wl=(e,t)=>{const{length:n}=e=e?e.filter(Boolean):[];if(t||n){let n,r=new AbortController;const a=function(e){if(!n){n=!0,i();const t=e instanceof Error?e:this.reason;r.abort(t instanceof Ss?t:new ll(t instanceof Error?t.message:t))}};let o=t&&setTimeout(()=>{o=null,a(new Ss(`timeout of ${t}ms exceeded`,Ss.ETIMEDOUT))},t);const i=()=>{e&&(o&&clearTimeout(o),o=null,e.forEach(e=>{e.unsubscribe?e.unsubscribe(a):e.removeEventListener("abort",a)}),e=null)};e.forEach(e=>e.addEventListener("abort",a));const{signal:s}=r;return s.unsubscribe=()=>As.asap(i),s}},El=function*(e,t){let n=e.byteLength;if(!t||n<t)return void(yield e);let r,a=0;for(;a<n;)r=a+t,yield e.slice(a,r),a=r},Rl=(e,t,n,r)=>{const a=async function*(e,t){for await(const n of async function*(e){if(e[Symbol.asyncIterator])return void(yield*e);const t=e.getReader();try{for(;;){const{done:e,value:n}=await t.read();if(e)break;yield n}}finally{await t.cancel()}}(e))yield*El(n,t)}(e,t);let o,i=0,s=e=>{o||(o=!0,r&&r(e))};return new ReadableStream({async pull(e){try{const{done:t,value:r}=await a.next();if(t)return s(),void e.close();let o=r.byteLength;if(n){let e=i+=o;n(e)}e.enqueue(new Uint8Array(r))}catch(e){throw s(e),e}},cancel:e=>(s(e),a.return())},{highWaterMark:2})},{isFunction:xl}=As,Al=(({Request:e,Response:t})=>({Request:e,Response:t}))(As.global),{ReadableStream:Cl,TextEncoder:Sl}=As.global,kl=(e,...t)=>{try{return!!e(...t)}catch(e){return!1}},Ol=e=>{e=As.merge.call({skipUndefined:!0},Al,e);const{fetch:t,Request:n,Response:r}=e,a=t?xl(t):"function"==typeof fetch,o=xl(n),i=xl(r);if(!a)return!1;const s=a&&xl(Cl),l=a&&("function"==typeof Sl?(c=new Sl,e=>c.encode(e)):async e=>new Uint8Array(await new n(e).arrayBuffer()));var c;const u=o&&s&&kl(()=>{let e=!1;const t=new n(Ws.origin,{body:new Cl,method:"POST",get duplex(){return e=!0,"half"}}),r=t.headers.has("Content-Type");return null!=t.body&&t.body.cancel(),e&&!r}),d=i&&s&&kl(()=>As.isReadableStream(new r("").body)),p={stream:d&&(e=>e.body)};a&&["text","arrayBuffer","blob","formData","stream"].forEach(e=>{!p[e]&&(p[e]=(t,n)=>{let r=t&&t[e];if(r)return r.call(t);throw new Ss(`Response type '${e}' is not supported`,Ss.ERR_NOT_SUPPORT,n)})});return async e=>{let{url:a,method:i,data:s,signal:c,cancelToken:f,timeout:m,onDownloadProgress:h,onUploadProgress:g,responseType:v,headers:b,withCredentials:y="same-origin",fetchOptions:w}=bl(e),E=t||fetch;v=v?(v+"").toLowerCase():"text";let R=wl([c,f&&f.toAbortSignal()],m),x=null;const A=R&&R.unsubscribe&&(()=>{R.unsubscribe()});let C;try{if(g&&u&&"get"!==i&&"head"!==i&&0!==(C=await(async(e,t)=>{const r=As.toFiniteNumber(e.getContentLength());return null==r?(async e=>{if(null==e)return 0;if(As.isBlob(e))return e.size;if(As.isSpecCompliantForm(e)){const t=new n(Ws.origin,{method:"POST",body:e});return(await t.arrayBuffer()).byteLength}return As.isArrayBufferView(e)||As.isArrayBuffer(e)?e.byteLength:(As.isURLSearchParams(e)&&(e+=""),As.isString(e)?(await l(e)).byteLength:void 0)})(t):r})(b,s))){let e,t=new n(a,{method:"POST",body:s,duplex:"half"});if(As.isFormData(s)&&(e=t.headers.get("content-type"))&&b.setContentType(e),t.body){const[e,n]=dl(C,ul(pl(g)));s=Rl(t.body,65536,e,n)}}As.isString(y)||(y=y?"include":"omit");const t=o&&"credentials"in n.prototype;if(As.isFormData(s)){const e=b.getContentType();e&&/^multipart\/form-data/i.test(e)&&!/boundary=/i.test(e)&&b.delete("content-type")}const c={...w,signal:R,method:i.toUpperCase(),headers:b.normalize().toJSON(),body:s,duplex:"half",credentials:t?y:void 0};x=o&&new n(a,c);let f=await(o?E(x,w):E(a,c));const m=d&&("stream"===v||"response"===v);if(d&&(h||m&&A)){const e={};["status","statusText","headers"].forEach(t=>{e[t]=f[t]});const t=As.toFiniteNumber(f.headers.get("content-length")),[n,a]=h&&dl(t,ul(pl(h),!0))||[];f=new r(Rl(f.body,65536,n,()=>{a&&a(),A&&A()}),e)}v=v||"text";let S=await p[As.findKey(p,v)||"text"](f,e);return!m&&A&&A(),await new Promise((t,n)=>{cl(t,n,{data:S,headers:ol.from(f.headers),status:f.status,statusText:f.statusText,config:e,request:x})})}catch(t){if(A&&A(),t&&"TypeError"===t.name&&/Load failed|fetch/i.test(t.message))throw Object.assign(new Ss("Network Error",Ss.ERR_NETWORK,e,x,t&&t.response),{cause:t.cause||t});throw Ss.from(t,t&&t.code,e,x,t&&t.response)}}},Pl=new Map,Ml=e=>{let t=e&&e.env||{};const{fetch:n,Request:r,Response:a}=t,o=[r,a,n];let i,s,l=o.length,c=Pl;for(;l--;)i=o[l],s=c.get(i),void 0===s&&c.set(i,s=l?new Map:Ol(t)),c=s;return s},Il=(Ml(),{http:null,xhr:yl,fetch:{get:Ml}});As.forEach(Il,(e,t)=>{if(e){try{Object.defineProperty(e,"name",{value:t})}catch(e){}Object.defineProperty(e,"adapterName",{value:t})}});const Tl=e=>`- ${e}`,_l=e=>As.isFunction(e)||null===e||!1===e,Nl=function(e,t){e=As.isArray(e)?e:[e];const{length:n}=e;let r,a;const o={};for(let i=0;i<n;i++){let n;if(r=e[i],a=r,!_l(r)&&(a=Il[(n=String(r)).toLowerCase()],void 0===a))throw new Ss(`Unknown adapter '${n}'`);if(a&&(As.isFunction(a)||(a=a.get(t))))break;o[n||"#"+i]=a}if(!a){const e=Object.entries(o).map(([e,t])=>`adapter ${e} `+(!1===t?"is not supported by the environment":"is not available in the build"));let t=n?e.length>1?"since :\n"+e.map(Tl).join("\n"):" "+Tl(e[0]):"as no adapter specified";throw new Ss("There is no suitable adapter to dispatch the request "+t,"ERR_NOT_SUPPORT")}return a};function Ll(e){if(e.cancelToken&&e.cancelToken.throwIfRequested(),e.signal&&e.signal.aborted)throw new ll(null,e)}function Dl(e){return Ll(e),e.headers=ol.from(e.headers),e.data=il.call(e,e.transformRequest),-1!==["post","put","patch"].indexOf(e.method)&&e.headers.setContentType("application/x-www-form-urlencoded",!1),Nl(e.adapter||Js.adapter,e)(e).then(function(t){return Ll(e),t.data=il.call(e,e.transformResponse,t),t.headers=ol.from(t.headers),t},function(t){return sl(t)||(Ll(e),t&&t.response&&(t.response.data=il.call(e,e.transformResponse,t.response),t.response.headers=ol.from(t.response.headers))),Promise.reject(t)})}const Bl="1.15.2",Fl={};["object","boolean","number","function","string","symbol"].forEach((e,t)=>{Fl[e]=function(n){return typeof n===e||"a"+(t<1?"n ":" ")+e}});const zl={};Fl.transitional=function(e,t,n){function r(e,t){return"[Axios v"+Bl+"] Transitional option '"+e+"'"+t+(n?". "+n:"")}return(n,a,o)=>{if(!1===e)throw new Ss(r(a," has been removed"+(t?" in "+t:"")),Ss.ERR_DEPRECATED);return t&&!zl[a]&&(zl[a]=!0,console.warn(r(a," has been deprecated since v"+t+" and will be removed in the near future"))),!e||e(n,a,o)}},Fl.spelling=function(e){return(t,n)=>(console.warn(`${n} is likely a misspelling of ${e}`),!0)};const jl={assertOptions:function(e,t,n){if("object"!=typeof e)throw new Ss("options must be an object",Ss.ERR_BAD_OPTION_VALUE);const r=Object.keys(e);let a=r.length;for(;a-- >0;){const o=r[a],i=Object.prototype.hasOwnProperty.call(t,o)?t[o]:void 0;if(i){const t=e[o],n=void 0===t||i(t,o,e);if(!0!==n)throw new Ss("option "+o+" must be "+n,Ss.ERR_BAD_OPTION_VALUE);continue}if(!0!==n)throw new Ss("Unknown option "+o,Ss.ERR_BAD_OPTION)}},validators:Fl},Hl=jl.validators;class Vl{constructor(e){this.defaults=e||{},this.interceptors={request:new Fs,response:new Fs}}async request(e,t){try{return await this._request(e,t)}catch(e){if(e instanceof Error){let t={};Error.captureStackTrace?Error.captureStackTrace(t):t=new Error;const n=(()=>{if(!t.stack)return"";const e=t.stack.indexOf("\n");return-1===e?"":t.stack.slice(e+1)})();try{if(e.stack){if(n){const t=n.indexOf("\n"),r=-1===t?-1:n.indexOf("\n",t+1),a=-1===r?"":n.slice(r+1);String(e.stack).endsWith(a)||(e.stack+="\n"+n)}}else e.stack=n}catch(e){}}throw e}}_request(e,t){"string"==typeof e?(t=t||{}).url=e:t=e||{},t=vl(this.defaults,t);const{transitional:n,paramsSerializer:r,headers:a}=t;void 0!==n&&jl.assertOptions(n,{silentJSONParsing:Hl.transitional(Hl.boolean),forcedJSONParsing:Hl.transitional(Hl.boolean),clarifyTimeoutError:Hl.transitional(Hl.boolean),legacyInterceptorReqResOrdering:Hl.transitional(Hl.boolean)},!1),null!=r&&(As.isFunction(r)?t.paramsSerializer={serialize:r}:jl.assertOptions(r,{encode:Hl.function,serialize:Hl.function},!0)),void 0!==t.allowAbsoluteUrls||(void 0!==this.defaults.allowAbsoluteUrls?t.allowAbsoluteUrls=this.defaults.allowAbsoluteUrls:t.allowAbsoluteUrls=!0),jl.assertOptions(t,{baseUrl:Hl.spelling("baseURL"),withXsrfToken:Hl.spelling("withXSRFToken")},!0),t.method=(t.method||this.defaults.method||"get").toLowerCase();let o=a&&As.merge(a.common,a[t.method]);a&&As.forEach(["delete","get","head","post","put","patch","common"],e=>{delete a[e]}),t.headers=ol.concat(o,a);const i=[];let s=!0;this.interceptors.request.forEach(function(e){if("function"==typeof e.runWhen&&!1===e.runWhen(t))return;s=s&&e.synchronous;const n=t.transitional||zs;n&&n.legacyInterceptorReqResOrdering?i.unshift(e.fulfilled,e.rejected):i.push(e.fulfilled,e.rejected)});const l=[];let c;this.interceptors.response.forEach(function(e){l.push(e.fulfilled,e.rejected)});let u,d=0;if(!s){const e=[Dl.bind(this),void 0];for(e.unshift(...i),e.push(...l),u=e.length,c=Promise.resolve(t);d<u;)c=c.then(e[d++],e[d++]);return c}u=i.length;let p=t;for(;d<u;){const e=i[d++],t=i[d++];try{p=e(p)}catch(e){t.call(this,e);break}}try{c=Dl.call(this,p)}catch(e){return Promise.reject(e)}for(d=0,u=l.length;d<u;)c=c.then(l[d++],l[d++]);return c}getUri(e){return Bs(hl((e=vl(this.defaults,e)).baseURL,e.url,e.allowAbsoluteUrls),e.params,e.paramsSerializer)}}As.forEach(["delete","get","head","options"],function(e){Vl.prototype[e]=function(t,n){return this.request(vl(n||{},{method:e,url:t,data:(n||{}).data}))}}),As.forEach(["post","put","patch"],function(e){function t(t){return function(n,r,a){return this.request(vl(a||{},{method:e,headers:t?{"Content-Type":"multipart/form-data"}:{},url:n,data:r}))}}Vl.prototype[e]=t(),Vl.prototype[e+"Form"]=t(!0)});const Gl=Vl;class ql{constructor(e){if("function"!=typeof e)throw new TypeError("executor must be a function.");let t;this.promise=new Promise(function(e){t=e});const n=this;this.promise.then(e=>{if(!n._listeners)return;let t=n._listeners.length;for(;t-- >0;)n._listeners[t](e);n._listeners=null}),this.promise.then=e=>{let t;const r=new Promise(e=>{n.subscribe(e),t=e}).then(e);return r.cancel=function(){n.unsubscribe(t)},r},e(function(e,r,a){n.reason||(n.reason=new ll(e,r,a),t(n.reason))})}throwIfRequested(){if(this.reason)throw this.reason}subscribe(e){this.reason?e(this.reason):this._listeners?this._listeners.push(e):this._listeners=[e]}unsubscribe(e){if(!this._listeners)return;const t=this._listeners.indexOf(e);-1!==t&&this._listeners.splice(t,1)}toAbortSignal(){const e=new AbortController,t=t=>{e.abort(t)};return this.subscribe(t),e.signal.unsubscribe=()=>this.unsubscribe(t),e.signal}static source(){let e;const t=new ql(function(t){e=t});return{token:t,cancel:e}}}const Ul=ql,Wl={Continue:100,SwitchingProtocols:101,Processing:102,EarlyHints:103,Ok:200,Created:201,Accepted:202,NonAuthoritativeInformation:203,NoContent:204,ResetContent:205,PartialContent:206,MultiStatus:207,AlreadyReported:208,ImUsed:226,MultipleChoices:300,MovedPermanently:301,Found:302,SeeOther:303,NotModified:304,UseProxy:305,Unused:306,TemporaryRedirect:307,PermanentRedirect:308,BadRequest:400,Unauthorized:401,PaymentRequired:402,Forbidden:403,NotFound:404,MethodNotAllowed:405,NotAcceptable:406,ProxyAuthenticationRequired:407,RequestTimeout:408,Conflict:409,Gone:410,LengthRequired:411,PreconditionFailed:412,PayloadTooLarge:413,UriTooLong:414,UnsupportedMediaType:415,RangeNotSatisfiable:416,ExpectationFailed:417,ImATeapot:418,MisdirectedRequest:421,UnprocessableEntity:422,Locked:423,FailedDependency:424,TooEarly:425,UpgradeRequired:426,PreconditionRequired:428,TooManyRequests:429,RequestHeaderFieldsTooLarge:431,UnavailableForLegalReasons:451,InternalServerError:500,NotImplemented:501,BadGateway:502,ServiceUnavailable:503,GatewayTimeout:504,HttpVersionNotSupported:505,VariantAlsoNegotiates:506,InsufficientStorage:507,LoopDetected:508,NotExtended:510,NetworkAuthenticationRequired:511,WebServerIsDown:521,ConnectionTimedOut:522,OriginIsUnreachable:523,TimeoutOccurred:524,SslHandshakeFailed:525,InvalidSslCertificate:526};Object.entries(Wl).forEach(([e,t])=>{Wl[t]=e});const Ql=Wl,Kl=function e(t){const n=new Gl(t),r=Ni(Gl.prototype.request,n);return As.extend(r,Gl.prototype,n,{allOwnKeys:!0}),As.extend(r,n,null,{allOwnKeys:!0}),r.create=function(n){return e(vl(t,n))},r}(Js);Kl.Axios=Gl,Kl.CanceledError=ll,Kl.CancelToken=Ul,Kl.isCancel=sl,Kl.VERSION=Bl,Kl.toFormData=Is,Kl.AxiosError=Ss,Kl.Cancel=Kl.CanceledError,Kl.all=function(e){return Promise.all(e)},Kl.spread=function(e){return function(t){return e.apply(null,t)}},Kl.isAxiosError=function(e){return As.isObject(e)&&!0===e.isAxiosError},Kl.mergeConfig=vl,Kl.AxiosHeaders=ol,Kl.formToJSON=e=>Qs(As.isHTMLForm(e)?new FormData(e):e),Kl.getAdapter=Nl,Kl.HttpStatusCode=Ql,Kl.default=Kl;const Zl=Kl;function Jl(){var e,t,n="function"==typeof Symbol?Symbol:{},r=n.iterator||"@@iterator",a=n.toStringTag||"@@toStringTag";function o(n,r,a,o){var l=r&&r.prototype instanceof s?r:s,c=Object.create(l.prototype);return Xl(c,"_invoke",function(n,r,a){var o,s,l,c=0,u=a||[],d=!1,p={p:0,n:0,v:e,a:f,f:f.bind(e,4),d:function(t,n){return o=t,s=0,l=e,p.n=n,i}};function f(n,r){for(s=n,l=r,t=0;!d&&c&&!a&&t<u.length;t++){var a,o=u[t],f=p.p,m=o[2];n>3?(a=m===r)&&(l=o[(s=o[4])?5:(s=3,3)],o[4]=o[5]=e):o[0]<=f&&((a=n<2&&f<o[1])?(s=0,p.v=r,p.n=o[1]):f<m&&(a=n<3||o[0]>r||r>m)&&(o[4]=n,o[5]=r,p.n=m,s=0))}if(a||n>1)return i;throw d=!0,r}return function(a,u,m){if(c>1)throw TypeError("Generator is already running");for(d&&1===u&&f(u,m),s=u,l=m;(t=s<2?e:l)||!d;){o||(s?s<3?(s>1&&(p.n=-1),f(s,l)):p.n=l:p.v=l);try{if(c=2,o){if(s||(a="next"),t=o[a]){if(!(t=t.call(o,l)))throw TypeError("iterator result is not an object");if(!t.done)return t;l=t.value,s<2&&(s=0)}else 1===s&&(t=o.return)&&t.call(o),s<2&&(l=TypeError("The iterator does not provide a '"+a+"' method"),s=1);o=e}else if((t=(d=p.n<0)?l:n.call(r,p))!==i)break}catch(t){o=e,s=1,l=t}finally{c=1}}return{value:t,done:d}}}(n,a,o),!0),c}var i={};function s(){}function l(){}function c(){}t=Object.getPrototypeOf;var u=[][r]?t(t([][r]())):(Xl(t={},r,function(){return this}),t),d=c.prototype=s.prototype=Object.create(u);function p(e){return Object.setPrototypeOf?Object.setPrototypeOf(e,c):(e.__proto__=c,Xl(e,a,"GeneratorFunction")),e.prototype=Object.create(d),e}return l.prototype=c,Xl(d,"constructor",c),Xl(c,"constructor",l),l.displayName="GeneratorFunction",Xl(c,a,"GeneratorFunction"),Xl(d),Xl(d,a,"Generator"),Xl(d,r,function(){return this}),Xl(d,"toString",function(){return"[object Generator]"}),(Jl=function(){return{w:o,m:p}})()}function Xl(e,t,n,r){var a=Object.defineProperty;try{a({},"",{})}catch(e){a=0}Xl=function(e,t,n,r){function o(t,n){Xl(e,t,function(e){return this._invoke(t,n,e)})}t?a?a(e,t,{value:n,enumerable:!r,configurable:!r,writable:!r}):e[t]=n:(o("next",0),o("throw",1),o("return",2))},Xl(e,t,n,r)}function Yl(e,t,n,r,a,o,i){try{var s=e[o](i),l=s.value}catch(e){return void n(e)}s.done?t(l):Promise.resolve(l).then(r,a)}function $l(e,t){(null==t||t>e.length)&&(t=e.length);for(var n=0,r=Array(t);n<t;n++)r[n]=e[n];return r}const ec=function(e){var t=function(e,t){return function(e){if(Array.isArray(e))return e}(e)||function(e,t){var n=null==e?null:"undefined"!=typeof Symbol&&e[Symbol.iterator]||e["@@iterator"];if(null!=n){var r,a,o,i,s=[],l=!0,c=!1;try{if(o=(n=n.call(e)).next,0===t){if(Object(n)!==n)return;l=!1}else for(;!(l=(r=o.call(n)).done)&&(s.push(r.value),s.length!==t);l=!0);}catch(e){c=!0,a=e}finally{try{if(!l&&null!=n.return&&(i=n.return(),Object(i)!==i))return}finally{if(c)throw a}}return s}}(e,t)||function(e,t){if(e){if("string"==typeof e)return $l(e,t);var n={}.toString.call(e).slice(8,-1);return"Object"===n&&e.constructor&&(n=e.constructor.name),"Map"===n||"Set"===n?Array.from(e):"Arguments"===n||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)?$l(e,t):void 0}}(e,t)||function(){throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.")}()}((0,i.useState)("Loading..."),2),n=t[0],r=t[1],a=new FormData;a.append("nonce",sp_eab_admin_dashboard_localize.nonce),a.append("action","sp_eap_changelog_data");var o=function(){var e=function(e){return function(){var t=this,n=arguments;return new Promise(function(r,a){var o=e.apply(t,n);function i(e){Yl(o,r,a,i,s,"next",e)}function s(e){Yl(o,r,a,i,s,"throw",e)}i(void 0)})}}(Jl().m(function e(t){var n,a,o;return Jl().w(function(e){for(;;)switch(e.p=e.n){case 0:return e.p=0,e.n=1,Zl.post(ajaxurl,t);case 1:n=e.v,a=n.data.changelog,r(a),e.n=3;break;case 2:e.p=2,o=e.v,console.error("Error fetching data:",o.message);case 3:return e.a(2)}},e,null,[[0,2]])}));return function(_x){return e.apply(this,arguments)}}();return(0,i.useEffect)(function(){e&&o(a)},[e]),n};var tc,nc=function(){return React.createElement("svg",{className:"eap-docs-link-icon",xmlns:"http://www.w3.org/2000/svg",width:14,height:14,fill:"none"},React.createElement("path",{stroke:"#757575",strokeLinecap:"round",strokeLinejoin:"round",d:"M8.75 1.458v.875c0 .825 0 1.238.256 1.494.257.256.67.256 1.494.256h.875"}),React.createElement("path",{stroke:"#757575",strokeLinecap:"round",strokeLinejoin:"round",d:"M2.333 9.333V4.667c0-1.65 0-2.475.513-2.988.512-.512 1.337-.512 2.987-.512h2.434c.238 0 .357 0 .465.044.107.045.191.129.36.297l2.233 2.234c.168.168.253.253.297.36.045.107.045.226.045.465v4.766c0 1.65 0 2.475-.513 2.988-.513.512-1.338.512-2.987.512H5.833c-1.65 0-2.475 0-2.987-.512-.513-.513-.513-1.338-.513-2.988ZM4.667 6.417h4.666m-4.666 1.75h4.666m-4.666 1.75H7.1"}))},rc=function(){return React.createElement("svg",{className:"eap-demo-link-icon",xmlns:"http://www.w3.org/2000/svg",width:14,height:14,fill:"none"},React.createElement("path",{stroke:"#757575",strokeLinecap:"round",strokeLinejoin:"round",d:"M6.474 1.75c-2.128.004-3.243.056-3.955.769-.769.768-.769 2.006-.769 4.48 0 2.476 0 3.713.769 4.482.769.769 2.006.769 4.48.769 2.475 0 3.712 0 4.481-.769.712-.712.764-1.827.768-3.956M11.99 2.04 6.446 7.617m5.546-5.579c-.288-.288-2.23-.261-2.64-.255m2.64.255c.288.289.261 2.233.255 2.644"}))},ac=function(){return React.createElement("svg",{className:"eap-video-link-icon",width:14,height:14,viewBox:"0 0 14 14",fill:"none",xmlns:"http://www.w3.org/2000/svg"},React.createElement("g",{clipPath:"url(#VideoPlayIcona)",fill:"#949494"},React.createElement("path",{fillRule:"evenodd",clipRule:"evenodd",d:"M5.067 9.824a.71.71 0 0 1-.362-.641V4.81c0-.348.154-.588.362-.705.209-.118.488-.121.756.032L9.559 6.38l.048.027c.266.152.393.394.393.632 0 .237-.128.48-.393.631l-3.78 2.183a.87.87 0 0 1-.76-.03M8.44 6.828 5.918 5.4l-.143-.082v3.198l.192-.118L8.44 6.995l.149-.083z"}),React.createElement("path",{d:"M12.416 7A5.415 5.415 0 1 0 7 12.415v.985A6.4 6.4 0 1 1 7 .6a6.4 6.4 0 0 1 0 12.8v-.985A5.415 5.415 0 0 0 12.416 7"})),React.createElement("defs",null,React.createElement("clipPath",{id:"VideoPlayIcona"},React.createElement("path",{fill:"#fff",d:"M0 0h14v14H0z"}))))},oc=function(e){var t=e.strokeColor,n=void 0===t?"#757575":t;return React.createElement("svg",{width:20,height:20,viewBox:"0 0 20 20",fill:"none",xmlns:"http://www.w3.org/2000/svg"},React.createElement("path",{d:"M12.917 10a2.917 2.917 0 1 1-5.833 0 2.917 2.917 0 0 1 5.833 0Z",stroke:n}),React.createElement("path",{d:"M17.509 11.747c.435-.117.652-.176.738-.288s.086-.293.086-.653V9.194c0-.36 0-.54-.086-.653s-.303-.17-.738-.288c-1.625-.438-2.643-2.138-2.223-3.752.115-.444.173-.666.118-.797-.055-.13-.213-.22-.53-.399l-1.437-.816c-.31-.176-.465-.264-.604-.245-.14.018-.296.175-.61.488-1.216 1.213-3.229 1.213-4.445 0-.314-.313-.47-.47-.61-.489-.14-.018-.294.07-.604.246l-1.438.816c-.316.18-.474.27-.529.4s.003.352.118.796c.42 1.614-.599 3.314-2.224 3.752-.435.117-.653.176-.739.288s-.085.293-.085.653v1.612c0 .36 0 .54.085.653s.304.17.739.288c1.625.438 2.642 2.138 2.223 3.752-.116.444-.173.666-.118.797.055.13.213.22.529.4l1.437.815c.31.176.466.264.605.246.14-.02.296-.176.61-.49 1.217-1.213 3.23-1.213 4.447 0 .314.314.47.47.61.49.14.018.295-.07.605-.246l1.437-.816c.316-.18.474-.27.53-.4.054-.13-.003-.352-.119-.796-.42-1.614.597-3.314 2.222-3.752Z",stroke:n,strokeLinecap:"round"}))},ic=function(){return React.createElement("svg",{xmlns:"http://www.w3.org/2000/svg",width:234,height:34,viewBox:"0 0 234 34",fill:"none"},React.createElement("g",{clipPath:"url(#Logoa)",fill:"#fff"},React.createElement("path",{d:"M1.185 8.03C.531 8.03 0 8.562 0 9.217v13.69c0 .655.53 1.186 1.185 1.186h29.63c.654 0 1.185-.531 1.185-1.186V9.216c0-.655-.53-1.185-1.185-1.185zm28.868 12.808c0 .654-.53 1.185-1.185 1.185H3.254c-.655 0-1.186-.53-1.186-1.185v-5.66c0-.655.531-1.185 1.186-1.185h25.614c.655 0 1.185.53 1.185 1.185zM0 1.185C0 .531.53 0 1.185 0h29.63C31.469 0 32 .53 32 1.185v3.592c0 .654-.53 1.185-1.185 1.185H1.185C.531 5.962 0 5.432 0 4.777zm0 26.038c0-.654.53-1.185 1.185-1.185h29.63c.654 0 1.185.53 1.185 1.185v3.592c0 .654-.53 1.185-1.185 1.185H1.185C.531 32 0 31.47 0 30.815zm40.517-.254V5.052h13.371v2.153H42.963v7.57h9.02v2.122h-9.02v7.918h10.925v2.154zM68.87 15.915v8.108q.096 1.172 1.842 1.394l-.095 1.868q-2.51 0-3.78-1.266-2.857 1.267-5.716 1.267-2.192 0-3.335-1.236t-1.143-3.547 1.175-3.389q1.175-1.108 3.684-1.362l4.986-.475v-1.362q0-1.615-.699-2.312-.697-.697-1.905-.697-2.54 0-5.272.317l-.985.095-.095-1.805q3.493-.697 6.193-.697t3.907 1.235q1.238 1.236 1.238 3.864m-9.782 6.461q0 2.914 2.414 2.914 2.16 0 4.256-.728l.73-.254v-5.226l-4.7.444q-1.43.127-2.065.823-.635.697-.635 2.027m19.468-9.438q-3.462 0-3.462 2.407 0 1.11.794 1.584.794.443 3.62.95 2.828.475 4.002 1.362 1.176.887 1.176 3.325 0 2.44-1.588 3.58-1.556 1.14-4.574 1.14-1.968 0-4.637-.444l-.952-.158.127-2.059q3.62.538 5.462.538t2.795-.57q.985-.6.985-1.963 0-1.394-.826-1.869-.825-.507-3.62-.95-2.796-.444-3.97-1.299-1.176-.854-1.176-3.167t1.62-3.42q1.652-1.11 4.097-1.109 1.936 0 4.86.443l.888.159-.063 2.027q-3.525-.507-5.558-.507m8.036-1.805h2.382l3.97 13.777h1.048l4.002-13.777h2.382L93.77 34h-2.382l2.064-7.031h-2.35zm13.882 15.836 4.859-21.537h8.321l4.859 21.537h-4.383l-.857-3.896h-7.559l-.857 3.896zm8.257-17.927-2.191 10.23h5.907l-2.191-10.23zm18.061 1.711q1.651 0 4.224.506l.858.19-.127 3.358q-2.51-.255-3.716-.254-2.191 0-2.922.95-.699.92-.699 3.516 0 2.598.699 3.579.73.95 2.954.95l3.684-.253.127 3.389q-3.398.665-5.177.665-3.525 0-5.082-1.964-1.524-1.995-1.524-6.366t1.588-6.303q1.588-1.963 5.113-1.963m14.05 0q1.651 0 4.224.506l.858.19-.127 3.358q-2.51-.255-3.716-.254-2.192 0-2.922.95-.699.92-.699 3.516 0 2.598.699 3.579.73.95 2.953.95l3.685-.253.127 3.389q-3.4.665-5.177.665-3.525 0-5.082-1.964-1.524-1.995-1.524-6.366t1.588-6.303q1.587-1.963 5.113-1.963m8.968 2.185q1.684-2.185 5.622-2.185t5.621 2.185q1.683 2.154 1.683 6.081 0 8.33-7.304 8.33t-7.305-8.33q0-3.927 1.683-6.08m3.272 9.66q.667 1.14 2.35 1.14t2.318-1.14q.667-1.14.667-3.579t-.667-3.547q-.635-1.11-2.318-1.109-1.684 0-2.35 1.109-.636 1.108-.636 3.547t.636 3.579m12.774 4.37V11.133h4.224v1.678q2.668-1.583 5.082-2.058v4.275q-2.573.54-4.415 1.109l-.635.222v10.61zm25.315-22.171v22.17h-4.224v-.664q-2.224 1.044-3.843 1.045-3.462 0-4.828-1.995-1.365-1.996-1.365-6.303 0-4.34 1.619-6.303 1.652-1.995 4.955-1.995 1.016 0 2.826.316l.604.127V4.798zm-4.701 18.37.445-.095v-8.33q-1.747-.316-3.113-.316-2.572 0-2.572 4.56 0 2.471.572 3.516.571 1.045 1.873 1.045 1.334 0 2.795-.38m8.633 3.801V11.133h4.256v15.836zm0-17.863V4.798h4.256v4.308zm9.046 3.832q1.683-2.185 5.621-2.185t5.622 2.185q1.683 2.154 1.683 6.081 0 8.33-7.305 8.33t-7.304-8.33q0-3.927 1.683-6.08m3.271 9.66q.667 1.14 2.35 1.14t2.319-1.14q.666-1.14.667-3.579 0-2.439-.667-3.547-.636-1.11-2.319-1.109-1.683 0-2.35 1.109-.635 1.108-.635 3.547t.635 3.579m17.03 4.37h-4.255V11.133h4.224v.887q2.16-1.267 3.969-1.267 3.177 0 4.383 1.868 1.207 1.87 1.207 5.765v8.583h-4.256v-8.457q0-2.026-.476-2.977-.477-.982-1.906-.982a7.2 7.2 0 0 0-2.509.444l-.381.126z"})),React.createElement("defs",null,React.createElement("clipPath",{id:"Logoa"},React.createElement("path",{fill:"#fff",d:"M0 0h233.978v34H0z"}))))},sc=function(){return React.createElement("svg",{xmlns:"http://www.w3.org/2000/svg",width:15,height:14,viewBox:"0 0 15 14",fill:"none"},React.createElement("g",{clipPath:"url(#clip0_21633_121782)"},React.createElement("path",{d:"M14.8435 7.00002C14.8435 10.8 11.7546 13.8889 7.95466 13.8889C4.48799 13.8889 1.64356 11.3334 1.13245 8.02226C1.06579 7.53338 1.39911 7.08894 1.88801 7.02227C2.37689 6.95561 2.82134 7.28893 2.888 7.77784C3.26578 10.2223 5.39911 12.1112 7.95466 12.1112C10.7769 12.1112 13.0658 9.82228 13.0658 7.00004C13.0658 4.17781 10.7769 1.8889 7.95466 1.8889C6.55466 1.8889 5.28799 2.44444 4.35467 3.35556L4.33243 3.37779L5.46578 4.51113C5.73244 4.77779 5.73244 5.20003 5.46578 5.44446C5.33245 5.57779 5.17689 5.64445 4.9991 5.64445H2.17687C1.44354 5.64445 0.843536 5.04447 0.843536 4.31111V1.48891C0.843536 1.31112 0.9102 1.13336 1.04353 1.02224C1.31018 0.755579 1.73243 0.755579 1.97685 1.02224L3.08797 2.13335L3.1102 2.11112C4.35464 0.866677 6.06575 0.111115 7.95466 0.111115C11.7546 0.111115 14.8435 3.20003 14.8435 7.00002ZM7.95466 3.8889C7.46578 3.8889 7.06577 4.28891 7.06577 4.77779V7.3778L8.44354 8.75557C8.79909 9.11112 9.35466 9.11112 9.71021 8.75557C10.0658 8.40002 10.0658 7.84445 9.71021 7.4889L8.84355 6.62224V4.77779C8.84352 4.28891 8.44354 3.8889 7.95466 3.8889Z",fill:"white"})),React.createElement("defs",null,React.createElement("clipPath",{id:"clip0_21633_121782"},React.createElement("rect",{width:14,height:14,fill:"white",transform:"translate(0.843536)"}))))},lc=function(){return React.createElement("svg",{xmlns:"http://www.w3.org/2000/svg",width:"16",height:"16",fill:"none",viewBox:"0 0 16 16"},React.createElement("path",{stroke:"#2F2F2F",strokeLinecap:"round",strokeLinejoin:"round",strokeWidth:"2",d:"m14.5 1.5-13 13m0-13 13 13"}))},cc=function(){return React.createElement("svg",{xmlns:"http://www.w3.org/2000/svg",width:20,height:20},React.createElement("path",{d:"m5.39 5.382.057 1.6 6.708-.244-7.664 7.664 1.132 1.13 7.666-7.665-.246 6.712 1.6.056.35-9.601-9.603.348Z"}))},uc=function(){return React.createElement("svg",{width:12,height:12,viewBox:"0 0 12 12",fill:"none",xmlns:"http://www.w3.org/2000/svg"},React.createElement("path",{d:"m2 10 8-8m0 6.153V2H3.846",stroke:"currentColor",strokeWidth:1.2,strokeLinecap:"round",strokeLinejoin:"round"}))},dc=function(){return React.createElement("svg",{width:"18",height:"18",viewBox:"0 0 18 18",fill:"none",xmlns:"http://www.w3.org/2000/svg"},React.createElement("g",{clipPath:"url(#clip0_25995_249574)"},React.createElement("path",{d:"M4.65129 4.92767L5.48877 3.93497L13.4466 12.1924L12.3618 12.9285C11.7111 13.5555 9.97594 13.9286 8.90513 13.9088L5.41372 13.8443L4.2773 14.9395C3.73658 15.4606 2.88173 15.4448 2.36962 14.9042C2.24569 14.7772 2.1482 14.6268 2.08282 14.4618C2.01744 14.2968 1.98546 14.1205 1.98874 13.943C1.99202 13.7656 2.03049 13.5905 2.10192 13.4281C2.17335 13.2656 2.27632 13.1189 2.40487 12.9966L3.54129 11.9014L3.60579 8.40995C3.62458 7.39313 4.01876 5.54609 4.65129 4.92767Z",stroke:"currentColor",strokeWidth:"1.5"}),React.createElement("path",{d:"M12.0812 2.49165C12.4413 2.14903 12.4554 1.57936 12.1128 1.21925C11.7702 0.859139 11.2005 0.844959 10.8404 1.18758L11.4608 1.83961L12.0812 2.49165ZM8.23339 4.91026L8.85375 5.56229L12.0812 2.49165L11.4608 1.83961L10.8404 1.18758L7.61302 4.25822L8.23339 4.91026Z",fill:"currentColor"}),React.createElement("path",{d:"M16.7339 7.38227C17.094 7.03965 17.1082 6.46998 16.7656 6.10987C16.423 5.74976 15.8533 5.73558 15.4932 6.0782L16.1136 6.73024L16.7339 7.38227ZM12.8862 9.80088L13.5065 10.4529L16.7339 7.38227L16.1136 6.73024L15.4932 6.0782L12.2658 9.14885L12.8862 9.80088Z",fill:"currentColor"})),React.createElement("defs",null,React.createElement("clipPath",{id:"clip0_25995_249574"},React.createElement("rect",{width:"18",height:"18",fill:"white"}))))},pc=function(){return React.createElement("svg",{xmlns:"http://www.w3.org/2000/svg",width:24,height:24,fill:"none"},React.createElement("path",{fill:"#F26C0D",d:"M1.636 14.182h3.782a.391.391 0 0 0 .364-.364.364.364 0 0 0-.364-.364H1.636a.364.364 0 0 0-.363.364c0 .218.181.364.363.364ZM3.527 19.6a.364.364 0 0 0-.364.363c0 .218.146.364.364.364h7.709l-2.4-.727h-5.31ZM2.945 12c0 .182.146.364.364.364h3.745l.218-.655c-.072-.072-.145-.072-.218-.072H3.31c-.218 0-.364.145-.364.363ZM5.709 16.727l.036-.109H.727a.391.391 0 0 0-.364.364c0 .218.182.364.364.364h4.91c0-.182.036-.4.072-.619ZM1.636 10.509h3.782a.391.391 0 0 0 .364-.364.391.391 0 0 0-.364-.363H1.636a.391.391 0 0 0-.363.363c0 .182.181.364.363.364ZM13.745 4.8l.727-2.4L10.4 4.582l2.4.727c.4.146.837-.073.946-.509Z"}),React.createElement("path",{fill:"#F26C0D",d:"M23.529 5.273a1.22 1.22 0 0 0-.655-.546L15.238 2.4l-.8 2.582c-.255.8-1.091 1.236-1.855.982l-2.582-.8-3.563 11.709c-.073.29-.037.581.072.836.146.255.364.436.655.545l10.618 3.237c.11.036.218.036.327.036.473 0 .91-.29 1.055-.764l4.473-14.69c.036-.255 0-.546-.11-.8Zm-6.182 13.309a.395.395 0 0 1-.437.254l-7.527-2.29a.395.395 0 0 1-.254-.437.395.395 0 0 1 .436-.255l7.527 2.255c.218.073.327.29.255.473Zm.69-2.328a.395.395 0 0 1-.436.255l-7.527-2.291a.395.395 0 0 1-.255-.436.395.395 0 0 1 .437-.255l7.563 2.291c.182.037.291.255.219.437Zm.728-2.327a.395.395 0 0 1-.437.255l-7.527-2.291a.395.395 0 0 1-.254-.437.395.395 0 0 1 .436-.254l7.527 2.29c.182.037.291.255.255.437Zm.69-2.327a.395.395 0 0 1-.436.255l-7.527-2.291a.395.395 0 0 1-.254-.437.395.395 0 0 1 .436-.254l7.527 2.29a.323.323 0 0 1 .255.437Zm.728-2.291c-.036.146-.182.255-.364.255h-.109l-7.527-2.291a.395.395 0 0 1-.255-.437.395.395 0 0 1 .437-.254l7.527 2.29c.218.037.327.219.291.437Zm.69-2.327a.395.395 0 0 1-.435.254l-4.182-1.272A.395.395 0 0 1 16 5.527c.037-.181.255-.29.437-.254l4.181 1.273c.218.036.328.218.255.436Z"}))},fc=function(){return React.createElement("svg",{xmlns:"http://www.w3.org/2000/svg",width:24,height:24,fill:"none"},React.createElement("path",{fill:"#F26C0D",d:"M16.249 4.129a.487.487 0 0 0-.408-.024l-.024.024a.56.56 0 0 0-.168.168l-.984 1.632c-.048.096-.072.216-.048.336.024.12.096.216.192.264a.458.458 0 0 0 .432 0 .56.56 0 0 0 .168-.168l.984-1.632c.048-.096.072-.216.048-.336a.505.505 0 0 0-.192-.264ZM7.344 4.129a.487.487 0 0 1 .408-.024l.024.024a.56.56 0 0 1 .168.168l.984 1.632c.048.096.072.216.048.336a.371.371 0 0 1-.192.264.458.458 0 0 1-.432 0 .56.56 0 0 1-.168-.168L7.2 4.729c-.048-.096-.072-.216-.048-.336a.503.503 0 0 1 .192-.264ZM5.305 8.544c.048 0 .072 0 .12-.024a.371.371 0 0 0 .264-.192.436.436 0 0 0-.168-.6l-1.656-.96a.387.387 0 0 0-.216-.072h-.024c-.144 0-.264.096-.36.216-.048.096-.072.216-.048.336.024.12.096.216.192.264l1.656.96a.536.536 0 0 0 .24.072ZM20.472 6.936a.414.414 0 0 0-.36-.216h-.023a.387.387 0 0 0-.217.072l-1.656.96a.483.483 0 0 0-.216.264c-.024.12-.024.24.048.336.072.144.216.216.384.216.072 0 .144-.024.216-.048l1.656-.96a.372.372 0 0 0 .192-.264c.048-.144.048-.264-.024-.36ZM11.856 3.192a.423.423 0 0 0-.36.192l-.024.024c-.048.072-.048.144-.048.216l-.024 1.92c0 .12.048.216.12.312a.387.387 0 0 0 .312.144c.168 0 .312-.072.384-.216a.387.387 0 0 0 .072-.216l.024-1.92a.506.506 0 0 0-.12-.312c-.12-.096-.216-.144-.336-.144ZM6.48 18.504V21h11.088v-2.496a2.654 2.654 0 0 0-2.688-2.688H9.192c-1.464 0-2.712 1.2-2.712 2.688ZM12.024 14.712a3.104 3.104 0 0 0 3.096-3.096 3.104 3.104 0 0 0-3.096-3.096 3.104 3.104 0 0 0-3.096 3.096c.024 1.704 1.392 3.096 3.096 3.096ZM4.8 15.168a2.433 2.433 0 0 0 2.424-2.424c0-1.32-1.08-2.448-2.424-2.448a2.458 2.458 0 0 0-2.448 2.448c0 1.344 1.104 2.424 2.448 2.424ZM19.272 15.168a2.433 2.433 0 0 0 2.424-2.424c0-1.32-1.104-2.424-2.424-2.424a2.433 2.433 0 0 0-2.424 2.424c0 1.32 1.08 2.424 2.424 2.424ZM2.544 16.056a2.115 2.115 0 0 0-2.112 2.112v1.968h5.184v-1.608c0-1.008.456-1.896 1.152-2.472H2.544ZM21.504 16.056h-4.176a3.253 3.253 0 0 1 1.128 2.472v1.608h5.184v-1.968c0-1.176-.936-2.112-2.136-2.112Z"}))},mc=function(){return React.createElement("svg",{xmlns:"http://www.w3.org/2000/svg",width:16,height:16,fill:"none"},React.createElement("path",{fill:"#fff",d:"M4.934 7.921c.09.025.184.038.283.038h.193c.016 0 .031-.002.047-.003.515 1.61 1.632 2.728 2.93 2.728 1.17 0 2.194-.912 2.761-2.273.193-.137.36-.29.488-.457.062-.005.124-.013.182-.028.443-.11.77-.486.77-.937v-.76c0-.45-.327-.828-.77-.937v-.867c0-1.784-1.543-3.235-3.442-3.235-1.898 0-3.442 1.451-3.442 3.235v.871c-.432.116-.75.49-.75.932v.761c0 .444.318.817.75.933Zm3.442-6.056c1.352 0 2.475.932 2.685 2.147-.586-.893-1.565-1.478-2.675-1.478-1.126 0-2.118.603-2.702 1.518.193-1.235 1.326-2.187 2.692-2.187ZM5.652 6.62c.11.036.236.093.37.187 0 0-.32-1.908.358-2.175 0 0 .936.454 2.006.484 1.07-.03 2.007-.484 2.007-.484.679.267.357 2.175.357 2.175.127-.088.246-.145.35-.181v.63a5.274 5.274 0 0 1-.23.793c-.436.303-1.057.517-1.757.577a.448.448 0 0 0-.376-.206H8.14a.45.45 0 1 0 0 .899h.597a.446.446 0 0 0 .396-.243c.52-.04.993-.157 1.401-.328-.52.88-1.288 1.439-2.147 1.439-1.305 0-2.401-1.286-2.734-3.036v-.53Z"}),React.createElement("path",{fill:"#fff",fillRule:"evenodd",d:"M14.886 14.104v.413a.285.285 0 0 1-.286.285H2.17a.285.285 0 0 1-.284-.285v-.413a4.305 4.305 0 0 1 3.683-3.842l.01-.001c.004 0 .009 0 .013-.002l.18-.02.002.01v.008l.005.043.002.01c.011.101.04.199.088.293.316.796 1.34 2.305 1.942 3.162l.124-1.78a1.045 1.045 0 0 1-.424-.413.822.822 0 0 1-.112-.4s.45.2.908.2c.026 0 .052 0 .079-.002.026.002.052.002.078.002.459 0 .908-.2.908-.2a.822.822 0 0 1-.112.4 1.04 1.04 0 0 1-.424.413l.124 1.78c.602-.857 1.626-2.365 1.942-3.162a.872.872 0 0 0 .088-.293l.003-.023a.561.561 0 0 0 .004-.039l.001-.009.182.02.012.002.01.001a4.304 4.304 0 0 1 3.684 3.842Z",clipRule:"evenodd"}))},hc=function(){return React.createElement("svg",{width:14,height:14,viewBox:"0 0 14 14",fill:"none",xmlns:"http://www.w3.org/2000/svg"},React.createElement("path",{d:"M2.29413 9.17787C2.07639 7.448 1.85865 5.71816 1.6409 3.98829C1.59262 3.60482 1.9496 3.34328 2.20354 3.57608C2.88193 4.19794 3.56029 4.81976 4.23869 5.44162C4.46205 5.64637 4.78027 5.57974 4.93512 5.2958L6.62943 2.18955C6.80848 1.8613 7.20309 1.8613 7.38214 2.18955L9.07644 5.2958C9.23129 5.57974 9.54952 5.64633 9.77288 5.44162C10.4513 4.81976 11.1296 4.19794 11.808 3.57608C12.062 3.34328 12.419 3.60482 12.3707 3.98829C12.153 5.71816 11.9352 7.448 11.7175 9.17787H2.29413Z",fill:"white"}),React.createElement("path",{d:"M11.2259 12.0572H2.78524C2.51391 12.0572 2.29395 11.7884 2.29395 11.4568V10.1377H11.7173V11.4568C11.7172 11.7884 11.4973 12.0572 11.2259 12.0572Z",fill:"white"}))},gc=function(){return React.createElement("svg",{xmlns:"http://www.w3.org/2000/svg",viewBox:"0 0 24 24",className:"my-icon",fill:"none"},React.createElement("path",{stroke:"currentColor",strokeWidth:2.032,d:"M15.326 9.025c.283.518.757.906 1.339 1.028a1.85 1.85 0 0 0 1.476-.324l.178-.145 3.506-3.215-.586 4.658-.552 4.383H3.334L2.195 6.369c1.17 1.071 2.338 2.143 3.507 3.215.458.419 1.063.593 1.654.47.583-.123 1.057-.511 1.34-1.03l3.315-6.078 3.315 6.079Z"}),React.createElement("path",{fill:"currentColor",d:"M20.585 22.275H3.435c-.55 0-.998-.546-.998-1.22v-2.68h19.146v2.68c0 .674-.447 1.22-.998 1.22Z"}))};function vc(e,t){(null==t||t>e.length)&&(t=e.length);for(var n=0,r=Array(t);n<t;n++)r[n]=e[n];return r}var bc=function(){var e;return React.createElement("img",{src:"".concat(null===(e=sp_eab_admin_dashboard_localize)||void 0===e?void 0:e.pluginUrl,"/assets/images/bell-icon.gif"),width:18,height:18,alt:""})},yc=[{title:(0,l.__)("Documentation","easy-accordion-free"),Icon:function(){return React.createElement("svg",{width:16,height:16,viewBox:"0 0 16 16",fill:"none",xmlns:"http://www.w3.org/2000/svg"},React.createElement("g",{clipPath:"url(#clip0_21217_9317)"},React.createElement("path",{fillRule:"evenodd",clipRule:"evenodd",d:"M8.46094 10.7544C9.22699 10.7546 9.84723 11.376 9.84766 12.1411C9.84766 12.9065 9.22728 13.5286 8.46094 13.5288C7.69448 13.5288 7.07324 12.9066 7.07324 12.1411C7.07367 11.3759 7.69477 10.7544 8.46094 10.7544ZM8.46094 11.688C8.21058 11.688 8.00726 11.891 8.00684 12.1411C8.00684 12.3916 8.21034 12.5952 8.46094 12.5952C8.71142 12.595 8.91406 12.3914 8.91406 12.1411C8.91364 11.8911 8.71118 11.6882 8.46094 11.688Z",fill:"#565A5F"}),React.createElement("path",{d:"M4.77832 11.6753C5.03605 11.6753 5.24512 11.8844 5.24512 12.1421C5.24501 12.3997 5.03599 12.6089 4.77832 12.6089H2.9375C2.67985 12.6089 2.47081 12.3997 2.4707 12.1421C2.4707 11.8844 2.67979 11.6753 2.9375 11.6753H4.77832Z",fill:"#565A5F"}),React.createElement("path",{d:"M9.38086 8.91357C9.63857 8.91357 9.84763 9.12266 9.84766 9.38037C9.84766 9.6381 9.63859 9.84717 9.38086 9.84717H2.9375C2.67979 9.84714 2.4707 9.63809 2.4707 9.38037C2.47073 9.12268 2.67981 8.9136 2.9375 8.91357H9.38086Z",fill:"#565A5F"}),React.createElement("path",{d:"M8 7.07275C8.25773 7.07275 8.4668 7.28182 8.4668 7.53955C8.46675 7.79724 8.2577 8.00635 8 8.00635H2.9375C2.67982 8.00632 2.47075 7.79722 2.4707 7.53955C2.4707 7.28183 2.67979 7.07278 2.9375 7.07275H8Z",fill:"#565A5F"}),React.createElement("path",{d:"M9.38086 5.23193C9.63859 5.23193 9.84766 5.441 9.84766 5.69873C9.84753 5.95635 9.63851 6.16553 9.38086 6.16553H2.9375C2.67987 6.1655 2.47083 5.95634 2.4707 5.69873C2.4707 5.44101 2.67979 5.23196 2.9375 5.23193H9.38086Z",fill:"#565A5F"}),React.createElement("path",{d:"M8 2.93018C8.25763 2.93018 8.46664 3.13938 8.4668 3.39697C8.4668 3.65471 8.25773 3.86377 8 3.86377H4.31836C4.06065 3.86374 3.85156 3.65469 3.85156 3.39697C3.85172 3.13939 4.06075 2.9302 4.31836 2.93018H8Z",fill:"#565A5F"}),React.createElement("path",{fillRule:"evenodd",clipRule:"evenodd",d:"M12.1426 0.629395C12.5098 0.629506 12.8629 0.775663 13.123 1.03564L13.2158 1.13721C13.4181 1.38419 13.5292 1.69469 13.5293 2.01611V2.93701C13.5293 3.19474 13.3202 3.40381 13.0625 3.40381H11.6885V14.9038C11.6882 15.1613 11.4792 15.3705 11.2217 15.3706H1.09668C0.839092 15.3706 0.630119 15.1613 0.629883 14.9038V2.01709C0.629883 1.6497 0.775907 1.29704 1.03613 1.03662C1.29639 0.776532 1.6503 0.629395 2.01758 0.629395H12.1426ZM2.01758 1.56299C1.89732 1.56299 1.78115 1.61111 1.69629 1.6958C1.61154 1.78064 1.56348 1.89633 1.56348 2.01709V14.437H10.7549V2.01611C10.7549 1.93008 10.7637 1.8457 10.7793 1.76416C10.792 1.69515 10.8095 1.62802 10.832 1.56299H2.01758ZM12.1426 1.56299C12.0174 1.56305 11.9044 1.61395 11.8223 1.6958C11.7606 1.7573 11.7165 1.83586 11.6982 1.92432C11.6921 1.95396 11.6885 1.98465 11.6885 2.01611V2.47021H12.5957V2.01611C12.5956 1.89559 12.5483 1.78049 12.4639 1.6958C12.379 1.61105 12.2628 1.5631 12.1426 1.56299Z",fill:"#565A5F"}),React.createElement("path",{fillRule:"evenodd",clipRule:"evenodd",d:"M13.9834 4.31104C14.3505 4.31115 14.7037 4.45747 14.9639 4.71729L15.0566 4.81885C15.2588 5.06575 15.3699 5.37648 15.3701 5.69775V13.5229C15.37 13.6148 15.3429 13.7053 15.292 13.7817L14.3711 15.1626C14.2846 15.292 14.1391 15.3705 13.9834 15.3706C13.8664 15.3705 13.7546 15.3262 13.6699 15.2495L13.5947 15.1626L12.6738 13.7817C12.6229 13.7053 12.5958 13.6148 12.5957 13.5229V5.69775C12.5961 4.93222 13.2175 4.31127 13.9834 4.31104ZM13.5293 13.3823L13.9824 14.063L14.4365 13.3833V7.08643H13.5293V13.3823ZM13.9834 5.24463C13.7331 5.24487 13.5297 5.44753 13.5293 5.69775V6.15186H14.4365V5.69775C14.4363 5.57738 14.3891 5.46205 14.3047 5.37744C14.2199 5.29286 14.1035 5.24474 13.9834 5.24463Z",fill:"#565A5F"})),React.createElement("defs",null,React.createElement("clipPath",{id:"clip0_21217_9317"},React.createElement("rect",{width:16,height:16,fill:"white"}))))},link:"https://easyaccordion.io/docs/"},{title:(0,l.__)("Technical Support","easy-accordion-free"),Icon:function(){return React.createElement("svg",{width:16,height:16,viewBox:"0 0 16 16",fill:"none",xmlns:"http://www.w3.org/2000/svg"},React.createElement("g",{clipPath:"url(#clip0_21217_9324)"},React.createElement("path",{fillRule:"evenodd",clipRule:"evenodd",d:"M7.99993 0.5C10.9174 0.500253 13.3116 2.73401 13.5683 5.58475H14.2287C15.2114 5.58501 16.0084 6.38171 16.0084 7.36441V9.90678C16.0082 10.8893 15.2112 11.6862 14.2287 11.6864H13.5495C13.3072 13.1289 12.0536 14.2286 10.5423 14.2288H9.70411C9.48514 14.9634 8.80564 15.4998 7.99993 15.5C7.01718 15.5 6.22049 14.703 6.22027 13.7203C6.22027 12.7375 7.01705 11.9407 7.99993 11.9407C8.80591 11.9409 9.48538 12.4769 9.70411 13.2119H10.5423C11.5952 13.2116 12.4611 12.411 12.5653 11.3855L12.5762 11.178V6.09322C12.5762 3.56597 10.5271 1.51722 7.99993 1.51695C5.47251 1.51695 3.42366 3.5658 3.42366 6.09322V11.178C3.42344 11.4584 3.19564 11.6862 2.91518 11.6864H1.77112C0.788383 11.6864 -0.00832685 10.8895 -0.00854492 9.90678V7.36441C-0.00854492 6.38154 0.788249 5.58475 1.77112 5.58475H2.43054C2.68731 2.73385 5.08218 0.5 7.99993 0.5ZM7.99993 12.9576C7.5787 12.9576 7.23722 13.2991 7.23722 13.7203C7.23744 14.1414 7.57883 14.4831 7.99993 14.4831C8.4208 14.4828 8.76242 14.1412 8.76264 13.7203C8.76264 13.2993 8.42094 12.9579 7.99993 12.9576ZM1.77112 6.6017C1.34989 6.6017 1.0084 6.94319 1.0084 7.36441V9.90678C1.00862 10.3278 1.35003 10.6695 1.77112 10.6695H2.40671V6.6017H1.77112ZM13.5932 10.6695H14.2287C14.6496 10.6692 14.9912 10.3277 14.9915 9.90678V7.36441C14.9915 6.94335 14.6497 6.60196 14.2287 6.6017H13.5932V10.6695Z",fill:"#565A5F"})),React.createElement("defs",null,React.createElement("clipPath",{id:"clip0_21217_9324"},React.createElement("rect",{width:16,height:16,fill:"white"}))))},link:"https://shapedplugin.com/create-new-ticket/"},{title:(0,l.__)("Setup Wizard","easy-accordion-free"),Icon:function(){return React.createElement("svg",{width:16,height:16,viewBox:"0 0 16 16",fill:"none",xmlns:"http://www.w3.org/2000/svg"},React.createElement("path",{d:"M7.073 2.61a.5.5 0 0 1 .524.046L9.614 4.17l2.395-.816a.498.498 0 0 1 .632.632l-.816 2.394L13.34 8.4a.498.498 0 0 1-.403.797l-2.524-.027-1.472 2.066a.498.498 0 0 1-.882-.142l-.267-.866-5.348 5.35a1.432 1.432 0 0 1-2.025-2.025l5.349-5.349-.865-.266a.498.498 0 0 1-.142-.882l2.066-1.473L6.8 3.059a.5.5 0 0 1 .273-.45m-5.95 11.646a.436.436 0 0 0 .617.617L7.46 9.15l-.145-.47-.47-.146zm10.142-1.621v-.436h-.435a.498.498 0 0 1 0-.995h.435v-.436a.498.498 0 0 1 .997 0v.436h.435a.498.498 0 1 1 0 .995h-.435v.436a.498.498 0 0 1-.997 0M7.826 5.83a.5.5 0 0 1-.208.41L6.159 7.28l.687.212.003.001 1.012.313.058.021c.13.058.229.17.271.308l.31 1.009.003.009.211.684 1.04-1.458.038-.046a.5.5 0 0 1 .373-.162l1.772.018-1.066-1.42a.5.5 0 0 1-.074-.46l.574-1.684-1.685.574a.5.5 0 0 1-.46-.074L7.806 4.06zm6.241 1.202v-.435h-.435a.498.498 0 0 1 0-.996h.435v-.436a.498.498 0 0 1 .996 0v.436h.436a.498.498 0 0 1 0 .996h-.436v.435a.498.498 0 0 1-.996 0M3.796 5.166V4.73h-.435a.498.498 0 0 1 0-.996h.436V3.3a.498.498 0 0 1 .995 0v.435h.436a.498.498 0 0 1 0 .996h-.436v.436a.498.498 0 1 1-.995 0m5.602-2.8V1.93h-.435a.498.498 0 0 1 0-.996h.435V.498a.498.498 0 0 1 .996 0v.436h.436a.498.498 0 0 1 0 .996h-.436v.435a.498.498 0 0 1-.996 0",fill:"#565a5f"}))},link:"".concat(null===(tc=sp_eab_admin_dashboard_localize)||void 0===tc?void 0:tc.homeUrl,"wp-admin/admin.php?page=eap_dashboard#setupwizard")},{title:(0,l.__)("Public Roadmap","easy-accordion-free"),Icon:function(){return React.createElement("svg",{width:13,height:16,viewBox:"0 0 13 16",fill:"none",xmlns:"http://www.w3.org/2000/svg"},React.createElement("path",{d:"M9 12.667H12V11H9V12.667ZM1 10.667H4V9H1V10.667ZM9 6.66699H12V5H9V6.66699ZM1 4.66699H4V3H1V4.66699ZM5 3.33301H6V0.5C6 0.223858 6.22386 0 6.5 0C6.77614 0 7 0.223858 7 0.5V5.33301H8V4.83301C8.00018 4.37303 8.37303 4.00018 8.83301 4H12.167C12.627 4.00018 12.9998 4.37303 13 4.83301V6.83301C13 7.29314 12.6271 7.66682 12.167 7.66699H8.83301C8.37292 7.66682 8 7.29314 8 6.83301V6.33301H7V11.333H8V10.833C8.00018 10.373 8.37303 10.0002 8.83301 10H12.167C12.627 10.0002 12.9998 10.373 13 10.833V12.833C13 13.2931 12.6271 13.6668 12.167 13.667H8.83301C8.37292 13.6668 8 13.2931 8 12.833V12.333H7V15.167C6.99982 15.443 6.77603 15.667 6.5 15.667C6.22397 15.667 6.00018 15.443 6 15.167V10.333H5V10.833C5 11.2931 4.62708 11.6668 4.16699 11.667H0.833008C0.372921 11.6668 0 11.2931 0 10.833V8.83301C0.000176177 8.37303 0.373028 8.00018 0.833008 8H4.16699C4.62697 8.00018 4.99982 8.37303 5 8.83301V9.33301H6V4.33301H5V4.83301C5 5.29314 4.62708 5.66682 4.16699 5.66699H0.833008C0.37292 5.66682 0 5.29314 0 4.83301V2.83301C0.000175919 2.37303 0.373028 2.00018 0.833008 2H4.16699C4.62697 2.00018 4.99982 2.37303 5 2.83301V3.33301Z",fill:"#565A5F"}))},link:""},{title:(0,l.__)("Request a Feature","easy-accordion-free"),Icon:function(){return React.createElement("svg",{width:15,height:13,viewBox:"0 0 15 13",fill:"none",xmlns:"http://www.w3.org/2000/svg"},React.createElement("path",{d:"M13.5844 0C14.0866 0.00036694 14.5 0.40801 14.5 0.913763V6.85187C14.4998 7.35793 14.0853 7.76526 13.5844 7.76563H13.3142V9.36359C13.3141 9.53876 13.2142 9.6992 13.0575 9.77754C12.9008 9.85571 12.7131 9.83828 12.5731 9.73325L9.95378 7.76563H4.60494C4.34958 7.76555 4.25024 7.55819 4.25 7.30287C4.25 7.04735 4.42774 6.8402 4.68324 6.84012H10.1074C10.2076 6.84018 10.3057 6.87217 10.3858 6.93231L12.3887 8.43807V7.30287C12.3887 7.0473 12.5959 6.84012 12.8514 6.84012H13.5745V0.925513H2.932V6.84012H4.74054C4.99578 6.84051 5.2033 7.04754 5.2033 7.30287C5.20306 7.558 4.99563 7.76523 4.74054 7.76563H2.92205C2.41939 7.76563 2.00665 7.35589 2.00648 6.85187V3.82497H0.925513V9.1295H2.26588C2.52133 9.12957 2.72854 9.33681 2.72864 9.59225V10.7275L4.7306 9.22259C4.81073 9.16244 4.90878 9.1295 5.00898 9.1295H10.0975C10.3529 9.12957 10.5601 9.33681 10.5602 9.59225C10.5602 9.84772 10.353 10.0549 10.0975 10.055H5.16263L2.54426 12.0226C2.40408 12.128 2.21577 12.1452 2.0589 12.0669C1.90218 11.9885 1.80312 11.8282 1.80312 11.653V10.055H0.915571C0.413233 10.0548 0 9.64711 0 9.14124V3.81232C0.000100153 3.30683 0.413768 2.89963 0.915571 2.89946H2.00648V0.913763C2.00649 0.408306 2.41983 0 2.92205 0H13.5844Z",fill:"#565A5F"}))},link:"https://shapedplugin.com/contact-us/"},{title:(0,l.__)("Video Tutorials","easy-accordion-free"),Icon:function(){return React.createElement("svg",{width:16,height:16,viewBox:"0 0 16 16",fill:"none",xmlns:"http://www.w3.org/2000/svg"},React.createElement("path",{d:"M1.13145 13.3764C1.13145 14.2004 1.79963 14.8686 2.62363 14.8686H13.3764C13.6888 14.8686 13.9421 15.1218 13.9421 15.4343C13.9421 15.7467 13.6888 16 13.3764 16H2.62363C1.17453 16 0 14.8255 0 13.3764V2.62363C0 2.31119 0.253283 2.0579 0.565723 2.0579C0.878163 2.0579 1.13145 2.31119 1.13145 2.62363V13.3764ZM13.9421 0C15.0786 0 16 0.921355 16 2.0579V11.3185C16 12.455 15.0786 13.3764 13.9421 13.3764H4.68153L4.47152 13.3653C3.43364 13.2601 2.62363 12.3841 2.62363 11.3185V2.0579C2.62363 0.921355 3.54498 0 4.68153 0H13.9421ZM4.68153 1.13145C4.17008 1.13145 3.75507 1.54646 3.75507 2.0579V11.3185C3.75507 11.8299 4.17008 12.2449 4.68153 12.2449H13.9421C14.4535 12.2449 14.8686 11.8299 14.8686 11.3185V2.0579C14.8686 1.54646 14.4535 1.13145 13.9421 1.13145H4.68153ZM6.97155 3.6576C7.11489 3.57824 7.29073 3.58294 7.42976 3.66966L11.6732 6.3174C11.8055 6.40003 11.8855 6.54527 11.8852 6.70125C11.8848 6.85726 11.8039 7.00205 11.6712 7.08409L7.42775 9.70772C7.28864 9.79362 7.11339 9.79729 6.97055 9.71777C6.82778 9.63803 6.73943 9.48641 6.73943 9.32287V4.0525C6.7396 3.88869 6.82829 3.73709 6.97155 3.6576ZM7.64178 8.51297L10.5779 6.69824L7.64178 4.86542V8.51297Z",fill:"#565A5F"}))},link:"https://youtu.be/JEv8hP5NvnY?si=-a4iL5GV-NZmo9bI"},{title:(0,l.__)("What's New","easy-accordion-free"),Icon:function(){return React.createElement("svg",{width:16,height:16,viewBox:"0 0 16 16",fill:"none",xmlns:"http://www.w3.org/2000/svg"},React.createElement("path",{d:"M13.9776 7.99978C13.9776 5.116 11.9304 2.70842 9.2081 2.1506L9.31094 1.65095L9.41278 1.15031C12.6012 1.80351 15 4.62136 15 7.99978C14.9999 11.5229 12.3908 14.4353 8.99743 14.9191L9.19812 15.1734C9.37262 15.3947 9.33473 15.7158 9.11325 15.8904C8.89167 16.0649 8.57026 16.0269 8.39538 15.8057L7.59863 14.7974C7.46615 14.6297 7.45225 14.3973 7.56369 14.215L8.23563 13.1189C8.38311 12.8786 8.69783 12.8032 8.93852 12.9504C9.17904 13.0977 9.25459 13.4121 9.10726 13.6525L8.95949 13.8928C11.8045 13.4342 13.9775 10.971 13.9776 7.99978ZM1 7.99978C1 4.47752 3.60757 1.56443 6.99957 1.0795L6.80088 0.828179C6.62574 0.60702 6.66335 0.285088 6.88475 0.110122C7.10616 -0.0648254 7.42846 -0.0272546 7.60362 0.193895L8.40137 1.20117C8.53414 1.36887 8.54784 1.60209 8.43631 1.78459L7.76637 2.88063C7.61923 3.1212 7.30439 3.19707 7.06347 3.05017C6.82269 2.90317 6.74669 2.58869 6.89374 2.34807L7.04051 2.10572C4.19535 2.5643 2.02239 5.02846 2.02239 7.99978C2.02244 10.8835 4.06964 13.2912 6.7919 13.8489L6.58622 14.8492C3.39803 14.1959 1.00005 11.378 1 7.99978ZM5.65968 10.2218V11.243H4.74711V10.2218H5.65968ZM11.2529 10.2218V11.243H6.57125V10.2218H11.2529ZM5.65968 8.39969V9.42093H4.74711V8.39969H5.65968ZM11.2529 8.39969V9.42093H6.57125V8.39969H11.2529ZM5.65968 6.57862V7.59986H4.74711V6.57862H5.65968ZM11.2529 6.57862V7.59986H6.57125V6.57862H11.2529ZM5.65968 4.75655V5.77779H4.74711V4.75655H5.65968ZM11.2529 4.75655V5.77779H6.57125V4.75655H11.2529Z",fill:"#565A5F"}))},link:"https://easyaccordion.io/changelog/"},{title:(0,l.__)("Blog: Latest News","easy-accordion-free"),Icon:function(){return React.createElement("svg",{width:16,height:16,viewBox:"0 0 16 16",fill:"none",xmlns:"http://www.w3.org/2000/svg"},React.createElement("path",{d:"M8.65039 8.5791C8.78091 8.45177 8.97104 8.40599 9.14551 8.45898L11.6055 9.20605L11.6631 9.22754C11.7193 9.25247 11.7708 9.28828 11.8145 9.33203L15.2383 12.7627H15.2373C15.9207 13.4461 15.9207 14.5539 15.2373 15.2373C14.5966 15.878 13.5829 15.9181 12.8955 15.3574L12.7627 15.2373L9.34473 11.8135C9.28389 11.7525 9.23981 11.6767 9.2168 11.5938L8.51855 9.07129C8.46988 8.89556 8.51987 8.70644 8.65039 8.5791ZM13.2607 14.3203L13.4697 14.5303L13.5264 14.582C13.8209 14.8223 14.2557 14.8049 14.5303 14.5303C14.8232 14.2373 14.8231 13.7626 14.5303 13.4697V13.4688L14.3213 13.2598L13.2607 14.3203ZM10.1455 11.1992L12.5537 13.6133L13.6152 12.5518L11.1943 10.126L9.72363 9.67969L10.1455 11.1992ZM14.75 10.0625V2.375C14.75 1.61561 14.1344 1 13.375 1H2.375C1.61561 1 1 1.61561 1 2.375V13.375C1 14.1344 1.61561 14.75 2.375 14.75H10.0312C10.3074 14.75 10.5312 14.9739 10.5312 15.25C10.5312 15.5261 10.3074 15.75 10.0312 15.75H2.375C1.06333 15.75 5.15407e-07 14.6867 0 13.375V2.375C0 1.06333 1.06333 0 2.375 0H13.375C14.6867 5.15415e-07 15.75 1.06333 15.75 2.375V10.0625C15.75 10.3386 15.5261 10.5625 15.25 10.5625C14.9739 10.5625 14.75 10.3386 14.75 10.0625ZM6.5 7.90625C6.7761 7.9063 7 8.13014 7 8.40625C6.99999 8.68235 6.77609 8.9062 6.5 8.90625H3.625C3.34886 8.90625 3.12501 8.68239 3.125 8.40625C3.125 8.13011 3.34886 7.90625 3.625 7.90625H6.5ZM12.125 5.40625C12.4011 5.4063 12.625 5.63014 12.625 5.90625C12.625 6.18235 12.4011 6.4062 12.125 6.40625H3.625C3.34886 6.40625 3.12501 6.18239 3.125 5.90625C3.125 5.63011 3.34886 5.40625 3.625 5.40625H12.125ZM12.125 2.90625C12.4011 2.9063 12.625 3.13014 12.625 3.40625C12.625 3.68235 12.4011 3.9062 12.125 3.90625H3.625C3.34886 3.90625 3.12501 3.68239 3.125 3.40625C3.125 3.13011 3.34886 2.90625 3.625 2.90625H12.125Z",fill:"#565A5F"}))},link:"https://shapedplugin.com/blog/"},{title:(0,l.__)("Join Community","easy-accordion-free"),Icon:function(){return React.createElement("svg",{width:16,height:16,viewBox:"0 0 16 16",fill:"none",xmlns:"http://www.w3.org/2000/svg"},React.createElement("path",{d:"M10.042 14.5273C10.042 13.4007 9.12664 12.4854 8 12.4854C6.87334 12.4854 5.95801 13.4007 5.95801 14.5273V15.0625H10.042V14.5273ZM9.03711 10.5107C9.03711 9.93841 8.57243 9.47266 8 9.47266C7.42759 9.47267 6.96289 9.93842 6.96289 10.5107C6.96306 11.0831 7.42763 11.5478 8 11.5479C8.57238 11.5479 9.03694 11.0832 9.03711 10.5107ZM5.02051 5.99121C5.02025 4.8649 4.10583 3.95036 2.97949 3.9502C1.85297 3.9502 0.937754 4.8648 0.9375 5.99121V6.52734H5.02051V5.99121ZM5.95801 6.99609C5.95787 7.25486 5.74806 7.46484 5.48926 7.46484H3.05273C2.98287 7.79927 2.9463 8.14612 2.94629 8.50195C2.94629 10.3841 3.97796 12.0274 5.50781 12.8975C5.78106 12.4806 6.15444 12.1348 6.5957 11.8984C6.2431 11.5417 6.02547 11.0516 6.02539 10.5107C6.02539 9.42071 6.90976 8.53517 8 8.53516C9.09026 8.53516 9.97461 9.4207 9.97461 10.5107C9.97453 11.0519 9.75623 11.5417 9.40332 11.8984C9.84476 12.1348 10.2178 12.4806 10.4912 12.8975C12.0215 12.0275 13.0537 10.3844 13.0537 8.50195C13.0537 8.14614 13.0171 7.79927 12.9473 7.46484H10.5107C10.2519 7.46484 10.0421 7.25486 10.042 6.99609V5.99121C10.0421 5.31709 10.2684 4.69665 10.6465 4.19727C9.87654 3.72246 8.97061 3.44824 8 3.44824C7.02909 3.44824 6.12263 3.72218 5.35254 4.19727C5.73087 4.69673 5.9579 5.31687 5.95801 5.99121V6.99609ZM10.9795 6.52734H15.0625V5.99121C15.0622 4.8648 14.147 3.9502 13.0205 3.9502C11.8941 3.95038 10.9797 4.86492 10.9795 5.99121V6.52734ZM4.0166 1.97461C4.01639 1.40256 3.55163 0.937663 2.97949 0.9375C2.40719 0.9375 1.94162 1.40245 1.94141 1.97461C1.94141 2.51132 2.35033 2.95358 2.87305 3.00684L2.97949 3.0127L3.08496 3.00684C3.60783 2.95375 4.0166 2.51144 4.0166 1.97461ZM14.0586 1.97461C14.0584 1.40245 13.5928 0.9375 13.0205 0.9375C12.4484 0.937686 11.9836 1.40257 11.9834 1.97461C11.9834 2.51143 12.3922 2.95373 12.915 3.00684L13.0205 3.0127L13.127 3.00684C13.6497 2.9536 14.0586 2.51134 14.0586 1.97461ZM14.9961 1.97461C14.9961 2.51629 14.7763 3.00639 14.4229 3.36328C15.3609 3.86504 15.9998 4.85385 16 5.99121V6.99609C15.9999 7.25486 15.79 7.46484 15.5312 7.46484H13.8984C13.9575 7.80213 13.9912 8.14833 13.9912 8.50195C13.9912 10.7682 12.7308 12.741 10.875 13.7588C10.9405 14.0042 10.9795 14.2614 10.9795 14.5273V15.5312C10.9795 15.79 10.7695 15.9998 10.5107 16H5.48926C5.23053 15.9998 5.02051 15.79 5.02051 15.5312V14.5273C5.02051 14.2615 5.05856 14.0042 5.12402 13.7588C3.26864 12.7408 2.00879 10.7679 2.00879 8.50195C2.0088 8.14834 2.04253 7.80214 2.10156 7.46484H0.46875C0.209952 7.46484 0.000139104 7.25486 0 6.99609V5.99121C0.000175572 4.85416 0.638542 3.86517 1.57617 3.36328C1.22304 3.00643 1.00391 2.51603 1.00391 1.97461C1.00412 0.884749 1.88936 0 2.97949 0C4.06944 0.000163301 4.95389 0.884844 4.9541 1.97461C4.9541 2.51613 4.73508 3.00642 4.38184 3.36328C4.4768 3.4141 4.56875 3.46981 4.65723 3.53027C5.61228 2.88665 6.76299 2.51074 8 2.51074C9.23672 2.51074 10.3869 2.88693 11.3418 3.53027C11.4305 3.46964 11.523 3.41423 11.6182 3.36328C11.2649 3.00642 11.0459 2.51612 11.0459 1.97461C11.0461 0.884857 11.9306 0.000185742 13.0205 0C14.1106 0 14.9959 0.88475 14.9961 1.97461Z",fill:"#565A5F"}))},link:" https://community.shapedplugin.com/"}];const wc=function(){var e,t=function(e,t){return function(e){if(Array.isArray(e))return e}(e)||function(e,t){var n=null==e?null:"undefined"!=typeof Symbol&&e[Symbol.iterator]||e["@@iterator"];if(null!=n){var r,a,o,i,s=[],l=!0,c=!1;try{if(o=(n=n.call(e)).next,0===t){if(Object(n)!==n)return;l=!1}else for(;!(l=(r=o.call(n)).done)&&(s.push(r.value),s.length!==t);l=!0);}catch(e){c=!0,a=e}finally{try{if(!l&&null!=n.return&&(i=n.return(),Object(i)!==i))return}finally{if(c)throw a}}return s}}(e,t)||function(e,t){if(e){if("string"==typeof e)return vc(e,t);var n={}.toString.call(e).slice(8,-1);return"Object"===n&&e.constructor&&(n=e.constructor.name),"Map"===n||"Set"===n?Array.from(e):"Arguments"===n||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)?vc(e,t):void 0}}(e,t)||function(){throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.")}()}((0,i.useState)(!1),2),n=t[0],r=t[1],a=function(e){return function(){r(e)}},o=ec(n);return React.createElement(React.Fragment,null,React.createElement("div",{className:"sp-eab-green-header-notice"},React.createElement("div",{className:"sp-eab-green-header-notice-content"},React.createElement(bc,null),React.createElement("span",{className:"sp-eab-green-header-notice-text"},React.createElement("strong",null,"You're on Lite")," — unlock the full power at"," ",React.createElement("strong",null,"50% OFF. Lifetime Deal.")," Pay once, Use forever."),React.createElement("a",{className:"sp-eab-green-header-notice-link",href:"https://easyaccordion.io/pricing/?ref=1",target:"_blank",rel:"noopener noreferrer"},(0,l.__)("Upgrade to Pro","easy-accordion-free"),React.createElement(uc,null)))),React.createElement("div",{className:"sp-eab-admin-dashboard-header"},React.createElement("div",{className:"sp-eab-block-setting-header-wrapper sp-d-flex sp-justify-between sp-align-center"},React.createElement("div",{className:"sp-eab-admin-dashboard-header-left sp-d-flex sp-align-center sp-gap-10px"},React.createElement(ic,null),React.createElement("span",{onClick:a(!0),className:"sp-eap-plugin-version"},React.createElement(sc,null),null===(e=sp_eab_admin_dashboard_localize)||void 0===e?void 0:e.pluginVersion),React.createElement(_i,{anchor:"right",open:n,onClose:a(!1),slotProps:{paper:{className:"sp-eab-admin-changelog-wrapper"}}},React.createElement("div",{className:"sp-eab-changelog-heading sp-d-flex sp-justify-between"},React.createElement("p",{className:"sp-eab-changelog-heading-title"},"Latest Updates - Changelog"),React.createElement("button",{className:"sp-eab-changelog-close-btn sp-d-flex sp-align-center sp-cursor-pointer",onClick:a(!1)},React.createElement(lc,null))),React.createElement("div",{className:"sp-eab-changelog-details",dangerouslySetInnerHTML:{__html:o}}))),React.createElement("div",{className:"sp-eab-admin-dashboard-header-right sp-d-flex sp-gap-4px sp-cursor-pointer"},React.createElement(mc,null),React.createElement("span",null,(0,l.__)("Get Help","easy-accordion-free")),React.createElement("div",{className:"sp-eab-help-drop-down sp-d-hidden sp-flex-col"},null==yc?void 0:yc.map(function(e,t){var n=e.title,r=e.link,a=e.Icon;return React.createElement(i.Fragment,{key:t},r&&React.createElement("a",{href:r,target:"_blank",rel:"noopener noreferrer",className:"sp-eap-support-link sp-d-flex sp-align-center sp-gap-10px"},React.createElement(a,null),React.createElement("span",null,n),React.createElement("span",{className:"drop-down-arrow"},React.createElement(cc,null))))}))))))};var Ec=function(e){var t=e.color,n=void 0===t?"#F26C0D":t;return React.createElement("svg",{width:"21",height:"21",viewBox:"0 0 21 21",fill:"none",xmlns:"http://www.w3.org/2000/svg"},React.createElement("path",{d:"M8.228 4.975c-.467-.26-.855.067-.855.594v9.862c0 .527.388.854.855.594l8.27-4.931c.435-.259.435-.883 0-1.142z",fill:n}))},Rc=function(){return React.createElement("svg",{width:12,height:12,viewBox:"0 0 12 12",fill:"none",xmlns:"http://www.w3.org/2000/svg"},React.createElement("path",{d:"m2 10 8-8m0 6.153V2H3.846",stroke:"currentColor",strokeWidth:1.5,strokeLinecap:"round",strokeLinejoin:"round"}))},xc=n(384),Ac=function(){return React.createElement("svg",{viewBox:"0 0 24 24",fill:"none",xmlns:"http://www.w3.org/2000/svg"},React.createElement("path",{d:"M22.35 1.85A.35.35 0 0 0 22 1.5H2a.35.35 0 0 0-.35.35v11.3c0 .193.157.35.35.35h20a.35.35 0 0 0 .35-.35zm1.3 11.3A1.65 1.65 0 0 1 22 14.8H2a1.65 1.65 0 0 1-1.65-1.65V1.85C.35.939 1.089.2 2 .2h20c.911 0 1.65.739 1.65 1.65z",fill:"#ff5b2e",className:"eab-block-icon"}),React.createElement("path",{d:"M18.788 3.147a1 1 0 0 1 1.414-.008l.65.644a.5.5 0 0 1-.704.71l-.65-.643-.643.65a.5.5 0 0 1-.71-.704zM12.5 3.1a.65.65 0 0 1 0 1.3h-9a.65.65 0 0 1 0-1.3zm5 5.657a.6.6 0 1 1 0 1.199h-14a.6.6 0 1 1 0-1.2zm-4 2.312a.5.5 0 1 1 0 1h-10a.5.5 0 0 1 0-1zM23 6.2a.65.65 0 0 1 0 1.3H1a.65.65 0 0 1 0-1.3zm-.65 11.95a.35.35 0 0 0-.35-.35H2a.35.35 0 0 0-.35.35v4c0 .193.157.35.35.35h20a.35.35 0 0 0 .35-.35zm1.3 4A1.65 1.65 0 0 1 22 23.8H2a1.65 1.65 0 0 1-1.65-1.65v-4c0-.911.739-1.65 1.65-1.65h20c.911 0 1.65.739 1.65 1.65z",fill:"#ff5b2e",className:"eab-block-icon"}),React.createElement("path",{d:"M18.082 19.4a.5.5 0 0 1 .707-.007l.663.65q.003.004.016.005.013-.001.016-.005l.67-.644a.5.5 0 0 1 .693.721l-.67.644a1.026 1.026 0 0 1-1.425-.007l-.662-.65a.5.5 0 0 1-.008-.707m-5.582.1a.65.65 0 0 1 0 1.3h-9a.65.65 0 0 1 0-1.3z",fill:"#ff5b2e",className:"eab-block-icon"}))},Cc=function(){return React.createElement("svg",{viewBox:"0 0 24 24",fill:"none",xmlns:"http://www.w3.org/2000/svg"},React.createElement("path",{d:"M14.05 2a.35.35 0 0 0-.35-.35h-12a.35.35 0 0 0-.35.35v20c0 .193.157.35.35.35h12a.35.35 0 0 0 .35-.35zm1.3 20a1.65 1.65 0 0 1-1.65 1.65h-12A1.65 1.65 0 0 1 .05 22V2C.05 1.089.789.35 1.7.35h12c.911 0 1.65.739 1.65 1.65z",fill:"#ff5b2e",className:"eab-block-icon"}),React.createElement("path",{d:"M2.897 5.217a1 1 0 0 1-.008-1.414l.644-.65a.5.5 0 0 1 .71.704l-.643.65.65.642a.5.5 0 0 1-.704.711zm-.047 6.288a.65.65 0 0 1 1.3 0v9a.65.65 0 0 1-1.3 0zm9.85-8.5a.5.5 0 0 1 0 1H8.3a.5.5 0 1 1 0-1zM11.3 4.8a.5.5 0 0 1 0 1h-3a.5.5 0 0 1 0-1zm.5 1.805a.5.5 0 0 1 0 1H8.3a.5.5 0 1 1 0-1zm.9 3a.5.5 0 0 1 0 1H8.3a.5.5 0 0 1 0-1zM11.3 11.4a.5.5 0 0 1 0 1h-3a.5.5 0 0 1 0-1zm.5 1.805a.5.5 0 1 1 0 1H8.3a.5.5 0 0 1 0-1zM5.65 23V1a.65.65 0 0 1 1.3 0v22a.65.65 0 0 1-1.3 0m17-21a.35.35 0 0 0-.35-.35h-3.6a.35.35 0 0 0-.35.35v20c0 .193.157.35.35.35h3.6a.35.35 0 0 0 .35-.35zm1.3 20c0 .911-.74 1.65-1.65 1.65h-3.6A1.65 1.65 0 0 1 17.05 22V2c0-.911.739-1.65 1.65-1.65h3.6c.91 0 1.65.739 1.65 1.65z",fill:"#ff5b2e",className:"eab-block-icon"}),React.createElement("path",{d:"M19.764 3.14a.5.5 0 0 1 .706.013l.644.67a1.026 1.026 0 0 1-.007 1.425l-.65.662a.5.5 0 0 1-.715-.699l.65-.663q.005-.003.006-.016-.001-.013-.005-.016l-.644-.67a.5.5 0 0 1 .015-.706m.086 17.36v-9a.65.65 0 0 1 1.3 0v9a.65.65 0 0 1-1.3 0",fill:"#ff5b2e",className:"eab-block-icon"}))},Sc=function(){return React.createElement("svg",{viewBox:"0 0 24 24",fill:"none",xmlns:"http://www.w3.org/2000/svg"},React.createElement("path",{d:"M14.05 2a.35.35 0 0 0-.35-.35h-12a.35.35 0 0 0-.35.35v20c0 .193.157.35.35.35h12a.35.35 0 0 0 .35-.35zm1.3 20a1.65 1.65 0 0 1-1.65 1.65h-12A1.65 1.65 0 0 1 .05 22V2C.05 1.089.789.35 1.7.35h12c.911 0 1.65.739 1.65 1.65z",fill:"#ff5b2e",className:"eab-block-icon"}),React.createElement("path",{d:"M9.469 14.831a.8.8 0 0 1 1.08.077l.058.069L14.9 20.7l-.8.6-4.155-5.54-3.426 3.428a.8.8 0 0 1-.977.12L3.629 18.16.9 21.8l-.8-.6 2.837-3.784a.8.8 0 0 1 .916-.27l.136.065 1.933 1.16 3.48-3.48zM4.5 13.5a.5.5 0 1 0-1 0 .5.5 0 0 0 1 0m1 0a1.5 1.5 0 1 1-3 0 1.5 1.5 0 0 1 3 0M22.65 2a.35.35 0 0 0-.35-.35h-3.6a.35.35 0 0 0-.35.35v20c0 .193.157.35.35.35h3.6a.35.35 0 0 0 .35-.35zm1.3 20c0 .911-.74 1.65-1.65 1.65h-3.6A1.65 1.65 0 0 1 17.05 22V2c0-.911.739-1.65 1.65-1.65h3.6c.91 0 1.65.739 1.65 1.65z",fill:"#ff5b2e",className:"eab-block-icon"}))},kc=function(){return React.createElement("svg",{xmlns:"http://www.w3.org/2000/svg",fill:"none",viewBox:"0 0 24 24"},React.createElement("path",{stroke:"#FF5B2E",fill:"#fff",strokeWidth:1.5,d:"M6.5 1H2a1 1 0 0 0-1 1v20a1 1 0 0 0 1 1h4.5m11-22H22a1 1 0 0 1 1 1v20a1 1 0 0 1-1 1h-4.5"}),React.createElement("g",{fill:"#FF5B2E"},React.createElement("path",{d:"M5.5 8.513a.5.5 0 0 0-.5.5v6.027a.5.5 0 0 0 .5.5h13a.5.5 0 0 0 .5-.5V9.013a.5.5 0 0 0-.5-.5h-13Zm12.648 5.622a.5.5 0 0 1-.5.5H6.405a.5.5 0 0 1-.5-.5v-2.513a.5.5 0 0 1 .5-.5h11.243a.5.5 0 0 1 .5.5v2.513ZM5 5.5a.5.5 0 0 1 .5-.5h13a.5.5 0 0 1 .5.5v1.608a.5.5 0 0 1-.5.5h-13a.5.5 0 0 1-.5-.5V5.5ZM5 16.892a.5.5 0 0 1 .5-.5h13a.5.5 0 0 1 .5.5V18.5a.5.5 0 0 1-.5.5h-13a.5.5 0 0 1-.5-.5v-1.608Z"})),React.createElement("defs",null,React.createElement("clipPath",{id:"a"},React.createElement("path",{fill:"#fff",d:"M5 5h14v14H5z"}))))},Oc=function(){return React.createElement("svg",{viewBox:"0 0 24 24",fill:"none",xmlns:"http://www.w3.org/2000/svg"},React.createElement("path",{d:"M15.55 1.8a.35.35 0 0 0-.35-.35H8.8a.35.35 0 0 0-.35.35v16.5c0 .193.157.35.35.35h6.4a.35.35 0 0 0 .35-.35zm1.3 16.5a1.65 1.65 0 0 1-1.65 1.65H8.8a1.65 1.65 0 0 1-1.65-1.65V1.8C7.15.889 7.889.15 8.8.15h6.4c.911 0 1.65.739 1.65 1.65z",fill:"#ff5b2e",className:"eab-block-icon"}),React.createElement("path",{d:"M12.84 9.97a.8.8 0 0 1 1.178.011l.062.08 2.33 3.345-.82.572-2.17-3.115-1.35 1.868a.8.8 0 0 1-1.075.207l-1.143-.722-1.442 2.07-.82-.572 1.55-2.226.048-.063a.8.8 0 0 1 1.036-.157l1.145.724 1.406-1.942zM11.5 7.5a.5.5 0 1 0-1 0 .5.5 0 0 0 1 0m1 0a1.5 1.5 0 1 1-3 0 1.5 1.5 0 0 1 3 0m-7.85 8.3V4.3a.35.35 0 0 0-.35-.35H2v-1.3h2.3c.911 0 1.65.739 1.65 1.65v11.5a1.65 1.65 0 0 1-1.65 1.65H2v-1.3h2.3a.35.35 0 0 0 .35-.35m13.4 0V4.3c0-.911.739-1.65 1.65-1.65H22v1.3h-2.3a.35.35 0 0 0-.35.35v11.5c0 .193.157.35.35.35H22v1.3h-2.3a1.65 1.65 0 0 1-1.65-1.65M10 22.5a1 1 0 1 1-2 0 1 1 0 0 1 2 0m3 0a1 1 0 1 1-2 0 1 1 0 0 1 2 0m3 0a1 1 0 1 1-2 0 1 1 0 0 1 2 0",fill:"#ff5b2e",className:"eab-block-icon"}),React.createElement("path",{d:"M22.046 8.446a.5.5 0 0 1 .707 0l.897.897a1 1 0 0 1 0 1.414l-.896.896a.5.5 0 1 1-.708-.707l.897-.896-.897-.896a.5.5 0 0 1 0-.708m-20.808 0a.5.5 0 0 1 .707.708l-.809.807a.126.126 0 0 0 0 .178l.809.808a.5.5 0 0 1-.707.707l-.809-.808a1.126 1.126 0 0 1 0-1.592z",fill:"#ff5b2e",className:"eab-block-icon"}))},Pc=function(){return React.createElement("svg",{xmlns:"http://www.w3.org/2000/svg",fill:"none",viewBox:"0 0 24 24"},React.createElement("path",{fill:"#FF5B2E",className:"eab-block-icon",d:"M22.65 2a.35.35 0 0 0-.35-.35H1.7a.35.35 0 0 0-.35.35v12c0 .193.157.35.35.35h20.6a.35.35 0 0 0 .35-.35V2Zm1.3 12c0 .911-.74 1.65-1.65 1.65H1.7A1.65 1.65 0 0 1 .05 14V2C.05 1.089.789.35 1.7.35h20.6c.91 0 1.65.739 1.65 1.65v12Z"}),React.createElement("path",{fill:"#FF5B2E",className:"eab-block-icon",d:"M8.55 9.3a.15.15 0 0 0-.15-.15H4a.15.15 0 0 0-.15.15v2.4c0 .083.067.15.15.15h4.4a.15.15 0 0 0 .15-.15V9.3Zm1.3 2.4c0 .8-.65 1.45-1.45 1.45H4c-.8 0-1.45-.65-1.45-1.45V9.3c0-.8.65-1.45 1.45-1.45h4.4c.8 0 1.45.65 1.45 1.45v2.4ZM18.988 2.897a1 1 0 0 1 1.414-.008l.65.644a.5.5 0 0 1-.704.71l-.65-.643-.643.65a.5.5 0 0 1-.71-.704l.643-.65ZM12.2 2.85a.65.65 0 0 1 0 1.3h-9a.65.65 0 0 1 0-1.3h9ZM20.2 8.9a.6.6 0 1 1 0 1.2h-8.5a.6.6 0 1 1 0-1.2h8.5ZM18.7 11a.5.5 0 1 1 0 1h-7a.5.5 0 0 1 0-1h7ZM23.3 5.35a.65.65 0 0 1 0 1.3H.7a.65.65 0 0 1 0-1.3h22.6ZM22.65 19a.35.35 0 0 0-.35-.35H1.7a.35.35 0 0 0-.35.35v3c0 .193.157.35.35.35h20.6a.35.35 0 0 0 .35-.35v-3Zm1.3 3c0 .911-.74 1.65-1.65 1.65H1.7A1.65 1.65 0 0 1 .05 22v-3c0-.911.739-1.65 1.65-1.65h20.6c.91 0 1.65.739 1.65 1.65v3Z"}),React.createElement("path",{fill:"#FF5B2E",className:"eab-block-icon",d:"M18.343 19.75a.5.5 0 0 1 .707-.007l.663.65c.002.002.006.005.015.005.01 0 .015-.003.017-.005l.669-.644a.5.5 0 0 1 .693.721l-.67.644a1.026 1.026 0 0 1-1.425-.007l-.662-.65a.5.5 0 0 1-.007-.707ZM12.2 19.85a.65.65 0 0 1 0 1.3h-9a.65.65 0 0 1 0-1.3h9Z"}))},Mc=function(){return React.createElement("svg",{xmlns:"http://www.w3.org/2000/svg",fill:"none",viewBox:"0 0 24 24"},React.createElement("path",{fill:"#FF5B2E",className:"eab-block-icon",d:"M22.35 3.8a.35.35 0 0 0-.35-.35H2a.35.35 0 0 0-.35.35v16.5c0 .193.157.35.35.35h20a.35.35 0 0 0 .35-.35V3.8Zm1.3 16.5c0 .911-.739 1.65-1.65 1.65H2A1.65 1.65 0 0 1 .35 20.3V3.8c0-.911.739-1.65 1.65-1.65h20c.911 0 1.65.739 1.65 1.65v16.5Z"}),React.createElement("path",{fill:"#FF5B2E",className:"eab-block-icon",d:"M6.5 4.8a.5.5 0 0 1 0 1h-3a.5.5 0 0 1 0-1h3ZM6.5 12.8a.5.5 0 1 1 0 1h-3a.5.5 0 0 1 0-1h3ZM6.5 15.3a.5.5 0 1 1 0 1h-3a.5.5 0 0 1 0-1h3ZM6.5 17.8a.5.5 0 1 1 0 1h-3a.5.5 0 0 1 0-1h3Z"}),React.createElement("path",{fill:"#FF5B2E",className:"eab-block-icon",fillRule:"evenodd",d:"M1 7.3h9v4H1v-4Zm5 2a.5.5 0 0 0-.5-.5h-2a.5.5 0 0 0 0 1h2a.5.5 0 0 0 .5-.5Zm1.265-.886a.3.3 0 0 1 .42-.05l.57.45c.15.12.244.291.245.481a.616.616 0 0 1-.238.484l-.565.455a.3.3 0 0 1-.377-.468l.565-.454a.037.037 0 0 0 .008-.01c-.002-.003-.005-.013-.01-.016l-.569-.45a.3.3 0 0 1-.05-.422Z",clipRule:"evenodd"}),React.createElement("path",{fill:"#FF5B2E",className:"eab-block-icon",d:"M20.3 5.3a.5.5 0 0 1 0 1h-7.8a.5.5 0 0 1 0-1h7.8ZM20.3 7.3a.5.5 0 0 1 0 1h-7.8a.5.5 0 0 1 0-1h7.8ZM18.3 9.3a.5.5 0 0 1 0 1h-5.8a.5.5 0 0 1 0-1h5.8ZM20.3 12.3a.5.5 0 1 1 0 1h-7.8a.5.5 0 0 1 0-1h7.8ZM20.3 14.3a.5.5 0 1 1 0 1h-7.8a.5.5 0 0 1 0-1h7.8ZM18.3 16.3a.5.5 0 1 1 0 1h-5.8a.5.5 0 0 1 0-1h5.8ZM9.35 21.3V2.8a.65.65 0 0 1 1.3 0v18.5a.65.65 0 0 1-1.3 0Z"}))},Ic=function(){return React.createElement("svg",{xmlns:"http://www.w3.org/2000/svg",fill:"none",viewBox:"0 0 24 24"},React.createElement("path",{fill:"#FF5B2E",className:"eab-block-icon",d:"M22.65 1.7a.35.35 0 0 0-.35-.35H1.7a.35.35 0 0 0-.35.35v13c0 .193.157.35.35.35h20.6a.35.35 0 0 0 .35-.35v-13Zm1.3 13c0 .911-.74 1.65-1.65 1.65H1.7A1.65 1.65 0 0 1 .05 14.7v-13C.05.789.789.05 1.7.05h20.6c.91 0 1.65.739 1.65 1.65v13Z"}),React.createElement("path",{fill:"#FF5B2E",className:"eab-block-icon",d:"M9.35 9A.35.35 0 0 0 9 8.65H4a.35.35 0 0 0-.35.35v3.5c0 .193.157.35.35.35h5a.35.35 0 0 0 .35-.35V9Zm1.3 3.5c0 .911-.739 1.65-1.65 1.65H4a1.65 1.65 0 0 1-1.65-1.65V9c0-.911.739-1.65 1.65-1.65h5c.911 0 1.65.739 1.65 1.65v3.5Z"}),React.createElement("path",{fill:"#FF5B2E",className:"eab-block-icon",d:"M5.8 9.3a.5.5 0 0 1 0 1h-1a.5.5 0 0 1 0-1h1ZM18.988 2.597a1 1 0 0 1 1.414-.008l.65.644a.5.5 0 0 1-.704.71l-.65-.643-.643.65a.5.5 0 0 1-.71-.704l.643-.65ZM12.2 2.55a.65.65 0 0 1 0 1.3h-9a.65.65 0 0 1 0-1.3h9ZM23.3 5.05a.65.65 0 0 1 0 1.3H.7a.65.65 0 0 1 0-1.3h22.6ZM20.8 12.2a.5.5 0 1 1 0 1h-8.3a.5.5 0 0 1 0-1h8.3ZM13.485 8l.459.889 1.026.142-.743.692.176.977-.918-.461-.918.461.175-.977L12 9.031l1.026-.142.459-.889ZM16.755 8l.459.889 1.026.142-.742.692.175.977-.918-.461-.918.461.175-.977-.742-.692 1.026-.142.459-.889ZM20.025 8l.459.889 1.026.142-.743.692.176.977-.918-.461-.918.461.175-.977-.742-.692 1.026-.142.459-.889ZM22.65 19.3a.35.35 0 0 0-.35-.35H1.7a.35.35 0 0 0-.35.35v3c0 .193.157.35.35.35h20.6a.35.35 0 0 0 .35-.35v-3Zm1.3 3c0 .911-.74 1.65-1.65 1.65H1.7A1.65 1.65 0 0 1 .05 22.3v-3c0-.911.739-1.65 1.65-1.65h20.6c.91 0 1.65.739 1.65 1.65v3Z"}),React.createElement("path",{fill:"#FF5B2E",className:"eab-block-icon",d:"M18.343 20.05a.5.5 0 0 1 .707-.007l.663.65c.002.002.006.005.015.005.01 0 .015-.003.017-.005l.669-.644a.5.5 0 0 1 .693.721l-.67.644a1.026 1.026 0 0 1-1.425-.007l-.662-.65a.5.5 0 0 1-.007-.707ZM12.2 20.15a.65.65 0 0 1 0 1.3h-9a.65.65 0 0 1 0-1.3h9Z"}))},Tc=function(){return React.createElement("svg",{xmlns:"http://www.w3.org/2000/svg",viewBox:"0 0 24 24",fill:"none"},React.createElement("rect",{x:.799805,y:4.5,width:10.1,height:8.15,rx:.6,stroke:"#FF5B2E",strokeWidth:1.3,fill:"none"}),React.createElement("path",{d:"M8.25 6.63919L8.5716 6.31435C8.66874 6.21623 8.82703 6.21543 8.92515 6.31257L9.24999 6.63417",stroke:"#FF5B2E",strokeWidth:.5,strokeLinecap:"round"}),React.createElement("path",{d:"M2.6499 6.44043H6.7499",stroke:"#FF5B2E",strokeWidth:.8,strokeLinecap:"round"}),React.createElement("path",{d:"M2.5498 9.63965H8.84981",stroke:"#FF5B2E",strokeWidth:.6,strokeLinecap:"round"}),React.createElement("path",{d:"M2.5498 10.7461H7.5498",stroke:"#FF5B2E",strokeWidth:.5,strokeLinecap:"round"}),React.createElement("path",{d:"M0.799805 8H10.8998",stroke:"#FF5B2E",strokeWidth:.8,strokeLinecap:"round"}),React.createElement("rect",{x:.799805,y:15.7246,width:10.1,height:3.85,rx:.6,stroke:"#FF5B2E",strokeWidth:1.3,fill:"none"}),React.createElement("path",{d:"M8.25 17.5395L8.5716 17.8644C8.66874 17.9625 8.82703 17.9633 8.92515 17.8661L9.24999 17.5445",stroke:"#FF5B2E",strokeWidth:.5,strokeLinecap:"round"}),React.createElement("path",{d:"M2.6499 17.7393H6.7499",stroke:"#FF5B2E",strokeWidth:.8,strokeLinecap:"round"}),React.createElement("path",{d:"M13.7407 5.3C13.7407 4.85817 14.0989 4.5 14.5407 4.5H22.3999C22.8417 4.5 23.1999 4.85817 23.1999 5.3V18.7365C23.1999 19.1783 22.8417 19.5365 22.3999 19.5365H14.5407C14.0989 19.5365 13.7407 19.1783 13.7407 18.7365V5.3Z",stroke:"#FF5B2E",strokeWidth:1.3,fill:"none"}),React.createElement("path",{d:"M13.7397 18.4798L15.6513 15.8236C15.7163 15.7332 15.8403 15.7088 15.9347 15.7679L17.3106 16.6282C17.3954 16.6812 17.5058 16.6675 17.5751 16.5954L19.9833 14.0855C20.0747 13.9902 20.2301 14.0012 20.3073 14.1083L23.1997 18.1277",stroke:"#FF5B2E",fill:"none"}),React.createElement("circle",{cx:16.5919,cy:12.8463,r:.802113,stroke:"#FF5B2E",strokeWidth:.9}))},_c=function(){return React.createElement("svg",{viewBox:"0 0 24 24",fill:"none",xmlns:"http://www.w3.org/2000/svg"},React.createElement("path",{d:"M20.85 2a.35.35 0 0 0-.35-.35h-17a.35.35 0 0 0-.35.35v20c0 .193.157.35.35.35h17a.35.35 0 0 0 .35-.35zm1.3 20a1.65 1.65 0 0 1-1.65 1.65h-17A1.65 1.65 0 0 1 1.85 22V2c0-.911.739-1.65 1.65-1.65h17c.911 0 1.65.739 1.65 1.65z",fill:"#ff5b2e"}),React.createElement("path",{d:"M11.5 6.3a.5.5 0 0 1 0 1h-6a.5.5 0 0 1 0-1zm0 2.8a.5.5 0 0 1 0 1h-6a.5.5 0 0 1 0-1zm1.5 2.8a.5.5 0 1 1 0 1H5.5a.5.5 0 0 1 0-1zm-1.5-8.4a.5.5 0 0 1 0 1h-6a.5.5 0 0 1 0-1zm5.647 5.988h-1.4q.005-.534.087-.914.088-.381.287-.686.2-.31.54-.633.268-.252.48-.474a2 2 0 0 0 .34-.475q.122-.252.122-.568 0-.357-.117-.598a.78.78 0 0 0-.334-.363 1.05 1.05 0 0 0-.545-.129q-.27 0-.51.111a.9.9 0 0 0-.386.346q-.147.229-.158.598H14q.018-.768.363-1.278.345-.516.932-.767.586-.258 1.312-.258.804 0 1.372.27a1.9 1.9 0 0 1 .873.773q.304.51.304 1.23 0 .516-.199.926-.2.405-.527.756-.329.35-.71.71-.333.297-.45.638a2.5 2.5 0 0 0-.123.785M15.6 11.31q0-.351.234-.586.24-.234.645-.234.404 0 .638.234.24.235.24.586 0 .34-.24.574-.234.235-.639.235-.404 0-.644-.235a.78.78 0 0 1-.234-.574M18 16a.5.5 0 0 0-.5-.5h-3a.5.5 0 0 0-.5.5v3a.5.5 0 0 0 .5.5h3a.5.5 0 0 0 .5-.5zm1 3a1.5 1.5 0 0 1-1.5 1.5h-3A1.5 1.5 0 0 1 13 19v-3a1.5 1.5 0 0 1 1.5-1.5h3A1.5 1.5 0 0 1 19 16z",fill:"#ff5b2e"}),React.createElement("path",{d:"M16.795 16.441a.4.4 0 0 1 .61.518l-1.31 1.549a.54.54 0 0 1-.788.04l-.683-.655a.4.4 0 0 1 .552-.578l.485.465z",fill:"#ff5b2e"}))},Nc=function(){return React.createElement("svg",{viewBox:"0 0 24 24",fill:"none",xmlns:"http://www.w3.org/2000/svg"},React.createElement("rect",{x:.7,y:15.3,width:22.6,height:8,rx:1,stroke:"#ff5b2e",strokeWidth:1.3}),React.createElement("path",{d:"M3.2 17.8h5",stroke:"#ff5b2e",strokeWidth:.8,strokeLinecap:"round"}),React.createElement("path",{d:"M3.2 19.3h14",stroke:"#ff5b2e",strokeLinecap:"round"}),React.createElement("path",{d:"M3.2 21h4M9 21h4",stroke:"#ff5b2e",strokeWidth:.8,strokeLinecap:"round"}),React.createElement("rect",{x:.7,y:.7,width:22.6,height:12,rx:1,stroke:"#ff5b2e",strokeWidth:1.3}),React.createElement("path",{d:"m1 10 4.3-2.793a.3.3 0 0 1 .372.036l2.15 2.085a.3.3 0 0 0 .38.031l7.554-5.24a.3.3 0 0 1 .344.002L23 9",stroke:"#ff5b2e",strokeWidth:1.3}),React.createElement("circle",{cx:8.5,cy:4,r:1,stroke:"#ff5b2e"}))},Lc=function(){return React.createElement("svg",{viewBox:"0 0 24 24",fill:"none",xmlns:"http://www.w3.org/2000/svg"},React.createElement("path",{d:"M14.35 2a.35.35 0 0 0-.35-.35H2a.35.35 0 0 0-.35.35v20c0 .193.157.35.35.35h12a.35.35 0 0 0 .35-.35zm1.3 20A1.65 1.65 0 0 1 14 23.65H2A1.65 1.65 0 0 1 .35 22V2C.35 1.089 1.089.35 2 .35h12c.911 0 1.65.739 1.65 1.65z",fill:"#ff5b2e"}),React.createElement("path",{d:"M10.16 14.8a.5.5 0 0 1 0 1h-4.3a.5.5 0 0 1 0-1zm2-2a.5.5 0 0 1 0 1h-8.3a.5.5 0 0 1 0-1zM4.745 8.6l.459.889 1.026.142-.743.692.176.977-.918-.461-.918.461.176-.977-.743-.692 1.026-.142zm3.27 0 .459.889L9.5 9.63l-.743.692.176.977-.918-.461-.918.461.175-.977-.742-.692 1.026-.142zm3.27 0 .459.889 1.026.142-.742.692.175.977-.918-.461-.918.461.175-.977-.742-.692 1.026-.142zM22.35 2a.35.35 0 0 0-.35-.35h-3a.35.35 0 0 0-.35.35v20c0 .193.157.35.35.35h3a.35.35 0 0 0 .35-.35zm1.3 20A1.65 1.65 0 0 1 22 23.65h-3A1.65 1.65 0 0 1 17.35 22V2c0-.911.739-1.65 1.65-1.65h3c.911 0 1.65.739 1.65 1.65z",fill:"#ff5b2e"}))},Dc=function(){return React.createElement("svg",{viewBox:"0 0 24 24",fill:"none",xmlns:"http://www.w3.org/2000/svg"},React.createElement("rect",{x:1,y:1,width:22,height:22,rx:1,stroke:"#FF5B2E",strokeWidth:1.3}),React.createElement("path",{d:"M3.5 3.5H9.5",stroke:"#FF5B2E",strokeWidth:1.2,strokeLinecap:"round"}),React.createElement("path",{d:"M19.5 3.5H20.5",stroke:"#FF5B2E",strokeWidth:1.2,strokeLinecap:"round"}),React.createElement("path",{d:"M3.5 17.4H9.5",stroke:"#FF5B2E",strokeWidth:1.2,strokeLinecap:"round"}),React.createElement("path",{d:"M19.5 17.4H20.5",stroke:"#FF5B2E",strokeWidth:1.2,strokeLinecap:"round"}),React.createElement("rect",{x:1,y:6,width:22,height:8.8,stroke:"#FF5B2E",strokeWidth:1.3}),React.createElement("path",{d:"M6.5 12.2H13.5",stroke:"#FF5B2E",strokeLinecap:"round"}),React.createElement("path",{d:"M19.5 12.2H20.5",stroke:"#FF5B2E",strokeLinecap:"round"}),React.createElement("path",{d:"M18.7 9.29791L19.3432 8.64823C19.5375 8.45199 19.8541 8.45041 20.0503 8.64469L20.7 9.28788",stroke:"#FF5B2E",strokeWidth:.8,strokeLinecap:"round"}),React.createElement("path",{d:"M3.5 8.90001H9.5",stroke:"#FF5B2E",strokeWidth:1.2,strokeLinecap:"round"}),React.createElement("path",{d:"M15.2 8.90001H16.2",stroke:"#FF5B2E",strokeWidth:1.2,strokeLinecap:"round"}),React.createElement("path",{d:"M18.7 19.9L19.3432 20.5497C19.5375 20.7459 19.8541 20.7475 20.0503 20.5532L20.7 19.91",stroke:"#FF5B2E",strokeWidth:.8,strokeLinecap:"round"}),React.createElement("path",{d:"M3.5 20.3H9.5",stroke:"#FF5B2E",strokeWidth:1.2,strokeLinecap:"round"}),React.createElement("path",{d:"M15.2 20.3H16.2",stroke:"#FF5B2E",strokeWidth:1.2,strokeLinecap:"round"}))},Bc=function(){return React.createElement("svg",{viewBox:"0 0 24 24",fill:"none",xmlns:"http://www.w3.org/2000/svg"},React.createElement("path",{d:"M18.292 10.496a7.796 7.796 0 1 0-15.591 0 7.796 7.796 0 0 0 15.591 0m1.4 0a9.196 9.196 0 1 1-18.392 0 9.196 9.196 0 0 1 18.392 0",fill:"#ff5b2e"}),React.createElement("path",{d:"M17.164 16.52a.7.7 0 1 0-.99.99l4.986 4.985a.7.7 0 0 0 .99-.99zm-6.097-4.302h-1.4q.005-.534.087-.914.088-.381.287-.686.2-.31.54-.633.268-.251.48-.474.216-.228.34-.475.123-.252.123-.568 0-.358-.118-.598a.78.78 0 0 0-.334-.363 1.05 1.05 0 0 0-.545-.129q-.27 0-.51.111a.9.9 0 0 0-.386.346q-.147.228-.158.598H7.92q.018-.768.363-1.278.345-.516.932-.767.586-.258 1.312-.258.804 0 1.372.27a1.9 1.9 0 0 1 .873.773q.304.51.304 1.23 0 .516-.199.926a3.1 3.1 0 0 1-.527.756q-.328.35-.71.71-.333.297-.45.638a2.5 2.5 0 0 0-.123.785M9.52 14.04q0-.351.234-.586.24-.234.645-.234t.638.234q.24.235.24.586 0 .34-.24.574-.234.235-.639.235-.404 0-.644-.235a.78.78 0 0 1-.234-.574",fill:"#ff5b2e"}))},Fc=function(){return React.createElement("svg",{viewBox:"0 0 24 24",fill:"none",xmlns:"http://www.w3.org/2000/svg"},React.createElement("path",{d:"M9.2 12a1.4 1.4 0 1 1-2.8 0 1.4 1.4 0 0 1 2.8 0m4.2 0a1.4 1.4 0 1 1-2.8 0 1.4 1.4 0 0 1 2.8 0m4.2 0a1.4 1.4 0 1 1-2.8 0 1.4 1.4 0 0 1 2.8 0M5.495 15.505a.7.7 0 0 1-.99.99L.858 12.85a1.2 1.2 0 0 1 0-1.698l3.647-3.646a.7.7 0 0 1 .99.99L1.99 12zm13.01 0a.7.7 0 0 0 .99.99l3.647-3.646a1.2 1.2 0 0 0 0-1.698l-3.647-3.646a.7.7 0 0 0-.99.99L22.01 12z",fill:"#ff5b2e"}))},zc=function(){return React.createElement("svg",{viewBox:"0 0 24 24",fill:"none",xmlns:"http://www.w3.org/2000/svg"},React.createElement("path",{d:"M22.65 8a.35.35 0 0 0-.35-.35H1.7a.35.35 0 0 0-.35.35v8c0 .193.157.35.35.35h20.6a.35.35 0 0 0 .35-.35zm1.3 8c0 .911-.74 1.65-1.65 1.65H1.7A1.65 1.65 0 0 1 .05 16V8c0-.911.739-1.65 1.65-1.65h20.6c.91 0 1.65.739 1.65 1.65z",fill:"#ff5b2e"}),React.createElement("path",{d:"M12 11.35a.65.65 0 0 1 0 1.3H5a.65.65 0 0 1 0-1.3zm5.058-1.706a1.21 1.21 0 0 1 1.683-.008l.907.871a.5.5 0 0 1-.694.72l-.906-.87a.213.213 0 0 0-.29 0l-.898.882a.5.5 0 0 1-.7-.715zm-.001 4.713a1.21 1.21 0 0 0 1.683.008l.907-.871a.5.5 0 0 0-.694-.72l-.906.87a.213.213 0 0 1-.29 0l-.898-.882a.5.5 0 0 0-.7.715z",fill:"#ff5b2e"}))},jc={"sp-easy-accordion-pro/faq-search":{icon:React.createElement(Bc,null),title:(0,l.__)("FAQ Search","easy-accordion-free"),docLink:"https://easyaccordion.io/docs/faq-searchchild-block/",demoLink:""},"sp-easy-accordion-pro/ajax-pagination":{icon:React.createElement(Fc,null),title:(0,l.__)("Ajax Pagination","easy-accordion-free"),docLink:"https://easyaccordion.io/docs/ajax-pagination-child-block/",demoLink:""},"sp-easy-accordion-pro/toggle-all":{icon:React.createElement(zc,null),title:(0,l.__)("Toggle All Button","easy-accordion-free"),docLink:"https://easyaccordion.io/docs/toggle-all-buttonchild-block/",demoLink:""},"sp-easy-accordion-pro/accordion-item":{icon:React.createElement(Ac,null),title:(0,l.__)("Accordion Single Item","easy-accordion-free"),docLink:"https://easyaccordion.io/docs/accordion-single-item/",demoLink:""},"sp-easy-accordion-pro/image-accordion-item":{icon:React.createElement(Sc,null),title:(0,l.__)("Single (Image) Accordion Item","easy-accordion-free"),docLink:"https://easyaccordion.io/docs/single-image-accordion-item/",demoLink:""},"sp-easy-accordion-pro/vertical-accordion":{icon:React.createElement(Ac,null),title:(0,l.__)("FAQ / Vertical Accordion","easy-accordion-free"),docLink:"https://easyaccordion.io/docs/vertical-accordion/",demoLink:"https://easyaccordion.io/blocks/#demoId15"},"sp-easy-accordion-pro/horizontal-accordion":{icon:React.createElement(Cc,null),title:(0,l.__)("Horizontal Accordion","easy-accordion-free"),docLink:"https://easyaccordion.io/docs/horizontal-accordion/",demoLink:"https://easyaccordion.io/blocks/#demoId9"},"sp-easy-accordion-pro/image-accordion":{icon:React.createElement(Sc,null),title:(0,l.__)("Image Accordion","easy-accordion-free"),docLink:"https://easyaccordion.io/docs/image-accordion/",demoLink:"https://easyaccordion.io/blocks/#demoId11"},"sp-easy-accordion-pro/accordion-slider":{icon:React.createElement(Oc,null),title:(0,l.__)("Accordion Slider","easy-accordion-free"),docLink:"https://easyaccordion.io/docs/accordion-slider/",demoLink:"https://easyaccordion.io/blocks/#demoId13"},"sp-easy-accordion-pro/sidebar-tab-accordion":{icon:React.createElement(Mc,null),title:(0,l.__)("Sidebar Tab Accordion","easy-accordion-free"),docLink:"https://easyaccordion.io/docs/sidebar-tab-accordion/",demoLink:"https://easyaccordion.io/blocks/#demoId119"},"sp-easy-accordion-pro/post-accordion":{icon:React.createElement(Pc,null),title:(0,l.__)("Post Accordion 01","easy-accordion-free"),docLink:"https://easyaccordion.io/docs/post-accordion-01/",demoLink:"https://easyaccordion.io/blocks/#demoId121"},"sp-easy-accordion-pro/product-accordion":{icon:React.createElement(Ic,null),title:(0,l.__)("Product Accordion 01","easy-accordion-free"),docLink:"https://easyaccordion.io/docs/product-accordion-01/",demoLink:"https://easyaccordion.io/blocks/#demoId123"},"sp-easy-accordion-pro/post-accordion-block-two":{icon:React.createElement(Nc,null),title:(0,l.__)("Post Accordion 02","easy-accordion-free"),docLink:"https://easyaccordion.io/docs/post-accordion-02/",demoLink:"https://easyaccordion.io/blocks/#demoId122"},"sp-easy-accordion-pro/post-accordion-two":{icon:React.createElement(Nc,null),title:(0,l.__)("Post Accordion 02","easy-accordion-free"),docLink:"https://easyaccordion.io/docs/post-accordion-02/",demoLink:"https://easyaccordion.io/blocks/#demoId122"},"sp-easy-accordion-pro/product-accordion-two":{icon:React.createElement(Lc,null),title:(0,l.__)("Product Accordion 02","easy-accordion-free"),docLink:"https://easyaccordion.io/docs/product-accordion-02/",demoLink:"https://easyaccordion.io/blocks/#demoId124"},"sp-easy-accordion-pro/menu-accordion":{icon:React.createElement(Dc,null),title:(0,l.__)("Category or Menu Accordion","easy-accordion-free"),docLink:"https://easyaccordion.io/docs/category-or-menu-accordion/",demoLink:"https://easyaccordion.io/blocks/#demoId125"},"sp-easy-accordion-pro/media-accordion":{icon:React.createElement(Tc,null),title:(0,l.__)("Media Accordion","easy-accordion-free"),docLink:"https://easyaccordion.io/docs/media-accordion/",demoLink:"https://easyaccordion.io/blocks/#demoId120"},"sp-easy-accordion-pro/user-faq-form":{icon:React.createElement(_c,null),title:(0,l.__)("User FAQ Forms","easy-accordion-free"),docLink:"https://easyaccordion.io/docs/user-faq-forms/",demoLink:"https://easyaccordion.io/blocks/#demoId126"},"sp-easy-accordion-pro/user-faq-forms":{icon:React.createElement(_c,null),title:(0,l.__)("User FAQ Forms","easy-accordion-free"),docLink:"https://easyaccordion.io/docs/user-faq-forms/",demoLink:"https://easyaccordion.io/blocks/#demoId126"},"sp-easy-accordion-pro/shortcode":{icon:React.createElement(kc,null),title:(0,l.__)("Easy Accordion Shortcode","easy-accordion-free"),docLink:"https://easyaccordion.io/docs/easy-accordion-shortcode/",demoLink:""}},Hc={modules:{generate_faqs_with_ai:{is_active:!0},saved_templates:{is_active:!0},pattern_library:{is_active:!0}},integrations:{gemini:{is_active:!0,model:"gemini-3.1-flash-lite-preview",api_key:"",max_token:2e3},google_recaptcha:{is_active:!0,site_key_v2:"",secret_key_v2:"",site_key_v3:"",secret_key_v3:""}}},Vc=["sp-easy-accordion-pro/accordion-slider","sp-easy-accordion-pro/media-accordion","sp-easy-accordion-pro/user-faq-form"];const Gc=function(e){var t=e.attributes,n=e.blockShowHideHandler,r=e.isUpcomingBlock,a=void 0!==r&&r,o=e.type,i=void 0===o?"":o,s=t.show,l=t.name;if(jc[l]){var c=jc[l],u=c.icon,d=c.demoLink,p=c.docLink,f=c.title,m=Vc.includes(l);return React.createElement("div",{className:"sp-eab-visibility-setting-card".concat(a?" sp-eab-upcoming-block":""," sp-d-flex sp-justify-between sp-align-center")},m&&React.createElement("div",{className:"sp-eab-pro-blocks-badge"},React.createElement(hc,null),React.createElement("span",null,"PRO")),React.createElement("div",{className:"sp-eab-visibility-setting-card-info sp-d-flex sp-align-center"},React.createElement("div",{className:"sp-eab-visibility-setting-card-icon sp-d-flex sp-align-center"},u),React.createElement("div",{className:"sp-eab-visibility-setting-card-docs"},React.createElement("h4",{className:"sp-eab-visibility-card-label sp-d-flex sp-align-center sp-gap-4px"},React.createElement("span",{className:"sp-eab-visibility-block-name"},f)),React.createElement("ul",{className:"sp-d-flex sp-align-center sp-gap-10px"},(p||a)&&"quick-start"!==i&&React.createElement("li",{className:"sp-eab-doc-link"},React.createElement("a",{className:"sp-d-flex sp-align-center",href:p,target:"_blank",rel:"noreferrer"},React.createElement(nc,null)," Docs")),(d||a)&&React.createElement("li",{className:"sp-eab-demo-link"},React.createElement("a",{className:"sp-d-flex sp-align-center",href:d,target:"_blank",rel:"noreferrer"},React.createElement(rc,null)," ","quick-start"===i?"Live Demo":"Demo"))))),React.createElement("div",{className:"sp-eab-visibility-setting-toggle"},React.createElement(xc.A,{icons:!1,defaultChecked:!a&&!m&&s,onChange:function(){a||m||n(l)},disabled:a||m})))}};var qc="easy-accordion-free/admin-settings";const Uc=window.wp.components;var Wc=function(){return(0,s.useSelect)(function(e){var t;return{deviceType:(null===(t=e("core/editor"))||void 0===t?void 0:t.getDeviceType())||"Desktop"}},[]).deviceType||""},Qc=function(e,t){return Object.keys(e).every(function(n){return e[n]===t[n]})},Kc=function(e){var t,n,r=e.onSave,a=e.onReset,o=e.isChanged;return React.createElement("div",{className:"sp-eap-settings-save-wrapper sp-d-flex sp-align-center sp-justify-start sp-gap-10px"},React.createElement("button",{className:"sp-eap-settings-save-btn sp-d-flex sp-align-center sp-gap-6px sp-cursor-pointer".concat(o?" active":""),onClick:r},React.createElement("img",{src:"".concat(null===(t=sp_eab_admin_dashboard_localize)||void 0===t?void 0:t.pluginUrl,"/admin/views/models/assets/images/save-icon.svg"),alt:(0,l.__)("Save Icon","easy-accordion-free")}),(0,l.__)("Save Changes","easy-accordion-free")),React.createElement("button",{className:"sp-eap-settings-reset-btn sp-d-flex sp-align-center sp-gap-6px sp-cursor-pointer",onClick:function(){window.confirm((0,l.__)("Are you sure you want to reset?","easy-accordion-free"))&&a()}},React.createElement("img",{src:"".concat(null===(n=sp_eab_admin_dashboard_localize)||void 0===n?void 0:n.pluginUrl,"/admin/views/models/assets/images/reset-icon.svg"),alt:(0,l.__)("Reset Icon","easy-accordion-free")}),(0,l.__)("Reset","easy-accordion-free")))},Zc=function(e){var t,n=e.text;return React.createElement("span",{className:"sp-eap-settings-info"},React.createElement("img",{src:"".concat(null===(t=sp_eab_admin_dashboard_localize)||void 0===t?void 0:t.pluginUrl,"/admin/views/models/assets/images/info.svg"),alt:(0,l.__)("Info Text Icon","easy-accordion-free")}),React.createElement("span",{className:"sp-eap-settings-info-text"},n))},Jc=function(e){var t=e.closeModal;return React.createElement(Uc.Modal,{title:(0,l.__)("What We Collect?","easy-accordion-free"),onRequestClose:t,className:"sp-eap-setup-page-modal"},React.createElement("hr",null),React.createElement("p",{className:"modal-description"},(0,l.__)("We collect only non-sensitive diagnostic data and basic plugin usage information. This may include:","easy-accordion-free")),React.createElement("ul",null,React.createElement("li",{className:"modal-description"},(0,l.__)("WordPress & PHP version","easy-accordion-free")),React.createElement("li",{className:"modal-description"},(0,l.__)("Active theme and plugins","easy-accordion-free")),React.createElement("li",{className:"modal-description"},(0,l.__)("General system details","easy-accordion-free")),React.createElement("li",{className:"modal-description"},(0,l.__)("Email address only for sending helpful updates or optional offers.","easy-accordion-free"))),React.createElement("p",{className:"modal-description"},(0,l.__)("This information helps us improve performance, fix issues faster, and ensure Location Weather stays compatible with the popular plugins and themes.","easy-accordion-free")),React.createElement("p",{className:"modal-description"},(0,l.__)("We","easy-accordion-free"),React.createElement("b",null,(0,l.__)("do not collect sensitive personal data,","easy-accordion-free")),(0,l.__)("and","easy-accordion-free"),React.createElement("b",null,(0,l.__)("never send spam","easy-accordion-free")),(0,l.__)("promise.","easy-accordion-free")),React.createElement("p",{className:"modal-description"},React.createElement("b",null,(0,l.__)("Your privacy comes first.","easy-accordion-free"))),React.createElement("a",{href:"https://easyaccordion.io/information-we-collect/",target:"_blank",rel:"noreferrer",className:"modal-description"},(0,l.__)("Learn More","easy-accordion-free"),React.createElement(cc,null)))},Xc=(0,i.memo)(function(e){var t=e.settings,n=e.updateSettingsOption,r=function(e){var t=e.target,r=t.name,a=t.value;n(r,a)};return React.createElement("div",{className:"sp-eap-integrations__modal-recaptcha-page"},React.createElement("span",{className:"sp-eap-recaptcha-dashboard-links sp-d-block"},React.createElement("a",{href:"https://cloud.google.com/security/products/recaptcha",target:"_blank",rel:"noreferrer"},"reCAPTCHA"," "),"is a free anti-spam service of Google that protects your website from spam and abuse.",React.createElement("a",{href:"https://www.google.com/recaptcha/admin/site/745648899#list",target:"_blank",rel:"noreferrer"}," ","Get your API Keys.")),React.createElement("div",{className:"sp-eap-integrations__modal-content-wrapper sp-d-flex sp-flex-col"},React.createElement("div",{className:"sp-eap-integrations__modal-field"},React.createElement("h4",{className:"sp-eap-integrations__modal-input-label"},"reCAPTCHA v2"),React.createElement("div",{className:"sp-eap-integrations__modal-field-row sp-d-flex sp-align-center"},React.createElement("div",{className:"sp-eap-site-secret-key-wrapper"},React.createElement("span",{className:"sp-eap-site-secret-key-label"},(0,l.__)("Site Key v2","easy-accordion-free")),React.createElement("input",{className:"sp-eap-integrations__modal-input",type:"text",placeholder:"Enter site key",name:"site_key_v2",value:null==t?void 0:t.site_key_v2,onChange:r})),React.createElement("div",{className:"sp-eap-site-secret-key-wrapper"},React.createElement("span",{className:"sp-eap-site-secret-key-label"},(0,l.__)("Secret Key v2","easy-accordion-free")),React.createElement("input",{className:"sp-eap-integrations__modal-input",type:"text",placeholder:"Enter secret key",name:"secret_key_v2",value:null==t?void 0:t.secret_key_v2,onChange:r})))),React.createElement("div",{className:"sp-eap-integrations__modal-field"},React.createElement("h4",{className:"sp-eap-integrations__modal-input-label"},"reCAPTCHA v3"),React.createElement("div",{className:"sp-eap-integrations__modal-field-row sp-d-flex sp-align-center"},React.createElement("div",{className:"sp-eap-site-secret-key-wrapper"},React.createElement("span",{className:"sp-eap-site-secret-key-label"},(0,l.__)("Site Key v3","easy-accordion-free")),React.createElement("input",{className:"sp-eap-integrations__modal-input",type:"text",placeholder:"Enter site key",name:"site_key_v3",value:null==t?void 0:t.site_key_v3,onChange:r})),React.createElement("div",{className:"sp-eap-site-secret-key-wrapper"},React.createElement("span",{className:"sp-eap-site-secret-key-label"},(0,l.__)("Secret Key v3","easy-accordion-free")),React.createElement("input",{className:"sp-eap-integrations__modal-input",type:"text",placeholder:"Enter secret key",name:"secret_key_v3",value:null==t?void 0:t.secret_key_v3,onChange:r}))))))}),Yc={chatgpt:{models:[{label:"GPT-5",value:"gpt-5"},{label:"GPT-5 Mini",value:"gpt-5-mini"},{label:"GPT-4.1",value:"gpt-4.1"},{label:"GPT-4.1 Mini",value:"gpt-4.1-mini"},{label:"GPT-5.4",value:"gpt-5.4"},{label:"GPT-5.4 Mini",value:"gpt-5.4-mini"},{label:"GPT-5.4 Nano",value:"gpt-5.4-nano"},{label:"GPT-4o Mini",value:"gpt-4o-mini"},{label:"o3 Mini",value:"o3-mini"}],modelsDocLink:"https://developers.openai.com/api/docs/models",modelFieldHelp:"Choose your AI model (e.g., ChatGPT-4o).",apiKeyDocLink:"https://platform.openai.com/settings/organization/api-keys",apiKeyFieldHelp:"Enter your OpenAI API key. Keep it private & secure."},gemini:{models:[{label:"Gemini 3.1 Flash-Lite",value:"gemini-3.1-flash-lite-preview"},{label:"Gemini 3.1 Pro (Preview)",value:"gemini-3.1-pro-preview"},{label:"Gemini 3.1 Flash",value:"gemini-3.1-flash"},{label:"Gemini 2.5 Pro",value:"gemini-2.5-pro"},{label:"Gemini 2.5 Flash",value:"gemini-2.5-flash"},{label:"Gemini 1.5 Pro",value:"gemini-1.5-pro"},{label:"Gemini 1.5 Flash",value:"gemini-1.5-flash"},{label:"Gemini 1.5 Flash-8B",value:"gemini-1.5-flash-8b"}],modelsDocLink:"https://ai.google.dev/gemini-api/docs/models",modelFieldHelp:"Choose your AI model (e.g., Gemini 3.1 Flash Lite).",apiKeyDocLink:"https://ai.google.dev/gemini-api/docs/api-key",apiKeyFieldHelp:"Enter your Gemini API key. Keep it private & secure."}},$c=(0,i.memo)(function(e){var t=e.openedPopup,n=e.settings,r=e.updateSettingsOption,a=function(e){var t=e.target,n=t.name,a=t.value;r(n,a)},o=Yc[t],i=o.models,s=o.modelsDocLink,l=o.modelFieldHelp,c=o.apiKeyDocLink,u=o.apiKeyFieldHelp;return React.createElement("div",{className:"sp-eap-integrations__modal-chatgpt-api-key-page"},React.createElement("div",{className:"sp-eap-integrations__modal-content-wrapper sp-d-flex sp-flex-col"},React.createElement("div",{className:"sp-eap-integrations__modal-field sp-d-flex sp-align-center sp-justify-between"},React.createElement("h4",{className:"sp-eap-integrations__modal-input-label"},"AI Model"),React.createElement("div",{className:"sp-eap-integrations__modal-field-wrapper sp-d-flex sp-flex-col sp-align-start sp-gap-4px"},React.createElement("select",{className:"sp-eap-integrations__modal-input",name:"model",value:null==n?void 0:n.model,onChange:a},null==i?void 0:i.map(function(e){var t=e.label,n=e.value;return React.createElement("option",{key:n,value:n},t)})),React.createElement("span",{className:"sp-eap-integration-input-help-text sp-d-flex sp-align-center sp-gap-4px"},l,React.createElement("a",{href:s,target:"_blank",rel:"noreferrer"},"Check Models")))),React.createElement("div",{className:"sp-eap-integrations__modal-field sp-d-flex sp-align-center sp-justify-between"},React.createElement("h4",{className:"sp-eap-integrations__modal-input-label"},"API Key"),React.createElement("div",{className:"sp-eap-integrations__modal-field-wrapper sp-d-flex sp-flex-col sp-align-start sp-gap-4px"},React.createElement("input",{className:"sp-eap-integrations__modal-input",type:"text",placeholder:"Place Your API Key",name:"api_key",value:null==n?void 0:n.api_key,onChange:a}),React.createElement("span",{className:"sp-eap-integration-input-help-text sp-d-flex sp-align-center sp-gap-4px"},u,React.createElement("a",{href:c,target:"_blank",rel:"noreferrer"},"Get your key")))),React.createElement("div",{className:"sp-eap-integrations__modal-field sp-d-flex sp-align-center sp-justify-between"},React.createElement("h4",{className:"sp-eap-integrations__modal-input-label"},"Set Max Tokens"),React.createElement("div",{className:"sp-eap-integrations__modal-field-wrapper sp-d-flex sp-flex-col sp-align-start sp-gap-4px"},React.createElement("input",{className:"sp-eap-integrations__modal-input max-token",type:"number",name:"max_token",value:null==n?void 0:n.max_token,onChange:a}),React.createElement("span",{className:"sp-eap-integration-input-help-text"},"FAQs will be generated within the token limit you set.")))))});function eu(e){return eu="function"==typeof Symbol&&"symbol"==typeof Symbol.iterator?function(e){return typeof e}:function(e){return e&&"function"==typeof Symbol&&e.constructor===Symbol&&e!==Symbol.prototype?"symbol":typeof e},eu(e)}function tu(e,t){var n=Object.keys(e);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(e);t&&(r=r.filter(function(t){return Object.getOwnPropertyDescriptor(e,t).enumerable})),n.push.apply(n,r)}return n}function nu(e){for(var t=1;t<arguments.length;t++){var n=null!=arguments[t]?arguments[t]:{};t%2?tu(Object(n),!0).forEach(function(t){ru(e,t,n[t])}):Object.getOwnPropertyDescriptors?Object.defineProperties(e,Object.getOwnPropertyDescriptors(n)):tu(Object(n)).forEach(function(t){Object.defineProperty(e,t,Object.getOwnPropertyDescriptor(n,t))})}return e}function ru(e,t,n){return(t=function(e){var t=function(e){if("object"!=eu(e)||!e)return e;var t=e[Symbol.toPrimitive];if(void 0!==t){var n=t.call(e,"string");if("object"!=eu(n))return n;throw new TypeError("@@toPrimitive must return a primitive value.")}return String(e)}(e);return"symbol"==eu(t)?t:t+""}(t))in e?Object.defineProperty(e,t,{value:n,enumerable:!0,configurable:!0,writable:!0}):e[t]=n,e}var au={apiData:{},isLoading:!1,isSaving:!1};function ou(){var e,t,n="function"==typeof Symbol?Symbol:{},r=n.iterator||"@@iterator",a=n.toStringTag||"@@toStringTag";function o(n,r,a,o){var l=r&&r.prototype instanceof s?r:s,c=Object.create(l.prototype);return iu(c,"_invoke",function(n,r,a){var o,s,l,c=0,u=a||[],d=!1,p={p:0,n:0,v:e,a:f,f:f.bind(e,4),d:function(t,n){return o=t,s=0,l=e,p.n=n,i}};function f(n,r){for(s=n,l=r,t=0;!d&&c&&!a&&t<u.length;t++){var a,o=u[t],f=p.p,m=o[2];n>3?(a=m===r)&&(l=o[(s=o[4])?5:(s=3,3)],o[4]=o[5]=e):o[0]<=f&&((a=n<2&&f<o[1])?(s=0,p.v=r,p.n=o[1]):f<m&&(a=n<3||o[0]>r||r>m)&&(o[4]=n,o[5]=r,p.n=m,s=0))}if(a||n>1)return i;throw d=!0,r}return function(a,u,m){if(c>1)throw TypeError("Generator is already running");for(d&&1===u&&f(u,m),s=u,l=m;(t=s<2?e:l)||!d;){o||(s?s<3?(s>1&&(p.n=-1),f(s,l)):p.n=l:p.v=l);try{if(c=2,o){if(s||(a="next"),t=o[a]){if(!(t=t.call(o,l)))throw TypeError("iterator result is not an object");if(!t.done)return t;l=t.value,s<2&&(s=0)}else 1===s&&(t=o.return)&&t.call(o),s<2&&(l=TypeError("The iterator does not provide a '"+a+"' method"),s=1);o=e}else if((t=(d=p.n<0)?l:n.call(r,p))!==i)break}catch(t){o=e,s=1,l=t}finally{c=1}}return{value:t,done:d}}}(n,a,o),!0),c}var i={};function s(){}function l(){}function c(){}t=Object.getPrototypeOf;var u=[][r]?t(t([][r]())):(iu(t={},r,function(){return this}),t),d=c.prototype=s.prototype=Object.create(u);function p(e){return Object.setPrototypeOf?Object.setPrototypeOf(e,c):(e.__proto__=c,iu(e,a,"GeneratorFunction")),e.prototype=Object.create(d),e}return l.prototype=c,iu(d,"constructor",c),iu(c,"constructor",l),l.displayName="GeneratorFunction",iu(c,a,"GeneratorFunction"),iu(d),iu(d,a,"Generator"),iu(d,r,function(){return this}),iu(d,"toString",function(){return"[object Generator]"}),(ou=function(){return{w:o,m:p}})()}function iu(e,t,n,r){var a=Object.defineProperty;try{a({},"",{})}catch(e){a=0}iu=function(e,t,n,r){function o(t,n){iu(e,t,function(e){return this._invoke(t,n,e)})}t?a?a(e,t,{value:n,enumerable:!r,configurable:!r,writable:!r}):e[t]=n:(o("next",0),o("throw",1),o("return",2))},iu(e,t,n,r)}function su(e,t,n,r,a,o,i){try{var s=e[o](i),l=s.value}catch(e){return void n(e)}s.done?t(l):Promise.resolve(l).then(r,a)}function lu(e){return function(){var t=this,n=arguments;return new Promise(function(r,a){var o=e.apply(t,n);function i(e){su(o,r,a,i,s,"next",e)}function s(e){su(o,r,a,i,s,"throw",e)}i(void 0)})}}var cu=function(e){return{type:"SET_API_DATA",data:e}},uu=function(e){return{type:"SET_LOADING",isLoading:e}},du=function(e){return{type:"SET_SAVING",isSaving:e}},pu=function(){return function(){var e=lu(ou().m(function e(t){var n,r,a,o,i,s;return ou().w(function(e){for(;;)switch(e.p=e.n){case 0:return(n=t.dispatch)(uu(!0)),e.p=1,(o=new FormData).append("nonce",null===(r=sp_eab_admin_dashboard_localize)||void 0===r?void 0:r.nonce),o.append("action","sp_eab_admin_option_update"),o.append("queryData",JSON.stringify({})),e.n=2,Zl.post(null===(a=sp_eab_admin_dashboard_localize)||void 0===a?void 0:a.ajax_url,o);case 2:i=e.v,n(cu(i.data)),e.n=4;break;case 3:e.p=3,s=e.v,console.error("Error fetching data:",s.message);case 4:n(uu(!1));case 5:return e.a(2)}},e,null,[[1,3]])}));return function(_x){return e.apply(this,arguments)}}()},fu=function(e,t){return function(){var n=lu(ou().m(function n(r){var a,o,i,s,l,c;return ou().w(function(n){for(;;)switch(n.p=n.n){case 0:return(a=r.dispatch)(du(!0)),n.p=1,(s=new FormData).append("nonce",null===(o=sp_eab_admin_dashboard_localize)||void 0===o?void 0:o.nonce),s.append("action","sp_eab_admin_option_update"),s.append("queryData",JSON.stringify(e)),void 0!==t&&s.append("editorPreference",t),n.n=2,Zl.post(null===(i=sp_eab_admin_dashboard_localize)||void 0===i?void 0:i.ajax_url,s);case 2:l=n.v,a(cu(l.data)),n.n=4;break;case 3:n.p=3,c=n.v,console.error("Error saving data:",c.message);case 4:a(du(!1));case 5:return n.a(2)}},n,null,[[1,3]])}));return function(e){return n.apply(this,arguments)}}()},mu=function(e){return e.apiData},hu=function(e){var t;return null===(t=e.apiData)||void 0===t?void 0:t.pluginSettings},gu=function(e){var t;return null===(t=e.apiData)||void 0===t?void 0:t.blockVisibility},vu=function(e){var t;return null===(t=e.apiData)||void 0===t?void 0:t.dashboardSettings},bu=function(e){var t;return null===(t=e.apiData)||void 0===t?void 0:t.eapShortcodes},yu=function(e){return e.isLoading},wu=function(e){return e.isSaving},Eu=(0,s.createReduxStore)(qc,{reducer:function(){var e=arguments.length>0&&void 0!==arguments[0]?arguments[0]:au,t=arguments.length>1?arguments[1]:void 0;switch(t.type){case"SET_API_DATA":return nu(nu({},e),{},{apiData:t.data});case"SET_LOADING":return nu(nu({},e),{},{isLoading:t.isLoading});case"SET_SAVING":return nu(nu({},e),{},{isSaving:t.isSaving});default:return e}},actions:a,selectors:o});(0,s.register)(Eu);var Ru=function(){return React.createElement("svg",{width:24,height:24,viewBox:"0 0 24 24",fill:"none",xmlns:"http://www.w3.org/2000/svg"},React.createElement("g",{clipPath:"url(#ProIndicatorIcona)"},React.createElement("path",{d:"m15.35 2.387 6.263 6.262m-4.986 5.828.084.538a4.92 4.92 0 0 1-2.453 5.047l-4.09 2.444.51-3.369M9.523 7.373l-.538-.084a4.92 4.92 0 0 0-5.047 2.453l-2.445 4.09 3.37-.51m12.236-2.285a2.801 2.801 0 1 1-3.962-3.961 2.801 2.801 0 0 1 3.962 3.96m-5.313 3.524a1.537 1.537 0 1 1-2.173-2.172 1.537 1.537 0 0 1 2.173 2.172m-1.152 4.532-5.727-5.727 6.244-7.93A10.56 10.56 0 0 1 22.14 1.86a10.56 10.56 0 0 1-3.574 10.988zm-5.649-.078 1.498-4.072 2.574 2.574z",stroke:"#fff",strokeWidth:1.4,strokeMiterlimit:10,strokeLinecap:"round",strokeLinejoin:"round"})),React.createElement("defs",null,React.createElement("clipPath",{id:"ProIndicatorIcona"},React.createElement("path",{fill:"#fff",d:"M0 0h24v24H0z"}))))},xu=function(){return React.createElement("svg",{width:45,height:20,viewBox:"0 0 45 20",fill:"none",xmlns:"http://www.w3.org/2000/svg"},React.createElement("path",{d:"M34.8.4a9.4 9.4 0 0 1 0 18.8h-25A9.4 9.4 0 0 1 9.8.4z",fill:"#effff5"}),React.createElement("path",{d:"M34.8.4a9.4 9.4 0 0 1 0 18.8h-25A9.4 9.4 0 0 1 9.8.4z",stroke:"#93dcac",strokeWidth:.8}),React.createElement("path",{d:"m5.766 11.667-.56-4.449c-.041-.328.265-.552.483-.353l1.744 1.6c.192.175.464.117.597-.126l1.452-2.662c.154-.282.492-.282.646 0l1.452 2.662c.133.243.405.3.597.125l1.744-1.599c.218-.2.524.025.482.353l-.56 4.449zm7.656 2.468H6.187c-.232 0-.42-.23-.42-.515v-1.13h8.076v1.13c0 .284-.188.515-.42.515m9.131-3.187H20.54v-1.16h2.014q.495 0 .8-.161.312-.167.457-.452.145-.29.145-.66 0-.36-.145-.672a1.17 1.17 0 0 0-.456-.504q-.306-.194-.8-.194h-1.531V13.8h-1.477V5.98h3.007q.914 0 1.558.327.65.322.988.897.345.57.344 1.3 0 .758-.344 1.305a2.2 2.2 0 0 1-.988.844q-.645.295-1.558.295m4.05-4.968h2.842q.891 0 1.53.268.64.27.983.795.344.527.344 1.295 0 .606-.215 1.052a2.05 2.05 0 0 1-.607.747q-.387.3-.913.473l-.462.236h-2.508l-.01-1.166h1.874q.456 0 .757-.16.3-.162.451-.447.156-.284.156-.65 0-.39-.15-.676a1.02 1.02 0 0 0-.457-.446q-.306-.156-.773-.156H28.08V13.8h-1.477zm4.415 7.82-1.81-3.502 1.563-.005 1.832 3.432v.075zm8.91-4.109v.403q0 .886-.235 1.595-.237.704-.672 1.198a2.9 2.9 0 0 1-1.036.757 3.3 3.3 0 0 1-1.338.263q-.724 0-1.332-.263a3 3 0 0 1-1.042-.757 3.5 3.5 0 0 1-.682-1.198 5 5 0 0 1-.242-1.595V9.69q0-.891.242-1.595a3.5 3.5 0 0 1 .677-1.198q.435-.5 1.036-.763a3.3 3.3 0 0 1 1.333-.263q.735 0 1.337.263.6.264 1.036.763.441.495.677 1.198.242.703.242 1.595m-1.492.403V9.68q0-.639-.118-1.122a2.4 2.4 0 0 0-.35-.822 1.5 1.5 0 0 0-.569-.5 1.66 1.66 0 0 0-.762-.171q-.43 0-.763.172a1.5 1.5 0 0 0-.559.499 2.5 2.5 0 0 0-.354.822 4.8 4.8 0 0 0-.119 1.122v.414q0 .634.119 1.123.123.488.354.827.236.333.57.505.332.171.762.171t.763-.171q.333-.172.558-.505.23-.339.35-.828a4.8 4.8 0 0 0 .118-1.122",fill:"#4ab866"}))},Au=function(){return React.createElement("svg",{xmlns:"http://www.w3.org/2000/svg",width:44,height:44,viewBox:"0 0 44 44",fill:"none"},React.createElement("rect",{width:44,height:44,rx:5.5,fill:"url(#AccordionFeaturedIcona)"}),React.createElement("path",{d:"M20.531 10.268c.696-1.119 2.371-1.081 3.001.113l3.256 6.17 6.874 1.189c1.373.238 1.918 1.916.947 2.915l-4.862 5.002.993 6.906c.198 1.379-1.23 2.416-2.48 1.802L22 31.285l-6.26 3.08c-1.25.614-2.678-.423-2.48-1.802l.992-6.906-4.861-5.002c-.971-1-.426-2.678.947-2.915l6.873-1.19 3.257-6.17zm-1.48 7.512c-.25.475-.708.808-1.237.9l-6.229 1.077 4.405 4.533c.375.385.55.922.473 1.454l-.9 6.255 5.672-2.788a1.73 1.73 0 0 1 1.345-.077l.185.077 5.67 2.788-.898-6.255a1.73 1.73 0 0 1 .473-1.454l4.404-4.533-6.228-1.078a1.73 1.73 0 0 1-1.237-.899L22 12.19z",fill:"#fff"}),React.createElement("defs",null,React.createElement("linearGradient",{id:"AccordionFeaturedIcona",x1:0,y1:22,x2:44,y2:22,gradientUnits:"userSpaceOnUse"},React.createElement("stop",{stopColor:"#00afff"}),React.createElement("stop",{offset:1,stopColor:"#2974ff"}))))};function Cu(e){return Cu="function"==typeof Symbol&&"symbol"==typeof Symbol.iterator?function(e){return typeof e}:function(e){return e&&"function"==typeof Symbol&&e.constructor===Symbol&&e!==Symbol.prototype?"symbol":typeof e},Cu(e)}function Su(){return Su=Object.assign?Object.assign.bind():function(e){for(var t=1;t<arguments.length;t++){var n=arguments[t];for(var r in n)({}).hasOwnProperty.call(n,r)&&(e[r]=n[r])}return e},Su.apply(null,arguments)}function ku(e,t){var n=Object.keys(e);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(e);t&&(r=r.filter(function(t){return Object.getOwnPropertyDescriptor(e,t).enumerable})),n.push.apply(n,r)}return n}function Ou(e){for(var t=1;t<arguments.length;t++){var n=null!=arguments[t]?arguments[t]:{};t%2?ku(Object(n),!0).forEach(function(t){Pu(e,t,n[t])}):Object.getOwnPropertyDescriptors?Object.defineProperties(e,Object.getOwnPropertyDescriptors(n)):ku(Object(n)).forEach(function(t){Object.defineProperty(e,t,Object.getOwnPropertyDescriptor(n,t))})}return e}function Pu(e,t,n){return(t=function(e){var t=function(e){if("object"!=Cu(e)||!e)return e;var t=e[Symbol.toPrimitive];if(void 0!==t){var n=t.call(e,"string");if("object"!=Cu(n))return n;throw new TypeError("@@toPrimitive must return a primitive value.")}return String(e)}(e);return"symbol"==Cu(t)?t:t+""}(t))in e?Object.defineProperty(e,t,{value:n,enumerable:!0,configurable:!0,writable:!0}):e[t]=n,e}function Mu(e,t){return function(e){if(Array.isArray(e))return e}(e)||function(e,t){var n=null==e?null:"undefined"!=typeof Symbol&&e[Symbol.iterator]||e["@@iterator"];if(null!=n){var r,a,o,i,s=[],l=!0,c=!1;try{if(o=(n=n.call(e)).next,0===t){if(Object(n)!==n)return;l=!1}else for(;!(l=(r=o.call(n)).done)&&(s.push(r.value),s.length!==t);l=!0);}catch(e){c=!0,a=e}finally{try{if(!l&&null!=n.return&&(i=n.return(),Object(i)!==i))return}finally{if(c)throw a}}return s}}(e,t)||function(e,t){if(e){if("string"==typeof e)return Iu(e,t);var n={}.toString.call(e).slice(8,-1);return"Object"===n&&e.constructor&&(n=e.constructor.name),"Map"===n||"Set"===n?Array.from(e):"Arguments"===n||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)?Iu(e,t):void 0}}(e,t)||function(){throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.")}()}function Iu(e,t){(null==t||t>e.length)&&(t=e.length);for(var n=0,r=Array(t);n<t;n++)r[n]=e[n];return r}var Tu={google_recaptcha:(0,l.__)("Google reCAPTCHA Settings","easy-accordion-free"),gemini:(0,l.__)("Google Gemini API Settings","easy-accordion-free"),chatgpt:(0,l.__)("ChatGPT API Settings","easy-accordion-free"),deepseek:(0,l.__)("DeepSeek API Settings","easy-accordion-free")},_u=[{index:3,key:"saved_templates",label:(0,l.__)("Saved Templates","easy-accordion-free"),href:"edit.php?post_type=sp_easy_accordion&page=eap_dashboard#saved_templates"},{index:12,key:"eap_tools",label:(0,l.__)("Tools","easy-accordion-free"),href:"edit.php?post_type=sp_easy_accordion&page=eap_tools"}];const Nu=(0,i.memo)(function(e){var t=e.items,n=void 0===t?[]:t,r=e.optionKey,a=void 0===r?"integrations":r,o=e.hideUpcoming,c=void 0!==o&&o,u=e.type,d=void 0===u?"":u,p=(0,s.useSelect)(function(e){return e(qc).getDashboardSettings()}),f=(0,s.useDispatch)(qc).saveSettings,m=Hc[a],h=(null==p?void 0:p[a])||m,g=Mu((0,i.useState)(null),2),v=g[0],b=g[1],y=Mu((0,i.useState)(h),2),w=y[0],E=y[1],R=Mu((0,i.useState)(!1),2),x=R[0],A=R[1],C=function(){var e=arguments.length>0&&void 0!==arguments[0]?arguments[0]:w,t=Ou(Ou({},p),{},Pu({},a,e));f({dashboardSettings:t}),A(!1)},S=function(){var e=Ou(Ou({},w),{},Pu({},v,m[v]));C(e),E(e)},k=function(e,t){var n=Ou(Ou({},null==w?void 0:w[v]),{},Pu({},e,t));A(!Qc(n,null==h?void 0:h[v])),E(Ou(Ou({},w),{},Pu({},v,n)))};return(0,i.useEffect)(function(){E(h)},[p]),React.createElement("div",{className:"sp-eab-integrations-page-items-wrapper sp-d-grid sp-grid-cols-3"},null==n?void 0:n.map(function(e){var t,n=e.id,r=e.key,o=e.Icon,i=e.label,s=e.desc,u=e.demoLink,p=e.docLink,f=e.videoLink,m=e.upcoming,h=e.isPro;return React.createElement("div",{key:n,className:"sp-eap-integrations-card sp-d-flex".concat(m?" sp-eap-upcoming-card":"")},React.createElement("div",{className:"sp-eap-integrations-card__icon"},React.createElement(o,null)),React.createElement("div",{className:"sp-eap-integrations-card__content sp-d-flex sp-flex-col sp-justify-between"},React.createElement("div",{className:"sp-d-flex sp-flex-col sp-gap-8px"},React.createElement("div",{className:"sp-d-flex sp-align-center sp-justify-between"},React.createElement("h4",{className:"sp-eap-integrations-card__label"},i,!c&&m&&React.createElement("span",{className:"sp-eap-dashboard-upcoming-text small"},(0,l.__)("Upcoming","easy-accordion-free"))),r&&React.createElement(xc.A,{icons:!1,defaultChecked:!m&&(null==w||null===(t=w[r])||void 0===t?void 0:t.is_active),onChange:function(){var e;m||function(e,t){C(Ou(Ou({},w),{},Pu({},e,Ou(Ou({},w[e]),{},{is_active:t})))),function(e){var t=("modules"===(arguments.length>1&&void 0!==arguments[1]?arguments[1]:"modules")?(0,l.__)("Module","easy-accordion-free"):(0,l.__)("Integration","easy-accordion-free"))+(e?(0,l.__)(" enabled successfully","easy-accordion-free"):(0,l.__)(" disabled successfully","easy-accordion-free"));z.success(t,{style:{marginTop:"20px",fontSize:"14px"}})}(t,a),"modules"===a&&function(e,t){var n=null==_u?void 0:_u.find(function(t){return t.key===e}),r=document.querySelector("#menu-posts-sp_easy_accordion .wp-submenu-wrap");if(n&&r){var a=r.querySelector('a[href="'.concat(n.href,'"]'));if(t){if(t&&!a){var o=document.createElement("li"),i=document.createElement("a");i.href=n.href,i.textContent=n.label,o.appendChild(i);var s=r.children[n.index];r.insertBefore(o,s)}}else if(a){var l=a.closest("li");null==l||l.remove()}}}(e,t)}(r,!(null!=w&&null!==(e=w[r])&&void 0!==e&&e.is_active))}}),h&&React.createElement(xu,null)),"quick-start"!==d&&React.createElement("span",{className:"sp-eap-integrations-card__desc"},s)),"quick-start"!==d&&React.createElement("div",{className:"sp-eap-integrations-card__links sp-d-flex sp-align-center sp-justify-between"},(p||u||f)&&React.createElement("div",{className:"sp-d-flex sp-align-center sp-gap-10px"},u&&React.createElement("a",Su({className:"sp-d-flex sp-align-center sp-gap-4px",href:u,target:"_blank",rel:"noreferrer"},"#"===u&&{style:{pointerEvents:"none",cursor:"default"}}),React.createElement(rc,null)," Demo"),f&&React.createElement("a",Su({className:"sp-d-flex sp-align-center sp-gap-4px",href:f,target:"_blank",rel:"noreferrer"},"#"===f&&{style:{pointerEvents:"none",cursor:"default"}}),React.createElement(ac,null)," Video"),p&&React.createElement("a",Su({className:"sp-d-flex sp-align-center sp-gap-4px",href:p,target:"_blank",rel:"noreferrer"},"#"===p&&{style:{pointerEvents:"none",cursor:"default"}}),React.createElement(nc,null)," Docs")),"integrations"===a&&"page-builder"!==d&&React.createElement("div",{className:"sp-eap-integrations-card__settings sp-cursor-pointer"},React.createElement("span",{onClick:function(){m||b(r)}},React.createElement(oc,null))))),v===r&&React.createElement(Uc.Modal,{className:"sp-eap-integrations__modal",title:Tu[r],onRequestClose:function(){return b(null)}},React.createElement("div",{className:"sp-eap-integrations__modal-content"},"google_recaptcha"===v?React.createElement(Xc,{settings:null==w?void 0:w.google_recaptcha,updateSettingsOption:k}):React.createElement($c,{openedPopup:v,settings:null==w?void 0:w[v],updateSettingsOption:k}),React.createElement(Kc,{onSave:function(){return C()},onReset:S,isChanged:x}))))}))});var Lu=[{id:3,Icon:function(){return React.createElement("svg",{width:44,height:44,viewBox:"0 0 44 44",fill:"none",xmlns:"http://www.w3.org/2000/svg"},React.createElement("path",{d:"M0 6a6 6 0 0 1 6-6h32a6 6 0 0 1 6 6v32a6 6 0 0 1-6 6H6a6 6 0 0 1-6-6z",fill:"url(#GenerateFaqsWithAIIcona)"}),React.createElement("path",{fillRule:"evenodd",clipRule:"evenodd",d:"M14.411 18.615c-1.722-1.206-.629-3.569-.553-3.676.096-.253.37-.302.624-.205.253.097.301.372.204.625s-.823 1.749.253 2.502a.45.45 0 0 1 .113.641.45.45 0 0 1-.64.113",fill:"#fff"}),React.createElement("path",{fillRule:"evenodd",clipRule:"evenodd",d:"m11.368 19.292-.054-.037c-.178-.205-.226-.48-.021-.657.075-.108 1.921-1.943 3.644-.737.215.15.263.425.112.64a.45.45 0 0 1-.64.114c-1.077-.754-2.438.618-2.438.618-.205.178-.442.172-.603.06m-.408-3.095a.45.45 0 0 1-.113-.64.45.45 0 0 1 .64-.114c1.076.754 2.438-.618 2.438-.618.205-.178.48-.226.657-.022s.226.48.022.657c-.076.107-1.976 1.905-3.644.737",fill:"#fff"}),React.createElement("path",{fillRule:"evenodd",clipRule:"evenodd",d:"M11.367 19.287c-.162-.113-.248-.334-.151-.587s.824-1.749-.253-2.502a.45.45 0 0 1-.112-.641.45.45 0 0 1 .64-.113c1.668 1.168.63 3.569.554 3.676-.097.253-.372.302-.624.205zm9.391-6.911c-1.418-.993-.518-2.938-.456-3.026.08-.209.306-.248.514-.169.208.08.248.306.169.514-.08.209-.679 1.44.207 2.06a.37.37 0 0 1 .093.528.37.37 0 0 1-.527.093",fill:"#fff"}),React.createElement("path",{fillRule:"evenodd",clipRule:"evenodd",d:"m18.255 12.944-.044-.03c-.147-.17-.186-.395-.018-.541.062-.089 1.582-1.6 3-.607a.37.37 0 0 1 .093.527.37.37 0 0 1-.528.093c-.886-.62-2.007.51-2.007.51-.168.146-.363.141-.496.048m-.333-2.547a.37.37 0 0 1-.093-.528.37.37 0 0 1 .528-.093c.886.62 2.007-.51 2.007-.51.168-.145.394-.185.54-.017.147.169.186.395.018.54-.062.09-1.626 1.57-3 .607",fill:"#fff"}),React.createElement("path",{fillRule:"evenodd",clipRule:"evenodd",d:"M18.252 12.94c-.133-.093-.203-.275-.124-.483.08-.209.678-1.44-.208-2.06a.37.37 0 0 1-.093-.528.37.37 0 0 1 .528-.093c1.373.962.518 2.938.456 3.026-.08.209-.306.248-.514.169zm14.638 2.35c-1.722-1.207-.63-3.57-.554-3.677.097-.253.372-.301.625-.204.253.096.301.371.204.624s-.824 1.75.253 2.503a.45.45 0 0 1 .113.64.45.45 0 0 1-.64.113",fill:"#fff"}),React.createElement("path",{fillRule:"evenodd",clipRule:"evenodd",d:"m29.845 15.967-.053-.038c-.178-.205-.226-.48-.022-.657.076-.107 1.922-1.943 3.644-.737a.45.45 0 0 1 .113.64.45.45 0 0 1-.64.114c-1.077-.754-2.439.618-2.439.618-.204.178-.441.173-.603.06m-.407-3.095a.45.45 0 0 1-.113-.64.45.45 0 0 1 .64-.114c1.077.754 2.44-.618 2.44-.618.204-.178.478-.226.656-.022s.226.48.021.657c-.075.108-1.975 1.905-3.644.737",fill:"#fff"}),React.createElement("path",{fillRule:"evenodd",clipRule:"evenodd",d:"M29.845 15.961c-.161-.113-.247-.333-.15-.586s.823-1.75-.253-2.503a.45.45 0 0 1-.113-.64.45.45 0 0 1 .64-.114c1.67 1.168.63 3.569.555 3.677-.097.252-.372.3-.625.204zM27.32 29.537c-1.373-.962-.473-2.907-.41-2.996.079-.208.305-.248.513-.168s.248.306.168.514-.678 1.44.164 2.03a.37.37 0 0 1 .093.527.37.37 0 0 1-.527.093",fill:"#fff"}),React.createElement("path",{fillRule:"evenodd",clipRule:"evenodd",d:"m24.859 30.126-.045-.032c-.146-.168-.186-.394-.017-.54.062-.089 1.582-1.6 2.955-.638a.37.37 0 0 1 .093.528.37.37 0 0 1-.527.093c-.842-.59-1.963.54-1.963.54-.169.146-.363.142-.496.048m-.332-2.547a.37.37 0 0 1-.093-.528.37.37 0 0 1 .527-.093c.887.62 2.008-.509 2.008-.509.168-.146.394-.186.54-.018.146.169.186.395.018.541-.062.089-1.626 1.568-3 .607",fill:"#fff"}),React.createElement("path",{fillRule:"evenodd",clipRule:"evenodd",d:"M24.858 30.12c-.133-.092-.204-.274-.124-.482s.68-1.44-.207-2.06a.37.37 0 0 1-.093-.528.37.37 0 0 1 .527-.093c1.374.962.518 2.938.456 3.027-.08.208-.306.248-.514.168zm7.709-7.192c-1.33-.93-.518-2.937-.456-3.026.049-.164.306-.248.514-.168.164.048.248.305.168.514 0 0-.633 1.47.208 2.06a.37.37 0 0 1 .093.527.37.37 0 0 1-.527.093",fill:"#fff"}),React.createElement("path",{fillRule:"evenodd",clipRule:"evenodd",d:"m30.094 23.442-.045-.031c-.146-.169-.155-.439-.017-.54.062-.09 1.64-1.494 2.97-.563a.37.37 0 0 1 .092.527.37.37 0 0 1-.527.093c-.842-.59-1.977.465-1.977.465-.168.146-.363.142-.496.049m-.317-2.472a.37.37 0 0 1-.093-.528.37.37 0 0 1 .528-.093c.841.59 1.963-.54 1.963-.54.168-.146.394-.186.54-.018.146.169.186.395.018.54-.062.09-1.582 1.6-2.956.639",fill:"#fff"}),React.createElement("path",{fillRule:"evenodd",clipRule:"evenodd",d:"M30.094 23.442c-.133-.093-.205-.274-.125-.483 0 0 .647-1.395-.195-1.985a.37.37 0 0 1-.093-.527.37.37 0 0 1 .528-.093c1.329.93.504 2.863.442 2.951-.08.208-.305.248-.514.169z",fill:"#fff"}),React.createElement("path",{d:"m11.745 32.823 1.81 1.19L24.822 16.89l-1.81-1.19zm3.103 2.833-.08.108c-.423.52-1.18.645-1.751.269l-2.913-1.917a1.32 1.32 0 0 1-.378-1.83l11.994-18.23a1.32 1.32 0 0 1 1.83-.377l2.913 1.916c.61.402.78 1.221.379 1.831z",fill:"#fff"}),React.createElement("path",{d:"m23.19 20.868-1.09 1.656-3.875-2.55 1.09-1.655z",fill:"#fff"}),React.createElement("defs",null,React.createElement("linearGradient",{id:"GenerateFaqsWithAIIcona",x1:0,y1:22,x2:44,y2:22,gradientUnits:"userSpaceOnUse"},React.createElement("stop",{stopColor:"#7a00df"}),React.createElement("stop",{offset:1,stopColor:"#1a74e4"}))))},key:"generate_faqs_with_ai",label:(0,l.__)("Generate FAQs with AI","easy-accordion-free"),desc:(0,l.__)("Automatically generate relevant FAQs from your content, keywords, or Prompts to save time and streamline content creation.","easy-accordion-free"),videoLink:"https://www.youtube.com/watch?v=xYL2HC6acgA",docLink:"https://easyaccordion.io/docs/generate-faqs-with-ai/"},{id:8,Icon:function(){return React.createElement("svg",{width:44,height:44,viewBox:"0 0 44 44",fill:"none",xmlns:"http://www.w3.org/2000/svg"},React.createElement("rect",{width:44,height:44,rx:5.5,fill:"url(#SaveTemplatesIcona)"}),React.createElement("path",{d:"M12.943 9.501c-1.888 0-3.442 1.545-3.442 3.433v18.122a3.46 3.46 0 0 0 3.442 3.442h18.122c1.888 0 3.433-1.553 3.433-3.442V17.741a.94.94 0 0 0-.166-.544l-5.158-7.299a.94.94 0 0 0-.766-.397zm0 1.873h14.976l4.706 6.653v13.03c0 .881-.678 1.568-1.56 1.568H12.943a1.55 1.55 0 0 1-1.569-1.569V12.934c0-.882.687-1.56 1.569-1.56",fill:"#fff"}),React.createElement("path",{d:"M16.69 21.377c-1.889 0-3.442 1.544-3.442 3.433v8.461a.937.937 0 0 0 .94.932.94.94 0 0 0 .942-.932V24.81c0-.882.677-1.56 1.56-1.56h10.62c.882 0 1.569.678 1.569 1.56v8.461a.937.937 0 0 0 1.873 0V24.81c0-1.888-1.554-3.433-3.442-3.433z",fill:"#fff"}),React.createElement("path",{d:"M17.926 25.123a.938.938 0 0 0 0 1.874h8.129a.937.937 0 0 0 0-1.874zm0 3.747a.937.937 0 0 0-.932.94.94.94 0 0 0 .932.942h8.129a.94.94 0 0 0 .932-.941.937.937 0 0 0-.932-.941zM14.189 9.889a.94.94 0 0 0-.941.941v4.06c0 1.888 1.553 3.433 3.441 3.433h6.958a3.44 3.44 0 0 0 3.432-3.433v-4.06a.936.936 0 1 0-1.873 0v4.06c0 .882-.677 1.56-1.56 1.56H16.69c-.882 0-1.56-.678-1.56-1.56v-4.06a.94.94 0 0 0-.94-.941",fill:"#fff"}),React.createElement("defs",null,React.createElement("linearGradient",{id:"SaveTemplatesIcona",x1:0,y1:22,x2:44,y2:22,gradientUnits:"userSpaceOnUse"},React.createElement("stop",{stopColor:"#00afff"}),React.createElement("stop",{offset:1,stopColor:"#2974ff"}))))},key:"saved_templates",label:(0,l.__)("Saved Templates","easy-accordion-free"),desc:(0,l.__)("Create unlimited templates by converting Gutenberg blocks into shortcodes for use anywhere, including Elementor, Divi, etc.","easy-accordion-free"),videoLink:"https://www.youtube.com/watch?v=HsbKNZ6NDKM",docLink:"https://easyaccordion.io/docs/saved-templates/"},{id:7,Icon:function(){return React.createElement("svg",{width:44,height:44,viewBox:"0 0 44 44",fill:"none",xmlns:"http://www.w3.org/2000/svg"},React.createElement("path",{d:"M0 5.5A5.5 5.5 0 0 1 5.5 0h33A5.5 5.5 0 0 1 44 5.5v33a5.5 5.5 0 0 1-5.5 5.5h-33A5.5 5.5 0 0 1 0 38.5z",fill:"url(#PatternLibraryIcona)"}),React.createElement("path",{d:"M22 33.25c-5.892 0-8.838 0-10.669-1.83-1.83-1.831-1.83-4.778-1.83-10.67v-3.82c0-2.27 0-3.405.475-4.257a3.75 3.75 0 0 1 1.447-1.448c.852-.475 1.987-.475 4.258-.475 1.455 0 2.182 0 2.819.239 1.453.545 2.053 1.865 2.709 3.177L22 15.75m-5 0h10.938c2.633 0 3.95 0 4.896.632.41.274.76.625 1.034 1.035.633.945.633 2.262.633 4.895",stroke:"#fff",strokeWidth:1.833,strokeLinecap:"round"}),React.createElement("path",{d:"M34.5 25.75h-8.75m8.75 3.75h-8.75m3.125 3.75H25.75",stroke:"#fff",strokeWidth:1.833,strokeLinecap:"round",strokeLinejoin:"round"}),React.createElement("defs",null,React.createElement("linearGradient",{id:"PatternLibraryIcona",x1:0,y1:22,x2:44,y2:22,gradientUnits:"userSpaceOnUse"},React.createElement("stop",{stopColor:"#ab4cfe"}),React.createElement("stop",{offset:1,stopColor:"#7317fe"}))))},key:"pattern_library",label:(0,l.__)("Ready Patterns Library","easy-accordion-free"),desc:(0,l.__)("Access a large collection of pre-designed patterns to build layouts faster with consistent design quality.","easy-accordion-free"),demoLink:"https://easyaccordion.io/patterns/",docLink:"https://easyaccordion.io/docs/ready-patterns-library/"},{id:1,Icon:function(){return React.createElement("svg",{width:44,height:44,viewBox:"0 0 44 44",fill:"none",xmlns:"http://www.w3.org/2000/svg"},React.createElement("path",{d:"M0 5.5A5.5 5.5 0 0 1 5.5 0h33A5.5 5.5 0 0 1 44 5.5v33a5.5 5.5 0 0 1-5.5 5.5h-33A5.5 5.5 0 0 1 0 38.5z",fill:"url(#SEOSChemaMarkupModuleIcona)"}),React.createElement("path",{d:"M34.1 11A1.1 1.1 0 0 0 33 9.9H11A1.1 1.1 0 0 0 9.9 11v22a1.1 1.1 0 0 0 1.1 1.1h22a1.1 1.1 0 0 0 1.1-1.1zm1.8 22a2.9 2.9 0 0 1-2.9 2.9H11A2.9 2.9 0 0 1 8.1 33V11A2.9 2.9 0 0 1 11 8.1h22a2.9 2.9 0 0 1 2.9 2.9z",fill:"#fff"}),React.createElement("path",{d:"M11.7 18a2.8 2.8 0 0 1 2.8-2.8h6.2a.8.8 0 0 1 0 1.6h-6.2a1.2 1.2 0 0 0 0 2.4h6.2a.8.8 0 0 1 0 1.6h-6.2a2.8 2.8 0 0 1-2.8-2.8",fill:"#fff"}),React.createElement("path",{d:"M30.7 18a4.7 4.7 0 1 0-9.4 0 4.7 4.7 0 0 0 9.4 0m1.6 0a6.3 6.3 0 1 1-12.6 0 6.3 6.3 0 0 1 12.6 0",fill:"#fff"}),React.createElement("path",{d:"M25.1 31v-7a.9.9 0 0 1 1.8 0v7a.9.9 0 0 1-1.8 0m2.547-14.853a.5.5 0 0 1 .707 0l1.146 1.146a1 1 0 0 1 0 1.414l-1.146 1.146a.5.5 0 1 1-.707-.707L28.793 18l-1.146-1.146a.5.5 0 0 1 0-.707m-3.293 3.707a.5.5 0 0 1-.707 0L22.5 18.707a1 1 0 0 1 0-1.414l1.146-1.146a.5.5 0 1 1 .707.707L23.208 18l1.146 1.146a.5.5 0 0 1 0 .707m.713-.198.88-3.284a.5.5 0 0 1 .966.258l-.88 3.285a.5.5 0 0 1-.966-.259M19 23.2a.8.8 0 1 1 0 1.6h-6.5a.8.8 0 1 1 0-1.6zm0 3a.8.8 0 1 1 0 1.6h-6.5a.8.8 0 1 1 0-1.6zm-1.5 3a.8.8 0 1 1 0 1.6h-5a.8.8 0 1 1 0-1.6z",fill:"#fff"}),React.createElement("defs",null,React.createElement("linearGradient",{id:"SEOSChemaMarkupModuleIcona",x1:0,y1:0,x2:44,y2:44,gradientUnits:"userSpaceOnUse"},React.createElement("stop",{stopColor:"#97abff"}),React.createElement("stop",{offset:1,stopColor:"#123597"}))))},key:"seo_schema_markup",label:(0,l.__)("SEO Schema Markup","easy-accordion-free"),desc:(0,l.__)("This allows you to add structured FAQ schema, improving search visibility and increasing clicks with rich results.","easy-accordion-free"),videoLink:"",docLink:"https://easyaccordion.io/docs/seo-schema-markup/"},{id:2,Icon:function(){return React.createElement("svg",{width:44,height:44,viewBox:"0 0 44 44",fill:"none",xmlns:"http://www.w3.org/2000/svg"},React.createElement("path",{d:"M0 5.5A5.5 5.5 0 0 1 5.5 0h33A5.5 5.5 0 0 1 44 5.5v33a5.5 5.5 0 0 1-5.5 5.5h-33A5.5 5.5 0 0 1 0 38.5z",fill:"url(#MultilevelAccordionModuleIcona)"}),React.createElement("path",{d:"M34.1 9.682a.28.28 0 0 0-.282-.282H10.182a.28.28 0 0 0-.282.282v15.636a.28.28 0 0 0 .282.281h23.636a.28.28 0 0 0 .282-.28zm1.8 15.636c0 1.15-.932 2.082-2.082 2.082H10.182A2.08 2.08 0 0 1 8.1 25.318V9.682c0-1.15.932-2.082 2.082-2.083h23.636c1.15 0 2.082.933 2.082 2.083z",fill:"#fff"}),React.createElement("path",{d:"M30.072 10.709a1.18 1.18 0 0 1 1.49-.008l.09.08.765.76a.591.591 0 0 1-.833.84l-.762-.758-.754.764a.591.591 0 1 1-.842-.829l.757-.767zm-7.484-.006a.8.8 0 1 1 0 1.6H12a.8.8 0 1 1 0-1.6zM34.1 30.682a.28.28 0 0 0-.282-.282H10.182a.28.28 0 0 0-.282.282v3.636c0 .156.126.281.282.282h23.636a.28.28 0 0 0 .282-.282zm1.8 3.636c0 1.15-.932 2.082-2.082 2.082H10.182A2.08 2.08 0 0 1 8.1 34.318v-3.636c0-1.15.932-2.082 2.082-2.082h23.636c1.15 0 2.082.932 2.082 2.081z",fill:"#fff"}),React.createElement("path",{d:"M30.072 33.264c.43.357 1.056.36 1.49.008l.09-.081.765-.76a.591.591 0 0 0-.833-.839l-.762.758-.754-.765a.591.591 0 1 0-.842.83l.757.767zm-7.484-1.591a.8.8 0 1 1 0 1.6H12a.8.8 0 1 1 0-1.6zm7.484-14.894a1.18 1.18 0 0 1 1.49-.008l.09.08.765.76a.591.591 0 0 1-.833.84l-.762-.758-.754.764a.591.591 0 1 1-.842-.829l.757-.767zm-7.484-.006a.8.8 0 1 1 0 1.6H12a.8.8 0 1 1 0-1.6zm5.958 3.277a.75.75 0 0 1 0 1.5H14a.75.75 0 0 1 0-1.5zm0 2.5a.75.75 0 0 1 0 1.5H14a.75.75 0 0 1 0-1.5zM35 13.731a.769.769 0 0 1 0 1.537H9a.769.769 0 0 1 0-1.537z",fill:"#fff"}),React.createElement("defs",null,React.createElement("linearGradient",{id:"MultilevelAccordionModuleIcona",x1:0,y1:0,x2:44,y2:44,gradientUnits:"userSpaceOnUse"},React.createElement("stop",{stopColor:"#f761a1"}),React.createElement("stop",{offset:1,stopColor:"#8c1bab"}))))},label:(0,l.__)("Multi-Level Accordions","easy-accordion-free"),desc:(0,l.__)("This enables you to organize complex content with nested accordions for better structure and navigation.","easy-accordion-free"),demoLink:"https://easyaccordion.io/multi-leve-accoridons/",docLink:"https://easyaccordion.io/docs/how-to-create-multi-level-or-nested-faq-accordion/"},{id:6,Icon:function(){return React.createElement("svg",{width:44,height:44,viewBox:"0 0 44 44",fill:"none",xmlns:"http://www.w3.org/2000/svg"},React.createElement("path",{d:"M0 5.5A5.5 5.5 0 0 1 5.5 0h33A5.5 5.5 0 0 1 44 5.5v33a5.5 5.5 0 0 1-5.5 5.5h-33A5.5 5.5 0 0 1 0 38.5z",fill:"url(#ExportImportModuleIcona)"}),React.createElement("path",{fillRule:"evenodd",clipRule:"evenodd",d:"m20.234 19.323-.065.105zm1.802-.823.31.013a3 3 0 0 0-.31-.014m.05 5.704-.154-.012q.082 0 .154.012m-.308 1.284.06.007zm.154.012-.095-.005q.047.005.095.005",fill:"#fff"}),React.createElement("path",{fillRule:"evenodd",clipRule:"evenodd",d:"m20.234 19.323-.065.105zm1.802-.823.31.013a3 3 0 0 0-.31-.014m-.104 5.692q.082 0 .154.012zm-.095 1.303-.059-.007zm0 0q.047.005.095.005z",fill:"#fff"}),React.createElement("path",{fillRule:"evenodd",clipRule:"evenodd",d:"m20.234 19.323-.065.105zm1.802-.823.31.013a3 3 0 0 0-.31-.014m-.847 1.848.01-.136q-.008.065-.01.136m.973-.84-.126-.006q.066 0 .126.006m.667.992.006-.123q0 .063-.006.123",fill:"#fff"}),React.createElement("path",{fillRule:"evenodd",clipRule:"evenodd",d:"m21.189 20.348.01-.136q-.008.065-.01.136m1.641.152.006-.123q0 .063-.007.123",fill:"#fff"}),React.createElement("path",{fillRule:"evenodd",clipRule:"evenodd",d:"M24.183 20.325q0 .325-.096.605l-.075.182a2.6 2.6 0 0 1-.44.63q-.266.285-.574.575a1.15 1.15 0 0 0-.336.473q-.088.254-.094.598v.099h-1.325l.001-.1a4 4 0 0 1 .073-.755l.043-.158q.05-.154.122-.292l.08-.134q.168-.262.448-.526l.203-.194q.095-.095.179-.183a1.5 1.5 0 0 0 .255-.356.9.9 0 0 0 .088-.413q-.002-.27-.084-.435a.53.53 0 0 0-.226-.248.76.76 0 0 0-.389-.092.9.9 0 0 0-.367.081q-.165.076-.269.24a.84.84 0 0 0-.11.43l-.004.097H19.84l.003-.103c.01-.425.11-.787.308-1.079q.294-.439.79-.652a2.7 2.7 0 0 1 1.095-.215q.661-.002 1.144.226.486.222.743.66.26.437.26 1.039m-3.949-1.002-.065.105zm1.802-.823.31.013a3 3 0 0 0-.31-.014m-.847 1.848.01-.136q-.008.065-.01.136m.973-.84-.126-.006q.066 0 .126.006m.667.992.006-.123q0 .063-.006.123m-.992 4.995-.059-.007.154.012z",fill:"#fff"}),React.createElement("path",{fillRule:"evenodd",clipRule:"evenodd",d:"M22.738 24.85a.72.72 0 0 1-.223.531c-.148.148-.346.218-.582.218-.237 0-.437-.068-.588-.216a.73.73 0 0 1-.218-.533c0-.213.072-.396.217-.54a.8.8 0 0 1 .589-.219c.236 0 .434.07.582.217a.73.73 0 0 1 .223.542m-.652-.646-.154-.012q.082 0 .154.012m-.308 1.284a1 1 0 0 0 .154.012z",fill:"#fff"}),React.createElement("path",{d:"M16.85 27.15h10.3v-10.3h-10.3zm12 .25c0 .8-.65 1.45-1.45 1.45H16.6a1.45 1.45 0 0 1-1.45-1.45V16.6c0-.8.649-1.45 1.45-1.45h10.8c.8 0 1.45.65 1.45 1.45zm-16.444-2.208a.85.85 0 0 1 1.188 1.217l-2.077 2.025a1.45 1.45 0 0 1-2.034 0l-2.077-2.026a.85.85 0 0 1 1.188-1.216L10.5 27.05z",fill:"#fff"}),React.createElement("path",{d:"M9.65 28V16a.85.85 0 1 1 1.7 0v12a.85.85 0 1 1-1.7 0m25.756-9.192a.85.85 0 0 0 1.188-1.216l-2.078-2.026a1.45 1.45 0 0 0-2.033 0l-2.077 2.026a.85.85 0 0 0 1.188 1.216L33.5 16.95z",fill:"#fff"}),React.createElement("path",{d:"M32.65 16v12a.85.85 0 1 0 1.7 0V16a.85.85 0 1 0-1.7 0",fill:"#fff"}),React.createElement("defs",null,React.createElement("linearGradient",{id:"ExportImportModuleIcona",x1:0,y1:0,x2:44,y2:44,gradientUnits:"userSpaceOnUse"},React.createElement("stop",{stopColor:"#3662b2"}),React.createElement("stop",{offset:1,stopColor:"#13d2c4"}))))},key:"eap_tools",label:(0,l.__)("Export / Import FAQs","easy-accordion-free"),desc:(0,l.__)("This enables you to transfer FAQs across websites easily, saving time during migration, backup, or content duplication.","easy-accordion-free"),videoLink:"https://www.youtube.com/watch?v=Yjycl8tAvIU",docLink:"https://easyaccordion.io/docs/export-import-faqs/"}],Du=[{id:1,Icon:function(){return React.createElement("svg",{xmlns:"http://www.w3.org/2000/svg",width:44,height:44,viewBox:"0 0 44 44",fill:"none"},React.createElement("path",{d:"M0 5.5A5.5 5.5 0 0 1 5.5 0h33A5.5 5.5 0 0 1 44 5.5v33a5.5 5.5 0 0 1-5.5 5.5h-33A5.5 5.5 0 0 1 0 38.5z",fill:"url(#BuiltinProTemplatesIcona)"}),React.createElement("path",{d:"M33.6 12a1.1 1.1 0 0 0-1.1-1.1h-17a1.1 1.1 0 0 0-1.1 1.1v16a1.1 1.1 0 0 0 1.1 1.1h17a1.1 1.1 0 0 0 1.1-1.1zm1.8 16a2.9 2.9 0 0 1-2.9 2.9h-17a2.9 2.9 0 0 1-2.9-2.9V12a2.9 2.9 0 0 1 2.9-2.9h17a2.9 2.9 0 0 1 2.9 2.9z",fill:"#fff"}),React.createElement("path",{d:"M29.325 14.064c.43.357 1.056.36 1.49.008l.09-.08.765-.76a.591.591 0 0 0-.834-.84l-.761.758-.754-.764a.591.591 0 1 0-.842.829l.757.767zm-5.315-1.591a.8.8 0 1 1 0 1.6H17a.8.8 0 1 1 0-1.6zM8.6 30V16a2.9 2.9 0 0 1 2.9-2.9h2v1.8h-2a1.1 1.1 0 0 0-1.1 1.1v14a3.1 3.1 0 0 0 3.1 3.1h15a1.1 1.1 0 0 0 1.1-1.1v-2h1.8v2a2.9 2.9 0 0 1-2.9 2.9h-15A4.9 4.9 0 0 1 8.6 30",fill:"#fff"}),React.createElement("path",{d:"M34.5 15.7a.8.8 0 1 1 0 1.6h-21a.8.8 0 1 1 0-1.6zM31 19.2a.8.8 0 1 1 0 1.6H17a.8.8 0 1 1 0-1.6zm0 3.3a.8.8 0 1 1 0 1.6H17a.8.8 0 1 1 0-1.6zm-2.6 3.3a.8.8 0 0 1 0 1.6H17a.8.8 0 1 1 0-1.6z",fill:"#fff"}),React.createElement("defs",null,React.createElement("linearGradient",{id:"BuiltinProTemplatesIcona",x1:1.833,y1:0,x2:42.167,y2:44,gradientUnits:"userSpaceOnUse"},React.createElement("stop",{stopColor:"#ffbd29"}),React.createElement("stop",{offset:1,stopColor:"#ff2db6"}))))},label:(0,l.__)("25+ Built-in Pro Templates","easy-accordion-free"),desc:(0,l.__)("Access professionally designed templates to quickly build attractive accordion layouts without starting from scratch.","easy-accordion-free"),demoLink:"#",docLink:"#",isPro:!0},{id:2,Icon:function(){return React.createElement("svg",{xmlns:"http://www.w3.org/2000/svg",width:44,height:44,viewBox:"0 0 44 44",fill:"none"},React.createElement("path",{d:"M0 5.5A5.5 5.5 0 0 1 5.5 0h33A5.5 5.5 0 0 1 44 5.5v33a5.5 5.5 0 0 1-5.5 5.5h-33A5.5 5.5 0 0 1 0 38.5z",fill:"url(#FAQTitlePrefixSuffixIcona)"}),React.createElement("path",{d:"M35.1 9.182a.28.28 0 0 0-.281-.282H9.182a.28.28 0 0 0-.281.282v15.136c0 .156.125.281.28.282H34.82a.28.28 0 0 0 .28-.282zm1.8 15.136c0 1.15-.932 2.082-2.081 2.082H9.182A2.08 2.08 0 0 1 7.1 24.318V9.182c0-1.15.932-2.082 2.082-2.082h25.637c1.15 0 2.081.932 2.082 2.082z",fill:"#fff"}),React.createElement("path",{d:"M30.572 10.969a1.18 1.18 0 0 1 1.49-.008l.09.08.765.76a.591.591 0 0 1-.833.84l-.762-.758-.754.764a.591.591 0 1 1-.842-.829l.757-.767zM12.7 11.2a.6.6 0 1 1 0 1.2h-1.2a.6.6 0 1 1 0-1.2zm7.04-.2a.8.8 0 1 1 0 1.6h-4.59a.8.8 0 1 1 0-1.6z",fill:"#fff"}),React.createElement("path",{fillRule:"evenodd",clipRule:"evenodd",d:"M22 10.6a.5.5 0 0 0-.5.5v1.4a.5.5 0 0 0 .5.5h2.6a.5.5 0 0 0 .5-.5v-1.4a.5.5 0 0 0-.5-.5zm1.8.7a.5.5 0 0 1 0 1h-1a.5.5 0 0 1 0-1z",fill:"#fff"}),React.createElement("path",{d:"M35.1 30.182a.28.28 0 0 0-.281-.282H9.182a.28.28 0 0 0-.281.282v4.636a.28.28 0 0 0 .28.282H34.82a.28.28 0 0 0 .28-.282zm1.8 4.636c0 1.15-.932 2.082-2.081 2.082H9.182A2.08 2.08 0 0 1 7.1 34.818v-4.636c0-1.15.932-2.082 2.082-2.082h25.637c1.15 0 2.081.932 2.082 2.082z",fill:"#fff"}),React.createElement("path",{d:"M30.572 33.226c.43.356 1.056.36 1.49.008l.09-.081.765-.76a.591.591 0 0 0-.833-.84l-.762.759-.754-.765a.591.591 0 1 0-.842.83l.757.767zM12.7 31.872a.6.6 0 1 1 0 1.199h-1.2a.6.6 0 1 1 0-1.2zm7.04-.2a.8.8 0 1 1 0 1.6h-4.59a.8.8 0 1 1 0-1.6z",fill:"#fff"}),React.createElement("path",{fillRule:"evenodd",clipRule:"evenodd",d:"M22 31.272a.5.5 0 0 0-.5.5v1.4a.5.5 0 0 0 .5.5h2.6a.5.5 0 0 0 .5-.5v-1.4a.5.5 0 0 0-.5-.5zm1.8.7a.5.5 0 0 1 0 1h-1a.5.5 0 1 1 0-1z",fill:"#fff"}),React.createElement("path",{d:"M32.05 18.25a.75.75 0 1 1 0 1.5H11.5a.75.75 0 0 1 0-1.5zm-4 3a.75.75 0 1 1 0 1.5H11.5a.75.75 0 0 1 0-1.5zM36 14.831a.769.769 0 0 1 0 1.538H8a.769.769 0 0 1 0-1.538z",fill:"#fff"}),React.createElement("defs",null,React.createElement("linearGradient",{id:"FAQTitlePrefixSuffixIcona",x1:0,y1:0,x2:44,y2:44,gradientUnits:"userSpaceOnUse"},React.createElement("stop",{stopColor:"#97abff"}),React.createElement("stop",{offset:1,stopColor:"#123597"}))))},label:(0,l.__)("FAQ Title Prefix & Suffix","easy-accordion-free"),desc:(0,l.__)("Add custom text before or after titles to improve clarity and guide users through structured content.","easy-accordion-free"),demoLink:"#",docLink:"#",isPro:!0},{id:3,Icon:function(){return React.createElement("svg",{xmlns:"http://www.w3.org/2000/svg",width:44,height:44,viewBox:"0 0 44 44",fill:"none"},React.createElement("path",{d:"M0 5.5A5.5 5.5 0 0 1 5.5 0h33A5.5 5.5 0 0 1 44 5.5v33a5.5 5.5 0 0 1-5.5 5.5h-33A5.5 5.5 0 0 1 0 38.5z",fill:"url(#a)"}),React.createElement("path",{d:"M7.1 24v-4A1.9 1.9 0 0 1 9 18.1h6v1.8H9a.1.1 0 0 0-.1.1v4a.1.1 0 0 0 .1.1h6v1.8H9A1.9 1.9 0 0 1 7.1 24m28 0v-4a.1.1 0 0 0-.1-.1h-6v-1.8h6a1.9 1.9 0 0 1 1.9 1.9v4a1.9 1.9 0 0 1-1.9 1.9h-6v-1.8h6a.1.1 0 0 0 .1-.1",fill:"#fff"}),React.createElement("path",{fillRule:"evenodd",clipRule:"evenodd",d:"M19.545 18.654a2 2 0 0 0-.09.131zm2.489-1.03.43.018a5 5 0 0 0-.43-.017m.07 7.131-.213-.014q.112 0 .212.014m-.426 1.606.082.01zm.213.014-.131-.005q.063.005.131.005",fill:"#fff"}),React.createElement("path",{fillRule:"evenodd",clipRule:"evenodd",d:"M19.545 18.654a2 2 0 0 0-.09.131zm2.489-1.03.43.018a5 5 0 0 0-.43-.017m-.143 7.117q.112 0 .212.014zm-.131 1.63-.082-.01zm0 0q.063.004.131.004z",fill:"#fff"}),React.createElement("path",{fillRule:"evenodd",clipRule:"evenodd",d:"M19.545 18.654a2 2 0 0 0-.09.131zm2.489-1.03.43.018a5 5 0 0 0-.43-.017m-1.17 2.312.015-.17q-.012.08-.015.17m1.345-1.05-.175-.009q.09 0 .175.009m.921 1.24.009-.155q0 .08-.009.155",fill:"#fff"}),React.createElement("path",{fillRule:"evenodd",clipRule:"evenodd",d:"m20.864 19.936.015-.17q-.012.08-.015.17m2.266.19.009-.155q0 .08-.009.155",fill:"#fff"}),React.createElement("path",{fillRule:"evenodd",clipRule:"evenodd",d:"M25 19.906q0 .407-.132.757l-.104.227a3.3 3.3 0 0 1-.607.789q-.368.356-.794.718-.348.285-.464.59-.121.319-.13.749v.123h-1.83l.001-.126q.007-.544.101-.942l.06-.198q.067-.192.168-.365l.11-.167q.232-.327.619-.658l.28-.243q.132-.119.248-.228.226-.218.352-.446.121-.224.122-.515a1.14 1.14 0 0 0-.116-.545.7.7 0 0 0-.313-.31 1.1 1.1 0 0 0-.537-.114q-.27 0-.507.1a.83.83 0 0 0-.37.3q-.14.19-.155.537l-.004.122H19l.004-.128q.018-.8.426-1.349.407-.548 1.092-.816.681-.269 1.512-.268.914-.001 1.58.282.672.279 1.027.825.36.548.359 1.3m-5.455-1.252a2 2 0 0 0-.09.131zm2.489-1.03.43.018a5 5 0 0 0-.43-.017m-1.17 2.312.015-.17q-.012.08-.015.17m1.345-1.05-.175-.009q.09 0 .175.009m.921 1.24.009-.155q0 .08-.009.155m-1.37 6.244-.082-.01.213.015z",fill:"#fff"}),React.createElement("path",{fillRule:"evenodd",clipRule:"evenodd",d:"M23.005 25.564q-.001.391-.31.664c-.204.185-.477.272-.804.272s-.603-.086-.812-.27a.87.87 0 0 1-.3-.666.88.88 0 0 1 .299-.677c.208-.184.486-.272.813-.272s.6.087.805.271c.205.181.308.41.308.678m-.902-.809-.212-.014q.112 0 .212.014m-.425 1.606a2 2 0 0 0 .213.014z",fill:"#fff"}),React.createElement("path",{d:"M29.1 22a7.1 7.1 0 1 0-14.2 0 7.1 7.1 0 1 0 14.2 0m1.8 0a8.9 8.9 0 1 1-17.8 0 8.9 8.9 0 0 1 17.8 0",fill:"#fff"}),React.createElement("defs",null,React.createElement("linearGradient",{id:"a",x1:0,y1:0,x2:44,y2:44,gradientUnits:"userSpaceOnUse"},React.createElement("stop",{stopColor:"#ff96f9"}),React.createElement("stop",{offset:1,stopColor:"#c32bac"}))))},label:(0,l.__)("FAQ Title Badges","easy-accordion-free"),desc:(0,l.__)("Highlight important FAQs with badges, helping users quickly identify featured or critical information within content.","easy-accordion-free"),demoLink:"#",docLink:"#",isPro:!0},{id:4,Icon:function(){return React.createElement("svg",{xmlns:"http://www.w3.org/2000/svg",width:44,height:44,viewBox:"0 0 44 44",fill:"none"},React.createElement("rect",{width:44,height:44,rx:5.5,fill:"url(#AccordionItemSubtitlesa)"}),React.createElement("path",{d:"M34.1 9.232a.28.28 0 0 0-.282-.281H10.182a.28.28 0 0 0-.282.28V23.37c0 .155.126.28.282.28h23.636a.28.28 0 0 0 .282-.28zm1.8 14.137c0 1.15-.932 2.082-2.082 2.082H10.182A2.08 2.08 0 0 1 8.1 23.369V9.232c0-1.15.932-2.082 2.082-2.082h23.636c1.15 0 2.082.932 2.082 2.082z",fill:"#fff"}),React.createElement("path",{d:"M30.013 11.229a1.18 1.18 0 0 1 1.49-.008l.09.081.765.76a.591.591 0 0 1-.833.839l-.762-.758-.754.765a.591.591 0 1 1-.842-.83l.757-.767zm-7.425 1.094a.8.8 0 1 1 0 1.6H12a.8.8 0 1 1 0-1.6zM18.59 10.1a.55.55 0 1 1 0 1.1H12a.55.55 0 1 1 0-1.1zM34.1 29.232a.28.28 0 0 0-.282-.281H10.182a.28.28 0 0 0-.282.28v5.537c0 .156.126.282.282.282h23.636a.28.28 0 0 0 .282-.282zm1.8 5.536c0 1.15-.932 2.082-2.082 2.082H10.182A2.08 2.08 0 0 1 8.1 34.768v-5.536c0-1.15.932-2.082 2.082-2.082h23.636c1.15 0 2.082.932 2.082 2.082z",fill:"#fff"}),React.createElement("path",{d:"M30.013 32.815c.43.356 1.056.36 1.49.007l.09-.08.765-.76a.591.591 0 0 0-.833-.84l-.762.759-.754-.765a.591.591 0 1 0-.842.829l.757.768zm-7.425-.492a.8.8 0 1 1 0 1.6H12a.8.8 0 1 1 0-1.6zM18.59 30.1a.55.55 0 1 1 0 1.1H12a.55.55 0 1 1 0-1.1zM31.05 18a.75.75 0 0 1 0 1.5H12.5a.75.75 0 1 1 0-1.5zm-3 2.7a.75.75 0 0 1 0 1.5H12.5a.75.75 0 0 1 0-1.5zM35 15.182a.769.769 0 0 1 0 1.537H9a.769.769 0 0 1 0-1.537z",fill:"#fff"}),React.createElement("defs",null,React.createElement("linearGradient",{id:"AccordionItemSubtitlesa",x1:22,y1:0,x2:22,y2:44,gradientUnits:"userSpaceOnUse"},React.createElement("stop",{stopColor:"#920523"}),React.createElement("stop",{offset:.25,stopColor:"#a61937"}),React.createElement("stop",{offset:.5,stopColor:"#ba2d4b"}),React.createElement("stop",{offset:.75,stopColor:"#ce415f"}),React.createElement("stop",{offset:1,stopColor:"#e25573"}))))},label:(0,l.__)("Accordion Item Subtitles","easy-accordion-free"),desc:(0,l.__)("Add descriptive subtitles to each item, providing additional context and improving readability for better understanding.","easy-accordion-free"),demoLink:"#",docLink:"#",isPro:!0},{id:5,Icon:Au,label:(0,l.__)("Accordion Featured Icon","easy-accordion-free"),desc:(0,l.__)("Enhance accordion titles with icons to improve visual appeal and make content easier to scan quickly.","easy-accordion-free"),demoLink:"#",docLink:"#",isPro:!0},{id:6,Icon:Au,label:(0,l.__)("Item Anchor Links","easy-accordion-free"),desc:(0,l.__)("Automatically generate unique anchor links for each item, enabling direct navigation using the item title or ID for easy sharing.","easy-accordion-free"),demoLink:"#",docLink:"#",isPro:!0},{id:7,Icon:function(){return React.createElement("svg",{xmlns:"http://www.w3.org/2000/svg",width:44,height:44,viewBox:"0 0 44 44",fill:"none"},React.createElement("path",{d:"M0 5.5A5.5 5.5 0 0 1 5.5 0h33A5.5 5.5 0 0 1 44 5.5v33a5.5 5.5 0 0 1-5.5 5.5h-33A5.5 5.5 0 0 1 0 38.5z",fill:"url(#AJAXFAQSearchIcona)"}),React.createElement("path",{d:"M21.19 22.38h-1.928q.009-.735.121-1.259a2.9 2.9 0 0 1 .396-.944q.274-.427.741-.87.371-.348.662-.654A2.7 2.7 0 0 0 21.65 18a1.76 1.76 0 0 0 .169-.782q0-.492-.161-.823a1.07 1.07 0 0 0-.46-.5q-.299-.177-.75-.177-.37 0-.702.153-.33.153-.532.476-.201.315-.218.822H16.86q.024-1.056.5-1.758a2.9 2.9 0 0 1 1.282-1.056Q19.449 14 20.449 14q1.105 0 1.887.371.79.363 1.202 1.065.42.701.419 1.693 0 .71-.274 1.274a4.3 4.3 0 0 1-.726 1.04q-.451.484-.976.976-.46.412-.62.88a3.5 3.5 0 0 0-.17 1.08m-2.13 2.507q0-.483.323-.806.331-.323.887-.323.558 0 .88.323.33.323.33.806 0 .468-.33.79-.322.323-.88.323-.555 0-.887-.323a1.08 1.08 0 0 1-.322-.79",fill:"#fff"}),React.createElement("path",{d:"M29.18 28.026A11.96 11.96 0 0 0 32.26 20c0-6.627-5.373-12-12-12-6.628 0-12 5.373-12 12 0 6.628 5.372 12 12 12 2.82 0 5.415-.974 7.464-2.603l6.31 6.31a1 1 0 1 0 1.414-1.414zM20.26 10c5.522 0 10 4.477 10 10s-4.478 10-10 10c-5.524 0-10-4.477-10-10s4.476-10 10-10",fill:"#fff"}),React.createElement("defs",null,React.createElement("linearGradient",{id:"AJAXFAQSearchIcona",x1:0,y1:0,x2:44,y2:44,gradientUnits:"userSpaceOnUse"},React.createElement("stop",{stopColor:"#3b2667"}),React.createElement("stop",{offset:1,stopColor:"#bc78ec"}))))},label:(0,l.__)("AJAX FAQ Search","easy-accordion-free"),desc:(0,l.__)("Enable instant FAQ search with real-time results, improving usability without requiring page reloads.","easy-accordion-free"),demoLink:"#",docLink:"#",isPro:!0},{id:8,Icon:function(){return React.createElement("svg",{xmlns:"http://www.w3.org/2000/svg",width:44,height:44,viewBox:"0 0 44 44",fill:"none"},React.createElement("path",{d:"M0 5.5A5.5 5.5 0 0 1 5.5 0h33A5.5 5.5 0 0 1 44 5.5v33a5.5 5.5 0 0 1-5.5 5.5h-33A5.5 5.5 0 0 1 0 38.5z",fill:"url(#FrontendLiveTaxonomyFilterIcona)"}),React.createElement("path",{d:"M10.498 23.89c0-.417.338-.755.756-.755h3.137a.755.755 0 1 1 0 1.51h-3.137a.755.755 0 0 1-.756-.755m7.637-.871a.545.545 0 0 1 .756.755l-.071.085-.779.78a.73.73 0 0 1-.912.092l-.116-.092-.778-.78-.07-.085a.545.545 0 0 1 .754-.756l.085.071.523.522.523-.522z",fill:"#fff"}),React.createElement("path",{d:"M19.85 21.564a.406.406 0 0 0-.405-.406H9.917a.406.406 0 0 0-.406.406v4.648c0 .224.182.406.406.406h9.528a.406.406 0 0 0 .406-.406zm1.511 4.648a1.917 1.917 0 0 1-1.916 1.917H9.917A1.92 1.92 0 0 1 8 26.212v-4.648c0-1.058.859-1.917 1.917-1.917h9.528c1.058 0 1.916.859 1.916 1.917zM16.888 15.87l.107.007a1.046 1.046 0 0 1 0 2.08l-.107.006H9.337a1.046 1.046 0 0 1 0-2.092zm14.347 0 .108.007a1.046 1.046 0 0 1 0 2.08l-.108.006h-7.143a1.046 1.046 0 0 1 0-2.092z",fill:"#fff"}),React.createElement("path",{d:"M10.498 23.89c0-.417.338-.755.756-.755h3.137a.755.755 0 1 1 0 1.51h-3.137a.755.755 0 0 1-.756-.755m14.639 0c0-.417.338-.755.756-.755h3.136a.755.755 0 1 1 0 1.51h-3.136a.755.755 0 0 1-.756-.755m7.637-.871a.545.545 0 0 1 .756.755l-.071.085-.779.78a.73.73 0 0 1-.912.092l-.116-.092-.778-.78-.07-.085a.545.545 0 0 1 .754-.756l.085.071.523.522.523-.522z",fill:"#fff"}),React.createElement("path",{d:"M34.49 21.564a.406.406 0 0 0-.406-.406h-9.528a.406.406 0 0 0-.406.406v4.648c0 .224.182.406.407.406h9.527a.406.406 0 0 0 .406-.406zM36 26.212a1.917 1.917 0 0 1-1.916 1.917h-9.528a1.92 1.92 0 0 1-1.917-1.917v-4.648c0-1.058.859-1.917 1.918-1.917h9.527c1.058 0 1.916.859 1.916 1.917z",fill:"#fff"}),React.createElement("path",{d:"M25.137 23.89c0-.417.338-.755.756-.755h3.136a.755.755 0 1 1 0 1.51h-3.136a.755.755 0 0 1-.756-.755",fill:"#fff"}),React.createElement("defs",null,React.createElement("linearGradient",{id:"FrontendLiveTaxonomyFilterIcona",x1:0,y1:0,x2:44,y2:44,gradientUnits:"userSpaceOnUse"},React.createElement("stop",{stopColor:"#374691"}),React.createElement("stop",{offset:1,stopColor:"#2160df"}))))},label:(0,l.__)("Frontend Live Taxonomy Filter","easy-accordion-free"),desc:(0,l.__)("Allow users to filter FAQs dynamically by categories or tags, improving content discovery and navigation.","easy-accordion-free"),demoLink:"#",docLink:"#",isPro:!0},{id:9,Icon:function(){return React.createElement("svg",{xmlns:"http://www.w3.org/2000/svg",width:44,height:44,viewBox:"0 0 44 44",fill:"none"},React.createElement("path",{d:"M0 5.5A5.5 5.5 0 0 1 5.5 0h33A5.5 5.5 0 0 1 44 5.5v33a5.5 5.5 0 0 1-5.5 5.5h-33A5.5 5.5 0 0 1 0 38.5z",fill:"url(#FAQAnalyticsIcona)"}),React.createElement("path",{d:"M34.1 11.182a.28.28 0 0 0-.282-.282H10.182a.28.28 0 0 0-.282.282v21.636c0 .156.126.282.282.282h23.636a.28.28 0 0 0 .282-.282zm1.8 21.636c0 1.15-.932 2.082-2.082 2.082H10.182A2.08 2.08 0 0 1 8.1 32.818V11.182c0-1.15.932-2.082 2.082-2.082h23.636c1.15 0 2.082.932 2.082 2.082z",fill:"#fff"}),React.createElement("path",{d:"M12 19.313v-6.228h4.252v1.223h-2.747v1.277h2.476v1.226h-2.476v2.502zm5.579 0h-1.618l2.101-6.228h2.005l2.101 6.228H20.55l-1.463-4.659h-.048zm-.216-2.45h3.382v1.143h-3.382zm7.564.212h1.217l.517.66.678.779 1.043 1.286h-1.363l-.73-.873-.431-.62zm3.497-.876q0 1.028-.395 1.743-.395.714-1.07 1.085-.672.372-1.509.372-.84 0-1.511-.375a2.73 2.73 0 0 1-1.068-1.085q-.392-.715-.392-1.74 0-1.028.392-1.742a2.7 2.7 0 0 1 1.068-1.086A3.1 3.1 0 0 1 25.45 13q.836 0 1.509.371.675.371 1.07 1.086.396.714.395 1.742m-1.538 0q0-.608-.174-1.028a1.35 1.35 0 0 0-.492-.635 1.34 1.34 0 0 0-.77-.216 1.35 1.35 0 0 0-.77.216q-.322.216-.495.635-.17.42-.17 1.028t.17 1.028q.173.42.496.636.322.216.77.216.45 0 .769-.216.322-.216.492-.636.174-.42.174-1.028M13.8 33.2h1.9v-4.4h-1.9zm3.5 1.6h-5.1v-6.5a1.1 1.1 0 0 1 1.1-1.1h2.9a1.1 1.1 0 0 1 1.1 1.1zm3.75-1.6h1.9v-7.4h-1.9zm3.5 1.6h-5.1v-9.5a1.1 1.1 0 0 1 1.1-1.1h2.9a1.1 1.1 0 0 1 1.1 1.1zm3.75-1.6h1.9V22.8h-1.9zm3.5 1.6h-5.1V22.3a1.1 1.1 0 0 1 1.1-1.1h2.9a1.1 1.1 0 0 1 1.1 1.1z",fill:"#fff"}),React.createElement("defs",null,React.createElement("linearGradient",{id:"FAQAnalyticsIcona",x1:0,y1:0,x2:44,y2:44,gradientUnits:"userSpaceOnUse"},React.createElement("stop",{stopColor:"#3662b2"}),React.createElement("stop",{offset:1,stopColor:"#13d2c4"}))))},label:(0,l.__)("FAQ Analytics","easy-accordion-free"),desc:(0,l.__)("Monitor FAQ clicks and impressions to understand user behavior and measure content performance effectively.","easy-accordion-free"),videoLink:"#",docLink:"#",isPro:!0},{id:10,Icon:function(){return React.createElement("svg",{xmlns:"http://www.w3.org/2000/svg",width:44,height:44,viewBox:"0 0 44 44",fill:"none"},React.createElement("path",{d:"M0 5.5A5.5 5.5 0 0 1 5.5 0h33A5.5 5.5 0 0 1 44 5.5v33a5.5 5.5 0 0 1-5.5 5.5h-33A5.5 5.5 0 0 1 0 38.5z",fill:"#873eff"}),React.createElement("path",{d:"M8 33.275v-22.55A2.725 2.725 0 0 1 10.725 8h2.819a.846.846 0 0 1 0 1.692h-2.819c-.57 0-1.033.462-1.033 1.033v22.55c0 .57.462 1.033 1.033 1.033h22.55c.57 0 1.033-.462 1.033-1.033v-16.35a.846.846 0 0 1 1.692 0v16.35A2.725 2.725 0 0 1 33.275 36h-22.55A2.725 2.725 0 0 1 8 33.275",fill:"#fff"}),React.createElement("path",{fillRule:"evenodd",clipRule:"evenodd",d:"M25.13 8c-.44 0-.726.158-.982.69l-1.167 2.43V8.96c0-.644-.277-.96-.788-.96-.512 0-.727.191-.983.734l-1.105 2.385V8.984c0-.69-.256-.984-.88-.984h-1.27c-.48 0-.746.249-.746.701s.255.723.726.723h.522v2.724c0 .769.471 1.221 1.146 1.221.676 0 .983-.294 1.32-.983l.738-1.526v1.288c0 .758.45 1.221 1.136 1.221s.941-.26 1.33-.983l1.7-3.165c.368-.69.112-1.22-.707-1.22zm3.192 0c-1.392 0-2.446 1.142-2.446 2.69s1.064 2.68 2.446 2.68 2.436-1.142 2.446-2.68c0-1.548-1.064-2.69-2.446-2.69m0 3.719c-.522 0-.88-.43-.88-1.029s.358-1.04.88-1.04.88.441.88 1.04c0 .6-.348 1.029-.88 1.029M33.554 8c-1.382 0-2.446 1.142-2.446 2.69s1.064 2.68 2.446 2.68S36 12.227 36 10.69 34.936 8 33.554 8m0 3.719c-.532 0-.87-.43-.87-1.029s.348-1.04.87-1.04.88.441.88 1.04c0 .6-.348 1.029-.88 1.029",fill:"#fff"}),React.createElement("path",{d:"M30.691 26.698a.235.235 0 0 0-.235-.235H13.544a.235.235 0 0 0-.235.235v3.758c0 .13.105.235.235.235h16.912c.13 0 .235-.105.235-.235zm1.41 3.758c0 .908-.737 1.644-1.645 1.644H13.544a1.644 1.644 0 0 1-1.644-1.644v-3.758c0-.908.736-1.645 1.644-1.645h16.912c.908 0 1.644.737 1.644 1.645z",fill:"#fff"}),React.createElement("path",{d:"M26.362 27.873a.47.47 0 0 1 .664-.008l.623.611q.003.004.015.005.013-.001.016-.005l.628-.604a.47.47 0 0 1 .652.677l-.63.605a.964.964 0 0 1-1.338-.007l-.623-.61a.47.47 0 0 1-.007-.664m-3.422-.001a.705.705 0 1 1 0 1.41h-7.517a.705.705 0 1 1 0-1.41zm7.751-10.1a.235.235 0 0 0-.235-.235H13.544a.235.235 0 0 0-.235.235v3.758c0 .13.105.235.235.235h16.912c.13 0 .235-.105.235-.235zm1.41 3.758c0 .908-.737 1.644-1.645 1.644H13.544A1.644 1.644 0 0 1 11.9 21.53v-3.758c0-.908.736-1.644 1.644-1.644h16.912c.908 0 1.644.736 1.644 1.644z",fill:"#fff"}),React.createElement("path",{d:"M26.362 18.947a.47.47 0 0 1 .664-.008l.623.611q.003.004.015.005.013-.001.016-.005l.628-.604a.47.47 0 0 1 .652.677l-.63.604a.964.964 0 0 1-1.338-.006l-.623-.61a.47.47 0 0 1-.007-.664m-3.422-.001a.705.705 0 1 1 0 1.41h-7.517a.705.705 0 1 1 0-1.41z",fill:"#fff"}))},label:(0,l.__)("WooCommerce Product FAQs","easy-accordion-free"),desc:(0,l.__)("Add FAQs directly to WooCommerce product pages to reduce customer doubts and increase conversions with clear information.","easy-accordion-free"),demoLink:"#",docLink:"#",isPro:!0},{id:11,Icon:function(){return React.createElement("svg",{xmlns:"http://www.w3.org/2000/svg",width:44,height:44,viewBox:"0 0 44 44",fill:"none"},React.createElement("rect",{width:44,height:44,rx:5.5,fill:"url(#MotionEffectsAnimationsIcona)"}),React.createElement("path",{d:"M36 25.1a.9.9 0 0 1 0 1.8H8a.9.9 0 0 1 0-1.8zm0 6a.9.9 0 0 1 0 1.8H20a.9.9 0 0 1 0-1.8z",fill:"#fff"}),React.createElement("path",{d:"M19.1 32a1.1 1.1 0 1 0-2.2 0 1.1 1.1 0 0 0 2.2 0m1.8 0a2.9 2.9 0 1 1-5.801 0 2.9 2.9 0 0 1 5.801 0",fill:"#fff"}),React.createElement("path",{d:"M16 31.1a.9.9 0 0 1 0 1.8H8a.9.9 0 0 1 0-1.8zM7.1 15.5a6.4 6.4 0 0 1 11.337-4.073.9.9 0 1 1-1.388 1.146 4.6 4.6 0 1 0 0 5.854.9.9 0 0 1 1.387 1.146A6.4 6.4 0 0 1 7.1 15.5",fill:"#fff"}),React.createElement("path",{d:"M15.6 15.5a6.4 6.4 0 0 1 11.337-4.073.9.9 0 1 1-1.388 1.146 4.6 4.6 0 1 0 0 5.854.9.9 0 0 1 1.387 1.146A6.4 6.4 0 0 1 15.6 15.5",fill:"#fff"}),React.createElement("path",{d:"M35.1 15.5a4.6 4.6 0 1 0-9.2 0 4.6 4.6 0 0 0 9.2 0m1.8 0a6.4 6.4 0 1 1-12.801 0 6.4 6.4 0 0 1 12.801 0",fill:"#fff"}),React.createElement("defs",null,React.createElement("linearGradient",{id:"MotionEffectsAnimationsIcona",x1:44,y1:44,x2:0,y2:0,gradientUnits:"userSpaceOnUse"},React.createElement("stop",{stopColor:"#ff4c4f"}),React.createElement("stop",{offset:1,stopColor:"#2402e3"}))))},label:(0,l.__)("Motion Effects & Animations","easy-accordion-free"),desc:(0,l.__)("Add modern motion effects and interactive behaviors to create engaging and visually dynamic user experiences.","easy-accordion-free"),demoLink:"#",docLink:"#",isPro:!0},{id:12,Icon:function(){return React.createElement("svg",{xmlns:"http://www.w3.org/2000/svg",width:44,height:44,viewBox:"0 0 44 44",fill:"none"},React.createElement("path",{d:"M0 5.5A5.5 5.5 0 0 1 5.5 0h33A5.5 5.5 0 0 1 44 5.5v33a5.5 5.5 0 0 1-5.5 5.5h-33A5.5 5.5 0 0 1 0 38.5z",fill:"url(#MultipleUserFAQFormsIcona)"}),React.createElement("path",{d:"M25.45 12a.2.2 0 0 0-.2-.2H9.75a.2.2 0 0 0-.2.2v11.5c0 .11.09.2.2.2h15.5a.2.2 0 0 0 .2-.2zm1.6 11.5a1.8 1.8 0 0 1-1.8 1.8H9.75a1.8 1.8 0 0 1-1.8-1.8V12a1.8 1.8 0 0 1 1.8-1.8h15.5a1.8 1.8 0 0 1 1.8 1.8z",fill:"#fff"}),React.createElement("path",{d:"M17.75 15.75a.75.75 0 0 1 0 1.5h-6a.75.75 0 0 1 0-1.5zm0 2.5a.75.75 0 0 1 0 1.5h-6a.75.75 0 0 1 0-1.5zm-3.5 2.5a.75.75 0 0 1 0 1.5h-2.5a.75.75 0 0 1 0-1.5zm1.5-7.5a.75.75 0 0 1 0 1.5h-4a.75.75 0 0 1 0-1.5zm6.347 6.138h-1.4q.005-.534.087-.914.088-.381.287-.686.2-.31.54-.633.269-.252.48-.474.216-.228.34-.475.122-.252.122-.568 0-.357-.117-.598a.77.77 0 0 0-.334-.363 1.05 1.05 0 0 0-.545-.129q-.27 0-.51.111a.9.9 0 0 0-.386.346q-.146.228-.158.598H18.95q.018-.768.363-1.278.345-.515.932-.767.585-.258 1.312-.258.804 0 1.372.27a1.9 1.9 0 0 1 .873.773q.304.51.304 1.23 0 .516-.199.926-.2.405-.527.756-.329.351-.71.71-.333.297-.45.638-.119.34-.123.785M20.55 21.21q0-.352.234-.586.24-.234.645-.234.404 0 .638.234.24.235.24.586 0 .34-.24.574-.234.235-.639.235-.404 0-.644-.235a.78.78 0 0 1-.234-.574",fill:"#fff"}),React.createElement("path",{d:"M16.95 32v-7h1.6v7c0 .11.09.2.2.2h15.5a.2.2 0 0 0 .2-.2V20a.2.2 0 0 0-.2-.2H26.5v-1.6h7.75a1.8 1.8 0 0 1 1.8 1.8v12a1.8 1.8 0 0 1-1.8 1.8h-15.5a1.8 1.8 0 0 1-1.8-1.8",fill:"#fff"}),React.createElement("path",{d:"M26.75 26.75a.75.75 0 0 1 0 1.5h-6a.75.75 0 0 1 0-1.5zm-3.5 2.5a.75.75 0 0 1 0 1.5h-2.5a.75.75 0 0 1 0-1.5zm7.847-1.862h-1.4q.005-.534.087-.914.088-.381.287-.686.2-.31.54-.633.269-.252.48-.474.216-.228.34-.475.122-.252.122-.568 0-.358-.117-.598a.77.77 0 0 0-.334-.363 1.05 1.05 0 0 0-.545-.129q-.27 0-.51.111a.9.9 0 0 0-.386.346q-.146.229-.158.598H27.95q.018-.768.363-1.278.345-.515.932-.767.585-.258 1.312-.258.804 0 1.372.27a1.9 1.9 0 0 1 .873.773q.304.51.304 1.23 0 .516-.199.926-.2.405-.527.756-.329.351-.71.71-.333.297-.45.638-.119.34-.123.785M29.55 29.21q0-.352.234-.586.24-.234.645-.234.404 0 .638.234.24.235.24.586 0 .34-.24.574-.234.235-.639.235-.404 0-.644-.235a.78.78 0 0 1-.234-.574",fill:"#fff"}),React.createElement("defs",null,React.createElement("linearGradient",{id:"MultipleUserFAQFormsIcona",x1:0,y1:0,x2:44,y2:44,gradientUnits:"userSpaceOnUse"},React.createElement("stop",{stopColor:"#374691"}),React.createElement("stop",{offset:1,stopColor:"#2160df"}))))},label:(0,l.__)("Multiple User FAQ Forms","easy-accordion-free"),desc:(0,l.__)("Allow users to submit FAQs from the frontend, helping collect user-generated content efficiently.","easy-accordion-free"),demoLink:"#",docLink:"#",isPro:!0},{id:13,Icon:function(){return React.createElement("svg",{xmlns:"http://www.w3.org/2000/svg",width:44,height:44,viewBox:"0 0 44 44",fill:"none"},React.createElement("rect",{width:44,height:44,rx:5.5,fill:"url(#SpamProtectionreCAPTCHAIcona)"}),React.createElement("path",{d:"M21.582 36.36c.276.053.56.053.837 0l.146-.033.144-.043.564-.195c5.729-2.066 8.683-5.45 10.144-9.243 1.48-3.844 1.39-8.035 1.323-11.407v-.026a28 28 0 0 1-.028-.888c-.026-1.656-1.375-2.947-3.01-3.035-3.473-.186-6.13-1.281-8.379-3.382l-.01-.008-.01-.01a1.975 1.975 0 0 0-2.605 0l-.01.01-.01.008c-2.109 1.97-4.576 3.055-7.737 3.336l-.642.046c-1.634.088-2.985 1.378-3.01 3.034l-.027.89-.001.012v.012c-.067 3.356-.165 7.547 1.31 11.394 1.504 3.922 4.604 7.41 10.722 9.453q.134.045.269.07v.002zm.339-1.767q-.03-.006-.057-.016c-5.635-1.883-8.31-4.997-9.61-8.39-1.33-3.465-1.261-7.298-1.193-10.712q.011-.23.018-.454l.01-.468.009-.12c.07-.592.586-1.108 1.299-1.146 3.841-.206 6.906-1.44 9.492-3.846a.175.175 0 0 1 .227.002c2.585 2.406 5.65 3.639 9.49 3.844.76.04 1.297.624 1.307 1.266l.011.467q.006.225.018.455c.067 3.428.129 7.262-1.204 10.723-1.304 3.389-3.98 6.497-9.6 8.38a.43.43 0 0 1-.216.015",fill:"#fff"}),React.createElement("path",{d:"M21.504 14.284a7.7 7.7 0 0 1 5.207 2.023 1 1 0 0 1 .03 1.445l-1.56 1.561a1 1 0 0 1-1.365.047 3.5 3.5 0 0 0-2.312-.87c-.969 0-1.846.393-2.481 1.028l-.001.001a3.5 3.5 0 0 0-.692.984 1 1 0 0 1 .437 1.641l-.111.102-2.89 2.268a1 1 0 0 1-1.547-.415l-1.368-3.409a1 1 0 0 1 1.188-1.34l.197.053a7.7 7.7 0 0 1 1.811-2.858 7.7 7.7 0 0 1 5.457-2.261m0 1.4a6.3 6.3 0 0 0-4.466 1.85 6.3 6.3 0 0 0-1.618 2.762.85.85 0 0 1-.975.609l.875 2.178 1.869-1.467a.85.85 0 0 1-.404-.979 4.9 4.9 0 0 1 1.247-2.108l.17-.162a4.9 4.9 0 0 1 3.302-1.277 4.9 4.9 0 0 1 2.94.979l1.002-1.002a6.3 6.3 0 0 0-3.942-1.383m5.786 3.732a1.002 1.002 0 0 1 1.447.485l1.368 3.408a1.001 1.001 0 0 1-1.188 1.341l-.2-.054q-.06.174-.129.343a.7.7 0 0 1-1.294-.534q.14-.342.241-.702a.85.85 0 0 1 .975-.608l-.875-2.18-1.869 1.468a.85.85 0 0 1 .404.98 4.9 4.9 0 0 1-1.037 1.886l-.21.222a4.9 4.9 0 0 1-3.471 1.439 4.9 4.9 0 0 1-2.94-.98l-1.003 1.002a6.3 6.3 0 0 0 3.943 1.384 6.3 6.3 0 0 0 4.75-2.153.7.7 0 1 1 1.052.923q-.167.19-.346.37a7.7 7.7 0 0 1-5.456 2.26 7.7 7.7 0 0 1-5.208-2.023 1 1 0 0 1-.03-1.445l1.56-1.56a1 1 0 0 1 1.288-.11l.078.061.24.194a3.5 3.5 0 0 0 2.072.677c.969 0 1.846-.392 2.481-1.028h.001c.285-.285.518-.619.691-.985a1 1 0 0 1-.325-1.742l2.89-2.269z",fill:"#fff"}),React.createElement("defs",null,React.createElement("linearGradient",{id:"SpamProtectionreCAPTCHAIcona",x1:44,y1:0,x2:0,y2:44,gradientUnits:"userSpaceOnUse"},React.createElement("stop",{stopColor:"#1b39aa"}),React.createElement("stop",{offset:1,stopColor:"#5490f7"}))))},label:(0,l.__)("Spam Protection (reCAPTCHA)","easy-accordion-free"),desc:(0,l.__)("Protect forms from spam submissions using Google reCAPTCHA, ensuring secure and reliable data collection.","easy-accordion-free"),videoLink:"#",docLink:"#",isPro:!0},{id:14,Icon:function(){return React.createElement("svg",{xmlns:"http://www.w3.org/2000/svg",width:44,height:44,viewBox:"0 0 44 44",fill:"none"},React.createElement("rect",{width:44,height:44,rx:5.5,fill:"url(#FAQContentEqualHeightIcona)"}),React.createElement("path",{d:"M34.6 11.982a.28.28 0 0 0-.282-.281H9.682a.28.28 0 0 0-.282.281v20.036c0 .156.126.282.282.282h24.636a.28.28 0 0 0 .282-.282zm1.8 20.036c0 1.15-.932 2.082-2.082 2.082H9.682A2.08 2.08 0 0 1 7.6 32.018V11.982c0-1.15.932-2.082 2.082-2.082h24.636c1.15 0 2.082.933 2.082 2.082z",fill:"#fff"}),React.createElement("path",{d:"M29.572 13.01a1.18 1.18 0 0 1 1.49-.008l.09.08.765.76a.591.591 0 0 1-.833.84l-.762-.759-.754.765a.591.591 0 1 1-.842-.83l.757-.767zm-7.484-.006a.8.8 0 1 1 0 1.6H11.5a.8.8 0 1 1 0-1.6zm3.962 6.046a.75.75 0 0 1 0 1.5H11.5a.75.75 0 1 1 0-1.5zm0 2.6a.75.75 0 0 1 0 1.5H11.5a.75.75 0 0 1 0-1.5zm0 2.6a.75.75 0 0 1 0 1.5H11.5a.75.75 0 0 1 0-1.5zm-2 2.6a.75.75 0 0 1 0 1.5H11.5a.75.75 0 0 1 0-1.5zm-3 2.6a.75.75 0 0 1 0 1.5H11.5a.75.75 0 1 1 0-1.5zM34.5 16.032a.769.769 0 0 1 0 1.537h-26a.769.769 0 0 1 0-1.537zM30.4 29.8v-10a.6.6 0 1 1 1.2 0v10a.6.6 0 1 1-1.2 0",fill:"#fff"}),React.createElement("path",{d:"M30.037 19.602a1.35 1.35 0 0 1 1.911-.009l.975.97a.6.6 0 1 1-.846.85l-.974-.969a.147.147 0 0 0-.21.001l-.965.979a.6.6 0 0 1-.856-.842zm-.957 8.971a.6.6 0 0 1 .848.007l.965.978c.058.059.15.06.21.001l.974-.969a.6.6 0 1 1 .846.85l-.975.97a1.35 1.35 0 0 1-1.91-.01l-.966-.979a.6.6 0 0 1 .007-.848",fill:"#fff"}),React.createElement("defs",null,React.createElement("linearGradient",{id:"FAQContentEqualHeightIcona",x1:0,y1:0,x2:44,y2:44,gradientUnits:"userSpaceOnUse"},React.createElement("stop",{stopColor:"#023c71"}),React.createElement("stop",{offset:1,stopColor:"#17cfef"}))))},label:(0,l.__)("FAQ Content Equal Height","easy-accordion-free"),desc:(0,l.__)("Maintain consistent height across accordion items for a balanced layout and improved visual presentation.","easy-accordion-free"),demoLink:"#",docLink:"#",isPro:!0},{id:15,Icon:function(){return React.createElement("svg",{xmlns:"http://www.w3.org/2000/svg",width:44,height:44,viewBox:"0 0 44 44",fill:"none"},React.createElement("path",{d:"M0 5.5A5.5 5.5 0 0 1 5.5 0h33A5.5 5.5 0 0 1 44 5.5v33a5.5 5.5 0 0 1-5.5 5.5h-33A5.5 5.5 0 0 1 0 38.5z",fill:"url(#ContentinCollapsedStateIcona)"}),React.createElement("path",{d:"M24.1 11.182a.28.28 0 0 0-.282-.282H10.182a.28.28 0 0 0-.282.282v21.636c0 .156.126.282.282.282h13.636a.28.28 0 0 0 .282-.282zm1.8 21.636c0 1.15-.932 2.082-2.082 2.082H10.182A2.08 2.08 0 0 1 8.1 32.818V11.182c0-1.15.932-2.082 2.082-2.082h13.636c1.15 0 2.082.932 2.082 2.082zm8.2-21.636a.28.28 0 0 0-.282-.282h-3.636a.28.28 0 0 0-.282.282v21.636c0 .156.126.282.282.282h3.636a.28.28 0 0 0 .282-.282zm1.8 21.636c0 1.15-.932 2.082-2.082 2.082h-3.636a2.08 2.08 0 0 1-2.082-2.082V11.182c0-1.15.932-2.082 2.082-2.082h3.636c1.15 0 2.082.932 2.082 2.082z",fill:"#fff"}),React.createElement("path",{d:"M31.2 30.59V16a.8.8 0 1 1 1.6 0v14.59a.8.8 0 1 1-1.6 0m-9.7-6.49a.9.9 0 0 1 0 1.8h-9a.9.9 0 0 1 0-1.8zm0 2.9a.8.8 0 1 1 0 1.6h-9a.8.8 0 1 1 0-1.6zM19 29.8a.8.8 0 1 1 0 1.6h-4a.8.8 0 1 1 0-1.6z",fill:"#fff"}),React.createElement("defs",null,React.createElement("linearGradient",{id:"ContentinCollapsedStateIcona",x1:0,y1:22,x2:44,y2:22,gradientUnits:"userSpaceOnUse"},React.createElement("stop",{stopColor:"#ab4cfe"}),React.createElement("stop",{offset:1,stopColor:"#7317fe"}))))},label:(0,l.__)("Content in Collapsed State","easy-accordion-free"),desc:(0,l.__)("Show partial content in collapsed items to encourage interaction while maintaining a clean and compact layout.","easy-accordion-free"),demoLink:"#",docLink:"#",isPro:!0},{id:16,Icon:function(){return React.createElement("svg",{xmlns:"http://www.w3.org/2000/svg",width:44,height:44,viewBox:"0 0 44 44",fill:"none"},React.createElement("path",{d:"M0 5.5A5.5 5.5 0 0 1 5.5 0h33A5.5 5.5 0 0 1 44 5.5v33a5.5 5.5 0 0 1-5.5 5.5h-33A5.5 5.5 0 0 1 0 38.5z",fill:"url(#ContentinCollapsedStateIcona)"}),React.createElement("path",{d:"M34.308 22c0-6.798-5.51-12.308-12.308-12.308S9.692 15.202 9.692 22 15.202 34.308 22 34.308 34.308 28.798 34.308 22M36 22c0 7.732-6.268 14-14 14S8 29.732 8 22 14.268 8 22 8s14 6.268 14 14",fill:"#fff"}),React.createElement("path",{d:"M30.722 26.9C29.475 31.972 26.204 36 22 36s-7.475-4.028-8.722-9.1l1.642-.404c1.185 4.817 4.072 7.812 7.08 7.812s5.896-2.995 7.08-7.812zM22 8c4.204 0 7.475 4.028 8.722 9.1l-1.642.404c-1.184-4.817-4.072-7.812-7.08-7.812s-5.895 2.995-7.08 7.812l-1.642-.404C14.525 12.028 17.796 8 22 8",fill:"#fff"}),React.createElement("path",{d:"M34.214 25.852a.846.846 0 0 1 0 1.692H9.786a.846.846 0 0 1 0-1.692zm0-9.396a.846.846 0 0 1 0 1.692H9.786a.846.846 0 0 1 0-1.692zm-9.395 4.698a.846.846 0 0 1 0 1.692H12.604a.846.846 0 0 1 0-1.692zm4.602-1.734a1.34 1.34 0 0 1 1.86-.008l.869.834a.658.658 0 0 1-.911.949l-.868-.835-.004-.002-.01-.002-.011.002-.004.002-.86.843a.658.658 0 0 1-.92-.94zm-.052 5.162a1.34 1.34 0 0 0 1.86.01l.869-.834a.658.658 0 0 0-.911-.95l-.868.836-.004.002-.011.001-.01-.002-.004-.001-.86-.843a.658.658 0 0 0-.92.939z",fill:"#fff"}),React.createElement("path",{d:"M21.154 17.302V8.846a.846.846 0 0 1 1.692 0v8.456a.846.846 0 0 1-1.692 0m0 17.852v-8.456a.846.846 0 0 1 1.692 0v8.456a.846.846 0 0 1-1.692 0",fill:"#fff"}),React.createElement("defs",null,React.createElement("linearGradient",{id:"ContentinCollapsedStateIcona",x1:0,y1:0,x2:44,y2:44,gradientUnits:"userSpaceOnUse"},React.createElement("stop",{stopColor:"#3b2667"}),React.createElement("stop",{offset:1,stopColor:"#bc78ec"}))))},label:(0,l.__)("Global Toggle All Button","easy-accordion-free"),desc:(0,l.__)("Enable users to expand or collapse all accordion items at once for faster navigation and better usability.","easy-accordion-free"),demoLink:"#",docLink:"#",isPro:!0},{id:17,Icon:function(){return React.createElement("svg",{xmlns:"http://www.w3.org/2000/svg",width:44,height:44,viewBox:"0 0 44 44",fill:"none"},React.createElement("path",{d:"M0 5.5A5.5 5.5 0 0 1 5.5 0h33A5.5 5.5 0 0 1 44 5.5v33a5.5 5.5 0 0 1-5.5 5.5h-33A5.5 5.5 0 0 1 0 38.5z",fill:"url(#ExtensiveCustomIconLibraryIcona)"}),React.createElement("path",{d:"M13.144 8.804a1.375 1.375 0 0 1 2.252 0l.108.18 1.223 2.427 2.57.466c1.135.206 1.486 1.576.765 2.352l-1.84 1.98.378 2.744c.142 1.038-.923 2.006-2 1.452l-2.33-1.2-2.33 1.2c-1.077.554-2.141-.414-1.999-1.452l.376-2.743-1.839-1.98c-.72-.777-.37-2.148.765-2.353l2.57-.466 1.224-2.428zm.186 3.597a1.39 1.39 0 0 1-.99.744l-2.067.373 1.488 1.601c.293.316.421.744.364 1.161l-.297 2.157 1.817-.933.15-.068c.307-.113.644-.113.951 0l.15.068 1.815.933-.296-2.157a1.42 1.42 0 0 1 .364-1.161l1.487-1.6-2.065-.374a1.39 1.39 0 0 1-.99-.744l-.94-1.866zm5.31 17.212a4.37 4.37 0 1 0-8.74 0 4.37 4.37 0 0 0 8.74 0m1.8 0a6.17 6.17 0 1 1-12.34 0 6.17 6.17 0 0 1 12.34 0M34.1 10.592a.27.27 0 0 0-.271-.27h-8.433a.27.27 0 0 0-.27.27v8.432c0 .15.12.272.27.272h8.433c.15 0 .271-.122.271-.272zm1.8 8.432a2.07 2.07 0 0 1-2.071 2.072h-8.433a2.07 2.07 0 0 1-2.071-2.072v-8.432c0-1.144.928-2.071 2.071-2.072h8.433c1.143 0 2.07.928 2.071 2.072zm-1.8 8.815c0 1.616-1.093 3.073-2.387 4.207a14 14 0 0 1-2.101 1.505 14 14 0 0 1-2.1-1.505c-1.293-1.134-2.386-2.59-2.386-4.207a2.058 2.058 0 0 1 3.749-1.175l.067.086a.9.9 0 0 0 1.41-.086 2.059 2.059 0 0 1 3.749 1.175m1.8 0a3.858 3.858 0 0 0-6.287-2.995 3.859 3.859 0 0 0-6.288 2.995c0 2.42 1.6 4.333 3 5.56a15.6 15.6 0 0 0 2.808 1.945l.053.028.015.008.005.002h.002l.265-.526-.264.528a.9.9 0 0 0 .807 0l-.403-.805.404.804.002-.001.005-.002.016-.008.052-.028q.069-.036.189-.102A15.6 15.6 0 0 0 32.9 33.4c1.4-1.227 2.999-3.14 2.999-5.56",fill:"#fff"}),React.createElement("defs",null,React.createElement("linearGradient",{id:"ExtensiveCustomIconLibraryIcona",x1:0,y1:22,x2:44,y2:22,gradientUnits:"userSpaceOnUse"},React.createElement("stop",{stopColor:"#ab4cfe"}),React.createElement("stop",{offset:1,stopColor:"#7317fe"}))))},label:(0,l.__)("Extensive Custom Icon Library","easy-accordion-free"),desc:(0,l.__)("Choose from a wide range of icons to enhance design flexibility and improve visual communication within content.","easy-accordion-free"),videoLink:"#",docLink:"#",isPro:!0},{id:18,Icon:function(){return React.createElement("svg",{xmlns:"http://www.w3.org/2000/svg",width:44,height:44,viewBox:"0 0 44 44",fill:"none"},React.createElement("path",{d:"M0 5.5A5.5 5.5 0 0 1 5.5 0h33A5.5 5.5 0 0 1 44 5.5v33a5.5 5.5 0 0 1-5.5 5.5h-33A5.5 5.5 0 0 1 0 38.5z",fill:"url(#ImageAccordionLightboxIcona)"}),React.createElement("path",{d:"M20.27 31.09c6.1 0 11.044-4.945 11.044-11.045S26.37 9 20.27 9 9.224 13.945 9.224 20.045 14.17 31.09 20.27 31.09ZM34.776 35l-6.482-6.482M15.488 19.99h9.579m-4.79 4.79V15.2",stroke:"#fff",strokeWidth:2,strokeMiterlimit:10,strokeLinecap:"round"}),React.createElement("defs",null,React.createElement("linearGradient",{id:"ImageAccordionLightboxIcona",x1:1.833,y1:0,x2:42.167,y2:44,gradientUnits:"userSpaceOnUse"},React.createElement("stop",{stopColor:"#ffbd29"}),React.createElement("stop",{offset:1,stopColor:"#ff2db6"}))))},label:(0,l.__)("Image Accordion Lightbox","easy-accordion-free"),desc:(0,l.__)("Open images in a popup view for distraction-free browsing and improved user focus on visual content.","easy-accordion-free"),demoLink:"#",docLink:"#",isPro:!0},{id:19,Icon:function(){return React.createElement("svg",{xmlns:"http://www.w3.org/2000/svg",width:44,height:44,viewBox:"0 0 44 44",fill:"none"},React.createElement("path",{d:"M0 5.5A5.5 5.5 0 0 1 5.5 0h33A5.5 5.5 0 0 1 44 5.5v33a5.5 5.5 0 0 1-5.5 5.5h-33A5.5 5.5 0 0 1 0 38.5z",fill:"url(#OneClickFAQCloseButtonIcona)"}),React.createElement("path",{d:"M34.1 10.432a.28.28 0 0 0-.282-.282H10.182a.28.28 0 0 0-.282.282v13.636c0 .156.126.281.282.282h23.636a.28.28 0 0 0 .282-.282zm1.8 13.636c0 1.15-.932 2.082-2.082 2.082H10.182A2.08 2.08 0 0 1 8.1 24.068V10.432c0-1.15.932-2.082 2.082-2.082h23.636c1.15 0 2.082.932 2.082 2.082zm-1.8 5.864a.28.28 0 0 0-.282-.282H10.182a.28.28 0 0 0-.282.282v3.636c0 .156.126.282.282.282h23.636a.28.28 0 0 0 .282-.282zm1.8 3.636c0 1.15-.932 2.082-2.082 2.082H10.182A2.08 2.08 0 0 1 8.1 33.568v-3.636c0-1.15.932-2.082 2.082-2.082h23.636c1.15 0 2.082.932 2.082 2.082z",fill:"#fff"}),React.createElement("path",{fillRule:"evenodd",clipRule:"evenodd",d:"M27.452 20.05a.65.65 0 0 0-.652.652v1.826c0 .36.292.652.652.652h4.696c.36 0 .652-.291.652-.652v-1.826a.65.65 0 0 0-.652-.652zm3.652.913a.652.652 0 0 1 0 1.304h-2.608a.652.652 0 0 1 0-1.304z",fill:"#fff"}),React.createElement("path",{d:"M30.072 11.459a1.18 1.18 0 0 1 1.49-.008l.09.081.765.76a.591.591 0 0 1-.833.839l-.762-.758-.754.765a.591.591 0 1 1-.842-.83l.757-.767zm-7.484-.107a.9.9 0 0 1 0 1.801H12a.9.9 0 0 1 0-1.8zm7.484 21.192c.43.357 1.056.36 1.49.008l.09-.081.765-.76a.591.591 0 0 0-.833-.839l-.762.758-.754-.764a.591.591 0 1 0-.842.829l.757.767zm-7.484-1.692a.9.9 0 0 1 0 1.801H12a.9.9 0 0 1 0-1.8zM31.55 17.3a.8.8 0 1 1 0 1.6H12a.8.8 0 1 1 0-1.6zm-7 2.7a.8.8 0 1 1 0 1.6H12a.8.8 0 1 1 0-1.6zM35 14.481a.769.769 0 0 1 0 1.538H9a.769.769 0 0 1 0-1.538z",fill:"#fff"}),React.createElement("defs",null,React.createElement("linearGradient",{id:"OneClickFAQCloseButtonIcona",x1:0,y1:0,x2:44,y2:44,gradientUnits:"userSpaceOnUse"},React.createElement("stop",{stopColor:"#ff96f9"}),React.createElement("stop",{offset:1,stopColor:"#c32bac"}))))},label:(0,l.__)("One-Click FAQ Close Button","easy-accordion-free"),desc:(0,l.__)("Allow users to quickly close open accordion items, improving browsing control and enhancing overall user experience.","easy-accordion-free"),demoLink:"#",docLink:"#",isPro:!0},{id:20,Icon:function(){return React.createElement("svg",{xmlns:"http://www.w3.org/2000/svg",width:44,height:44,viewBox:"0 0 44 44",fill:"none"},React.createElement("path",{d:"M0 5.5A5.5 5.5 0 0 1 5.5 0h33A5.5 5.5 0 0 1 44 5.5v33a5.5 5.5 0 0 1-5.5 5.5h-33A5.5 5.5 0 0 1 0 38.5z",fill:"url(#ContentAnimationsIcona)"}),React.createElement("path",{d:"M35.843 9.457a1.155 1.155 0 0 1 0 2.31H18.66a1.155 1.155 0 0 1 0-2.31zm-4.909 10.666a1.534 1.534 0 0 1 0 3.069H13.752a1.534 1.534 0 0 1 0-3.069zm-4.91 10.739a1.84 1.84 0 1 1 0 3.682H8.843a1.84 1.84 0 1 1 0-3.682z",fill:"#fff"}),React.createElement("defs",null,React.createElement("linearGradient",{id:"ContentAnimationsIcona",x1:0,y1:0,x2:44,y2:44,gradientUnits:"userSpaceOnUse"},React.createElement("stop",{stopColor:"#3662b2"}),React.createElement("stop",{offset:1,stopColor:"#13d2c4"}))))},label:(0,l.__)("25+ Content Animations","easy-accordion-free"),desc:(0,l.__)("Apply smooth animations to accordion content, creating dynamic interactions and improving user engagement.","easy-accordion-free"),demoLink:"#",docLink:"#",isPro:!0},{id:21,Icon:function(){return React.createElement("svg",{xmlns:"http://www.w3.org/2000/svg",width:44,height:44,viewBox:"0 0 44 44",fill:"none"},React.createElement("path",{d:"M0 5.5A5.5 5.5 0 0 1 5.5 0h33A5.5 5.5 0 0 1 44 5.5v33a5.5 5.5 0 0 1-5.5 5.5h-33A5.5 5.5 0 0 1 0 38.5z",fill:"url(#ImageHoverEffectsIcona)"}),React.createElement("path",{d:"M34.25 12.278c0-.59-.48-1.069-1.07-1.069H10.82c-.59 0-1.07.478-1.07 1.069v19.444c0 .59.48 1.069 1.07 1.069h22.36c.59 0 1.07-.478 1.07-1.07zM36 31.722a2.82 2.82 0 0 1-2.82 2.82H10.82A2.82 2.82 0 0 1 8 31.722V12.278a2.82 2.82 0 0 1 2.82-2.82h22.36a2.82 2.82 0 0 1 2.82 2.82z",fill:"#fff"}),React.createElement("path",{d:"M24.93 23.428a1.166 1.166 0 0 1 1.503.011l9.26 7.917-1.137 1.33-8.887-7.599-5.785 4.802c-.338.28-.804.346-1.207.172l-3.991-1.719-5.206 4.984-1.21-1.264 5.485-5.25.134-.111c.282-.2.638-.263.97-.175l.165.057 4.017 1.73zm-12.885-5.771a4.348 4.348 0 0 1 7.7-2.767.718.718 0 1 1-1.108.915 2.91 2.91 0 1 0 0 3.703.72.72 0 0 1 1.108.915 4.347 4.347 0 0 1-7.7-2.767",fill:"#fff"}),React.createElement("path",{d:"M17.653 17.657a4.348 4.348 0 0 1 7.7-2.767.718.718 0 1 1-1.108.915 2.91 2.91 0 1 0 0 3.703.72.72 0 0 1 1.108.915 4.347 4.347 0 0 1-7.7-2.767",fill:"#fff"}),React.createElement("path",{d:"M30.518 17.657a2.91 2.91 0 1 0-5.82 0 2.91 2.91 0 0 0 5.82 0m1.436 0a4.347 4.347 0 1 1-8.693 0 4.347 4.347 0 0 1 8.693 0",fill:"#fff"}),React.createElement("defs",null,React.createElement("linearGradient",{id:"ImageHoverEffectsIcona",x1:0,y1:0,x2:44,y2:44,gradientUnits:"userSpaceOnUse"},React.createElement("stop",{stopColor:"#3662b2"}),React.createElement("stop",{offset:1,stopColor:"#13d2c4"}))))},label:(0,l.__)("Image Hover Effects","easy-accordion-free"),desc:(0,l.__)("Add interactive hover animations to images, increasing engagement and enhancing the visual experience.","easy-accordion-free"),demoLink:"#",docLink:"#",isPro:!0},{id:22,Icon:function(){return React.createElement("svg",{xmlns:"http://www.w3.org/2000/svg",width:44,height:44,viewBox:"0 0 44 44",fill:"none"},React.createElement("rect",{width:44,height:44,rx:5.5,fill:"url(#ExpandedAreaWidthControlIcona)"}),React.createElement("path",{d:"M34.1 10.682a.28.28 0 0 0-.282-.282H10.182a.28.28 0 0 0-.282.282v3.636c0 .156.126.282.282.282h23.636a.28.28 0 0 0 .282-.282zm1.8 3.636c0 1.15-.932 2.082-2.082 2.082H10.182A2.08 2.08 0 0 1 8.1 14.318v-3.636c0-1.15.932-2.082 2.082-2.082h23.636c1.15 0 2.082.932 2.082 2.082z",fill:"#fff"}),React.createElement("path",{d:"M30.072 13.264c.43.357 1.056.36 1.49.008l.09-.081.765-.76a.591.591 0 0 0-.833-.839l-.762.758-.754-.764a.591.591 0 1 0-.842.829l.757.767zm-7.484-1.591a.8.8 0 1 1 0 1.6H12a.8.8 0 1 1 0-1.6zM34.1 20.682a.28.28 0 0 0-.282-.282H10.182a.28.28 0 0 0-.282.282v3.636c0 .156.126.281.282.282h23.636a.28.28 0 0 0 .282-.282zm1.8 3.636c0 1.15-.932 2.082-2.082 2.082H10.182A2.08 2.08 0 0 1 8.1 24.318v-3.636c0-1.15.932-2.082 2.082-2.082h23.636c1.15 0 2.082.932 2.082 2.082z",fill:"#fff"}),React.createElement("path",{d:"M30.072 23.264c.43.357 1.056.36 1.49.008l.09-.081.765-.76a.591.591 0 0 0-.833-.839l-.762.758-.754-.764a.591.591 0 1 0-.842.829l.757.767zm-7.484-1.591a.8.8 0 1 1 0 1.6H12a.8.8 0 1 1 0-1.6zM23.1 32a1.6 1.6 0 1 0-3.199 0 1.6 1.6 0 0 0 3.199 0m1.8 0a3.4 3.4 0 1 1-6.8 0 3.4 3.4 0 0 1 6.8 0",fill:"#fff"}),React.createElement("path",{d:"M18.5 31.1a.9.9 0 0 1 0 1.8H9a.9.9 0 0 1 0-1.8zm16.5 0a.9.9 0 0 1 0 1.8H24.5a.9.9 0 0 1 0-1.8z",fill:"#fff"}),React.createElement("defs",null,React.createElement("linearGradient",{id:"ExpandedAreaWidthControlIcona",x1:0,y1:0,x2:44,y2:44,gradientUnits:"userSpaceOnUse"},React.createElement("stop",{stopColor:"#79f1a4"}),React.createElement("stop",{offset:1,stopColor:"#0e5cad"}))))},label:(0,l.__)("Expanded Area Width Control","easy-accordion-free"),desc:(0,l.__)("Control the width of expanded content areas to improve readability and fit different layout requirements.","easy-accordion-free"),videoLink:"#",docLink:"#",isPro:!0},{id:23,Icon:function(){return React.createElement("svg",{xmlns:"http://www.w3.org/2000/svg",width:44,height:44,viewBox:"0 0 44 44",fill:"none"},React.createElement("path",{d:"M0 5.5A5.5 5.5 0 0 1 5.5 0h33A5.5 5.5 0 0 1 44 5.5v33a5.5 5.5 0 0 1-5.5 5.5h-33A5.5 5.5 0 0 1 0 38.5z",fill:"url(#ImageFlipFocalPointIcona)"}),React.createElement("path",{d:"M34.6 12a1.1 1.1 0 0 0-1.1-1.1h-23A1.1 1.1 0 0 0 9.4 12v20a1.1 1.1 0 0 0 1.1 1.1h23a1.1 1.1 0 0 0 1.1-1.1zm1.8 20a2.9 2.9 0 0 1-2.9 2.9h-23A2.9 2.9 0 0 1 7.6 32V12a2.9 2.9 0 0 1 2.9-2.9h23a2.9 2.9 0 0 1 2.9 2.9z",fill:"#fff"}),React.createElement("path",{d:"M25.014 23.469a1.2 1.2 0 0 1 1.546.011l9.525 8.144-1.17 1.368-9.142-7.816-5.95 4.938a1.2 1.2 0 0 1-1.241.178l-4.105-1.769-5.355 5.127-1.244-1.3 5.642-5.4.137-.115a1.2 1.2 0 0 1 .998-.18l.17.059 4.131 1.78zM23 18a1 1 0 1 1-2 0 1 1 0 0 1 2 0",fill:"#fff"}),React.createElement("path",{d:"M24.028 18a2.028 2.028 0 1 0-4.058 0 2.028 2.028 0 0 0 4.058 0m1.5 0a3.529 3.529 0 1 1-7.058-.001 3.529 3.529 0 0 1 7.058 0",fill:"#fff"}),React.createElement("path",{d:"M21.25 23v-2a.75.75 0 0 1 1.5 0v2a.75.75 0 0 1-1.5 0m0-8v-2a.75.75 0 0 1 1.5 0v2a.75.75 0 0 1-1.5 0M19 17.25a.75.75 0 0 1 0 1.5h-2a.75.75 0 0 1 0-1.5zm8 0a.75.75 0 0 1 0 1.5h-2a.75.75 0 0 1 0-1.5z",fill:"#fff"}),React.createElement("defs",null,React.createElement("linearGradient",{id:"ImageFlipFocalPointIcona",x1:0,y1:0,x2:44,y2:44,gradientUnits:"userSpaceOnUse"},React.createElement("stop",{stopColor:"#f761a1"}),React.createElement("stop",{offset:1,stopColor:"#8c1bab"}))))},label:(0,l.__)("Image Flip & Focal Point","easy-accordion-free"),desc:(0,l.__)("Flip images and adjust focal points to improve visual storytelling and highlight important content areas effectively.","easy-accordion-free"),videoLink:"#",docLink:"#",isPro:!0},{id:24,Icon:function(){return React.createElement("svg",{xmlns:"http://www.w3.org/2000/svg",width:44,height:44,viewBox:"0 0 44 44",fill:"none"},React.createElement("path",{d:"M0 5.5A5.5 5.5 0 0 1 5.5 0h33A5.5 5.5 0 0 1 44 5.5v33a5.5 5.5 0 0 1-5.5 5.5h-33A5.5 5.5 0 0 1 0 38.5z",fill:"url(#CustomReadMoreButtonIcona)"}),React.createElement("path",{d:"M26.1 18a4.1 4.1 0 1 0-8.2 0 4.1 4.1 0 0 0 8.2 0m1.8 0a5.9 5.9 0 1 1-11.8 0 5.9 5.9 0 0 1 11.8 0",fill:"#fff"}),React.createElement("path",{d:"M24 18.8a.8.8 0 1 0 0-1.6h-4a.8.8 0 1 0 0 1.6z",fill:"#fff"}),React.createElement("path",{d:"M22.8 16a.8.8 0 1 0-1.6 0v4a.8.8 0 1 0 1.6 0z",fill:"#fff"}),React.createElement("path",{d:"M8.1 29v-6a2.9 2.9 0 0 1 2.9-2.9h7v1.8h-7A1.1 1.1 0 0 0 9.9 23v6a1.1 1.1 0 0 0 1.1 1.1h22a1.1 1.1 0 0 0 1.1-1.1v-6a1.1 1.1 0 0 0-1.1-1.1h-7v-1.8h7a2.9 2.9 0 0 1 2.9 2.9v6a2.9 2.9 0 0 1-2.9 2.9H11A2.9 2.9 0 0 1 8.1 29",fill:"#fff"}),React.createElement("path",{d:"M30 25.1a.9.9 0 0 1 0 1.8H14a.9.9 0 0 1 0-1.8z",fill:"#fff"}),React.createElement("defs",null,React.createElement("linearGradient",{id:"CustomReadMoreButtonIcona",x1:0,y1:22,x2:44,y2:22,gradientUnits:"userSpaceOnUse"},React.createElement("stop",{stopColor:"#ab4cfe"}),React.createElement("stop",{offset:1,stopColor:"#7317fe"}))))},label:(0,l.__)("Custom Read More Button","easy-accordion-free"),desc:(0,l.__)("Add expandable content sections with customizable buttons, helping users explore more without cluttering the layout.","easy-accordion-free"),demoLink:"#",docLink:"#",isPro:!0},{id:25,Icon:function(){return React.createElement("svg",{xmlns:"http://www.w3.org/2000/svg",width:44,height:44,viewBox:"0 0 44 44",fill:"none"},React.createElement("path",{d:"M0 5.5A5.5 5.5 0 0 1 5.5 0h33A5.5 5.5 0 0 1 44 5.5v33a5.5 5.5 0 0 1-5.5 5.5h-33A5.5 5.5 0 0 1 0 38.5z",fill:"url(#PostProductMetaDisplayIcona)"}),React.createElement("path",{d:"M35.557 11.996a.79.79 0 0 1 0 1.58h-11.53a.79.79 0 1 1 0-1.58zm-9.951-2.738a.685.685 0 0 1 0 1.37h-1.58a.685.685 0 0 1 0-1.37zm4.212 0a.685.685 0 0 1 0 1.37H28.24a.685.685 0 0 1 0-1.37zm3.212 5.582a.79.79 0 0 1 0 1.579h-9.003a.79.79 0 1 1 0-1.58zm-4.212 2.842a.79.79 0 1 1 0 1.58h-4.791a.79.79 0 1 1 0-1.58zM8.863 18.789h11.373V9.52H8.863zm12.636.185c0 .595-.482 1.077-1.077 1.077H8.678A1.08 1.08 0 0 1 7.6 18.974V9.336c0-.595.482-1.077 1.078-1.078h11.744c.595 0 1.077.483 1.077 1.078z",fill:"#fff"}),React.createElement("path",{d:"M16.464 13.638a.77.77 0 0 1 .753.052l.106.085 3.982 3.812-.874.913-3.683-3.527-3.122 2.243a.77.77 0 0 1-.75.081l-1.802-.776-2.406 2.303-.874-.914 2.644-2.53.088-.072a.77.77 0 0 1 .637-.115l.108.037 1.847.794 3.23-2.318zm-3.108-1.659a.983.983 0 1 1-1.965 0 .983.983 0 0 1 1.965 0M35.61 27.844a.79.79 0 1 1 0 1.58H24.027a.79.79 0 1 1 0-1.58zm-11.32-1.519-.451.237a.158.158 0 0 1-.23-.166l.087-.503a.34.34 0 0 0-.099-.303l-.365-.356a.158.158 0 0 1 .088-.27l.504-.072a.34.34 0 0 0 .258-.188l.226-.457a.158.158 0 0 1 .283 0l.226.457c.05.101.146.171.258.188l.505.073c.129.019.18.178.087.269l-.365.356a.34.34 0 0 0-.099.303l.086.503a.158.158 0 0 1-.228.166l-.452-.237a.34.34 0 0 0-.319 0m3.852 0-.452.237a.158.158 0 0 1-.229-.166l.086-.503a.34.34 0 0 0-.098-.303l-.365-.356a.158.158 0 0 1 .087-.27l.505-.072a.34.34 0 0 0 .258-.188l.226-.457a.158.158 0 0 1 .282 0l.226.457c.05.101.147.171.258.188l.505.073c.13.019.18.178.087.269l-.365.356a.34.34 0 0 0-.098.303l.086.503a.158.158 0 0 1-.229.166l-.451-.237a.34.34 0 0 0-.32 0m3.852 0-.452.237a.158.158 0 0 1-.228-.166l.086-.503a.34.34 0 0 0-.099-.303l-.365-.356a.158.158 0 0 1 .087-.27l.505-.072a.34.34 0 0 0 .258-.188l.226-.457a.158.158 0 0 1 .283 0l.226.457c.05.101.146.171.258.188l.504.073c.13.019.181.178.088.269l-.365.356a.34.34 0 0 0-.099.303l.086.503a.158.158 0 0 1-.229.166l-.451-.237a.34.34 0 0 0-.32 0m-1.647 4.31a.685.685 0 0 1 0 1.37h-6.318a.685.685 0 0 1 0-1.37zm0 2.685a.685.685 0 0 1 0 1.37h-6.318a.685.685 0 0 1 0-1.37zM16.24 28.705a.547.547 0 0 1 1.092-.055l.111-.063-.313-1.204a1.06 1.06 0 0 0-.57-.691l-.233-.11c-.113.214-.26.424-.444.604-.323.32-.776.572-1.334.572-.874 0-1.47-.59-1.78-1.177l-.229.11a1.06 1.06 0 0 0-.568.688l-.32 1.207.112.065a.547.547 0 0 1 1.093.054v3.4a.15.15 0 0 0 .102.14 5.15 5.15 0 0 0 3.177 0h.003l.04-.02a.14.14 0 0 0 .061-.12zm-1.019-2.334c-.186.033-.46.053-.677.053a4 4 0 0 1-.64-.053c.167.174.287.32.64.348.284 0 .51-.184.677-.348m2.118 5.734c0 .545-.35 1.02-.864 1.187l-.001-.002a6.23 6.23 0 0 1-3.853 0 1.25 1.25 0 0 1-.862-1.185v-2.189l-.858-.494-.007-.005a.8.8 0 0 1-.37-.862l.005-.019.38-1.437a2.16 2.16 0 0 1 1.157-1.4l1.04-.496.01-.005.01-.004a.8.8 0 0 1 .318-.068c.007 0 .074-.002.163.018h.032l.09.034q.417.149.816.148c.268 0 .481-.04.735-.12l.015-.003.013-.004.005-.002.016-.007h.002l.024-.01.012-.003.032-.017.02-.004.03-.011h.028a.8.8 0 0 1 .353.003l.137.046.009.004.01.005 1.042.495c.58.275 1.004.792 1.165 1.406l.238.913.04-.023v.173l.098.376a.79.79 0 0 1-.375.89l-.822.47v-.005l-.033.018z",fill:"#fff"}),React.createElement("path",{d:"M8.863 34.479h11.373v-10.32H8.863zm12.636.03c0 .68-.552 1.233-1.233 1.233H8.833A1.233 1.233 0 0 1 7.6 34.509v-10.38c0-.682.552-1.234 1.233-1.234h11.433c.681 0 1.233.552 1.233 1.233z",fill:"#fff"}),React.createElement("defs",null,React.createElement("linearGradient",{id:"PostProductMetaDisplayIcona",x1:0,y1:0,x2:44,y2:44,gradientUnits:"userSpaceOnUse"},React.createElement("stop",{stopColor:"#374691"}),React.createElement("stop",{offset:1,stopColor:"#2160df"}))))},label:(0,l.__)("Post & Product Meta Display","easy-accordion-free"),desc:(0,l.__)("Display additional post or product metadata within accordion items to provide more context and useful information.","easy-accordion-free"),demoLink:"#",docLink:"#",isPro:!0},{id:26,Icon:function(){return React.createElement("svg",{xmlns:"http://www.w3.org/2000/svg",width:44,height:44,viewBox:"0 0 44 44",fill:"none"},React.createElement("path",{d:"M0 5.5A5.5 5.5 0 0 1 5.5 0h33A5.5 5.5 0 0 1 44 5.5v33a5.5 5.5 0 0 1-5.5 5.5h-33A5.5 5.5 0 0 1 0 38.5z",fill:"url(#PerItemCustomizationControlsIcona)"}),React.createElement("path",{d:"M34.1 25.818V10.182a.28.28 0 0 0-.282-.282H10.182a.28.28 0 0 0-.282.282v15.636c0 .156.126.281.282.282H13v1.8h-2.818A2.08 2.08 0 0 1 8.1 25.818V10.182c0-1.15.932-2.082 2.082-2.082h23.636c1.15 0 2.082.932 2.082 2.082v15.636c0 1.15-.932 2.082-2.082 2.082H31v-1.8h2.818a.28.28 0 0 0 .282-.282",fill:"#fff"}),React.createElement("path",{d:"M30.1 20.182a.28.28 0 0 0-.282-.282H14.182a.28.28 0 0 0-.282.282v13.636c0 .156.126.282.282.282h15.636a.28.28 0 0 0 .282-.282zm1.8 13.636c0 1.15-.932 2.082-2.082 2.082H14.182a2.08 2.08 0 0 1-2.082-2.082V20.182c0-1.15.932-2.082 2.082-2.082h15.636c1.15 0 2.082.932 2.082 2.082zm-1.828-22.609a1.18 1.18 0 0 1 1.49-.008l.09.081.765.76a.591.591 0 0 1-.833.839l-.762-.758-.754.765a.591.591 0 1 1-.842-.83l.757-.767zm-7.484-.107a.9.9 0 0 1 0 1.801H12a.9.9 0 0 1 0-1.8zM35 14.231a.769.769 0 0 1 0 1.538H9a.769.769 0 0 1 0-1.538z",fill:"#fff"}),React.createElement("path",{d:"M28 23.25a.75.75 0 0 1 0 1.5h-6a.75.75 0 0 1 0-1.5z",fill:"#fff"}),React.createElement("path",{d:"M21.25 24a.75.75 0 1 0-1.5 0 .75.75 0 0 0 1.5 0m1.5 0a2.25 2.25 0 1 1-4.5 0 2.25 2.25 0 0 1 4.5 0",fill:"#fff"}),React.createElement("path",{d:"M19 23.25a.75.75 0 0 1 0 1.5h-3a.75.75 0 0 1 0-1.5zm-3 6a.75.75 0 0 0 0 1.5h6a.75.75 0 0 0 0-1.5z",fill:"#fff"}),React.createElement("path",{d:"M22.75 30a.75.75 0 1 1 1.5 0 .75.75 0 0 1-1.5 0m-1.5 0a2.25 2.25 0 1 0 4.5 0 2.25 2.25 0 0 0-4.5 0",fill:"#fff"}),React.createElement("path",{d:"M25 29.25a.75.75 0 0 0 0 1.5h3a.75.75 0 0 0 0-1.5z",fill:"#fff"}),React.createElement("defs",null,React.createElement("linearGradient",{id:"PerItemCustomizationControlsIcona",x1:0,y1:0,x2:44,y2:44,gradientUnits:"userSpaceOnUse"},React.createElement("stop",{stopColor:"#3662b2"}),React.createElement("stop",{offset:1,stopColor:"#13d2c4"}))))},label:(0,l.__)("Per-Item Customization Controls","easy-accordion-free"),desc:(0,l.__)("Customize each accordion item individually to achieve precise control over content, styling, and behavior.","easy-accordion-free"),videoLink:"#",docLink:"#",isPro:!0},{id:27,Icon:function(){return React.createElement("svg",{xmlns:"http://www.w3.org/2000/svg",width:44,height:44,viewBox:"0 0 44 44",fill:"none"},React.createElement("path",{d:"M0 5.5A5.5 5.5 0 0 1 5.5 0h33A5.5 5.5 0 0 1 44 5.5v33a5.5 5.5 0 0 1-5.5 5.5h-33A5.5 5.5 0 0 1 0 38.5z",fill:"url(#AJAXPaginationsIcona)"}),React.createElement("path",{d:"M35.15 18.388c.3-.3.786-.3 1.086 0l2.346 2.345c.699.7.699 1.835 0 2.534l-2.346 2.346a.768.768 0 0 1-1.085-1.086l2.345-2.346c.1-.1.1-.262 0-.362l-2.346-2.346c-.3-.3-.3-.785 0-1.085m-26.3 7.225c-.3.3-.786.3-1.086 0l-2.346-2.346a1.793 1.793 0 0 1 0-2.534l2.346-2.345a.768.768 0 0 1 1.085 1.085L6.504 21.82c-.1.1-.1.263 0 .363l2.345 2.345c.3.3.3.786 0 1.085m4.733-6.683v6.14h-1.115v-4.657l-1.476.484v-1.08l2.464-.887zm16.809 2.593h.612q.323 0 .533-.111a.74.74 0 0 0 .315-.312 1 1 0 0 0 .107-.463 1 1 0 0 0-.094-.447.65.65 0 0 0-.287-.296 1 1 0 0 0-.484-.106 1 1 0 0 0-.44.094.8.8 0 0 0-.315.27.73.73 0 0 0-.115.415h-1.086q0-.485.254-.849a1.75 1.75 0 0 1 .697-.578q.44-.21.98-.21.59 0 1.034.197.447.194.693.57.25.378.25.936 0 .266-.127.533a1.5 1.5 0 0 1-.365.475q-.238.21-.587.34a2.3 2.3 0 0 1-.791.128h-.784zm0 .836v-.578h.784q.504 0 .873.119.374.114.615.328.242.21.357.488.12.279.12.599 0 .417-.157.746-.156.324-.438.55-.279.225-.657.344a2.8 2.8 0 0 1-.816.115q-.381 0-.742-.103a2.1 2.1 0 0 1-.644-.315 1.56 1.56 0 0 1-.455-.534 1.6 1.6 0 0 1-.168-.75h1.086q0 .246.12.439a.86.86 0 0 0 .336.303q.217.107.488.107.3 0 .512-.107a.8.8 0 0 0 .332-.311 1 1 0 0 0 .115-.488q0-.338-.127-.546a.75.75 0 0 0-.365-.308 1.4 1.4 0 0 0-.557-.098z",fill:"#fff"}),React.createElement("path",{fillRule:"evenodd",clipRule:"evenodd",d:"M16.593 18.47c0-.848.688-1.535 1.535-1.535h7.06c.848 0 1.535.687 1.535 1.535v7.06c0 .848-.687 1.535-1.534 1.535h-7.06a1.535 1.535 0 0 1-1.536-1.535zm7.277 5.59v1.01h-4.18v-.857l1.953-2.07q.275-.316.437-.556.166-.242.24-.437a1.08 1.08 0 0 0-.012-.823.63.63 0 0 0-.245-.287.74.74 0 0 0-.395-.1.7.7 0 0 0-.428.13.8.8 0 0 0-.274.357q-.096.225-.096.511h-1.305a1.95 1.95 0 0 1 1.01-1.733q.478-.275 1.118-.275.657 0 1.102.208.444.208.673.595.23.386.229.93 0 .309-.1.595a2.5 2.5 0 0 1-.279.57 5 5 0 0 1-.44.577q-.258.292-.582.615l-.915 1.04z",fill:"#fff"}),React.createElement("defs",null,React.createElement("linearGradient",{id:"AJAXPaginationsIcona",x1:1.833,y1:0,x2:42.167,y2:44,gradientUnits:"userSpaceOnUse"},React.createElement("stop",{stopColor:"#ffbd29"}),React.createElement("stop",{offset:1,stopColor:"#ff2db6"}))))},label:(0,l.__)("AJAX Paginations","easy-accordion-free"),desc:(0,l.__)("Load content dynamically without refreshing pages, ensuring smoother browsing and improved performance.","easy-accordion-free"),demoLink:"#",docLink:"#",isPro:!0},{id:28,Icon:function(){return React.createElement("svg",{xmlns:"http://www.w3.org/2000/svg",width:44,height:44,viewBox:"0 0 44 44",fill:"none"},React.createElement("path",{d:"M0 5.5A5.5 5.5 0 0 1 5.5 0h33A5.5 5.5 0 0 1 44 5.5v33a5.5 5.5 0 0 1-5.5 5.5h-33A5.5 5.5 0 0 1 0 38.5z",fill:"url(#InfiniteScrollPaginationIcona)"}),React.createElement("path",{d:"M19.976 10.463a.7.7 0 0 1 .061-.987l1.37-1.21a1.2 1.2 0 0 1 1.587 0l1.37 1.21a.7.7 0 1 1-.928 1.048L22.2 9.434l-1.236 1.09a.7.7 0 0 1-.987-.061m4.047 23.074a.7.7 0 0 1-.061.987l-1.37 1.21a1.2 1.2 0 0 1-1.587 0l-1.37-1.21a.7.7 0 1 1 .928-1.048l1.237 1.09 1.236-1.09a.7.7 0 0 1 .987.061M26.6 18.5a4.6 4.6 0 1 0-9.2 0v7a4.6 4.6 0 1 0 9.2 0zm1.8 7a6.4 6.4 0 0 1-12.8 0v-7a6.4 6.4 0 0 1 12.8 0z",fill:"#fff"}),React.createElement("path",{d:"M15.6 19v-1h1.8v1a1.1 1.1 0 0 0 1.1 1.1h7a1.1 1.1 0 0 0 1.1-1.1v-1h1.8v1a2.9 2.9 0 0 1-2.9 2.9h-7a2.9 2.9 0 0 1-2.9-2.9",fill:"#fff"}),React.createElement("path",{d:"M21.2 18v-2a.8.8 0 1 1 1.6 0v2a.8.8 0 1 1-1.6 0",fill:"#fff"}),React.createElement("defs",null,React.createElement("linearGradient",{id:"InfiniteScrollPaginationIcona",x1:0,y1:0,x2:44,y2:44,gradientUnits:"userSpaceOnUse"},React.createElement("stop",{stopColor:"#3662b2"}),React.createElement("stop",{offset:1,stopColor:"#13d2c4"}))))},label:(0,l.__)("Infinite Scroll Pagination","easy-accordion-free"),desc:(0,l.__)("Automatically load additional content as users scroll, creating a seamless and uninterrupted browsing experience.","easy-accordion-free"),demoLink:"#",docLink:"#",isPro:!0},{id:29,Icon:function(){return React.createElement("svg",{xmlns:"http://www.w3.org/2000/svg",width:44,height:44,viewBox:"0 0 44 44",fill:"none"},React.createElement("path",{d:"M0 5.5A5.5 5.5 0 0 1 5.5 0h33A5.5 5.5 0 0 1 44 5.5v33a5.5 5.5 0 0 1-5.5 5.5h-33A5.5 5.5 0 0 1 0 38.5z",fill:"url(#FAQTitleCustomLinkingIcona)"}),React.createElement("path",{d:"M34.1 24.318V11.682a.28.28 0 0 0-.282-.282H10.182a.28.28 0 0 0-.282.282v12.636c0 .156.126.281.282.282H13v1.8h-2.818A2.08 2.08 0 0 1 8.1 24.318V11.682c0-1.15.932-2.082 2.082-2.082h23.636c1.15 0 2.082.932 2.082 2.082v12.636c0 1.15-.932 2.082-2.082 2.082H31v-1.8h2.818a.28.28 0 0 0 .282-.282",fill:"#fff"}),React.createElement("path",{d:"M30.072 12.879a1.18 1.18 0 0 1 1.49-.008l.09.081.765.76a.591.591 0 0 1-.833.839l-.762-.758-.754.764a.591.591 0 1 1-.842-.829l.757-.767zm-7.184-.107a.9.9 0 0 1 0 1.801H12.3a.9.9 0 0 1 0-1.8zm7.912 5.91a.28.28 0 0 0-.282-.282H13.482a.28.28 0 0 0-.282.282v13.636c0 .156.126.282.282.282h17.036a.28.28 0 0 0 .282-.282zm1.8 13.636c0 1.15-.933 2.082-2.082 2.082H13.482a2.08 2.08 0 0 1-2.082-2.082V18.682c0-1.15.932-2.082 2.082-2.082h17.036c1.15 0 2.082.932 2.082 2.082z",fill:"#fff"}),React.createElement("path",{d:"M21.051 21.51a3.45 3.45 0 0 1 4.879 4.878l-.62.62a.817.817 0 0 1-1.156-1.156l.62-.62a1.815 1.815 0 0 0-2.567-2.566l-.62.62a.817.817 0 0 1-1.155-1.156zm-2.481 2.482a.818.818 0 0 1 1.156 1.156l-.62.62a1.815 1.815 0 0 0 2.566 2.566l.62-.62a.817.817 0 0 1 1.156 1.156l-.62.62a3.45 3.45 0 0 1-4.878-4.879z",fill:"#fff"}),React.createElement("path",{d:"M22.913 23.371a.818.818 0 0 1 1.156 1.156l-3.102 3.101a.817.817 0 0 1-1.156-1.155z",fill:"#fff"}),React.createElement("defs",null,React.createElement("linearGradient",{id:"FAQTitleCustomLinkingIcona",x1:0,y1:0,x2:44,y2:44,gradientUnits:"userSpaceOnUse"},React.createElement("stop",{stopColor:"#f761a1"}),React.createElement("stop",{offset:1,stopColor:"#8c1bab"}))))},label:(0,l.__)("FAQ Title Custom Linking","easy-accordion-free"),desc:(0,l.__)("Link accordion titles to external or internal pages, improving navigation and directing users to relevant resources.","easy-accordion-free"),videoLink:"#",docLink:"#",isPro:!0},{id:30,Icon:function(){return React.createElement("svg",{xmlns:"http://www.w3.org/2000/svg",width:44,height:44,viewBox:"0 0 44 44",fill:"none"},React.createElement("path",{d:"M0 5.5A5.5 5.5 0 0 1 5.5 0h33A5.5 5.5 0 0 1 44 5.5v33a5.5 5.5 0 0 1-5.5 5.5h-33A5.5 5.5 0 0 1 0 38.5z",fill:"url(#AJAXFormSubmissionIcona)"}),React.createElement("path",{d:"M28.425 14v-4a.1.1 0 0 0-.1-.1h-19a.1.1 0 0 0-.1.1v24a.1.1 0 0 0 .1.1h19a.1.1 0 0 0 .1-.1v-3.3a.9.9 0 0 1 1.8 0V34a1.9 1.9 0 0 1-1.9 1.9h-19a1.9 1.9 0 0 1-1.9-1.9V10a1.9 1.9 0 0 1 1.9-1.9h19a1.9 1.9 0 0 1 1.9 1.9v4a.9.9 0 0 1-1.8 0",fill:"#fff"}),React.createElement("path",{d:"M12.476 14.15h9.199v-1.2h-9.2zm10.5.35a.95.95 0 0 1-.95.95h-9.901a.95.95 0 0 1-.95-.95v-1.9a.95.95 0 0 1 .95-.95h9.9a.95.95 0 0 1 .95.95zm-10.5 4.65h9.199v-1.2h-9.2zm10.5.35a.95.95 0 0 1-.95.95h-9.901a.95.95 0 0 1-.95-.95v-1.9a.95.95 0 0 1 .95-.95h9.9a.95.95 0 0 1 .95.95zm-10.5 6.15h9.199v-2.7h-9.2zm10.5.35a.95.95 0 0 1-.95.95h-9.901a.95.95 0 0 1-.95-.95v-3.4a.95.95 0 0 1 .95-.95h9.9a.95.95 0 0 1 .95.95zm-10.5 5.15h12.699v-1.7h-12.7zm14 .35a.95.95 0 0 1-.95.95H12.124a.95.95 0 0 1-.95-.95v-2.4a.95.95 0 0 1 .95-.95h13.4a.95.95 0 0 1 .95.95z",fill:"#fff"}),React.createElement("path",{d:"M31.58 15.366c.832-1.007 2.298-1.1 3.236-.177l1.042 1.026c.895.881.957 2.35.16 3.313l-6.607 7.999a3.7 3.7 0 0 1-1.382 1.042l-3.77 1.612a.85.85 0 0 1-1.158-.99l1.082-4.259a4 4 0 0 1 .79-1.568zm-5.385 9.2a2.3 2.3 0 0 0-.286.535l-.079.25-.658 2.59 2.188-.935.203-.102q.299-.174.538-.46zm1.08-1.321 1.913 1.883 3.334-4.038-1.926-1.866zm6.347-6.845c-.214-.21-.523-.203-.731.048l-1.208 1.462 1.925 1.866 1.1-1.331c.243-.294.214-.766-.043-1.019z",fill:"#fff"}),React.createElement("defs",null,React.createElement("linearGradient",{id:"AJAXFormSubmissionIcona",x1:0,y1:22,x2:44,y2:22,gradientUnits:"userSpaceOnUse"},React.createElement("stop",{stopColor:"#ab4cfe"}),React.createElement("stop",{offset:1,stopColor:"#7317fe"}))))},label:(0,l.__)("AJAX Form Submission","easy-accordion-free"),desc:(0,l.__)("Submit forms instantly without page reload, improving user experience and increasing completion rates.","easy-accordion-free"),demoLink:"#",docLink:"#",isPro:!0},{id:31,Icon:function(){return React.createElement("svg",{xmlns:"http://www.w3.org/2000/svg",width:44,height:44,viewBox:"0 0 44 44",fill:"none"},React.createElement("rect",{width:44,height:44,rx:5.5,fill:"url(#EmailNotificationAndApprovalIcona)"}),React.createElement("path",{d:"M35.161 29.797a4.508 4.508 0 1 0-9.016 0 4.508 4.508 0 0 0 9.016 0m1.8 0a6.308 6.308 0 1 1-12.616 0 6.308 6.308 0 0 1 12.616 0",fill:"#fff"}),React.createElement("path",{d:"M32.3 28.104a.8.8 0 0 1 1.033 1.223l-2.885 2.433a.8.8 0 0 1-1.165-.143l-1.443-2.001a.8.8 0 0 1 1.3-.936l.936 1.3zM21.117 16.267v-3.785a1.82 1.82 0 1 0-3.642 0v3.785a.8.8 0 1 1-1.6 0v-3.785a3.42 3.42 0 0 1 6.843 0v3.785a.8.8 0 0 1-1.601 0",fill:"#fff"}),React.createElement("path",{d:"M23.082 15.466a.8.8 0 1 1 0 1.6h-7.571a.8.8 0 1 1 0-1.6zM18.496 9.86V8.695a.8.8 0 1 1 1.6 0V9.86a.8.8 0 0 1-1.6 0",fill:"#fff"}),React.createElement("path",{d:"M17.166 17.483v-1.217a.8.8 0 1 1 1.6 0v1.217a.526.526 0 0 0 1.05 0v-1.217a.8.8 0 0 1 1.6 0v1.217a2.125 2.125 0 0 1-4.25 0",fill:"#fff"}),React.createElement("path",{d:"M7.04 28.407V17.346c0-.692.313-1.345.849-1.78l4.652-4.036a.9.9 0 0 1 1.18 1.36l-4.654 4.037-.038.031a.49.49 0 0 0-.19.388v11.061c0 .271.22.49.491.49h15.915a.9.9 0 1 1 0 1.801H9.33a2.29 2.29 0 0 1-2.29-2.29m22.713-4.018v-7.043a.49.49 0 0 0-.19-.388l-.039-.031-4.652-4.037a.9.9 0 1 1 1.179-1.36l4.651 4.035a2.29 2.29 0 0 1 .85 1.78v7.044a.9.9 0 1 1-1.8 0",fill:"#fff"}),React.createElement("path",{d:"M18.83 20.989a.9.9 0 0 1 .933 0l7.03 4.255a.9.9 0 0 1-.933 1.54l-6.564-3.974-10.43 6.314a.9.9 0 1 1-.932-1.54z",fill:"#fff"}),React.createElement("path",{d:"M7.357 16.204a.9.9 0 0 1 1.262-.159l8.543 6.625a.9.9 0 0 1-1.103 1.423l-8.543-6.626a.9.9 0 0 1-.16-1.263m22.617-.159a.9.9 0 0 1 1.104 1.422l-8.543 6.626a.9.9 0 0 1-1.104-1.423z",fill:"#fff"}),React.createElement("defs",null,React.createElement("linearGradient",{id:"EmailNotificationAndApprovalIcona",x1:0,y1:0,x2:44,y2:44,gradientUnits:"userSpaceOnUse"},React.createElement("stop",{stopColor:"#79f1a4"}),React.createElement("stop",{offset:1,stopColor:"#0e5cad"}))))},label:(0,l.__)("Email Notification & Approval","easy-accordion-free"),desc:(0,l.__)("Send instant notifications and manage approval workflows to control and moderate submitted content effectively.","easy-accordion-free"),videoLink:"#",docLink:"#",isPro:!0},{id:32,Icon:function(){return React.createElement("svg",{xmlns:"http://www.w3.org/2000/svg",width:44,height:44,viewBox:"0 0 44 44",fill:"none"},React.createElement("rect",{width:44,height:44,rx:5.5,fill:"url(#AdvancedPostQueryBuilderIcona)"}),React.createElement("path",{d:"M34.1 11.5a1.1 1.1 0 0 0-1.1-1.1H11a1.1 1.1 0 0 0-1.1 1.1v21a1.1 1.1 0 0 0 1.1 1.1h22a1.1 1.1 0 0 0 1.1-1.1zm1.8 21a2.9 2.9 0 0 1-2.9 2.9H11a2.9 2.9 0 0 1-2.9-2.9v-21A2.9 2.9 0 0 1 11 8.6h22a2.9 2.9 0 0 1 2.9 2.9z",fill:"#fff"}),React.createElement("path",{d:"M28.46 23.635a2.881 2.881 0 1 1-5.762 0 2.881 2.881 0 0 1 5.762 0m1.6 0a4.482 4.482 0 1 0-8.963 0 4.482 4.482 0 0 0 8.964 0",fill:"#fff"}),React.createElement("path",{d:"M30.516 30.342a.8.8 0 1 0 1.13-1.13l-3.084-3.085a.8.8 0 1 0-1.13 1.131zM22.16 26.36v1.98a.343.343 0 0 1-.457.322l-1.466-.523a.34.34 0 0 1-.227-.322v-4.378c0-.613-.29-1.19-.782-1.557l-5.37-4a.34.34 0 0 1-.138-.274v-2.566c0-.189.154-.342.343-.342h13.844c.19 0 .342.153.342.342v2.56a.34.34 0 0 1-.14.276l-2.076 1.521a.8.8 0 0 0 .947 1.29l2.075-1.52c.499-.366.794-.948.794-1.567v-2.56a1.94 1.94 0 0 0-1.942-1.942H14.063c-1.073 0-1.943.87-1.943 1.942v2.566c0 .613.29 1.19.782 1.557l5.37 4a.34.34 0 0 1 .138.274v4.378c0 .82.516 1.553 1.29 1.829l1.465.523a1.942 1.942 0 0 0 2.595-1.83V26.36a.8.8 0 1 0-1.6 0",fill:"#fff"}),React.createElement("defs",null,React.createElement("linearGradient",{id:"AdvancedPostQueryBuilderIcona",x1:0,y1:0,x2:44,y2:44,gradientUnits:"userSpaceOnUse"},React.createElement("stop",{stopColor:"#79f1a4"}),React.createElement("stop",{offset:1,stopColor:"#0e5cad"}))))},label:(0,l.__)("Advanced Post Query Builder","easy-accordion-free"),desc:(0,l.__)("Fetch and display dynamic content using flexible query controls for better content management and automation.","easy-accordion-free"),videoLink:"#",docLink:"#",isPro:!0},{id:33,Icon:function(){return React.createElement("svg",{xmlns:"http://www.w3.org/2000/svg",width:44,height:44,viewBox:"0 0 44 44",fill:"none"},React.createElement("path",{d:"M0 5.5A5.5 5.5 0 0 1 5.5 0h33A5.5 5.5 0 0 1 44 5.5v33a5.5 5.5 0 0 1-5.5 5.5h-33A5.5 5.5 0 0 1 0 38.5z",fill:"url(#ReadyPatternsLibraryIcona)"}),React.createElement("path",{d:"M8.494 20.778v-3.735c0-1.092-.001-1.976.062-2.69.064-.726.2-1.37.53-1.96a4.67 4.67 0 0 1 1.8-1.801c.591-.33 1.235-.466 1.962-.53.713-.063 1.597-.062 2.69-.062 1.343 0 2.274-.015 3.107.297 1.858.697 2.6 2.415 3.192 3.597l.497.995h5.188c1.272 0 2.456-.003 3.436.077.943.077 1.898.24 2.592.703q.765.51 1.275 1.276c.824 1.232.67 2.47.67 2.855a1 1 0 1 1-2 0c0-.614.08-1.127-.332-1.744a2.6 2.6 0 0 0-.724-.725c-.231-.154-.725-.297-1.643-.372-.881-.071-1.972-.07-3.274-.07H16.827a1 1 0 0 1 0-2H20.1l-.051-.1c-.692-1.384-1.121-2.25-2.106-2.619-.412-.155-.904-.17-2.405-.17-1.128 0-1.908.002-2.514.055-.591.052-.92.148-1.162.283a2.67 2.67 0 0 0-1.029 1.03c-.135.242-.231.57-.283 1.161-.053.605-.055 1.386-.055 2.514v3.735c0 2.908.002 4.99.215 6.572.209 1.553.604 2.475 1.282 3.153.43.43.736.691 1.057.876.309.178.681.314 1.265.411 1.237.207 3.18.21 6.98.21a1 1 0 1 1 0 2c-3.698 0-5.864.004-7.31-.237-.758-.127-1.37-.326-1.934-.651-.552-.319-1.007-.73-1.472-1.195-1.112-1.112-1.612-2.526-1.85-4.3-.235-1.747-.233-3.987-.233-6.84",fill:"#fff"}),React.createElement("path",{d:"M33.694 24a.2.2 0 0 0-.2-.2h-8a.2.2 0 0 0-.2.2v8c0 .11.09.2.2.2h8a.2.2 0 0 0 .2-.2zm1.6 8a1.8 1.8 0 0 1-1.8 1.8h-8a1.8 1.8 0 0 1-1.8-1.8v-8a1.8 1.8 0 0 1 1.8-1.8h8a1.8 1.8 0 0 1 1.8 1.8z",fill:"#fff"}),React.createElement("path",{d:"M31.494 25.6a.9.9 0 0 1 0 1.8h-4a.9.9 0 0 1 0-1.8zm-1 3a.9.9 0 0 1 0 1.8h-3a.9.9 0 0 1 0-1.8z",fill:"#fff"}),React.createElement("defs",null,React.createElement("linearGradient",{id:"ReadyPatternsLibraryIcona",x1:0,y1:22,x2:44,y2:22,gradientUnits:"userSpaceOnUse"},React.createElement("stop",{stopColor:"#ab4cfe"}),React.createElement("stop",{offset:1,stopColor:"#7317fe"}))))},label:(0,l.__)("200+ Ready Patterns Library","easy-accordion-free"),desc:(0,l.__)("Access a large collection of pre-designed patterns to build layouts faster with consistent design quality.","easy-accordion-free"),demoLink:"#",docLink:"#",isPro:!0}];const Bu=function(){return React.createElement("div",{className:"sp-eap-modules-page"},React.createElement("div",{className:"eap-dashboard-page-header sp-d-flex sp-flex-col sp-gap-10px"},React.createElement("span",{className:"eap-dashboard-page-header__label"},(0,l.__)("Manage Modules","easy-accordion-free")),React.createElement("span",{className:"eap-dashboard-page-header__desc"},(0,l.__)("Enable only the modules you need to keep your site fast and optimized.","easy-accordion-free"))),React.createElement(Nu,{items:Lu,optionKey:"modules"}),React.createElement("div",{className:"eap-dashboard-page-header sp-d-flex sp-align-center sp-justify-between eaf-pro-modules"},React.createElement("span",{className:"sp-d-flex sp-flex-col sp-gap-10px"},React.createElement("span",{className:"eap-dashboard-page-header__label"},(0,l.__)("Unlock Powerful Features with Pro!","easy-accordion-free")),React.createElement("span",{className:"eap-dashboard-page-header__desc"},(0,l.__)("Upgrade now to unlock advanced features and streamline your workflow.","easy-accordion-free"))),React.createElement("a",{href:"https://easyaccordion.io/pricing/?ref=1",target:"_blank",rel:"noreferrer",className:"eaf-pro-modules-indicator-button sp-d-flex sp-align-center sp-gap-6px"},React.createElement(Ru,null),(0,l.__)("Upgrade to Pro","easy-accordion-free"))),React.createElement(Nu,{items:Du,optionKey:"modules"}))};function Fu(e){return Fu="function"==typeof Symbol&&"symbol"==typeof Symbol.iterator?function(e){return typeof e}:function(e){return e&&"function"==typeof Symbol&&e.constructor===Symbol&&e!==Symbol.prototype?"symbol":typeof e},Fu(e)}function zu(e,t){var n=Object.keys(e);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(e);t&&(r=r.filter(function(t){return Object.getOwnPropertyDescriptor(e,t).enumerable})),n.push.apply(n,r)}return n}function ju(e){for(var t=1;t<arguments.length;t++){var n=null!=arguments[t]?arguments[t]:{};t%2?zu(Object(n),!0).forEach(function(t){Hu(e,t,n[t])}):Object.getOwnPropertyDescriptors?Object.defineProperties(e,Object.getOwnPropertyDescriptors(n)):zu(Object(n)).forEach(function(t){Object.defineProperty(e,t,Object.getOwnPropertyDescriptor(n,t))})}return e}function Hu(e,t,n){return(t=function(e){var t=function(e){if("object"!=Fu(e)||!e)return e;var t=e[Symbol.toPrimitive];if(void 0!==t){var n=t.call(e,"string");if("object"!=Fu(n))return n;throw new TypeError("@@toPrimitive must return a primitive value.")}return String(e)}(e);return"symbol"==Fu(t)?t:t+""}(t))in e?Object.defineProperty(e,t,{value:n,enumerable:!0,configurable:!0,writable:!0}):e[t]=n,e}function Vu(e,t){return function(e){if(Array.isArray(e))return e}(e)||function(e,t){var n=null==e?null:"undefined"!=typeof Symbol&&e[Symbol.iterator]||e["@@iterator"];if(null!=n){var r,a,o,i,s=[],l=!0,c=!1;try{if(o=(n=n.call(e)).next,0===t){if(Object(n)!==n)return;l=!1}else for(;!(l=(r=o.call(n)).done)&&(s.push(r.value),s.length!==t);l=!0);}catch(e){c=!0,a=e}finally{try{if(!l&&null!=n.return&&(i=n.return(),Object(i)!==i))return}finally{if(c)throw a}}return s}}(e,t)||function(e,t){if(e){if("string"==typeof e)return Gu(e,t);var n={}.toString.call(e).slice(8,-1);return"Object"===n&&e.constructor&&(n=e.constructor.name),"Map"===n||"Set"===n?Array.from(e):"Arguments"===n||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)?Gu(e,t):void 0}}(e,t)||function(){throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.")}()}function Gu(e,t){(null==t||t>e.length)&&(t=e.length);for(var n=0,r=Array(t);n<t;n++)r[n]=e[n];return r}var qu=["generate_faqs_with_ai","saved_templates","pattern_library","seo_schema_markup"],Uu=["sp-easy-accordion-pro/vertical-accordion","sp-easy-accordion-pro/horizontal-accordion","sp-easy-accordion-pro/image-accordion","sp-easy-accordion-pro/accordion-slider","sp-easy-accordion-pro/sidebar-tab-accordion","sp-easy-accordion-pro/post-accordion","sp-easy-accordion-pro/product-accordion","sp-easy-accordion-pro/menu-accordion","sp-easy-accordion-pro/media-accordion","sp-easy-accordion-pro/user-faq-form"],Wu=React.createElement("svg",{width:"13",height:"13",viewBox:"0 0 13 13",fill:"none",xmlns:"http://www.w3.org/2000/svg"},React.createElement("path",{d:"M6.47461 1.24707C6.85097 3.76847 8.83144 5.7481 11.3525 6.125L12.5225 6.2998L11.3525 6.47461C8.83157 6.85179 6.85112 8.83112 6.47461 11.3525L6.2998 12.5225L6.125 11.3525C5.74845 8.83092 3.76819 6.85166 1.24707 6.47461L0.0761719 6.2998L1.24707 6.125C3.76832 5.74824 5.7486 3.76856 6.125 1.24707L6.2998 0.0761719L6.47461 1.24707Z",fill:"#FF734C",stroke:"#FF734C",strokeWidth:"0.0224423"})),Qu=[{url:"https://easyaccordion.io/generate-high-converting-faqs-withpowerful-ai-in-seconds/",icon:Wu,label:(0,l.__)("Unlimited FAQs Generation with AI","easy-accordion-free"),hot:!0},{url:"https://easyaccordion.io/patterns/",icon:Wu,label:(0,l.__)("200+ Ready Patterns Library","easy-accordion-free")},{url:"https://easyaccordion.io/blocks/",icon:Wu,label:(0,l.__)("15+ Powerful Gutenberg Blocks","easy-accordion-free")},{url:"https://easyaccordion.io/patterns/#accordion-slider",icon:Wu,label:(0,l.__)("Interactive Accordion Slider","easy-accordion-free")},{url:"https://easyaccordion.io/core-accordion-content-features/#FAQ-Title-Prefix-&-Suffix",icon:Wu,label:(0,l.__)("FAQ Title Badges, Prefix & Suffix","easy-accordion-free"),hot:!0},{url:"https://easyaccordion.io/core-accordion-content-features/#Accordion-Featured-Icon",icon:Wu,label:(0,l.__)("Accordion Subtitles & Featured Icon","easy-accordion-free")},{url:"https://easyaccordion.io/faq-title-custom-linking/",icon:Wu,label:(0,l.__)("FAQ Title Custom Linking","easy-accordion-free")},{url:"https://easyaccordion.io/woocommerce-product-faqs-tab/",icon:Wu,label:(0,l.__)("WooCommerce Product FAQ Tab","easy-accordion-free")},{url:"https://easyaccordion.io/add-smart-faq-search-filters-to-help-usersfind-answers-faster/",icon:Wu,label:(0,l.__)("Frontend Live Taxonomy Filter","easy-accordion-free")},{url:"https://easyaccordion.io/faq-analytics/",icon:Wu,label:(0,l.__)("FAQ Analytics (Impressions & Clicks)","easy-accordion-free")},{url:"https://easyaccordion.io/user-faq-forms/",icon:Wu,label:(0,l.__)("User FAQ Submission Forms","easy-accordion-free")},{url:"https://easyaccordion.io/accordion-animation/",icon:Wu,label:(0,l.__)("Motion Effects & Animations","easy-accordion-free")}];const Ku=function(e){var t,n,r,a,o=e.setPageAndHash,c=(0,s.useSelect)(function(e){return e(qc).getBlockVisibility()}),u=((0,s.useSelect)(function(e){return e(qc).getDashboardSettings()}),(0,s.useDispatch)(qc).saveSettings),d=Vu((0,i.useState)(!1),2),p=d[0],f=d[1],m=Vu((0,i.useState)(""),2),h=m[0],g=m[1],v=(0,i.useMemo)(function(){var e=(new Date).getHours();return e<12?(0,l.__)("Good morning","easy-accordion-free"):e<17?(0,l.__)("Good afternoon","easy-accordion-free"):e<21?(0,l.__)("Good evening","easy-accordion-free"):(0,l.__)("Good night","easy-accordion-free")},[]);(0,i.useEffect)(function(){var e=function(){var e,t;if(null!==(e=sp_eab_admin_dashboard_localize)&&void 0!==e&&e.current_user)return(t=sp_eab_admin_dashboard_localize.current_user).charAt(0).toUpperCase()+t.slice(1);try{var n,r=null===(n=wp.data)||void 0===n?void 0:n.select("core");if(r){var a,o=(null===(a=r.getCurrentUser)||void 0===a?void 0:a.call(r))||r.currentUser;return(null==o?void 0:o.display_name)||(null==o?void 0:o.name)||""}}catch(e){}return""}();e&&g(", ".concat(e))},[]);var b=function(e){var t=null==c?void 0:c.map(function(t){return e===t.name?(n=t.show?(0,l.__)("Block disabled successfully","easy-accordion-free"):(0,l.__)("Block enabled successfully","easy-accordion-free"),z.success(n,{style:{marginTop:"20px",fontSize:"14px"}}),ju(ju({},t),{},{show:!t.show})):t;var n});u({blockVisibility:t})};return React.createElement("div",{className:"speap-settings-getting-start-page"},React.createElement("div",{className:"speap-settings-getting-start-page-content"},React.createElement("div",{className:"speap-qs-left"},React.createElement("div",{className:"speap-qs-about-section"},React.createElement("div",{className:"speap-qs-about-content"},React.createElement("div",{className:"speap-qs-about-text"},React.createElement("p",{className:"speap-qs-greeting"},v+h),React.createElement("h3",{className:"speap-qs-welcome-title"},(0,l.__)("Welcome to Easy Accordion!","easy-accordion-free")),React.createElement("p",{className:"speap-qs-welcome-desc"},(0,l.__)("Thank you for installing Easy Accordion! This video will help you get started with the plugin. Enjoy!","easy-accordion-free")),React.createElement("a",{href:"".concat(null===(t=sp_eab_admin_dashboard_localize)||void 0===t?void 0:t.homeUrl,"wp-admin/post-new.php?post_type=sp_eap_template&eabblock_inserter=true"),className:"speap-qs-create-btn"},React.createElement("i",{className:"dashicons dashicons-plus-alt2"}),(0,l.__)("Add Your First FAQs / Accordion","easy-accordion-free"))),React.createElement("div",{className:"speap-qs-video-wrapper"},React.createElement("img",{src:"".concat(null===(n=sp_eab_admin_dashboard_localize)||void 0===n?void 0:n.pluginUrl,"/admin/img/video-overlay.jpg"),alt:(0,l.__)("Video Tutorial","easy-accordion-free"),className:"speap-qs-video-placeholder"}),React.createElement("button",{className:"speap-qs-play-btn",onClick:function(){return f(!0)}},React.createElement(Ec,{color:"#F26C0D"}))))),React.createElement("div",{className:"speap-qs-blocks-section sp-eab-visibility-page"},React.createElement("div",{className:"speap-qs-section-header"},React.createElement("h3",{className:"speap-qs-section-title"},(0,l.__)("Accordion Blocks","easy-accordion-free")),React.createElement("button",{className:"speap-qs-view-more-btn",onClick:function(){o("blocks"),setTimeout(function(){return window.scrollTo(0,0)},100)}},(0,l.__)("View All Blocks","easy-accordion-free"),React.createElement(Rc,null))),React.createElement("div",{className:"speap-qs-blocks-grid sp-eab-all-block-list sp-d-grid sp-grid-cols-2"},Uu.map(function(e){var t=null==c?void 0:c.find(function(t){return t.name===e}),n={name:e,show:!t||t.show};return React.createElement(Gc,{key:e,attributes:n,onlyLiveDemo:!0,blockShowHideHandler:b,type:"quick-start"})})),React.createElement("div",{className:"speap-qs-blocks-gradient"})),React.createElement("div",{className:"speap-qs-modules-page"},React.createElement("div",{className:"speap-qs-section-header"},React.createElement("h3",{className:"speap-qs-section-title"},(0,l.__)("Modules","easy-accordion-free")),React.createElement("button",{className:"speap-qs-view-more-btn",onClick:function(){o("modules"),setTimeout(function(){return window.scrollTo(0,0)},100)}},(0,l.__)("Manage All Modules","easy-accordion-free"),React.createElement(Rc,null))),React.createElement("div",{className:"speap-qs-modules-grid"},React.createElement(Nu,{items:Lu.filter(function(e){return qu.includes(e.key)}),optionKey:"modules",type:"quick-start"})),React.createElement("div",{className:"speap-qs-modules-gradient"})),React.createElement("div",{className:"speap-qs-tutorials-section"},React.createElement("div",{className:"speap-qs-section-header"},React.createElement("h3",{className:"speap-qs-section-title"},(0,l.__)("Video Tutorials","easy-accordion-free")),React.createElement("a",{href:"https://www.youtube.com/watch?v=u3lRDX0zG9Y&list=PLoUb-7uG-5jPNXkpGII8cTTfB-L4TCaqv",target:"_blank",rel:"noreferrer",className:"speap-qs-view-more-btn"},(0,l.__)("View More Tutorials","easy-accordion-free"),React.createElement(Rc,null))),React.createElement("div",{className:"speap-qs-tutorials-grid"},React.createElement("div",{className:"speap-qs-tutorial-card"},React.createElement("div",{className:"speap-qs-tutorial-video"},React.createElement("iframe",{width:"560",height:"315",src:"https://www.youtube.com/embed/u3lRDX0zG9Y?si=ty1Q76VBL8F3xcX8",title:"YouTube video player",frameBorder:"0",allow:"accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture; web-share",referrerPolicy:"strict-origin-when-cross-origin",allowFullScreen:!0})),React.createElement("h4",{className:"speap-qs-tutorial-title"},(0,l.__)("How to Use Easy Accordion Gutenberg Blocks","easy-accordion-free"))),React.createElement("div",{className:"speap-qs-tutorial-card"},React.createElement("div",{className:"speap-qs-tutorial-video"},React.createElement("iframe",{width:"560",height:"315",src:"https://www.youtube.com/embed/xs3AlJKQHL4?si=osNaPeeUmuZmX03x",title:"YouTube video player",frameBorder:"0",allow:"accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture; web-share",referrerPolicy:"strict-origin-when-cross-origin",allowFullScreen:!0})),React.createElement("h4",{className:"speap-qs-tutorial-title"},(0,l.__)("How to Use Easy Accordion Blocks in Elementor","easy-accordion-free")))))),React.createElement("div",{className:"speap-qs-sidebar"},React.createElement("div",{className:"speap-qs-patterns-card"},React.createElement("div",{className:"speap-qs-patterns-image"},React.createElement("div",{className:"speap-qs-patterns-bg"}),React.createElement("img",{src:"".concat(null===(r=sp_eab_admin_dashboard_localize)||void 0===r?void 0:r.pluginUrl,"/admin/img/patterns-card.png"),alt:(0,l.__)("Accordion Patterns","easy-accordion-free"),className:"speap-qs-patterns-cards"}),React.createElement("span",{className:"speap-qs-hot-tag"},(0,l.__)("Hot","easy-accordion-free")),React.createElement("div",{className:"speap-qs-patterns-gradient"},React.createElement("span",{className:"speap-qs-patterns-text"},"200+ Ready Patterns Library"))),React.createElement("div",{className:"speap-qs-patterns-content"},React.createElement("h4",{className:"speap-qs-patterns-title"},(0,l.__)("Ready Accordion Patterns Made Easy","easy-accordion-free")),React.createElement("p",{className:"speap-qs-patterns-desc"},(0,l.__)("Choose from beautifully crafted accordion layouts and launch stunning FAQs in seconds.","easy-accordion-free")),React.createElement("div",{className:"speap-qs-patterns-btn-wrapper"},React.createElement("a",{href:"".concat(null===(a=sp_eab_admin_dashboard_localize)||void 0===a?void 0:a.homeUrl,"wp-admin/post-new.php?post_type=sp_eap_template&eab_pattern_library"),className:"speap-qs-patterns-btn"},(0,l.__)("Start with Ready Patterns","easy-accordion-free"))))),React.createElement("div",{className:"speap-qs-pro-card"},React.createElement("div",{className:"speap-qs-pro-content"},React.createElement("div",{className:"speap-qs-pro-header"},React.createElement("h4",{className:"speap-qs-pro-title"},(0,l.__)("Go Pro & Unlock More! 🚀","easy-accordion-free")),React.createElement("p",{className:"speap-qs-pro-desc"},(0,l.__)("Unlock the full potential of Easy Accordion to create and manage FAQs / accordions.","easy-accordion-free"))),React.createElement("div",{className:"speap-qs-pro-features"},Qu.map(function(e,t){return React.createElement("a",{key:t,href:e.url,target:"_blank",rel:"noreferrer",className:"speap-qs-pro-feature"},React.createElement("span",{className:"speap-qs-pro-icon"},e.icon),React.createElement("span",null,e.label,e.hot&&" 🔥"),React.createElement(Rc,{className:"speap-qs-pro-feature-arrow"}))})),React.createElement("div",{className:"speap-qs-pro-buttons"},React.createElement("a",{href:"https://easyaccordion.io/pricing/?ref=1",target:"_blank",rel:"noreferrer",className:"speap-qs-pro-upgrade-btn"},React.createElement(gc,null),(0,l.__)("Upgrade to Pro","easy-accordion-free")),React.createElement("button",{onClick:function(){o("lite_vs_pro"),setTimeout(function(){return window.scrollTo(0,0)},100)},className:"speap-qs-pro-compare-btn"},(0,l.__)("Lite vs Pro","easy-accordion-free"))))),React.createElement("div",{className:"speap-qs-info-card"},React.createElement("div",{className:"speap-qs-info-header"},React.createElement("div",{className:"speap-qs-info-icon"},React.createElement(pc,null)),React.createElement("h4",{className:"speap-qs-info-title"},(0,l.__)("Documentation","easy-accordion-free"))),React.createElement("div",{className:"speap-qs-info-content-wrapper"},React.createElement("p",{className:"speap-qs-info-desc"},(0,l.__)("Explore Easy Accordion plugin capabilities in our enriched documentation.","easy-accordion-free")),React.createElement("div",{className:"speap-qs-info-link-wrapper"},React.createElement("a",{href:"https://easyaccordion.io/docs/",target:"_blank",rel:"noreferrer",className:"speap-qs-info-link"},(0,l.__)("Browse Now","easy-accordion-free"),React.createElement(Rc,null))))),React.createElement("div",{className:"speap-qs-info-card"},React.createElement("div",{className:"speap-qs-info-header"},React.createElement("div",{className:"speap-qs-info-icon"},React.createElement(fc,null)),React.createElement("h4",{className:"speap-qs-info-title"},(0,l.__)("Join The Community","easy-accordion-free"))),React.createElement("div",{className:"speap-qs-info-content-wrapper"},React.createElement("p",{className:"speap-qs-info-desc"},(0,l.__)("Join the official ShapedPlugin Community to share your experiences, thoughts, and ideas.","easy-accordion-free")),React.createElement("div",{className:"speap-qs-info-link-wrapper"},React.createElement("a",{href:"https://community.shapedplugin.com/portal/space/easyaccordion/home",target:"_blank",rel:"noreferrer",className:"speap-qs-info-link"},(0,l.__)("Join Now","easy-accordion-free"),React.createElement(Rc,null))))))),p&&React.createElement("div",{className:"speap-qs-video-modal",onClick:function(){return f(!1)}},React.createElement("div",{className:"speap-qs-video-modal-content",onClick:function(e){return e.stopPropagation()}},React.createElement("button",{className:"speap-qs-video-modal-close",onClick:function(){return f(!1)}},"×"),React.createElement("div",{className:"speap-qs-video-modal-wrapper"},React.createElement("iframe",{width:"100%",height:"100%",src:"https://www.youtube.com/embed/u3lRDX0zG9Y?si=uG_yZ6xfFjWkRqqW&autoplay=1",title:"YouTube video player",frameBorder:"0",allow:"accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture",allowFullScreen:!0})))))};function Zu(e){return Zu="function"==typeof Symbol&&"symbol"==typeof Symbol.iterator?function(e){return typeof e}:function(e){return e&&"function"==typeof Symbol&&e.constructor===Symbol&&e!==Symbol.prototype?"symbol":typeof e},Zu(e)}function Ju(e,t){var n=Object.keys(e);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(e);t&&(r=r.filter(function(t){return Object.getOwnPropertyDescriptor(e,t).enumerable})),n.push.apply(n,r)}return n}function Xu(e){for(var t=1;t<arguments.length;t++){var n=null!=arguments[t]?arguments[t]:{};t%2?Ju(Object(n),!0).forEach(function(t){Yu(e,t,n[t])}):Object.getOwnPropertyDescriptors?Object.defineProperties(e,Object.getOwnPropertyDescriptors(n)):Ju(Object(n)).forEach(function(t){Object.defineProperty(e,t,Object.getOwnPropertyDescriptor(n,t))})}return e}function Yu(e,t,n){return(t=function(e){var t=function(e){if("object"!=Zu(e)||!e)return e;var t=e[Symbol.toPrimitive];if(void 0!==t){var n=t.call(e,"string");if("object"!=Zu(n))return n;throw new TypeError("@@toPrimitive must return a primitive value.")}return String(e)}(e);return"symbol"==Zu(t)?t:t+""}(t))in e?Object.defineProperty(e,t,{value:n,enumerable:!0,configurable:!0,writable:!0}):e[t]=n,e}var $u=[{name:"sp-easy-accordion-pro/post-accordion-block-two",show:!1},{name:"sp-easy-accordion-pro/product-accordion-two",show:!1},{name:"sp-easy-accordion-pro/menu-accordion",show:!1}];const ed=function(e){var t=e.showHeading,n=void 0===t||t,r=(0,s.useSelect)(function(e){return e(qc).getBlockVisibility()}),a=(0,s.useDispatch)(qc).saveSettings,o=function(e){var t=null==r?void 0:r.map(function(t){return e===t.name?(n=t.show?(0,l.__)("Block disabled successfully","easy-accordion-free"):(0,l.__)("Block enabled successfully","easy-accordion-free"),z.success(n,{style:{marginTop:"20px",fontSize:"14px"}}),Xu(Xu({},t),{},{show:!t.show})):t;var n});a({blockVisibility:t})};return React.createElement("div",{className:"sp-eab-visibility-page"},n&&React.createElement("div",{className:"eap-dashboard-page-header sp-d-flex sp-flex-col sp-gap-10px"},React.createElement("span",{className:"eap-dashboard-page-header__label"},(0,l.__)("Control Blocks","easy-accordion-free")),React.createElement("span",{className:"eap-dashboard-page-header__desc"},(0,l.__)("Turn blocks on or off as needed to improve performance.","easy-accordion-free"))),React.createElement("div",{className:"sp-eab-all-block-list sp-d-grid sp-grid-cols-3"},null==r?void 0:r.map(function(e,t){return React.createElement(Gc,{key:t,attributes:e,blockShowHideHandler:o})})),React.createElement("div",{className:"eap-dashboard-page-header sp-d-flex sp-flex-col sp-gap-10px",style:{marginTop:"48px"}},React.createElement("span",{className:"eap-dashboard-page-header__label"},(0,l.__)("Upcoming Blocks","easy-accordion-free"))),React.createElement("div",{className:"sp-eab-all-block-list sp-d-grid sp-grid-cols-3"},null==$u?void 0:$u.map(function(e,t){return React.createElement(Gc,{key:t,attributes:e,blockShowHideHandler:o,isUpcomingBlock:!0})})))};function td(){var e,t,n="function"==typeof Symbol?Symbol:{},r=n.iterator||"@@iterator",a=n.toStringTag||"@@toStringTag";function o(n,r,a,o){var l=r&&r.prototype instanceof s?r:s,c=Object.create(l.prototype);return nd(c,"_invoke",function(n,r,a){var o,s,l,c=0,u=a||[],d=!1,p={p:0,n:0,v:e,a:f,f:f.bind(e,4),d:function(t,n){return o=t,s=0,l=e,p.n=n,i}};function f(n,r){for(s=n,l=r,t=0;!d&&c&&!a&&t<u.length;t++){var a,o=u[t],f=p.p,m=o[2];n>3?(a=m===r)&&(l=o[(s=o[4])?5:(s=3,3)],o[4]=o[5]=e):o[0]<=f&&((a=n<2&&f<o[1])?(s=0,p.v=r,p.n=o[1]):f<m&&(a=n<3||o[0]>r||r>m)&&(o[4]=n,o[5]=r,p.n=m,s=0))}if(a||n>1)return i;throw d=!0,r}return function(a,u,m){if(c>1)throw TypeError("Generator is already running");for(d&&1===u&&f(u,m),s=u,l=m;(t=s<2?e:l)||!d;){o||(s?s<3?(s>1&&(p.n=-1),f(s,l)):p.n=l:p.v=l);try{if(c=2,o){if(s||(a="next"),t=o[a]){if(!(t=t.call(o,l)))throw TypeError("iterator result is not an object");if(!t.done)return t;l=t.value,s<2&&(s=0)}else 1===s&&(t=o.return)&&t.call(o),s<2&&(l=TypeError("The iterator does not provide a '"+a+"' method"),s=1);o=e}else if((t=(d=p.n<0)?l:n.call(r,p))!==i)break}catch(t){o=e,s=1,l=t}finally{c=1}}return{value:t,done:d}}}(n,a,o),!0),c}var i={};function s(){}function l(){}function c(){}t=Object.getPrototypeOf;var u=[][r]?t(t([][r]())):(nd(t={},r,function(){return this}),t),d=c.prototype=s.prototype=Object.create(u);function p(e){return Object.setPrototypeOf?Object.setPrototypeOf(e,c):(e.__proto__=c,nd(e,a,"GeneratorFunction")),e.prototype=Object.create(d),e}return l.prototype=c,nd(d,"constructor",c),nd(c,"constructor",l),l.displayName="GeneratorFunction",nd(c,a,"GeneratorFunction"),nd(d),nd(d,a,"Generator"),nd(d,r,function(){return this}),nd(d,"toString",function(){return"[object Generator]"}),(td=function(){return{w:o,m:p}})()}function nd(e,t,n,r){var a=Object.defineProperty;try{a({},"",{})}catch(e){a=0}nd=function(e,t,n,r){function o(t,n){nd(e,t,function(e){return this._invoke(t,n,e)})}t?a?a(e,t,{value:n,enumerable:!r,configurable:!r,writable:!r}):e[t]=n:(o("next",0),o("throw",1),o("return",2))},nd(e,t,n,r)}function rd(e,t,n,r,a,o,i){try{var s=e[o](i),l=s.value}catch(e){return void n(e)}s.done?t(l):Promise.resolve(l).then(r,a)}var ad=function(e){return le.success(e,{style:{marginTop:"28px",fontSize:"15px",padding:"10px 18px"}})},od=function(e){return le.error(e,{style:{marginTop:"28px",fontSize:"15px",padding:"10px 18px"}})},id=function(){var e=function(e){return function(){var t=this,n=arguments;return new Promise(function(r,a){var o=e.apply(t,n);function i(e){rd(o,r,a,i,s,"next",e)}function s(e){rd(o,r,a,i,s,"throw",e)}i(void 0)})}}(td().m(function e(t){var n,r,a,o;return td().w(function(e){for(;;)switch(e.p=e.n){case 0:if(!navigator.clipboard||!navigator.clipboard.writeText){e.n=4;break}return e.p=1,e.n=2,navigator.clipboard.writeText(t);case 2:return e.a(2,!0);case 3:e.p=3,a=e.v,console.warn("Clipboard API failed, using fallback.",a);case 4:return e.p=4,(n=document.createElement("textarea")).value=t,n.style.position="fixed",n.style.opacity="0",n.style.pointerEvents="none",document.body.appendChild(n),n.select(),r=document.execCommand("copy"),document.body.removeChild(n),e.a(2,r);case 5:return e.p=5,o=e.v,console.error("Fallback copy failed:",o),e.a(2,!1)}},e,null,[[4,5],[1,3]])}));return function(_x){return e.apply(this,arguments)}}(),sd=function(e){return e?"1":"0"},ld=function(e){return"1"===e||"1"===e||1===e||!0===e},cd=function(){return React.createElement("svg",{xmlns:"http://www.w3.org/2000/svg",width:16,height:16,viewBox:"0 0 16 16",fill:"none"},React.createElement("path",{d:"M10.1421 3.98828L11.0765 3.05377C11.5927 2.53766 12.4295 2.53766 12.9456 3.05377C13.4617 3.56989 13.4617 4.40667 12.9456 4.92279L12.0111 5.85729M10.1421 3.98828L4.65284 9.47755C3.95597 10.1744 3.60752 10.5228 3.37026 10.9474C3.133 11.372 2.89428 12.3746 2.66602 13.3334C3.62474 13.1051 4.62734 12.8664 5.05194 12.6291C5.47654 12.3918 5.82498 12.0434 6.52185 11.3466L12.0111 5.85729M10.1421 3.98828L12.0111 5.85729",stroke:"#757575",strokeWidth:1.25,strokeLinecap:"round",strokeLinejoin:"round"}),React.createElement("path",{d:"M7.33398 13.3333H11.334",stroke:"#757575",strokeWidth:1.25,strokeLinecap:"round"}))},ud=function(){return React.createElement("svg",{xmlns:"http://www.w3.org/2000/svg",width:16,height:16,viewBox:"0 0 16 16",fill:"none"},React.createElement("g",{clipPath:"url(#clip0_20469_150666)"},React.createElement("path",{d:"M6 10C6 8.1144 6 7.1716 6.58579 6.58579C7.1716 6 8.1144 6 10 6H10.6667C12.5523 6 13.4951 6 14.0809 6.58579C14.6667 7.1716 14.6667 8.1144 14.6667 10V10.6667C14.6667 12.5523 14.6667 13.4951 14.0809 14.0809C13.4951 14.6667 12.5523 14.6667 10.6667 14.6667H10C8.1144 14.6667 7.1716 14.6667 6.58579 14.0809C6 13.4951 6 12.5523 6 10.6667V10Z",stroke:"#757575",strokeWidth:1.25,strokeLinecap:"round",strokeLinejoin:"round"}),React.createElement("path",{d:"M11.3339 5.99998C11.3323 4.02859 11.3025 3.00745 10.7286 2.30827C10.6178 2.17324 10.494 2.04943 10.359 1.93862C9.62145 1.33331 8.52565 1.33331 6.33398 1.33331C4.14233 1.33331 3.0465 1.33331 2.30894 1.93862C2.17391 2.04943 2.0501 2.17324 1.93929 2.30827C1.33398 3.04583 1.33398 4.14166 1.33398 6.33331C1.33398 8.52498 1.33398 9.62078 1.93929 10.3584C2.0501 10.4934 2.17391 10.6172 2.30894 10.728C3.00812 11.3018 4.02926 11.3316 6.00065 11.3332",stroke:"#757575",strokeWidth:1.25,strokeLinecap:"round",strokeLinejoin:"round"})),React.createElement("defs",null,React.createElement("clipPath",{id:"clip0_20469_150666"},React.createElement("rect",{width:16,height:16,fill:"white"}))))},dd=function(){return React.createElement("svg",{xmlns:"http://www.w3.org/2000/svg",width:16,height:16,viewBox:"0 0 16 16",fill:"none"},React.createElement("path",{d:"M13 3.66669L12.5869 10.3501C12.4813 12.0576 12.4285 12.9114 12.0005 13.5253C11.7889 13.8288 11.5165 14.0849 11.2005 14.2774C10.5614 14.6667 9.706 14.6667 7.99513 14.6667C6.28208 14.6667 5.42553 14.6667 4.78603 14.2766C4.46987 14.0838 4.19733 13.8272 3.98579 13.5232C3.55792 12.9084 3.5063 12.0534 3.40307 10.3435L3 3.66669",stroke:"#757575",strokeWidth:1.25,strokeLinecap:"round"}),React.createElement("path",{d:"M2 3.66665H14M10.7038 3.66665L10.2487 2.7278C9.9464 2.10415 9.7952 1.79233 9.53447 1.59785C9.47667 1.55471 9.4154 1.51634 9.35133 1.48311C9.0626 1.33331 8.71607 1.33331 8.023 1.33331C7.31253 1.33331 6.95733 1.33331 6.66379 1.48939C6.59873 1.52399 6.53665 1.56391 6.47819 1.60876C6.21443 1.81111 6.06709 2.13435 5.77241 2.78082L5.36861 3.66665",stroke:"#757575",strokeWidth:1.25,strokeLinecap:"round"}),React.createElement("path",{d:"M6.33398 11V7",stroke:"#757575",strokeWidth:1.25,strokeLinecap:"round"}),React.createElement("path",{d:"M9.66602 11V7",stroke:"#757575",strokeWidth:1.25,strokeLinecap:"round"}))},pd=function(){return React.createElement("svg",{xmlns:"http://www.w3.org/2000/svg",width:20,height:13,viewBox:"0 0 5 9",fill:"none"},React.createElement("path",{fillRule:"evenodd",clipRule:"evenodd",d:"M1.15403 0.865234L4.74524 4.81555L1.15403 8.76588L0.423828 8.10206L3.41156 4.81555L0.423829 1.52906L1.15403 0.865234Z",fill:"#757575"}))},fd=function(){return React.createElement("svg",{xmlns:"http://www.w3.org/2000/svg",width:20,height:13,viewBox:"0 0 5 9",fill:"none"},React.createElement("path",{fillRule:"evenodd",clipRule:"evenodd",d:"M4.26589 0.865234L0.674678 4.81555L4.26589 8.76588L4.99609 8.10206L2.00836 4.81555L4.99609 1.52906L4.26589 0.865234Z",fill:"#757575"}))},md=function(){return React.createElement("svg",{width:15,height:15,viewBox:"0 0 15 15",fill:"none",xmlns:"http://www.w3.org/2000/svg"},React.createElement("path",{d:"M5.544 9.18a1.457 1.457 0 0 0 2.062 0l2.856-2.856a.53.53 0 1 0-.75-.75L6.856 8.428a.4.4 0 0 1-.561 0L5.289 7.423a.53.53 0 0 0-.75.75z",fill:"#317d46"}),React.createElement("path",{d:"M7.5 14c3.584 0 6.5-2.916 6.5-6.5S11.084 1 7.5 1A6.507 6.507 0 0 0 1 7.5C1 11.084 3.916 14 7.5 14m0-11.939A5.445 5.445 0 0 1 12.939 7.5 5.445 5.445 0 0 1 7.5 12.939 5.445 5.445 0 0 1 2.061 7.5 5.445 5.445 0 0 1 7.5 2.061",fill:"#317d46"}))};function hd(e,t){(null==t||t>e.length)&&(t=e.length);for(var n=0,r=Array(t);n<t;n++)r[n]=e[n];return r}var gd="xs3AlJKQHL4",vd=function(){var e,t=function(e,t){return function(e){if(Array.isArray(e))return e}(e)||function(e,t){var n=null==e?null:"undefined"!=typeof Symbol&&e[Symbol.iterator]||e["@@iterator"];if(null!=n){var r,a,o,i,s=[],l=!0,c=!1;try{if(o=(n=n.call(e)).next,0===t){if(Object(n)!==n)return;l=!1}else for(;!(l=(r=o.call(n)).done)&&(s.push(r.value),s.length!==t);l=!0);}catch(e){c=!0,a=e}finally{try{if(!l&&null!=n.return&&(i=n.return(),Object(i)!==i))return}finally{if(c)throw a}}return s}}(e,t)||function(e,t){if(e){if("string"==typeof e)return hd(e,t);var n={}.toString.call(e).slice(8,-1);return"Object"===n&&e.constructor&&(n=e.constructor.name),"Map"===n||"Set"===n?Array.from(e):"Arguments"===n||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)?hd(e,t):void 0}}(e,t)||function(){throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.")}()}((0,i.useState)(!1),2),n=t[0],r=t[1],a="".concat(null===(e=sp_eab_admin_dashboard_localize)||void 0===e?void 0:e.homeUrl,"wp-admin/post-new.php?post_type=sp_eap_template&eabblock_inserter");return React.createElement("div",{className:"speap-saved-template-promo"},React.createElement("div",{className:"speap-saved-template-promo__text"},React.createElement("div",{className:"speap-saved-template-promo__title-wrap"},React.createElement("h2",{className:"speap-saved-template-promo__title"},(0,l.__)("Design visually.","easy-accordion-free")," ",React.createElement("span",null,(0,l.__)("Place it ","easy-accordion-free")),React.createElement("span",{className:"speap-saved-template-promo__title-accent"},(0,l.__)("anywhere.","easy-accordion-free"))),React.createElement("p",{className:"speap-saved-template-promo__desc"},"Saved Templates let you build accordion layouts with Gutenberg blocks and use them as"," ",React.createElement("b",null,"shortcodes")," — perfect for page builders like ",React.createElement("b",null,"Elementor, Divi, WPBakery"),", and more."),React.createElement("p",{className:"speap-saved-template-promo__desc"},"Easy Accordion blocks work directly on any page or post in Gutenberg. To reuse blocks use WordPress's built-in"," ",React.createElement("a",{href:"https://easyaccordion.io/docs/how-to-create-gutenberg-reusable-blocks-with-patterns-in-wordpress/",target:"_blank"},React.createElement("b",null,"Reusable Blocks (Patterns)"))," ","feature.")),React.createElement("a",{href:a,rel:"noreferrer",className:"speap-saved-template-promo__cta"},React.createElement("i",{className:"dashicons dashicons-plus-alt2"}),(0,l.__)("Add New Template","easy-accordion-free"))),React.createElement("div",{className:"speap-saved-template-promo__video"},n?React.createElement("iframe",{className:"speap-saved-template-promo__video-frame",src:"https://www.youtube.com/embed/".concat(gd,"?autoplay=1"),title:(0,l.__)("Easy Accordion overview video","easy-accordion-free"),allow:"accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture",allowFullScreen:!0}):React.createElement("button",{type:"button",className:"speap-saved-template-promo__video-thumb",style:{backgroundImage:"url(https://img.youtube.com/vi/".concat(gd,"/maxresdefault.jpg)")},onClick:function(){return r(!0)},"aria-label":(0,l.__)("Play overview video","easy-accordion-free")},React.createElement("span",{className:"speap-saved-template-promo__video-overlay"}),React.createElement("span",{className:"speap-saved-template-promo__video-play"},React.createElement("svg",{width:"22",height:"22",viewBox:"0 0 22 22",fill:"none",xmlns:"http://www.w3.org/2000/svg","aria-hidden":"true"},React.createElement("path",{d:"M19 11L4 19.6603L4 2.33975L19 11Z",fill:"#F26C0D"}))))))};function bd(){var e,t,n="function"==typeof Symbol?Symbol:{},r=n.iterator||"@@iterator",a=n.toStringTag||"@@toStringTag";function o(n,r,a,o){var l=r&&r.prototype instanceof s?r:s,c=Object.create(l.prototype);return yd(c,"_invoke",function(n,r,a){var o,s,l,c=0,u=a||[],d=!1,p={p:0,n:0,v:e,a:f,f:f.bind(e,4),d:function(t,n){return o=t,s=0,l=e,p.n=n,i}};function f(n,r){for(s=n,l=r,t=0;!d&&c&&!a&&t<u.length;t++){var a,o=u[t],f=p.p,m=o[2];n>3?(a=m===r)&&(l=o[(s=o[4])?5:(s=3,3)],o[4]=o[5]=e):o[0]<=f&&((a=n<2&&f<o[1])?(s=0,p.v=r,p.n=o[1]):f<m&&(a=n<3||o[0]>r||r>m)&&(o[4]=n,o[5]=r,p.n=m,s=0))}if(a||n>1)return i;throw d=!0,r}return function(a,u,m){if(c>1)throw TypeError("Generator is already running");for(d&&1===u&&f(u,m),s=u,l=m;(t=s<2?e:l)||!d;){o||(s?s<3?(s>1&&(p.n=-1),f(s,l)):p.n=l:p.v=l);try{if(c=2,o){if(s||(a="next"),t=o[a]){if(!(t=t.call(o,l)))throw TypeError("iterator result is not an object");if(!t.done)return t;l=t.value,s<2&&(s=0)}else 1===s&&(t=o.return)&&t.call(o),s<2&&(l=TypeError("The iterator does not provide a '"+a+"' method"),s=1);o=e}else if((t=(d=p.n<0)?l:n.call(r,p))!==i)break}catch(t){o=e,s=1,l=t}finally{c=1}}return{value:t,done:d}}}(n,a,o),!0),c}var i={};function s(){}function l(){}function c(){}t=Object.getPrototypeOf;var u=[][r]?t(t([][r]())):(yd(t={},r,function(){return this}),t),d=c.prototype=s.prototype=Object.create(u);function p(e){return Object.setPrototypeOf?Object.setPrototypeOf(e,c):(e.__proto__=c,yd(e,a,"GeneratorFunction")),e.prototype=Object.create(d),e}return l.prototype=c,yd(d,"constructor",c),yd(c,"constructor",l),l.displayName="GeneratorFunction",yd(c,a,"GeneratorFunction"),yd(d),yd(d,a,"Generator"),yd(d,r,function(){return this}),yd(d,"toString",function(){return"[object Generator]"}),(bd=function(){return{w:o,m:p}})()}function yd(e,t,n,r){var a=Object.defineProperty;try{a({},"",{})}catch(e){a=0}yd=function(e,t,n,r){function o(t,n){yd(e,t,function(e){return this._invoke(t,n,e)})}t?a?a(e,t,{value:n,enumerable:!r,configurable:!r,writable:!r}):e[t]=n:(o("next",0),o("throw",1),o("return",2))},yd(e,t,n,r)}function wd(e,t,n,r,a,o,i){try{var s=e[o](i),l=s.value}catch(e){return void n(e)}s.done?t(l):Promise.resolve(l).then(r,a)}function Ed(e){return function(){var t=this,n=arguments;return new Promise(function(r,a){var o=e.apply(t,n);function i(e){wd(o,r,a,i,s,"next",e)}function s(e){wd(o,r,a,i,s,"throw",e)}i(void 0)})}}function Rd(e){return function(e){if(Array.isArray(e))return Cd(e)}(e)||function(e){if("undefined"!=typeof Symbol&&null!=e[Symbol.iterator]||null!=e["@@iterator"])return Array.from(e)}(e)||Ad(e)||function(){throw new TypeError("Invalid attempt to spread non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.")}()}function xd(e,t){return function(e){if(Array.isArray(e))return e}(e)||function(e,t){var n=null==e?null:"undefined"!=typeof Symbol&&e[Symbol.iterator]||e["@@iterator"];if(null!=n){var r,a,o,i,s=[],l=!0,c=!1;try{if(o=(n=n.call(e)).next,0===t){if(Object(n)!==n)return;l=!1}else for(;!(l=(r=o.call(n)).done)&&(s.push(r.value),s.length!==t);l=!0);}catch(e){c=!0,a=e}finally{try{if(!l&&null!=n.return&&(i=n.return(),Object(i)!==i))return}finally{if(c)throw a}}return s}}(e,t)||Ad(e,t)||function(){throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.")}()}function Ad(e,t){if(e){if("string"==typeof e)return Cd(e,t);var n={}.toString.call(e).slice(8,-1);return"Object"===n&&e.constructor&&(n=e.constructor.name),"Map"===n||"Set"===n?Array.from(e):"Arguments"===n||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)?Cd(e,t):void 0}}function Cd(e,t){(null==t||t>e.length)&&(t=e.length);for(var n=0,r=Array(t);n<t;n++)r[n]=e[n];return r}const Sd=function(){var e,t=xd((0,i.useState)(""),2),n=t[0],r=t[1],a=xd((0,i.useState)(""),2),o=a[0],c=a[1],u=xd((0,i.useState)(1),2),d=u[0],p=u[1],f=xd((0,i.useState)(!1),2),m=f[0],h=f[1],g=xd((0,i.useState)([]),2),v=g[0],b=g[1],y=xd((0,i.useState)(""),2),w=y[0],E=y[1],R=xd((0,i.useState)(!1),2),x=R[0],A=R[1],C=(0,i.useRef)(null),S=(0,s.useSelect)(function(e){var t;return(null===(t=e("core"))||void 0===t||null===(t=t.getEntityRecords("postType","sp_eap_template",{status:"any",per_page:-1,search:o,_fields:["id"]}))||void 0===t?void 0:t.length)||0},[o]),k=(0,s.useSelect)(function(e){var t;return(null===(t=e("core"))||void 0===t||null===(t=t.getEntityRecords("postType","sp_easy_accordion",{status:"any",per_page:-1,search:o,_fields:["id"]}))||void 0===t?void 0:t.length)||0},[o]),O=k<1?["checkBox","title","shortcode","date","action"]:["checkBox","title","editor_type","shortcode","date","action"],P=S+k,M=(0,s.useSelect)(function(e){var t;return(null===(t=e("core"))||void 0===t?void 0:t.getEntityRecords("postType","sp_eap_template",{status:"any",per_page:-1,search:o,_fields:["id","modified","title","status"]}))||[]},[o]),I=(0,s.useSelect)(function(e){var t;return(null===(t=e("core"))||void 0===t?void 0:t.getEntityRecords("postType","sp_easy_accordion",{status:"any",per_page:-1,search:o,_fields:["id","modified","title","status"]}))||[]},[o]),T=[].concat(Rd(M),Rd(I)).sort(function(e,t){return new Date(t.modified)-new Date(e.modified)}),_=T.slice(o?0:10*(d-1),o?10:10*d),N=(0,s.useDispatch)("core"),L=N.deleteEntityRecord,D=N.editEntityRecord,B=N.saveEntityRecord,F=N.saveEditedEntityRecord,z=N.invalidateResolution,j=function(e){return(null==M?void 0:M.some(function(t){return t.id===e.id}))?"sp_eap_template":"sp_easy_accordion"},H=function(){var e=Ed(bd().m(function e(){var t,n,r,a=arguments;return bd().w(function(e){for(;;)switch(e.n){case 0:if(!((null==(n=(t=a.length>0&&void 0!==a[0]?a[0]:null)?[t]:v)?void 0:n.length)<1)){e.n=1;break}return e.a(2);case 1:if(!window.confirm("Are you sure you want to delete this saved template?")){e.n=3;break}return e.n=2,Promise.all(n.map(function(){var e=Ed(bd().m(function e(t){var n,r;return bd().w(function(e){for(;;)switch(e.p=e.n){case 0:return e.p=0,n=j({id:t}),e.n=1,L("postType",n,t,{force:!0});case 1:e.n=3;break;case 2:e.p=2,r=e.v,od("Error deleting template ID: ".concat(t,": ").concat(r," "));case 3:return e.a(2)}},e,null,[[0,2]])}));return function(_x){return e.apply(this,arguments)}}()));case 2:r=t?null==v?void 0:v.filter(function(e){return e!==n[0]}):[],b(r),ad("Template deleted successfully.");case 3:return e.a(2)}},e)}));return function(){return e.apply(this,arguments)}}(),V=function(){var e=Ed(bd().m(function e(){var t,n,r=arguments;return bd().w(function(e){for(;;)switch(e.n){case 0:if(t=r.length>0&&void 0!==r[0]?r[0]:"publish",!((null==(n=v)?void 0:n.length)<1)){e.n=1;break}return e.a(2);case 1:return e.n=2,Promise.all(null==n?void 0:n.map(function(){var e=Ed(bd().m(function e(n){var r,a;return bd().w(function(e){for(;;)switch(e.p=e.n){case 0:if(e.p=0,n){e.n=1;break}return e.a(2);case 1:return r=j({id:n}),e.n=2,(0,s.resolveSelect)("core").getEntityRecord("postType",r,n);case 2:if(e.v){e.n=3;break}return e.a(2);case 3:return e.n=4,D("postType",r,n,{status:t});case 4:return e.n=5,F("postType",r,n);case 5:e.n=7;break;case 6:e.p=6,a=e.v,od("Error while updating template ID: ".concat(n,": ").concat(a," "));case 7:return e.a(2)}},e,null,[[0,6]])}));return function(t){return e.apply(this,arguments)}}()));case 2:ad("Template post status updated successfully."),b([]);case 3:return e.a(2)}},e)}));return function(){return e.apply(this,arguments)}}(),G=function(){var e=Ed(bd().m(function e(t){var n,r,a,i,c,u,d,p;return bd().w(function(e){for(;;)switch(e.p=e.n){case 0:if(e.p=0,"sp_eap_template"!==j(t)){e.n=4;break}return e.n=1,(0,s.resolveSelect)("core").getEntityRecord("postType","sp_eap_template",t.id);case 1:if(r=e.v){e.n=2;break}return od("Template not found"),e.a(2);case 2:return e.n=3,B("postType","sp_eap_template",{title:"".concat(r.title.raw||"(No title)"," (Copy)"),content:(null===(n=r.content)||void 0===n?void 0:n.raw)||"",meta:r.meta||{},status:"draft"});case 3:e.n=7;break;case 4:return(i=new FormData).append("action","eap_duplicate_classic_shortcode"),i.append("nonce",null===(a=sp_eab_admin_dashboard_localize)||void 0===a?void 0:a.nonce),i.append("post_id",t.id),e.n=5,fetch(ajaxurl,{method:"POST",body:i});case 5:return c=e.v,e.n=6,c.json();case 6:if((u=e.v).success){e.n=7;break}return od((null===(d=u.data)||void 0===d?void 0:d.message)||(0,l.__)("Failed to duplicate template","easy-accordion-free")),e.a(2);case 7:z("getEntityRecords",["postType","sp_eap_template",{status:"any",per_page:-1,search:o,_fields:["id","modified","title","status"]}]),z("getEntityRecords",["postType","sp_easy_accordion",{status:"any",per_page:-1,search:o,_fields:["id","modified","title","status"]}]),ad("Template duplicated successfully."),e.n=9;break;case 8:e.p=8,p=e.v,od("Failed to duplicate template: ".concat(p.message));case 9:return e.a(2)}},e,null,[[0,8]])}));return function(t){return e.apply(this,arguments)}}();(0,i.useEffect)(function(){if(w){var e=setTimeout(function(){E("")},2e3);return function(){return clearTimeout(e)}}},[w]),(0,i.useEffect)(function(){(null==_?void 0:_.length)<1&&(C.current&&clearTimeout(C.current),C.current=setTimeout(function(){A(!0)},1500))},[_]);var q=Math.ceil(P/10),U=Array.from({length:q},function(e,t){return t+1});return React.createElement("div",{className:"speap-saved-templates-page-wrapper"},React.createElement("div",{className:"sp-eab-saved-templates-page-container sp-d-flex sp-flex-col"},React.createElement("div",{className:"sp-eab-saved-template-header sp-d-flex sp-align-center sp-justify-between"},React.createElement("div",{className:"sp-eab-saved-template-header-left sp-d-flex"},React.createElement("select",{name:"bulk-action",className:"sp-eab-saved-template-select",value:n,onChange:function(e){return r(e.target.value)}},React.createElement("option",{value:""},"Bulk Action"),React.createElement("option",{value:"publish"},"Publish"),React.createElement("option",{value:"draft"},"Draft"),React.createElement("option",{value:"delete"},"Delete")),React.createElement("button",{className:"sp-eab-saved-template-select-apply",onClick:function(){if(""!==n){switch(n){case"publish":V("publish");break;case"draft":V("draft");break;case"delete":H()}b([]),h(!1),r("")}}},"Apply"),React.createElement("input",{name:"search-weather-template",className:"sp-eab-saved-template-search-field",type:"text",placeholder:"Search...",spellCheck:"false","data-ms-editor":"true",onChange:function(e){var t,n=null===(t=e.target)||void 0===t?void 0:t.value;C.current&&clearTimeout(C.current),C.current=setTimeout(function(){c(n)},1e3)}})),React.createElement("div",{className:"sp-eab-saved-template-header-right"},React.createElement("a",{href:"".concat(null===(e=sp_eab_admin_dashboard_localize)||void 0===e?void 0:e.homeUrl,"wp-admin/post-new.php?post_type=sp_eap_template"),className:"sp-eab-saved-template-add-new sp-d-flex sp-align-center sp-justify-center sp-gap-8px sp-cursor-pointer",rel:"noreferrer"},React.createElement("i",{className:"dashicons dashicons-plus-alt2"}),"Add New Template"))),React.createElement("table",{className:"sp-eab-saved-template-content-table"},React.createElement("thead",{className:"sp-eab-saved-template-table-head"},React.createElement("tr",null,null==O?void 0:O.map(function(e,t){return React.createElement("th",{key:t,className:"sp-eab-saved-template-table-".concat(e)},"checkBox"===e?React.createElement("input",{type:"checkbox",onChange:function(){h(function(e){return!e}),b(m?[]:null==_?void 0:_.map(function(e){return e.id}))},checked:m}):"editor_type"===e?"Editor Type":e)}))),React.createElement("tbody",{className:"sp-eab-saved-template-table-body"},!x&&(!_||0===_.length)&&React.createElement("tr",null,React.createElement("td",{className:"sp-eab-saved-template-preloader-no-data"},React.createElement("span",{className:"sp-eab-saved-template-loading"},React.createElement(Uc.Spinner,null)))),null==_?void 0:_.map(function(e,t){var n,r,a,o=new Date(null==e?void 0:e.modified),i=!!m||(null==v?void 0:v.some(function(t){return t===(null==e?void 0:e.id)})),s="sp_eap_template"===j(e);return React.createElement("tr",{key:t,className:"sp-eab-saved-template-table-row"},React.createElement("td",{id:null==e?void 0:e.id,className:"sp-eab-saved-template-table-checkBox"},React.createElement("input",{type:"checkbox",onChange:function(){return t=null==e?void 0:e.id,n=v.includes(t)?null==v?void 0:v.filter(function(e){return e!==t}):[].concat(Rd(v),[t]),b(n),void h(!1);var t,n},checked:i})),React.createElement("td",{className:"sp-eab-saved-template-table-title"},React.createElement("a",{href:"".concat(null===(n=sp_eab_admin_dashboard_localize)||void 0===n?void 0:n.homeUrl,"wp-admin/post.php?post=").concat(null==e?void 0:e.id,"&action=edit"),rel:"noreferrer noopener"},React.createElement("span",{dangerouslySetInnerHTML:{__html:(null==e||null===(r=e.title)||void 0===r?void 0:r.rendered)||"(No Title)"}}))),(null==O?void 0:O.includes("editor_type"))&&React.createElement("td",{className:"sp-eab-saved-template-table-editor_type"},React.createElement("span",{className:"sp-eab-editor-type-badge ".concat(s?"block-editor":"classic-editor")},s?"Block Editor":"Classic")),React.createElement("td",{className:"sp-eab-saved-template-table-shortcode"},React.createElement("span",{className:"sp-eab-saved-template-shortcode-text",onClick:function(){return function(e){var t="sp_eap_template"===j(e)?'[sp_eap_template id="'.concat(e.id,'"]'):'[sp_easyaccordion id="'.concat(e.id,'"]');id(t)?E(e.id):od((0,l.__)("Failed to copy shortcode","easy-accordion-free"))}(e)}},s?'[sp_eap_template id="'.concat(null==e?void 0:e.id,'"]'):'[sp_easyaccordion id="'.concat(null==e?void 0:e.id,'"]'))," ",React.createElement("span",{className:"sp-eab-shortcode-copy-tooltip",style:{opacity:w===e.id?1:0}},React.createElement(md,null),"Copied!"),w!==e.id&&React.createElement("svg",{width:"14",height:"14",viewBox:"0 0 14 14",fill:"none",xmlns:"http://www.w3.org/2000/svg"},React.createElement("path",{fillRule:"evenodd",clipRule:"evenodd",d:"M1.35417 1.25H9.47917C9.53667 1.25 9.58333 1.29667 9.58333 1.35417V9.47917C9.58333 9.50679 9.57236 9.53329 9.55282 9.55282C9.53329 9.57236 9.50679 9.58333 9.47917 9.58333H1.35417C1.32654 9.58333 1.30004 9.57236 1.28051 9.55282C1.26097 9.53329 1.25 9.50679 1.25 9.47917V1.35417C1.25 1.29667 1.29667 1.25 1.35417 1.25ZM0 1.35417C0 0.606667 0.606667 0 1.35417 0H9.47917C10.2275 0 10.8333 0.606667 10.8333 1.35417V9.47917C10.8333 10.2275 10.2275 10.8333 9.47917 10.8333H1.35417C0.995019 10.8333 0.650582 10.6907 0.396626 10.4367C0.142671 10.1828 0 9.83831 0 9.47917V1.35417ZM12.0833 11.0675V3.5675H13.3333V11.0675C13.3333 12.3333 12.3083 13.3333 11.0425 13.3333H1.875V12.0833H11.0425C11.6175 12.0833 12.0833 11.6433 12.0833 11.0675Z",fill:"#757575"}))),React.createElement("td",{className:"sp-eab-saved-template-table-date"},React.createElement("div",null,null==e?void 0:e.status),React.createElement("div",null,null==o?void 0:o.toLocaleString("en-US"))),React.createElement("td",{className:"sp-eab-saved-template-table-action"},React.createElement("div",{className:"sp-eab-saved-template-table-action-btn"},React.createElement(Uc.Tooltip,{text:"Edit",delay:300,placement:"top"},React.createElement("a",{"aria-label":"Edit",href:"".concat(null===(a=sp_eab_admin_dashboard_localize)||void 0===a?void 0:a.homeUrl,"wp-admin/post.php?post=").concat(null==e?void 0:e.id,"&action=edit"),className:"sp-eab-saved-template-action sp-action-edit",rel:"noreferrer"},React.createElement(cd,null))),React.createElement(Uc.Tooltip,{text:"Duplicate",delay:300,placement:"top"},React.createElement("button",{"aria-label":"Duplicate",className:"sp-eab-saved-template-action sp-action-copy",onClick:function(){return G(e)}},React.createElement(ud,null))),React.createElement(Uc.Tooltip,{text:"Delete",delay:300,placement:"top"},React.createElement("button",{"aria-label":"Delete",className:"sp-eab-saved-template-action sp-action-delete",onClick:function(){return H(null==e?void 0:e.id)}},React.createElement(dd,null))))))}),x&&(!_||0===_.length)&&React.createElement("tr",null,React.createElement("td",{className:"sp-eab-saved-template-preloader-no-data"},React.createElement("span",{className:"sp-eab-saved-template-no-data"},(0,l.__)("No saved template found!","easy-accordion-free")))))),React.createElement("div",{className:"sp-eab-saved-template-footer"},React.createElement("div",{className:"sp-eab-saved-template-count"},"Page ",d," of ",Math.ceil(P/10)||1,"  "," ",React.createElement("span",null,"[ ",P," Items ]")),React.createElement("div",{className:"sp-eab-saved-template-pagination"},(null==U?void 0:U.length)>1&&React.createElement(React.Fragment,null,React.createElement("button",{className:"sp-eab-saved-template-pagination-btn sp-btn-prev ".concat(1===d?"btn-disabled":""),onClick:function(){return p(1!==d?d-1:1)}},React.createElement(fd,null)),U.map(function(e,t){return React.createElement("button",{key:t,className:"sp-eab-saved-template-pagination-btn ".concat(d===e?"btn-active":"sp-btn-numb"),onClick:function(e){var t;return p(Number(null===(t=e.target)||void 0===t?void 0:t.value))},value:e},e)}),React.createElement("button",{className:"sp-eab-saved-template-pagination-btn sp-btn-next ".concat(d===(null==U?void 0:U.length)?"btn-disabled":""),onClick:function(){return p(d!==(null==U?void 0:U.length)?d+1:null==U?void 0:U.length)}},React.createElement(pd,null)))))),React.createElement(vd,null))};function kd(e){return kd="function"==typeof Symbol&&"symbol"==typeof Symbol.iterator?function(e){return typeof e}:function(e){return e&&"function"==typeof Symbol&&e.constructor===Symbol&&e!==Symbol.prototype?"symbol":typeof e},kd(e)}function Od(e){var t=function(e){if("object"!=kd(e)||!e)return e;var t=e[Symbol.toPrimitive];if(void 0!==t){var n=t.call(e,"string");if("object"!=kd(n))return n;throw new TypeError("@@toPrimitive must return a primitive value.")}return String(e)}(e);return"symbol"==kd(t)?t:t+""}function Pd(e,t,n){return(t=Od(t))in e?Object.defineProperty(e,t,{value:n,enumerable:!0,configurable:!0,writable:!0}):e[t]=n,e}function Md(e,t){var n=Object.keys(e);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(e);t&&(r=r.filter(function(t){return Object.getOwnPropertyDescriptor(e,t).enumerable})),n.push.apply(n,r)}return n}function Id(e){for(var t=1;t<arguments.length;t++){var n=null!=arguments[t]?arguments[t]:{};t%2?Md(Object(n),!0).forEach(function(t){Pd(e,t,n[t])}):Object.getOwnPropertyDescriptors?Object.defineProperties(e,Object.getOwnPropertyDescriptors(n)):Md(Object(n)).forEach(function(t){Object.defineProperty(e,t,Object.getOwnPropertyDescriptor(n,t))})}return e}function Td(e,t){(null==t||t>e.length)&&(t=e.length);for(var n=0,r=Array(t);n<t;n++)r[n]=e[n];return r}function _d(e,t){if(e){if("string"==typeof e)return Td(e,t);var n={}.toString.call(e).slice(8,-1);return"Object"===n&&e.constructor&&(n=e.constructor.name),"Map"===n||"Set"===n?Array.from(e):"Arguments"===n||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)?Td(e,t):void 0}}function Nd(e,t){return function(e){if(Array.isArray(e))return e}(e)||function(e,t){var n=null==e?null:"undefined"!=typeof Symbol&&e[Symbol.iterator]||e["@@iterator"];if(null!=n){var r,a,o,i,s=[],l=!0,c=!1;try{if(o=(n=n.call(e)).next,0===t){if(Object(n)!==n)return;l=!1}else for(;!(l=(r=o.call(n)).done)&&(s.push(r.value),s.length!==t);l=!0);}catch(e){c=!0,a=e}finally{try{if(!l&&null!=n.return&&(i=n.return(),Object(i)!==i))return}finally{if(c)throw a}}return s}}(e,t)||_d(e,t)||function(){throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.")}()}function Ld(e,t){if(null==e)return{};var n,r,a=Ao(e,t);if(Object.getOwnPropertySymbols){var o=Object.getOwnPropertySymbols(e);for(r=0;r<o.length;r++)n=o[r],-1===t.indexOf(n)&&{}.propertyIsEnumerable.call(e,n)&&(a[n]=e[n])}return a}var Dd=["defaultInputValue","defaultMenuIsOpen","defaultValue","inputValue","menuIsOpen","onChange","onInputChange","onMenuClose","onMenuOpen","value"];function Bd(e,t){for(var n=0;n<t.length;n++){var r=t[n];r.enumerable=r.enumerable||!1,r.configurable=!0,"value"in r&&(r.writable=!0),Object.defineProperty(e,Od(r.key),r)}}function Fd(e){return Fd=Object.setPrototypeOf?Object.getPrototypeOf.bind():function(e){return e.__proto__||Object.getPrototypeOf(e)},Fd(e)}function zd(){try{var e=!Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],function(){}))}catch(e){}return(zd=function(){return!!e})()}function jd(e){return function(e){if(Array.isArray(e))return Td(e)}(e)||function(e){if("undefined"!=typeof Symbol&&null!=e[Symbol.iterator]||null!=e["@@iterator"])return Array.from(e)}(e)||_d(e)||function(){throw new TypeError("Invalid attempt to spread non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.")}()}n(146);var Hd,Vd,Gd=function(e,t){var n=arguments;if(null==t||!Zt.call(t,"css"))return c.createElement.apply(void 0,n);var r=n.length,a=new Array(r);a[0]=$t,a[1]=function(e,t){var n={};for(var r in t)Zt.call(t,r)&&(n[r]=t[r]);return n[Jt]=e,n}(e,t);for(var o=2;o<r;o++)a[o]=n[o];return c.createElement.apply(null,a)};function qd(){for(var e=arguments.length,t=new Array(e),n=0;n<e;n++)t[n]=arguments[n];return Gt(t)}Hd=Gd||(Gd={}),Vd||(Vd=Hd.JSX||(Hd.JSX={}));const Ud=Math.min,Wd=Math.max,Qd=Math.round,Kd=Math.floor,Zd=e=>({x:e,y:e});function Jd(){return"undefined"!=typeof window}function Xd(e){return ep(e)?(e.nodeName||"").toLowerCase():"#document"}function Yd(e){var t;return(null==e||null==(t=e.ownerDocument)?void 0:t.defaultView)||window}function $d(e){var t;return null==(t=(ep(e)?e.ownerDocument:e.document)||window.document)?void 0:t.documentElement}function ep(e){return!!Jd()&&(e instanceof Node||e instanceof Yd(e).Node)}function tp(e){return!!Jd()&&(e instanceof Element||e instanceof Yd(e).Element)}function np(e){return!!Jd()&&(e instanceof HTMLElement||e instanceof Yd(e).HTMLElement)}function rp(e){return!(!Jd()||"undefined"==typeof ShadowRoot)&&(e instanceof ShadowRoot||e instanceof Yd(e).ShadowRoot)}function ap(e){const{overflow:t,overflowX:n,overflowY:r,display:a}=ip(e);return/auto|scroll|overlay|hidden|clip/.test(t+r+n)&&"inline"!==a&&"contents"!==a}let op;function ip(e){return Yd(e).getComputedStyle(e)}function sp(e){const t=function(e){if("html"===Xd(e))return e;const t=e.assignedSlot||e.parentNode||rp(e)&&e.host||$d(e);return rp(t)?t.host:t}(e);return function(e){return/^(html|body|#document)$/.test(Xd(e))}(t)?e.ownerDocument?e.ownerDocument.body:e.body:np(t)&&ap(t)?t:sp(t)}function lp(e,t,n){var r;void 0===t&&(t=[]),void 0===n&&(n=!0);const a=sp(e),o=a===(null==(r=e.ownerDocument)?void 0:r.body),i=Yd(a);if(o){const e=cp(i);return t.concat(i,i.visualViewport||[],ap(a)?a:[],e&&n?lp(e):[])}return t.concat(a,lp(a,[],n))}function cp(e){return e.parent&&Object.getPrototypeOf(e.parent)?e.frameElement:null}function up(e){return tp(e)?e:e.contextElement}function dp(e){const t=up(e);if(!np(t))return Zd(1);const n=t.getBoundingClientRect(),{width:r,height:a,$:o}=function(e){const t=ip(e);let n=parseFloat(t.width)||0,r=parseFloat(t.height)||0;const a=np(e),o=a?e.offsetWidth:n,i=a?e.offsetHeight:r,s=Qd(n)!==o||Qd(r)!==i;return s&&(n=o,r=i),{width:n,height:r,$:s}}(t);let i=(o?Qd(n.width):n.width)/r,s=(o?Qd(n.height):n.height)/a;return i&&Number.isFinite(i)||(i=1),s&&Number.isFinite(s)||(s=1),{x:i,y:s}}const pp=Zd(0);function fp(e){const t=Yd(e);return null==op&&(op="undefined"!=typeof CSS&&CSS.supports&&CSS.supports("-webkit-backdrop-filter","none")),op&&t.visualViewport?{x:t.visualViewport.offsetLeft,y:t.visualViewport.offsetTop}:pp}function mp(e,t,n,r){void 0===t&&(t=!1),void 0===n&&(n=!1);const a=e.getBoundingClientRect(),o=up(e);let i=Zd(1);t&&(r?tp(r)&&(i=dp(r)):i=dp(e));const s=function(e,t,n){return void 0===t&&(t=!1),!(!n||t&&n!==Yd(e))&&t}(o,n,r)?fp(o):Zd(0);let l=(a.left+s.x)/i.x,c=(a.top+s.y)/i.y,u=a.width/i.x,d=a.height/i.y;if(o){const e=Yd(o),t=r&&tp(r)?Yd(r):r;let n=e,a=cp(n);for(;a&&r&&t!==n;){const e=dp(a),t=a.getBoundingClientRect(),r=ip(a),o=t.left+(a.clientLeft+parseFloat(r.paddingLeft))*e.x,i=t.top+(a.clientTop+parseFloat(r.paddingTop))*e.y;l*=e.x,c*=e.y,u*=e.x,d*=e.y,l+=o,c+=i,n=Yd(a),a=cp(n)}}return function(e){const{x:t,y:n,width:r,height:a}=e;return{width:r,height:a,top:n,left:t,right:t+r,bottom:n+a,x:t,y:n}}({width:u,height:d,x:l,y:c})}function hp(e,t){return e.x===t.x&&e.y===t.y&&e.width===t.width&&e.height===t.height}var gp=c.useLayoutEffect,vp=["className","clearValue","cx","getStyles","getClassNames","getValue","hasValue","isMulti","isRtl","options","selectOption","selectProps","setValue","theme"],bp=function(){};function yp(e,t){return t?"-"===t[0]?e+t:e+"__"+t:e}function Ep(e,t){for(var n=arguments.length,r=new Array(n>2?n-2:0),a=2;a<n;a++)r[a-2]=arguments[a];var o=[].concat(r);if(t&&e)for(var i in t)t.hasOwnProperty(i)&&t[i]&&o.push("".concat(yp(e,i)));return o.filter(function(e){return e}).map(function(e){return String(e).trim()}).join(" ")}var Rp=function(e){return function(e){return Array.isArray(e)}(e)?e.filter(Boolean):"object"===kd(e)&&null!==e?[e]:[]},xp=function(e){return e.className,e.clearValue,e.cx,e.getStyles,e.getClassNames,e.getValue,e.hasValue,e.isMulti,e.isRtl,e.options,e.selectOption,e.selectProps,e.setValue,e.theme,Id({},Ld(e,vp))},Ap=function(e,t,n){var r=e.cx,a=e.getStyles,o=e.getClassNames,i=e.className;return{css:a(t,e),className:r(null!=n?n:{},o(t,e),i)}};function Cp(e){return[document.documentElement,document.body,window].indexOf(e)>-1}function Sp(e){return Cp(e)?window.pageYOffset:e.scrollTop}function kp(e,t){Cp(e)?window.scrollTo(0,t):e.scrollTop=t}function Op(e,t){var n=arguments.length>2&&void 0!==arguments[2]?arguments[2]:200,r=arguments.length>3&&void 0!==arguments[3]?arguments[3]:bp,a=Sp(e),o=t-a,i=0;!function t(){var s=function(e,t,n,r){return n*((e=e/r-1)*e*e+1)+t}(i+=10,a,o,n);kp(e,s),i<n?window.requestAnimationFrame(t):r(e)}()}function Pp(e,t){var n=e.getBoundingClientRect(),r=t.getBoundingClientRect(),a=t.offsetHeight/3;r.bottom+a>n.bottom?kp(e,Math.min(t.offsetTop+t.clientHeight-e.offsetHeight+a,e.scrollHeight)):r.top-a<n.top&&kp(e,Math.max(t.offsetTop-a,0))}function Mp(){try{return document.createEvent("TouchEvent"),!0}catch(e){return!1}}var Ip=!1,Tp={get passive(){return Ip=!0}},_p="undefined"!=typeof window?window:{};_p.addEventListener&&_p.removeEventListener&&(_p.addEventListener("p",bp,Tp),_p.removeEventListener("p",bp,!1));var Np=Ip;function Lp(e){return null!=e}function Dp(e,t,n){return e?t:n}var Bp=["children","innerProps"],Fp=["children","innerProps"];var zp,jp=function(e){return"auto"===e?"bottom":e},Hp=(0,c.createContext)(null),Vp=function(e){var t=e.children,n=e.minMenuHeight,r=e.maxMenuHeight,a=e.menuPlacement,o=e.menuPosition,i=e.menuShouldScrollIntoView,s=e.theme,l=((0,c.useContext)(Hp)||{}).setPortalPlacement,u=(0,c.useRef)(null),d=Nd((0,c.useState)(r),2),p=d[0],f=d[1],m=Nd((0,c.useState)(null),2),h=m[0],g=m[1],v=s.spacing.controlHeight;return gp(function(){var e=u.current;if(e){var t="fixed"===o,s=function(e){var t=e.maxHeight,n=e.menuEl,r=e.minHeight,a=e.placement,o=e.shouldScroll,i=e.isFixedPosition,s=e.controlHeight,l=function(e){var t=getComputedStyle(e),n="absolute"===t.position,r=/(auto|scroll)/;if("fixed"===t.position)return document.documentElement;for(var a=e;a=a.parentElement;)if(t=getComputedStyle(a),(!n||"static"!==t.position)&&r.test(t.overflow+t.overflowY+t.overflowX))return a;return document.documentElement}(n),c={placement:"bottom",maxHeight:t};if(!n||!n.offsetParent)return c;var u,d=l.getBoundingClientRect().height,p=n.getBoundingClientRect(),f=p.bottom,m=p.height,h=p.top,g=n.offsetParent.getBoundingClientRect().top,v=i||Cp(u=l)?window.innerHeight:u.clientHeight,b=Sp(l),y=parseInt(getComputedStyle(n).marginBottom,10),w=parseInt(getComputedStyle(n).marginTop,10),E=g-w,R=v-h,x=E+b,A=d-b-h,C=f-v+b+y,S=b+h-w,k=160;switch(a){case"auto":case"bottom":if(R>=m)return{placement:"bottom",maxHeight:t};if(A>=m&&!i)return o&&Op(l,C,k),{placement:"bottom",maxHeight:t};if(!i&&A>=r||i&&R>=r)return o&&Op(l,C,k),{placement:"bottom",maxHeight:i?R-y:A-y};if("auto"===a||i){var O=t,P=i?E:x;return P>=r&&(O=Math.min(P-y-s,t)),{placement:"top",maxHeight:O}}if("bottom"===a)return o&&kp(l,C),{placement:"bottom",maxHeight:t};break;case"top":if(E>=m)return{placement:"top",maxHeight:t};if(x>=m&&!i)return o&&Op(l,S,k),{placement:"top",maxHeight:t};if(!i&&x>=r||i&&E>=r){var M=t;return(!i&&x>=r||i&&E>=r)&&(M=i?E-w:x-w),o&&Op(l,S,k),{placement:"top",maxHeight:M}}return{placement:"bottom",maxHeight:t};default:throw new Error('Invalid placement provided "'.concat(a,'".'))}return c}({maxHeight:r,menuEl:e,minHeight:n,placement:a,shouldScroll:i&&!t,isFixedPosition:t,controlHeight:v});f(s.maxHeight),g(s.placement),null==l||l(s.placement)}},[r,a,o,i,n,l,v]),t({ref:u,placerProps:Id(Id({},e),{},{placement:h||jp(a),maxHeight:p})})},Gp=function(e,t){var n=e.theme,r=n.spacing.baseUnit,a=n.colors;return Id({textAlign:"center"},t?{}:{color:a.neutral40,padding:"".concat(2*r,"px ").concat(3*r,"px")})},qp=Gp,Up=Gp,Wp=["size"],Qp=["innerProps","isRtl","size"],Kp={name:"8mmkcg",styles:"display:inline-block;fill:currentColor;line-height:1;stroke:currentColor;stroke-width:0"},Zp=function(e){var t=e.size,n=Ld(e,Wp);return Gd("svg",ke({height:t,width:t,viewBox:"0 0 20 20","aria-hidden":"true",focusable:"false",css:Kp},n))},Jp=function(e){return Gd(Zp,ke({size:20},e),Gd("path",{d:"M14.348 14.849c-0.469 0.469-1.229 0.469-1.697 0l-2.651-3.030-2.651 3.029c-0.469 0.469-1.229 0.469-1.697 0-0.469-0.469-0.469-1.229 0-1.697l2.758-3.15-2.759-3.152c-0.469-0.469-0.469-1.228 0-1.697s1.228-0.469 1.697 0l2.652 3.031 2.651-3.031c0.469-0.469 1.228-0.469 1.697 0s0.469 1.229 0 1.697l-2.758 3.152 2.758 3.15c0.469 0.469 0.469 1.229 0 1.698z"}))},Xp=function(e){return Gd(Zp,ke({size:20},e),Gd("path",{d:"M4.516 7.548c0.436-0.446 1.043-0.481 1.576 0l3.908 3.747 3.908-3.747c0.533-0.481 1.141-0.446 1.574 0 0.436 0.445 0.408 1.197 0 1.615-0.406 0.418-4.695 4.502-4.695 4.502-0.217 0.223-0.502 0.335-0.787 0.335s-0.57-0.112-0.789-0.335c0 0-4.287-4.084-4.695-4.502s-0.436-1.17 0-1.615z"}))},Yp=function(e,t){var n=e.isFocused,r=e.theme,a=r.spacing.baseUnit,o=r.colors;return Id({label:"indicatorContainer",display:"flex",transition:"color 150ms"},t?{}:{color:n?o.neutral60:o.neutral20,padding:2*a,":hover":{color:n?o.neutral80:o.neutral40}})},$p=Yp,ef=Yp,tf=function(){var e=qd.apply(void 0,arguments),t="animation-"+e.name;return{name:t,styles:"@keyframes "+t+"{"+e.styles+"}",anim:1,toString:function(){return"_EMO_"+this.name+"_"+this.styles+"_EMO_"}}}(zp||(zp=function(e,t){return t||(t=e.slice(0)),Object.freeze(Object.defineProperties(e,{raw:{value:Object.freeze(t)}}))}(["\n  0%, 80%, 100% { opacity: 0; }\n  40% { opacity: 1; }\n"]))),nf=function(e){var t=e.delay,n=e.offset;return Gd("span",{css:qd({animation:"".concat(tf," 1s ease-in-out ").concat(t,"ms infinite;"),backgroundColor:"currentColor",borderRadius:"1em",display:"inline-block",marginLeft:n?"1em":void 0,height:"1em",verticalAlign:"top",width:"1em"},"","")})},rf=["data"],af=["innerRef","isDisabled","isHidden","inputClassName"],of={gridArea:"1 / 2",font:"inherit",minWidth:"2px",border:0,margin:0,outline:0,padding:0},sf={flex:"1 1 auto",display:"inline-grid",gridArea:"1 / 1 / 2 / 3",gridTemplateColumns:"0 min-content","&:after":Id({content:'attr(data-value) " "',visibility:"hidden",whiteSpace:"pre"},of)},lf=function(e){return Id({label:"input",color:"inherit",background:0,opacity:e?0:1,width:"100%"},of)},cf=function(e){var t=e.children,n=e.innerProps;return Gd("div",n,t)},uf={ClearIndicator:function(e){var t=e.children,n=e.innerProps;return Gd("div",ke({},Ap(e,"clearIndicator",{indicator:!0,"clear-indicator":!0}),n),t||Gd(Jp,null))},Control:function(e){var t=e.children,n=e.isDisabled,r=e.isFocused,a=e.innerRef,o=e.innerProps,i=e.menuIsOpen;return Gd("div",ke({ref:a},Ap(e,"control",{control:!0,"control--is-disabled":n,"control--is-focused":r,"control--menu-is-open":i}),o,{"aria-disabled":n||void 0}),t)},DropdownIndicator:function(e){var t=e.children,n=e.innerProps;return Gd("div",ke({},Ap(e,"dropdownIndicator",{indicator:!0,"dropdown-indicator":!0}),n),t||Gd(Xp,null))},DownChevron:Xp,CrossIcon:Jp,Group:function(e){var t=e.children,n=e.cx,r=e.getStyles,a=e.getClassNames,o=e.Heading,i=e.headingProps,s=e.innerProps,l=e.label,c=e.theme,u=e.selectProps;return Gd("div",ke({},Ap(e,"group",{group:!0}),s),Gd(o,ke({},i,{selectProps:u,theme:c,getStyles:r,getClassNames:a,cx:n}),l),Gd("div",null,t))},GroupHeading:function(e){var t=xp(e);t.data;var n=Ld(t,rf);return Gd("div",ke({},Ap(e,"groupHeading",{"group-heading":!0}),n))},IndicatorsContainer:function(e){var t=e.children,n=e.innerProps;return Gd("div",ke({},Ap(e,"indicatorsContainer",{indicators:!0}),n),t)},IndicatorSeparator:function(e){var t=e.innerProps;return Gd("span",ke({},t,Ap(e,"indicatorSeparator",{"indicator-separator":!0})))},Input:function(e){var t=e.cx,n=e.value,r=xp(e),a=r.innerRef,o=r.isDisabled,i=r.isHidden,s=r.inputClassName,l=Ld(r,af);return Gd("div",ke({},Ap(e,"input",{"input-container":!0}),{"data-value":n||""}),Gd("input",ke({className:t({input:!0},s),ref:a,style:lf(i),disabled:o},l)))},LoadingIndicator:function(e){var t=e.innerProps,n=e.isRtl,r=e.size,a=void 0===r?4:r,o=Ld(e,Qp);return Gd("div",ke({},Ap(Id(Id({},o),{},{innerProps:t,isRtl:n,size:a}),"loadingIndicator",{indicator:!0,"loading-indicator":!0}),t),Gd(nf,{delay:0,offset:n}),Gd(nf,{delay:160,offset:!0}),Gd(nf,{delay:320,offset:!n}))},Menu:function(e){var t=e.children,n=e.innerRef,r=e.innerProps;return Gd("div",ke({},Ap(e,"menu",{menu:!0}),{ref:n},r),t)},MenuList:function(e){var t=e.children,n=e.innerProps,r=e.innerRef,a=e.isMulti;return Gd("div",ke({},Ap(e,"menuList",{"menu-list":!0,"menu-list--is-multi":a}),{ref:r},n),t)},MenuPortal:function(e){var t=e.appendTo,n=e.children,r=e.controlElement,a=e.innerProps,o=e.menuPlacement,i=e.menuPosition,s=(0,c.useRef)(null),l=(0,c.useRef)(null),u=Nd((0,c.useState)(jp(o)),2),d=u[0],p=u[1],f=(0,c.useMemo)(function(){return{setPortalPlacement:p}},[]),m=Nd((0,c.useState)(null),2),h=m[0],g=m[1],v=(0,c.useCallback)(function(){if(r){var e=function(e){var t=e.getBoundingClientRect();return{bottom:t.bottom,height:t.height,left:t.left,right:t.right,top:t.top,width:t.width}}(r),t="fixed"===i?0:window.pageYOffset,n=e[d]+t;n===(null==h?void 0:h.offset)&&e.left===(null==h?void 0:h.rect.left)&&e.width===(null==h?void 0:h.rect.width)||g({offset:n,rect:e})}},[r,i,d,null==h?void 0:h.offset,null==h?void 0:h.rect.left,null==h?void 0:h.rect.width]);gp(function(){v()},[v]);var b=(0,c.useCallback)(function(){"function"==typeof l.current&&(l.current(),l.current=null),r&&s.current&&(l.current=function(e,t,n,r){void 0===r&&(r={});const{ancestorScroll:a=!0,ancestorResize:o=!0,elementResize:i="function"==typeof ResizeObserver,layoutShift:s="function"==typeof IntersectionObserver,animationFrame:l=!1}=r,c=up(e),u=a||o?[...c?lp(c):[],...t?lp(t):[]]:[];u.forEach(e=>{a&&e.addEventListener("scroll",n,{passive:!0}),o&&e.addEventListener("resize",n)});const d=c&&s?function(e,t){let n,r=null;const a=$d(e);function o(){var e;clearTimeout(n),null==(e=r)||e.disconnect(),r=null}return function i(s,l){void 0===s&&(s=!1),void 0===l&&(l=1),o();const c=e.getBoundingClientRect(),{left:u,top:d,width:p,height:f}=c;if(s||t(),!p||!f)return;const m={rootMargin:-Kd(d)+"px "+-Kd(a.clientWidth-(u+p))+"px "+-Kd(a.clientHeight-(d+f))+"px "+-Kd(u)+"px",threshold:Wd(0,Ud(1,l))||1};let h=!0;function g(t){const r=t[0].intersectionRatio;if(r!==l){if(!h)return i();r?i(!1,r):n=setTimeout(()=>{i(!1,1e-7)},1e3)}1!==r||hp(c,e.getBoundingClientRect())||i(),h=!1}try{r=new IntersectionObserver(g,{...m,root:a.ownerDocument})}catch(e){r=new IntersectionObserver(g,m)}r.observe(e)}(!0),o}(c,n):null;let p,f=-1,m=null;i&&(m=new ResizeObserver(e=>{let[r]=e;r&&r.target===c&&m&&t&&(m.unobserve(t),cancelAnimationFrame(f),f=requestAnimationFrame(()=>{var e;null==(e=m)||e.observe(t)})),n()}),c&&!l&&m.observe(c),t&&m.observe(t));let h=l?mp(e):null;return l&&function t(){const r=mp(e);h&&!hp(h,r)&&n(),h=r,p=requestAnimationFrame(t)}(),n(),()=>{var e;u.forEach(e=>{a&&e.removeEventListener("scroll",n),o&&e.removeEventListener("resize",n)}),null==d||d(),null==(e=m)||e.disconnect(),m=null,l&&cancelAnimationFrame(p)}}(r,s.current,v,{elementResize:"ResizeObserver"in window}))},[r,v]);gp(function(){b()},[b]);var y=(0,c.useCallback)(function(e){s.current=e,b()},[b]);if(!t&&"fixed"!==i||!h)return null;var w=Gd("div",ke({ref:y},Ap(Id(Id({},e),{},{offset:h.offset,position:i,rect:h.rect}),"menuPortal",{"menu-portal":!0}),a),n);return Gd(Hp.Provider,{value:f},t?(0,Re.createPortal)(w,t):w)},LoadingMessage:function(e){var t=e.children,n=void 0===t?"Loading...":t,r=e.innerProps,a=Ld(e,Fp);return Gd("div",ke({},Ap(Id(Id({},a),{},{children:n,innerProps:r}),"loadingMessage",{"menu-notice":!0,"menu-notice--loading":!0}),r),n)},NoOptionsMessage:function(e){var t=e.children,n=void 0===t?"No options":t,r=e.innerProps,a=Ld(e,Bp);return Gd("div",ke({},Ap(Id(Id({},a),{},{children:n,innerProps:r}),"noOptionsMessage",{"menu-notice":!0,"menu-notice--no-options":!0}),r),n)},MultiValue:function(e){var t=e.children,n=e.components,r=e.data,a=e.innerProps,o=e.isDisabled,i=e.removeProps,s=e.selectProps,l=n.Container,c=n.Label,u=n.Remove;return Gd(l,{data:r,innerProps:Id(Id({},Ap(e,"multiValue",{"multi-value":!0,"multi-value--is-disabled":o})),a),selectProps:s},Gd(c,{data:r,innerProps:Id({},Ap(e,"multiValueLabel",{"multi-value__label":!0})),selectProps:s},t),Gd(u,{data:r,innerProps:Id(Id({},Ap(e,"multiValueRemove",{"multi-value__remove":!0})),{},{"aria-label":"Remove ".concat(t||"option")},i),selectProps:s}))},MultiValueContainer:cf,MultiValueLabel:cf,MultiValueRemove:function(e){var t=e.children,n=e.innerProps;return Gd("div",ke({role:"button"},n),t||Gd(Jp,{size:14}))},Option:function(e){var t=e.children,n=e.isDisabled,r=e.isFocused,a=e.isSelected,o=e.innerRef,i=e.innerProps;return Gd("div",ke({},Ap(e,"option",{option:!0,"option--is-disabled":n,"option--is-focused":r,"option--is-selected":a}),{ref:o,"aria-disabled":n},i),t)},Placeholder:function(e){var t=e.children,n=e.innerProps;return Gd("div",ke({},Ap(e,"placeholder",{placeholder:!0}),n),t)},SelectContainer:function(e){var t=e.children,n=e.innerProps,r=e.isDisabled,a=e.isRtl;return Gd("div",ke({},Ap(e,"container",{"--is-disabled":r,"--is-rtl":a}),n),t)},SingleValue:function(e){var t=e.children,n=e.isDisabled,r=e.innerProps;return Gd("div",ke({},Ap(e,"singleValue",{"single-value":!0,"single-value--is-disabled":n}),r),t)},ValueContainer:function(e){var t=e.children,n=e.innerProps,r=e.isMulti,a=e.hasValue;return Gd("div",ke({},Ap(e,"valueContainer",{"value-container":!0,"value-container--is-multi":r,"value-container--has-value":a}),n),t)}},df=Number.isNaN||function(e){return"number"==typeof e&&e!=e};function pf(e,t){return e===t||!(!df(e)||!df(t))}function ff(e,t){if(e.length!==t.length)return!1;for(var n=0;n<e.length;n++)if(!pf(e[n],t[n]))return!1;return!0}for(var mf={name:"7pg0cj-a11yText",styles:"label:a11yText;z-index:9999;border:0;clip:rect(1px, 1px, 1px, 1px);height:1px;width:1px;position:absolute;overflow:hidden;padding:0;white-space:nowrap"},hf=function(e){return Gd("span",ke({css:mf},e))},gf={guidance:function(e){var t=e.isSearchable,n=e.isMulti,r=e.tabSelectsValue,a=e.context,o=e.isInitialFocus;switch(a){case"menu":return"Use Up and Down to choose options, press Enter to select the currently focused option, press Escape to exit the menu".concat(r?", press Tab to select the option and exit the menu":"",".");case"input":return o?"".concat(e["aria-label"]||"Select"," is focused ").concat(t?",type to refine list":"",", press Down to open the menu, ").concat(n?" press left to focus selected values":""):"";case"value":return"Use left and right to toggle between focused values, press Backspace to remove the currently focused value";default:return""}},onChange:function(e){var t=e.action,n=e.label,r=void 0===n?"":n,a=e.labels,o=e.isDisabled;switch(t){case"deselect-option":case"pop-value":case"remove-value":return"option ".concat(r,", deselected.");case"clear":return"All selected options have been cleared.";case"initial-input-focus":return"option".concat(a.length>1?"s":""," ").concat(a.join(","),", selected.");case"select-option":return"option ".concat(r,o?" is disabled. Select another option.":", selected.");default:return""}},onFocus:function(e){var t=e.context,n=e.focused,r=e.options,a=e.label,o=void 0===a?"":a,i=e.selectValue,s=e.isDisabled,l=e.isSelected,c=e.isAppleDevice,u=function(e,t){return e&&e.length?"".concat(e.indexOf(t)+1," of ").concat(e.length):""};if("value"===t&&i)return"value ".concat(o," focused, ").concat(u(i,n),".");if("menu"===t&&c){var d=s?" disabled":"",p="".concat(l?" selected":"").concat(d);return"".concat(o).concat(p,", ").concat(u(r,n),".")}return""},onFilter:function(e){var t=e.inputValue,n=e.resultsMessage;return"".concat(n).concat(t?" for search term "+t:"",".")}},vf=function(e){var t=e.ariaSelection,n=e.focusedOption,r=e.focusedValue,a=e.focusableOptions,o=e.isFocused,i=e.selectValue,s=e.selectProps,l=e.id,u=e.isAppleDevice,d=s.ariaLiveMessages,p=s.getOptionLabel,f=s.inputValue,m=s.isMulti,h=s.isOptionDisabled,g=s.isSearchable,v=s.menuIsOpen,b=s.options,y=s.screenReaderStatus,w=s.tabSelectsValue,E=s.isLoading,R=s["aria-label"],x=s["aria-live"],A=(0,c.useMemo)(function(){return Id(Id({},gf),d||{})},[d]),C=(0,c.useMemo)(function(){var e,n="";if(t&&A.onChange){var r=t.option,a=t.options,o=t.removedValue,s=t.removedValues,l=t.value,c=o||r||(e=l,Array.isArray(e)?null:e),u=c?p(c):"",d=a||s||void 0,f=d?d.map(p):[],m=Id({isDisabled:c&&h(c,i),label:u,labels:f},t);n=A.onChange(m)}return n},[t,A,h,i,p]),S=(0,c.useMemo)(function(){var e="",t=n||r,o=!!(n&&i&&i.includes(n));if(t&&A.onFocus){var s={focused:t,label:p(t),isDisabled:h(t,i),isSelected:o,options:a,context:t===n?"menu":"value",selectValue:i,isAppleDevice:u};e=A.onFocus(s)}return e},[n,r,p,h,A,a,i,u]),k=(0,c.useMemo)(function(){var e="";if(v&&b.length&&!E&&A.onFilter){var t=y({count:a.length});e=A.onFilter({inputValue:f,resultsMessage:t})}return e},[a,f,v,A,b,y,E]),O="initial-input-focus"===(null==t?void 0:t.action),P=(0,c.useMemo)(function(){var e="";if(A.guidance){var t=r?"value":v?"menu":"input";e=A.guidance({"aria-label":R,context:t,isDisabled:n&&h(n,i),isMulti:m,isSearchable:g,tabSelectsValue:w,isInitialFocus:O})}return e},[R,n,r,m,h,g,v,A,i,w,O]),M=Gd(c.Fragment,null,Gd("span",{id:"aria-selection"},C),Gd("span",{id:"aria-focused"},S),Gd("span",{id:"aria-results"},k),Gd("span",{id:"aria-guidance"},P));return Gd(c.Fragment,null,Gd(hf,{id:l},O&&M),Gd(hf,{"aria-live":x,"aria-atomic":"false","aria-relevant":"additions text",role:"log"},o&&!O&&M))},bf=[{base:"A",letters:"AⒶＡÀÁÂẦẤẪẨÃĀĂẰẮẴẲȦǠÄǞẢÅǺǍȀȂẠẬẶḀĄȺⱯ"},{base:"AA",letters:"Ꜳ"},{base:"AE",letters:"ÆǼǢ"},{base:"AO",letters:"Ꜵ"},{base:"AU",letters:"Ꜷ"},{base:"AV",letters:"ꜸꜺ"},{base:"AY",letters:"Ꜽ"},{base:"B",letters:"BⒷＢḂḄḆɃƂƁ"},{base:"C",letters:"CⒸＣĆĈĊČÇḈƇȻꜾ"},{base:"D",letters:"DⒹＤḊĎḌḐḒḎĐƋƊƉꝹ"},{base:"DZ",letters:"ǱǄ"},{base:"Dz",letters:"ǲǅ"},{base:"E",letters:"EⒺＥÈÉÊỀẾỄỂẼĒḔḖĔĖËẺĚȄȆẸỆȨḜĘḘḚƐƎ"},{base:"F",letters:"FⒻＦḞƑꝻ"},{base:"G",letters:"GⒼＧǴĜḠĞĠǦĢǤƓꞠꝽꝾ"},{base:"H",letters:"HⒽＨĤḢḦȞḤḨḪĦⱧⱵꞍ"},{base:"I",letters:"IⒾＩÌÍÎĨĪĬİÏḮỈǏȈȊỊĮḬƗ"},{base:"J",letters:"JⒿＪĴɈ"},{base:"K",letters:"KⓀＫḰǨḲĶḴƘⱩꝀꝂꝄꞢ"},{base:"L",letters:"LⓁＬĿĹĽḶḸĻḼḺŁȽⱢⱠꝈꝆꞀ"},{base:"LJ",letters:"Ǉ"},{base:"Lj",letters:"ǈ"},{base:"M",letters:"MⓂＭḾṀṂⱮƜ"},{base:"N",letters:"NⓃＮǸŃÑṄŇṆŅṊṈȠƝꞐꞤ"},{base:"NJ",letters:"Ǌ"},{base:"Nj",letters:"ǋ"},{base:"O",letters:"OⓄＯÒÓÔỒỐỖỔÕṌȬṎŌṐṒŎȮȰÖȪỎŐǑȌȎƠỜỚỠỞỢỌỘǪǬØǾƆƟꝊꝌ"},{base:"OI",letters:"Ƣ"},{base:"OO",letters:"Ꝏ"},{base:"OU",letters:"Ȣ"},{base:"P",letters:"PⓅＰṔṖƤⱣꝐꝒꝔ"},{base:"Q",letters:"QⓆＱꝖꝘɊ"},{base:"R",letters:"RⓇＲŔṘŘȐȒṚṜŖṞɌⱤꝚꞦꞂ"},{base:"S",letters:"SⓈＳẞŚṤŜṠŠṦṢṨȘŞⱾꞨꞄ"},{base:"T",letters:"TⓉＴṪŤṬȚŢṰṮŦƬƮȾꞆ"},{base:"TZ",letters:"Ꜩ"},{base:"U",letters:"UⓊＵÙÚÛŨṸŪṺŬÜǛǗǕǙỦŮŰǓȔȖƯỪỨỮỬỰỤṲŲṶṴɄ"},{base:"V",letters:"VⓋＶṼṾƲꝞɅ"},{base:"VY",letters:"Ꝡ"},{base:"W",letters:"WⓌＷẀẂŴẆẄẈⱲ"},{base:"X",letters:"XⓍＸẊẌ"},{base:"Y",letters:"YⓎＹỲÝŶỸȲẎŸỶỴƳɎỾ"},{base:"Z",letters:"ZⓏＺŹẐŻŽẒẔƵȤⱿⱫꝢ"},{base:"a",letters:"aⓐａẚàáâầấẫẩãāăằắẵẳȧǡäǟảåǻǎȁȃạậặḁąⱥɐ"},{base:"aa",letters:"ꜳ"},{base:"ae",letters:"æǽǣ"},{base:"ao",letters:"ꜵ"},{base:"au",letters:"ꜷ"},{base:"av",letters:"ꜹꜻ"},{base:"ay",letters:"ꜽ"},{base:"b",letters:"bⓑｂḃḅḇƀƃɓ"},{base:"c",letters:"cⓒｃćĉċčçḉƈȼꜿↄ"},{base:"d",letters:"dⓓｄḋďḍḑḓḏđƌɖɗꝺ"},{base:"dz",letters:"ǳǆ"},{base:"e",letters:"eⓔｅèéêềếễểẽēḕḗĕėëẻěȅȇẹệȩḝęḙḛɇɛǝ"},{base:"f",letters:"fⓕｆḟƒꝼ"},{base:"g",letters:"gⓖｇǵĝḡğġǧģǥɠꞡᵹꝿ"},{base:"h",letters:"hⓗｈĥḣḧȟḥḩḫẖħⱨⱶɥ"},{base:"hv",letters:"ƕ"},{base:"i",letters:"iⓘｉìíîĩīĭïḯỉǐȉȋịįḭɨı"},{base:"j",letters:"jⓙｊĵǰɉ"},{base:"k",letters:"kⓚｋḱǩḳķḵƙⱪꝁꝃꝅꞣ"},{base:"l",letters:"lⓛｌŀĺľḷḹļḽḻſłƚɫⱡꝉꞁꝇ"},{base:"lj",letters:"ǉ"},{base:"m",letters:"mⓜｍḿṁṃɱɯ"},{base:"n",letters:"nⓝｎǹńñṅňṇņṋṉƞɲŉꞑꞥ"},{base:"nj",letters:"ǌ"},{base:"o",letters:"oⓞｏòóôồốỗổõṍȭṏōṑṓŏȯȱöȫỏőǒȍȏơờớỡởợọộǫǭøǿɔꝋꝍɵ"},{base:"oi",letters:"ƣ"},{base:"ou",letters:"ȣ"},{base:"oo",letters:"ꝏ"},{base:"p",letters:"pⓟｐṕṗƥᵽꝑꝓꝕ"},{base:"q",letters:"qⓠｑɋꝗꝙ"},{base:"r",letters:"rⓡｒŕṙřȑȓṛṝŗṟɍɽꝛꞧꞃ"},{base:"s",letters:"sⓢｓßśṥŝṡšṧṣṩșşȿꞩꞅẛ"},{base:"t",letters:"tⓣｔṫẗťṭțţṱṯŧƭʈⱦꞇ"},{base:"tz",letters:"ꜩ"},{base:"u",letters:"uⓤｕùúûũṹūṻŭüǜǘǖǚủůűǔȕȗưừứữửựụṳųṷṵʉ"},{base:"v",letters:"vⓥｖṽṿʋꝟʌ"},{base:"vy",letters:"ꝡ"},{base:"w",letters:"wⓦｗẁẃŵẇẅẘẉⱳ"},{base:"x",letters:"xⓧｘẋẍ"},{base:"y",letters:"yⓨｙỳýŷỹȳẏÿỷẙỵƴɏỿ"},{base:"z",letters:"zⓩｚźẑżžẓẕƶȥɀⱬꝣ"}],yf=new RegExp("["+bf.map(function(e){return e.letters}).join("")+"]","g"),wf={},Ef=0;Ef<bf.length;Ef++)for(var Rf=bf[Ef],xf=0;xf<Rf.letters.length;xf++)wf[Rf.letters[xf]]=Rf.base;var Af=function(e){return e.replace(yf,function(e){return wf[e]})},Cf=function(e,t){void 0===t&&(t=ff);var n=null;function r(){for(var r=[],a=0;a<arguments.length;a++)r[a]=arguments[a];if(n&&n.lastThis===this&&t(r,n.lastArgs))return n.lastResult;var o=e.apply(this,r);return n={lastResult:o,lastArgs:r,lastThis:this},o}return r.clear=function(){n=null},r}(Af),Sf=function(e){return e.replace(/^\s+|\s+$/g,"")},kf=function(e){return"".concat(e.label," ").concat(e.value)},Of=["innerRef"];function Pf(e){var t=e.innerRef,n=function(e){for(var t=arguments.length,n=new Array(t>1?t-1:0),r=1;r<t;r++)n[r-1]=arguments[r];var a=Object.entries(e).filter(function(e){var t=Nd(e,1)[0];return!n.includes(t)});return a.reduce(function(e,t){var n=Nd(t,2),r=n[0],a=n[1];return e[r]=a,e},{})}(Ld(e,Of),"onExited","in","enter","exit","appear");return Gd("input",ke({ref:t},n,{css:qd({label:"dummyInput",background:0,border:0,caretColor:"transparent",fontSize:"inherit",gridArea:"1 / 1 / 2 / 3",outline:0,padding:0,width:1,color:"transparent",left:-100,opacity:0,position:"relative",transform:"scale(.01)"},"","")}))}var Mf=["boxSizing","height","overflow","paddingRight","position"],If={boxSizing:"border-box",overflow:"hidden",position:"relative",height:"100%"};function Tf(e){e.cancelable&&e.preventDefault()}function _f(e){e.stopPropagation()}function Nf(){var e=this.scrollTop,t=this.scrollHeight,n=e+this.offsetHeight;0===e?this.scrollTop=1:n===t&&(this.scrollTop=e-1)}function Lf(){return"ontouchstart"in window||navigator.maxTouchPoints}var Df=!("undefined"==typeof window||!window.document||!window.document.createElement),Bf=0,Ff={capture:!1,passive:!1},zf=function(e){var t=e.target;return t.ownerDocument.activeElement&&t.ownerDocument.activeElement.blur()},jf={name:"1kfdb0e",styles:"position:fixed;left:0;bottom:0;right:0;top:0"};function Hf(e){var t=e.children,n=e.lockEnabled,r=e.captureEnabled,a=function(e){var t=e.isEnabled,n=e.onBottomArrive,r=e.onBottomLeave,a=e.onTopArrive,o=e.onTopLeave,i=(0,c.useRef)(!1),s=(0,c.useRef)(!1),l=(0,c.useRef)(0),u=(0,c.useRef)(null),d=(0,c.useCallback)(function(e,t){if(null!==u.current){var l=u.current,c=l.scrollTop,d=l.scrollHeight,p=l.clientHeight,f=u.current,m=t>0,h=d-p-c,g=!1;h>t&&i.current&&(r&&r(e),i.current=!1),m&&s.current&&(o&&o(e),s.current=!1),m&&t>h?(n&&!i.current&&n(e),f.scrollTop=d,g=!0,i.current=!0):!m&&-t>c&&(a&&!s.current&&a(e),f.scrollTop=0,g=!0,s.current=!0),g&&function(e){e.cancelable&&e.preventDefault(),e.stopPropagation()}(e)}},[n,r,a,o]),p=(0,c.useCallback)(function(e){d(e,e.deltaY)},[d]),f=(0,c.useCallback)(function(e){l.current=e.changedTouches[0].clientY},[]),m=(0,c.useCallback)(function(e){var t=l.current-e.changedTouches[0].clientY;d(e,t)},[d]),h=(0,c.useCallback)(function(e){if(e){var t=!!Np&&{passive:!1};e.addEventListener("wheel",p,t),e.addEventListener("touchstart",f,t),e.addEventListener("touchmove",m,t)}},[m,f,p]),g=(0,c.useCallback)(function(e){e&&(e.removeEventListener("wheel",p,!1),e.removeEventListener("touchstart",f,!1),e.removeEventListener("touchmove",m,!1))},[m,f,p]);return(0,c.useEffect)(function(){if(t){var e=u.current;return h(e),function(){g(e)}}},[t,h,g]),function(e){u.current=e}}({isEnabled:void 0===r||r,onBottomArrive:e.onBottomArrive,onBottomLeave:e.onBottomLeave,onTopArrive:e.onTopArrive,onTopLeave:e.onTopLeave}),o=function(e){var t=e.isEnabled,n=e.accountForScrollbars,r=void 0===n||n,a=(0,c.useRef)({}),o=(0,c.useRef)(null),i=(0,c.useCallback)(function(e){if(Df){var t=document.body,n=t&&t.style;if(r&&Mf.forEach(function(e){var t=n&&n[e];a.current[e]=t}),r&&Bf<1){var o=parseInt(a.current.paddingRight,10)||0,i=document.body?document.body.clientWidth:0,s=window.innerWidth-i+o||0;Object.keys(If).forEach(function(e){var t=If[e];n&&(n[e]=t)}),n&&(n.paddingRight="".concat(s,"px"))}t&&Lf()&&(t.addEventListener("touchmove",Tf,Ff),e&&(e.addEventListener("touchstart",Nf,Ff),e.addEventListener("touchmove",_f,Ff))),Bf+=1}},[r]),s=(0,c.useCallback)(function(e){if(Df){var t=document.body,n=t&&t.style;Bf=Math.max(Bf-1,0),r&&Bf<1&&Mf.forEach(function(e){var t=a.current[e];n&&(n[e]=t)}),t&&Lf()&&(t.removeEventListener("touchmove",Tf,Ff),e&&(e.removeEventListener("touchstart",Nf,Ff),e.removeEventListener("touchmove",_f,Ff)))}},[r]);return(0,c.useEffect)(function(){if(t){var e=o.current;return i(e),function(){s(e)}}},[t,i,s]),function(e){o.current=e}}({isEnabled:n});return Gd(c.Fragment,null,n&&Gd("div",{onClick:zf,css:jf}),t(function(e){a(e),o(e)}))}var Vf={name:"1a0ro4n-requiredInput",styles:"label:requiredInput;opacity:0;pointer-events:none;position:absolute;bottom:0;left:0;right:0;width:100%"},Gf=function(e){var t=e.name,n=e.onFocus;return Gd("input",{required:!0,name:t,tabIndex:-1,"aria-hidden":"true",onFocus:n,css:Vf,value:"",onChange:function(){}})};function qf(e){var t;return"undefined"!=typeof window&&null!=window.navigator&&e.test((null===(t=window.navigator.userAgentData)||void 0===t?void 0:t.platform)||window.navigator.platform)}function Uf(){return qf(/^Mac/i)}var Wf={clearIndicator:ef,container:function(e){var t=e.isDisabled;return{label:"container",direction:e.isRtl?"rtl":void 0,pointerEvents:t?"none":void 0,position:"relative"}},control:function(e,t){var n=e.isDisabled,r=e.isFocused,a=e.theme,o=a.colors,i=a.borderRadius;return Id({label:"control",alignItems:"center",cursor:"default",display:"flex",flexWrap:"wrap",justifyContent:"space-between",minHeight:a.spacing.controlHeight,outline:"0 !important",position:"relative",transition:"all 100ms"},t?{}:{backgroundColor:n?o.neutral5:o.neutral0,borderColor:n?o.neutral10:r?o.primary:o.neutral20,borderRadius:i,borderStyle:"solid",borderWidth:1,boxShadow:r?"0 0 0 1px ".concat(o.primary):void 0,"&:hover":{borderColor:r?o.primary:o.neutral30}})},dropdownIndicator:$p,group:function(e,t){var n=e.theme.spacing;return t?{}:{paddingBottom:2*n.baseUnit,paddingTop:2*n.baseUnit}},groupHeading:function(e,t){var n=e.theme,r=n.colors,a=n.spacing;return Id({label:"group",cursor:"default",display:"block"},t?{}:{color:r.neutral40,fontSize:"75%",fontWeight:500,marginBottom:"0.25em",paddingLeft:3*a.baseUnit,paddingRight:3*a.baseUnit,textTransform:"uppercase"})},indicatorsContainer:function(){return{alignItems:"center",alignSelf:"stretch",display:"flex",flexShrink:0}},indicatorSeparator:function(e,t){var n=e.isDisabled,r=e.theme,a=r.spacing.baseUnit,o=r.colors;return Id({label:"indicatorSeparator",alignSelf:"stretch",width:1},t?{}:{backgroundColor:n?o.neutral10:o.neutral20,marginBottom:2*a,marginTop:2*a})},input:function(e,t){var n=e.isDisabled,r=e.value,a=e.theme,o=a.spacing,i=a.colors;return Id(Id({visibility:n?"hidden":"visible",transform:r?"translateZ(0)":""},sf),t?{}:{margin:o.baseUnit/2,paddingBottom:o.baseUnit/2,paddingTop:o.baseUnit/2,color:i.neutral80})},loadingIndicator:function(e,t){var n=e.isFocused,r=e.size,a=e.theme,o=a.colors,i=a.spacing.baseUnit;return Id({label:"loadingIndicator",display:"flex",transition:"color 150ms",alignSelf:"center",fontSize:r,lineHeight:1,marginRight:r,textAlign:"center",verticalAlign:"middle"},t?{}:{color:n?o.neutral60:o.neutral20,padding:2*i})},loadingMessage:Up,menu:function(e,t){var n,r=e.placement,a=e.theme,o=a.borderRadius,i=a.spacing,s=a.colors;return Id((Pd(n={label:"menu"},function(e){return e?{bottom:"top",top:"bottom"}[e]:"bottom"}(r),"100%"),Pd(n,"position","absolute"),Pd(n,"width","100%"),Pd(n,"zIndex",1),n),t?{}:{backgroundColor:s.neutral0,borderRadius:o,boxShadow:"0 0 0 1px hsla(0, 0%, 0%, 0.1), 0 4px 11px hsla(0, 0%, 0%, 0.1)",marginBottom:i.menuGutter,marginTop:i.menuGutter})},menuList:function(e,t){var n=e.maxHeight,r=e.theme.spacing.baseUnit;return Id({maxHeight:n,overflowY:"auto",position:"relative",WebkitOverflowScrolling:"touch"},t?{}:{paddingBottom:r,paddingTop:r})},menuPortal:function(e){var t=e.rect,n=e.offset,r=e.position;return{left:t.left,position:r,top:n,width:t.width,zIndex:1}},multiValue:function(e,t){var n=e.theme,r=n.spacing,a=n.borderRadius,o=n.colors;return Id({label:"multiValue",display:"flex",minWidth:0},t?{}:{backgroundColor:o.neutral10,borderRadius:a/2,margin:r.baseUnit/2})},multiValueLabel:function(e,t){var n=e.theme,r=n.borderRadius,a=n.colors,o=e.cropWithEllipsis;return Id({overflow:"hidden",textOverflow:o||void 0===o?"ellipsis":void 0,whiteSpace:"nowrap"},t?{}:{borderRadius:r/2,color:a.neutral80,fontSize:"85%",padding:3,paddingLeft:6})},multiValueRemove:function(e,t){var n=e.theme,r=n.spacing,a=n.borderRadius,o=n.colors,i=e.isFocused;return Id({alignItems:"center",display:"flex"},t?{}:{borderRadius:a/2,backgroundColor:i?o.dangerLight:void 0,paddingLeft:r.baseUnit,paddingRight:r.baseUnit,":hover":{backgroundColor:o.dangerLight,color:o.danger}})},noOptionsMessage:qp,option:function(e,t){var n=e.isDisabled,r=e.isFocused,a=e.isSelected,o=e.theme,i=o.spacing,s=o.colors;return Id({label:"option",cursor:"default",display:"block",fontSize:"inherit",width:"100%",userSelect:"none",WebkitTapHighlightColor:"rgba(0, 0, 0, 0)"},t?{}:{backgroundColor:a?s.primary:r?s.primary25:"transparent",color:n?s.neutral20:a?s.neutral0:"inherit",padding:"".concat(2*i.baseUnit,"px ").concat(3*i.baseUnit,"px"),":active":{backgroundColor:n?void 0:a?s.primary:s.primary50}})},placeholder:function(e,t){var n=e.theme,r=n.spacing,a=n.colors;return Id({label:"placeholder",gridArea:"1 / 1 / 2 / 3"},t?{}:{color:a.neutral50,marginLeft:r.baseUnit/2,marginRight:r.baseUnit/2})},singleValue:function(e,t){var n=e.isDisabled,r=e.theme,a=r.spacing,o=r.colors;return Id({label:"singleValue",gridArea:"1 / 1 / 2 / 3",maxWidth:"100%",overflow:"hidden",textOverflow:"ellipsis",whiteSpace:"nowrap"},t?{}:{color:n?o.neutral40:o.neutral80,marginLeft:a.baseUnit/2,marginRight:a.baseUnit/2})},valueContainer:function(e,t){var n=e.theme.spacing,r=e.isMulti,a=e.hasValue,o=e.selectProps.controlShouldRenderValue;return Id({alignItems:"center",display:r&&a&&o?"flex":"grid",flex:1,flexWrap:"wrap",WebkitOverflowScrolling:"touch",position:"relative",overflow:"hidden"},t?{}:{padding:"".concat(n.baseUnit/2,"px ").concat(2*n.baseUnit,"px")})}},Qf={borderRadius:4,colors:{primary:"#2684FF",primary75:"#4C9AFF",primary50:"#B2D4FF",primary25:"#DEEBFF",danger:"#DE350B",dangerLight:"#FFBDAD",neutral0:"hsl(0, 0%, 100%)",neutral5:"hsl(0, 0%, 95%)",neutral10:"hsl(0, 0%, 90%)",neutral20:"hsl(0, 0%, 80%)",neutral30:"hsl(0, 0%, 70%)",neutral40:"hsl(0, 0%, 60%)",neutral50:"hsl(0, 0%, 50%)",neutral60:"hsl(0, 0%, 40%)",neutral70:"hsl(0, 0%, 30%)",neutral80:"hsl(0, 0%, 20%)",neutral90:"hsl(0, 0%, 10%)"},spacing:{baseUnit:4,controlHeight:38,menuGutter:8}},Kf={"aria-live":"polite",backspaceRemovesValue:!0,blurInputOnSelect:Mp(),captureMenuScroll:!Mp(),classNames:{},closeMenuOnSelect:!0,closeMenuOnScroll:!1,components:{},controlShouldRenderValue:!0,escapeClearsValue:!1,filterOption:function(e,t){if(e.data.__isNew__)return!0;var n=Id({ignoreCase:!0,ignoreAccents:!0,stringify:kf,trim:!0,matchFrom:"any"},void 0),r=n.ignoreCase,a=n.ignoreAccents,o=n.stringify,i=n.trim,s=n.matchFrom,l=i?Sf(t):t,c=i?Sf(o(e)):o(e);return r&&(l=l.toLowerCase(),c=c.toLowerCase()),a&&(l=Cf(l),c=Af(c)),"start"===s?c.substr(0,l.length)===l:c.indexOf(l)>-1},formatGroupLabel:function(e){return e.label},getOptionLabel:function(e){return e.label},getOptionValue:function(e){return e.value},isDisabled:!1,isLoading:!1,isMulti:!1,isRtl:!1,isSearchable:!0,isOptionDisabled:function(e){return!!e.isDisabled},loadingMessage:function(){return"Loading..."},maxMenuHeight:300,minMenuHeight:140,menuIsOpen:!1,menuPlacement:"bottom",menuPosition:"absolute",menuShouldBlockScroll:!1,menuShouldScrollIntoView:!function(){try{return/Android|webOS|iPhone|iPad|iPod|BlackBerry|IEMobile|Opera Mini/i.test(navigator.userAgent)}catch(e){return!1}}(),noOptionsMessage:function(){return"No options"},openMenuOnFocus:!1,openMenuOnClick:!0,options:[],pageSize:5,placeholder:"Select...",screenReaderStatus:function(e){var t=e.count;return"".concat(t," result").concat(1!==t?"s":""," available")},styles:{},tabIndex:0,tabSelectsValue:!0,unstyled:!1};function Zf(e,t,n,r){return{type:"option",data:t,isDisabled:rm(e,t,n),isSelected:am(e,t,n),label:tm(e,t),value:nm(e,t),index:r}}function Jf(e,t){return e.options.map(function(n,r){if("options"in n){var a=n.options.map(function(n,r){return Zf(e,n,t,r)}).filter(function(t){return $f(e,t)});return a.length>0?{type:"group",data:n,options:a,index:r}:void 0}var o=Zf(e,n,t,r);return $f(e,o)?o:void 0}).filter(Lp)}function Xf(e){return e.reduce(function(e,t){return"group"===t.type?e.push.apply(e,jd(t.options.map(function(e){return e.data}))):e.push(t.data),e},[])}function Yf(e,t){return e.reduce(function(e,n){return"group"===n.type?e.push.apply(e,jd(n.options.map(function(e){return{data:e.data,id:"".concat(t,"-").concat(n.index,"-").concat(e.index)}}))):e.push({data:n.data,id:"".concat(t,"-").concat(n.index)}),e},[])}function $f(e,t){var n=e.inputValue,r=void 0===n?"":n,a=t.data,o=t.isSelected,i=t.label,s=t.value;return(!im(e)||!o)&&om(e,{label:i,value:s,data:a},r)}var em=function(e,t){var n;return(null===(n=e.find(function(e){return e.data===t}))||void 0===n?void 0:n.id)||null},tm=function(e,t){return e.getOptionLabel(t)},nm=function(e,t){return e.getOptionValue(t)};function rm(e,t,n){return"function"==typeof e.isOptionDisabled&&e.isOptionDisabled(t,n)}function am(e,t,n){if(n.indexOf(t)>-1)return!0;if("function"==typeof e.isOptionSelected)return e.isOptionSelected(t,n);var r=nm(e,t);return n.some(function(t){return nm(e,t)===r})}function om(e,t,n){return!e.filterOption||e.filterOption(t,n)}var im=function(e){var t=e.hideSelectedOptions,n=e.isMulti;return void 0===t?n:t},sm=1,lm=function(e){!function(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Super expression must either be null or a function");e.prototype=Object.create(t&&t.prototype,{constructor:{value:e,writable:!0,configurable:!0}}),Object.defineProperty(e,"prototype",{writable:!1}),t&&Co(e,t)}(n,e);var t=function(e){var t=zd();return function(){var n,r=Fd(e);if(t){var a=Fd(this).constructor;n=Reflect.construct(r,arguments,a)}else n=r.apply(this,arguments);return function(e,t){if(t&&("object"==kd(t)||"function"==typeof t))return t;if(void 0!==t)throw new TypeError("Derived constructors may only return object or undefined");return function(e){if(void 0===e)throw new ReferenceError("this hasn't been initialised - super() hasn't been called");return e}(e)}(this,n)}}(n);function n(e){var r;if(function(e,t){if(!(e instanceof t))throw new TypeError("Cannot call a class as a function")}(this,n),(r=t.call(this,e)).state={ariaSelection:null,focusedOption:null,focusedOptionId:null,focusableOptionsWithIds:[],focusedValue:null,inputIsHidden:!1,isFocused:!1,selectValue:[],clearFocusValueOnUpdate:!1,prevWasFocused:!1,inputIsHiddenAfterUpdate:void 0,prevProps:void 0,instancePrefix:"",isAppleDevice:!1},r.blockOptionHover=!1,r.isComposing=!1,r.commonProps=void 0,r.initialTouchX=0,r.initialTouchY=0,r.openAfterFocus=!1,r.scrollToFocusedOptionOnUpdate=!1,r.userIsDragging=void 0,r.controlRef=null,r.getControlRef=function(e){r.controlRef=e},r.focusedOptionRef=null,r.getFocusedOptionRef=function(e){r.focusedOptionRef=e},r.menuListRef=null,r.getMenuListRef=function(e){r.menuListRef=e},r.inputRef=null,r.getInputRef=function(e){r.inputRef=e},r.focus=r.focusInput,r.blur=r.blurInput,r.onChange=function(e,t){var n=r.props,a=n.onChange,o=n.name;t.name=o,r.ariaOnChange(e,t),a(e,t)},r.setValue=function(e,t,n){var a=r.props,o=a.closeMenuOnSelect,i=a.isMulti,s=a.inputValue;r.onInputChange("",{action:"set-value",prevInputValue:s}),o&&(r.setState({inputIsHiddenAfterUpdate:!i}),r.onMenuClose()),r.setState({clearFocusValueOnUpdate:!0}),r.onChange(e,{action:t,option:n})},r.selectOption=function(e){var t=r.props,n=t.blurInputOnSelect,a=t.isMulti,o=t.name,i=r.state.selectValue,s=a&&r.isOptionSelected(e,i),l=r.isOptionDisabled(e,i);if(s){var c=r.getOptionValue(e);r.setValue(i.filter(function(e){return r.getOptionValue(e)!==c}),"deselect-option",e)}else{if(l)return void r.ariaOnChange(e,{action:"select-option",option:e,name:o});a?r.setValue([].concat(jd(i),[e]),"select-option",e):r.setValue(e,"select-option")}n&&r.blurInput()},r.removeValue=function(e){var t=r.props.isMulti,n=r.state.selectValue,a=r.getOptionValue(e),o=n.filter(function(e){return r.getOptionValue(e)!==a}),i=Dp(t,o,o[0]||null);r.onChange(i,{action:"remove-value",removedValue:e}),r.focusInput()},r.clearValue=function(){var e=r.state.selectValue;r.onChange(Dp(r.props.isMulti,[],null),{action:"clear",removedValues:e})},r.popValue=function(){var e=r.props.isMulti,t=r.state.selectValue,n=t[t.length-1],a=t.slice(0,t.length-1),o=Dp(e,a,a[0]||null);n&&r.onChange(o,{action:"pop-value",removedValue:n})},r.getFocusedOptionId=function(e){return em(r.state.focusableOptionsWithIds,e)},r.getFocusableOptionsWithIds=function(){return Yf(Jf(r.props,r.state.selectValue),r.getElementId("option"))},r.getValue=function(){return r.state.selectValue},r.cx=function(){for(var e=arguments.length,t=new Array(e),n=0;n<e;n++)t[n]=arguments[n];return Ep.apply(void 0,[r.props.classNamePrefix].concat(t))},r.getOptionLabel=function(e){return tm(r.props,e)},r.getOptionValue=function(e){return nm(r.props,e)},r.getStyles=function(e,t){var n=r.props.unstyled,a=Wf[e](t,n);a.boxSizing="border-box";var o=r.props.styles[e];return o?o(a,t):a},r.getClassNames=function(e,t){var n,a;return null===(n=(a=r.props.classNames)[e])||void 0===n?void 0:n.call(a,t)},r.getElementId=function(e){return"".concat(r.state.instancePrefix,"-").concat(e)},r.getComponents=function(){return e=r.props,Id(Id({},uf),e.components);var e},r.buildCategorizedOptions=function(){return Jf(r.props,r.state.selectValue)},r.getCategorizedOptions=function(){return r.props.menuIsOpen?r.buildCategorizedOptions():[]},r.buildFocusableOptions=function(){return Xf(r.buildCategorizedOptions())},r.getFocusableOptions=function(){return r.props.menuIsOpen?r.buildFocusableOptions():[]},r.ariaOnChange=function(e,t){r.setState({ariaSelection:Id({value:e},t)})},r.onMenuMouseDown=function(e){0===e.button&&(e.stopPropagation(),e.preventDefault(),r.focusInput())},r.onMenuMouseMove=function(e){r.blockOptionHover=!1},r.onControlMouseDown=function(e){if(!e.defaultPrevented){var t=r.props.openMenuOnClick;r.state.isFocused?r.props.menuIsOpen?"INPUT"!==e.target.tagName&&"TEXTAREA"!==e.target.tagName&&r.onMenuClose():t&&r.openMenu("first"):(t&&(r.openAfterFocus=!0),r.focusInput()),"INPUT"!==e.target.tagName&&"TEXTAREA"!==e.target.tagName&&e.preventDefault()}},r.onDropdownIndicatorMouseDown=function(e){if(!(e&&"mousedown"===e.type&&0!==e.button||r.props.isDisabled)){var t=r.props,n=t.isMulti,a=t.menuIsOpen;r.focusInput(),a?(r.setState({inputIsHiddenAfterUpdate:!n}),r.onMenuClose()):r.openMenu("first"),e.preventDefault()}},r.onClearIndicatorMouseDown=function(e){e&&"mousedown"===e.type&&0!==e.button||(r.clearValue(),e.preventDefault(),r.openAfterFocus=!1,"touchend"===e.type?r.focusInput():setTimeout(function(){return r.focusInput()}))},r.onScroll=function(e){"boolean"==typeof r.props.closeMenuOnScroll?e.target instanceof HTMLElement&&Cp(e.target)&&r.props.onMenuClose():"function"==typeof r.props.closeMenuOnScroll&&r.props.closeMenuOnScroll(e)&&r.props.onMenuClose()},r.onCompositionStart=function(){r.isComposing=!0},r.onCompositionEnd=function(){r.isComposing=!1},r.onTouchStart=function(e){var t=e.touches,n=t&&t.item(0);n&&(r.initialTouchX=n.clientX,r.initialTouchY=n.clientY,r.userIsDragging=!1)},r.onTouchMove=function(e){var t=e.touches,n=t&&t.item(0);if(n){var a=Math.abs(n.clientX-r.initialTouchX),o=Math.abs(n.clientY-r.initialTouchY);r.userIsDragging=a>5||o>5}},r.onTouchEnd=function(e){r.userIsDragging||(r.controlRef&&!r.controlRef.contains(e.target)&&r.menuListRef&&!r.menuListRef.contains(e.target)&&r.blurInput(),r.initialTouchX=0,r.initialTouchY=0)},r.onControlTouchEnd=function(e){r.userIsDragging||r.onControlMouseDown(e)},r.onClearIndicatorTouchEnd=function(e){r.userIsDragging||r.onClearIndicatorMouseDown(e)},r.onDropdownIndicatorTouchEnd=function(e){r.userIsDragging||r.onDropdownIndicatorMouseDown(e)},r.handleInputChange=function(e){var t=r.props.inputValue,n=e.currentTarget.value;r.setState({inputIsHiddenAfterUpdate:!1}),r.onInputChange(n,{action:"input-change",prevInputValue:t}),r.props.menuIsOpen||r.onMenuOpen()},r.onInputFocus=function(e){r.props.onFocus&&r.props.onFocus(e),r.setState({inputIsHiddenAfterUpdate:!1,isFocused:!0}),(r.openAfterFocus||r.props.openMenuOnFocus)&&r.openMenu("first"),r.openAfterFocus=!1},r.onInputBlur=function(e){var t=r.props.inputValue;r.menuListRef&&r.menuListRef.contains(document.activeElement)?r.inputRef.focus():(r.props.onBlur&&r.props.onBlur(e),r.onInputChange("",{action:"input-blur",prevInputValue:t}),r.onMenuClose(),r.setState({focusedValue:null,isFocused:!1}))},r.onOptionHover=function(e){if(!r.blockOptionHover&&r.state.focusedOption!==e){var t=r.getFocusableOptions().indexOf(e);r.setState({focusedOption:e,focusedOptionId:t>-1?r.getFocusedOptionId(e):null})}},r.shouldHideSelectedOptions=function(){return im(r.props)},r.onValueInputFocus=function(e){e.preventDefault(),e.stopPropagation(),r.focus()},r.onKeyDown=function(e){var t=r.props,n=t.isMulti,a=t.backspaceRemovesValue,o=t.escapeClearsValue,i=t.inputValue,s=t.isClearable,l=t.isDisabled,c=t.menuIsOpen,u=t.onKeyDown,d=t.tabSelectsValue,p=t.openMenuOnFocus,f=r.state,m=f.focusedOption,h=f.focusedValue,g=f.selectValue;if(!(l||"function"==typeof u&&(u(e),e.defaultPrevented))){switch(r.blockOptionHover=!0,e.key){case"ArrowLeft":if(!n||i)return;r.focusValue("previous");break;case"ArrowRight":if(!n||i)return;r.focusValue("next");break;case"Delete":case"Backspace":if(i)return;if(h)r.removeValue(h);else{if(!a)return;n?r.popValue():s&&r.clearValue()}break;case"Tab":if(r.isComposing)return;if(e.shiftKey||!c||!d||!m||p&&r.isOptionSelected(m,g))return;r.selectOption(m);break;case"Enter":if(229===e.keyCode)break;if(c){if(!m)return;if(r.isComposing)return;r.selectOption(m);break}return;case"Escape":c?(r.setState({inputIsHiddenAfterUpdate:!1}),r.onInputChange("",{action:"menu-close",prevInputValue:i}),r.onMenuClose()):s&&o&&r.clearValue();break;case" ":if(i)return;if(!c){r.openMenu("first");break}if(!m)return;r.selectOption(m);break;case"ArrowUp":c?r.focusOption("up"):r.openMenu("last");break;case"ArrowDown":c?r.focusOption("down"):r.openMenu("first");break;case"PageUp":if(!c)return;r.focusOption("pageup");break;case"PageDown":if(!c)return;r.focusOption("pagedown");break;case"Home":if(!c)return;r.focusOption("first");break;case"End":if(!c)return;r.focusOption("last");break;default:return}e.preventDefault()}},r.state.instancePrefix="react-select-"+(r.props.instanceId||++sm),r.state.selectValue=Rp(e.value),e.menuIsOpen&&r.state.selectValue.length){var a=r.getFocusableOptionsWithIds(),o=r.buildFocusableOptions(),i=o.indexOf(r.state.selectValue[0]);r.state.focusableOptionsWithIds=a,r.state.focusedOption=o[i],r.state.focusedOptionId=em(a,o[i])}return r}return function(e,t,n){t&&Bd(e.prototype,t),n&&Bd(e,n),Object.defineProperty(e,"prototype",{writable:!1})}(n,[{key:"componentDidMount",value:function(){this.startListeningComposition(),this.startListeningToTouch(),this.props.closeMenuOnScroll&&document&&document.addEventListener&&document.addEventListener("scroll",this.onScroll,!0),this.props.autoFocus&&this.focusInput(),this.props.menuIsOpen&&this.state.focusedOption&&this.menuListRef&&this.focusedOptionRef&&Pp(this.menuListRef,this.focusedOptionRef),(Uf()||qf(/^iPhone/i)||qf(/^iPad/i)||Uf()&&navigator.maxTouchPoints>1)&&this.setState({isAppleDevice:!0})}},{key:"componentDidUpdate",value:function(e){var t=this.props,n=t.isDisabled,r=t.menuIsOpen,a=this.state.isFocused;(a&&!n&&e.isDisabled||a&&r&&!e.menuIsOpen)&&this.focusInput(),a&&n&&!e.isDisabled?this.setState({isFocused:!1},this.onMenuClose):a||n||!e.isDisabled||this.inputRef!==document.activeElement||this.setState({isFocused:!0}),this.menuListRef&&this.focusedOptionRef&&this.scrollToFocusedOptionOnUpdate&&(Pp(this.menuListRef,this.focusedOptionRef),this.scrollToFocusedOptionOnUpdate=!1)}},{key:"componentWillUnmount",value:function(){this.stopListeningComposition(),this.stopListeningToTouch(),document.removeEventListener("scroll",this.onScroll,!0)}},{key:"onMenuOpen",value:function(){this.props.onMenuOpen()}},{key:"onMenuClose",value:function(){this.onInputChange("",{action:"menu-close",prevInputValue:this.props.inputValue}),this.props.onMenuClose()}},{key:"onInputChange",value:function(e,t){this.props.onInputChange(e,t)}},{key:"focusInput",value:function(){this.inputRef&&this.inputRef.focus()}},{key:"blurInput",value:function(){this.inputRef&&this.inputRef.blur()}},{key:"openMenu",value:function(e){var t=this,n=this.state,r=n.selectValue,a=n.isFocused,o=this.buildFocusableOptions(),i="first"===e?0:o.length-1;if(!this.props.isMulti){var s=o.indexOf(r[0]);s>-1&&(i=s)}this.scrollToFocusedOptionOnUpdate=!(a&&this.menuListRef),this.setState({inputIsHiddenAfterUpdate:!1,focusedValue:null,focusedOption:o[i],focusedOptionId:this.getFocusedOptionId(o[i])},function(){return t.onMenuOpen()})}},{key:"focusValue",value:function(e){var t=this.state,n=t.selectValue,r=t.focusedValue;if(this.props.isMulti){this.setState({focusedOption:null});var a=n.indexOf(r);r||(a=-1);var o=n.length-1,i=-1;if(n.length){switch(e){case"previous":i=0===a?0:-1===a?o:a-1;break;case"next":a>-1&&a<o&&(i=a+1)}this.setState({inputIsHidden:-1!==i,focusedValue:n[i]})}}}},{key:"focusOption",value:function(){var e=arguments.length>0&&void 0!==arguments[0]?arguments[0]:"first",t=this.props.pageSize,n=this.state.focusedOption,r=this.getFocusableOptions();if(r.length){var a=0,o=r.indexOf(n);n||(o=-1),"up"===e?a=o>0?o-1:r.length-1:"down"===e?a=(o+1)%r.length:"pageup"===e?(a=o-t)<0&&(a=0):"pagedown"===e?(a=o+t)>r.length-1&&(a=r.length-1):"last"===e&&(a=r.length-1),this.scrollToFocusedOptionOnUpdate=!0,this.setState({focusedOption:r[a],focusedValue:null,focusedOptionId:this.getFocusedOptionId(r[a])})}}},{key:"getTheme",value:function(){return this.props.theme?"function"==typeof this.props.theme?this.props.theme(Qf):Id(Id({},Qf),this.props.theme):Qf}},{key:"getCommonProps",value:function(){var e=this.clearValue,t=this.cx,n=this.getStyles,r=this.getClassNames,a=this.getValue,o=this.selectOption,i=this.setValue,s=this.props,l=s.isMulti,c=s.isRtl,u=s.options;return{clearValue:e,cx:t,getStyles:n,getClassNames:r,getValue:a,hasValue:this.hasValue(),isMulti:l,isRtl:c,options:u,selectOption:o,selectProps:s,setValue:i,theme:this.getTheme()}}},{key:"hasValue",value:function(){return this.state.selectValue.length>0}},{key:"hasOptions",value:function(){return!!this.getFocusableOptions().length}},{key:"isClearable",value:function(){var e=this.props,t=e.isClearable,n=e.isMulti;return void 0===t?n:t}},{key:"isOptionDisabled",value:function(e,t){return rm(this.props,e,t)}},{key:"isOptionSelected",value:function(e,t){return am(this.props,e,t)}},{key:"filterOption",value:function(e,t){return om(this.props,e,t)}},{key:"formatOptionLabel",value:function(e,t){if("function"==typeof this.props.formatOptionLabel){var n=this.props.inputValue,r=this.state.selectValue;return this.props.formatOptionLabel(e,{context:t,inputValue:n,selectValue:r})}return this.getOptionLabel(e)}},{key:"formatGroupLabel",value:function(e){return this.props.formatGroupLabel(e)}},{key:"startListeningComposition",value:function(){document&&document.addEventListener&&(document.addEventListener("compositionstart",this.onCompositionStart,!1),document.addEventListener("compositionend",this.onCompositionEnd,!1))}},{key:"stopListeningComposition",value:function(){document&&document.removeEventListener&&(document.removeEventListener("compositionstart",this.onCompositionStart),document.removeEventListener("compositionend",this.onCompositionEnd))}},{key:"startListeningToTouch",value:function(){document&&document.addEventListener&&(document.addEventListener("touchstart",this.onTouchStart,!1),document.addEventListener("touchmove",this.onTouchMove,!1),document.addEventListener("touchend",this.onTouchEnd,!1))}},{key:"stopListeningToTouch",value:function(){document&&document.removeEventListener&&(document.removeEventListener("touchstart",this.onTouchStart),document.removeEventListener("touchmove",this.onTouchMove),document.removeEventListener("touchend",this.onTouchEnd))}},{key:"renderInput",value:function(){var e=this.props,t=e.isDisabled,n=e.isSearchable,r=e.inputId,a=e.inputValue,o=e.tabIndex,i=e.form,s=e.menuIsOpen,l=e.required,u=this.getComponents().Input,d=this.state,p=d.inputIsHidden,f=d.ariaSelection,m=this.commonProps,h=r||this.getElementId("input"),g=Id(Id(Id({"aria-autocomplete":"list","aria-expanded":s,"aria-haspopup":!0,"aria-errormessage":this.props["aria-errormessage"],"aria-invalid":this.props["aria-invalid"],"aria-label":this.props["aria-label"],"aria-labelledby":this.props["aria-labelledby"],"aria-required":l,role:"combobox","aria-activedescendant":this.state.isAppleDevice?void 0:this.state.focusedOptionId||""},s&&{"aria-controls":this.getElementId("listbox")}),!n&&{"aria-readonly":!0}),this.hasValue()?"initial-input-focus"===(null==f?void 0:f.action)&&{"aria-describedby":this.getElementId("live-region")}:{"aria-describedby":this.getElementId("placeholder")});return n?c.createElement(u,ke({},m,{autoCapitalize:"none",autoComplete:"off",autoCorrect:"off",id:h,innerRef:this.getInputRef,isDisabled:t,isHidden:p,onBlur:this.onInputBlur,onChange:this.handleInputChange,onFocus:this.onInputFocus,spellCheck:"false",tabIndex:o,form:i,type:"text",value:a},g)):c.createElement(Pf,ke({id:h,innerRef:this.getInputRef,onBlur:this.onInputBlur,onChange:bp,onFocus:this.onInputFocus,disabled:t,tabIndex:o,inputMode:"none",form:i,value:""},g))}},{key:"renderPlaceholderOrValue",value:function(){var e=this,t=this.getComponents(),n=t.MultiValue,r=t.MultiValueContainer,a=t.MultiValueLabel,o=t.MultiValueRemove,i=t.SingleValue,s=t.Placeholder,l=this.commonProps,u=this.props,d=u.controlShouldRenderValue,p=u.isDisabled,f=u.isMulti,m=u.inputValue,h=u.placeholder,g=this.state,v=g.selectValue,b=g.focusedValue,y=g.isFocused;if(!this.hasValue()||!d)return m?null:c.createElement(s,ke({},l,{key:"placeholder",isDisabled:p,isFocused:y,innerProps:{id:this.getElementId("placeholder")}}),h);if(f)return v.map(function(t,i){var s=t===b,u="".concat(e.getOptionLabel(t),"-").concat(e.getOptionValue(t));return c.createElement(n,ke({},l,{components:{Container:r,Label:a,Remove:o},isFocused:s,isDisabled:p,key:u,index:i,removeProps:{onClick:function(){return e.removeValue(t)},onTouchEnd:function(){return e.removeValue(t)},onMouseDown:function(e){e.preventDefault()}},data:t}),e.formatOptionLabel(t,"value"))});if(m)return null;var w=v[0];return c.createElement(i,ke({},l,{data:w,isDisabled:p}),this.formatOptionLabel(w,"value"))}},{key:"renderClearIndicator",value:function(){var e=this.getComponents().ClearIndicator,t=this.commonProps,n=this.props,r=n.isDisabled,a=n.isLoading,o=this.state.isFocused;if(!this.isClearable()||!e||r||!this.hasValue()||a)return null;var i={onMouseDown:this.onClearIndicatorMouseDown,onTouchEnd:this.onClearIndicatorTouchEnd,"aria-hidden":"true"};return c.createElement(e,ke({},t,{innerProps:i,isFocused:o}))}},{key:"renderLoadingIndicator",value:function(){var e=this.getComponents().LoadingIndicator,t=this.commonProps,n=this.props,r=n.isDisabled,a=n.isLoading,o=this.state.isFocused;return e&&a?c.createElement(e,ke({},t,{innerProps:{"aria-hidden":"true"},isDisabled:r,isFocused:o})):null}},{key:"renderIndicatorSeparator",value:function(){var e=this.getComponents(),t=e.DropdownIndicator,n=e.IndicatorSeparator;if(!t||!n)return null;var r=this.commonProps,a=this.props.isDisabled,o=this.state.isFocused;return c.createElement(n,ke({},r,{isDisabled:a,isFocused:o}))}},{key:"renderDropdownIndicator",value:function(){var e=this.getComponents().DropdownIndicator;if(!e)return null;var t=this.commonProps,n=this.props.isDisabled,r=this.state.isFocused,a={onMouseDown:this.onDropdownIndicatorMouseDown,onTouchEnd:this.onDropdownIndicatorTouchEnd,"aria-hidden":"true"};return c.createElement(e,ke({},t,{innerProps:a,isDisabled:n,isFocused:r}))}},{key:"renderMenu",value:function(){var e=this,t=this.getComponents(),n=t.Group,r=t.GroupHeading,a=t.Menu,o=t.MenuList,i=t.MenuPortal,s=t.LoadingMessage,l=t.NoOptionsMessage,u=t.Option,d=this.commonProps,p=this.state.focusedOption,f=this.props,m=f.captureMenuScroll,h=f.inputValue,g=f.isLoading,v=f.loadingMessage,b=f.minMenuHeight,y=f.maxMenuHeight,w=f.menuIsOpen,E=f.menuPlacement,R=f.menuPosition,x=f.menuPortalTarget,A=f.menuShouldBlockScroll,C=f.menuShouldScrollIntoView,S=f.noOptionsMessage,k=f.onMenuScrollToTop,O=f.onMenuScrollToBottom;if(!w)return null;var P,M=function(t,n){var r=t.type,a=t.data,o=t.isDisabled,i=t.isSelected,s=t.label,l=t.value,f=p===a,m=o?void 0:function(){return e.onOptionHover(a)},h=o?void 0:function(){return e.selectOption(a)},g="".concat(e.getElementId("option"),"-").concat(n),v={id:g,onClick:h,onMouseMove:m,onMouseOver:m,tabIndex:-1,role:"option","aria-selected":e.state.isAppleDevice?void 0:i};return c.createElement(u,ke({},d,{innerProps:v,data:a,isDisabled:o,isSelected:i,key:g,label:s,type:r,value:l,isFocused:f,innerRef:f?e.getFocusedOptionRef:void 0}),e.formatOptionLabel(t.data,"menu"))};if(this.hasOptions())P=this.getCategorizedOptions().map(function(t){if("group"===t.type){var a=t.data,o=t.options,i=t.index,s="".concat(e.getElementId("group"),"-").concat(i),l="".concat(s,"-heading");return c.createElement(n,ke({},d,{key:s,data:a,options:o,Heading:r,headingProps:{id:l,data:t.data},label:e.formatGroupLabel(t.data)}),t.options.map(function(e){return M(e,"".concat(i,"-").concat(e.index))}))}if("option"===t.type)return M(t,"".concat(t.index))});else if(g){var I=v({inputValue:h});if(null===I)return null;P=c.createElement(s,d,I)}else{var T=S({inputValue:h});if(null===T)return null;P=c.createElement(l,d,T)}var _={minMenuHeight:b,maxMenuHeight:y,menuPlacement:E,menuPosition:R,menuShouldScrollIntoView:C},N=c.createElement(Vp,ke({},d,_),function(t){var n=t.ref,r=t.placerProps,i=r.placement,s=r.maxHeight;return c.createElement(a,ke({},d,_,{innerRef:n,innerProps:{onMouseDown:e.onMenuMouseDown,onMouseMove:e.onMenuMouseMove},isLoading:g,placement:i}),c.createElement(Hf,{captureEnabled:m,onTopArrive:k,onBottomArrive:O,lockEnabled:A},function(t){return c.createElement(o,ke({},d,{innerRef:function(n){e.getMenuListRef(n),t(n)},innerProps:{role:"listbox","aria-multiselectable":d.isMulti,id:e.getElementId("listbox")},isLoading:g,maxHeight:s,focusedOption:p}),P)}))});return x||"fixed"===R?c.createElement(i,ke({},d,{appendTo:x,controlElement:this.controlRef,menuPlacement:E,menuPosition:R}),N):N}},{key:"renderFormField",value:function(){var e=this,t=this.props,n=t.delimiter,r=t.isDisabled,a=t.isMulti,o=t.name,i=t.required,s=this.state.selectValue;if(i&&!this.hasValue()&&!r)return c.createElement(Gf,{name:o,onFocus:this.onValueInputFocus});if(o&&!r){if(a){if(n){var l=s.map(function(t){return e.getOptionValue(t)}).join(n);return c.createElement("input",{name:o,type:"hidden",value:l})}var u=s.length>0?s.map(function(t,n){return c.createElement("input",{key:"i-".concat(n),name:o,type:"hidden",value:e.getOptionValue(t)})}):c.createElement("input",{name:o,type:"hidden",value:""});return c.createElement("div",null,u)}var d=s[0]?this.getOptionValue(s[0]):"";return c.createElement("input",{name:o,type:"hidden",value:d})}}},{key:"renderLiveRegion",value:function(){var e=this.commonProps,t=this.state,n=t.ariaSelection,r=t.focusedOption,a=t.focusedValue,o=t.isFocused,i=t.selectValue,s=this.getFocusableOptions();return c.createElement(vf,ke({},e,{id:this.getElementId("live-region"),ariaSelection:n,focusedOption:r,focusedValue:a,isFocused:o,selectValue:i,focusableOptions:s,isAppleDevice:this.state.isAppleDevice}))}},{key:"render",value:function(){var e=this.getComponents(),t=e.Control,n=e.IndicatorsContainer,r=e.SelectContainer,a=e.ValueContainer,o=this.props,i=o.className,s=o.id,l=o.isDisabled,u=o.menuIsOpen,d=this.state.isFocused,p=this.commonProps=this.getCommonProps();return c.createElement(r,ke({},p,{className:i,innerProps:{id:s,onKeyDown:this.onKeyDown},isDisabled:l,isFocused:d}),this.renderLiveRegion(),c.createElement(t,ke({},p,{innerRef:this.getControlRef,innerProps:{onMouseDown:this.onControlMouseDown,onTouchEnd:this.onControlTouchEnd},isDisabled:l,isFocused:d,menuIsOpen:u}),c.createElement(a,ke({},p,{isDisabled:l}),this.renderPlaceholderOrValue(),this.renderInput()),c.createElement(n,ke({},p,{isDisabled:l}),this.renderClearIndicator(),this.renderLoadingIndicator(),this.renderIndicatorSeparator(),this.renderDropdownIndicator())),this.renderMenu(),this.renderFormField())}}],[{key:"getDerivedStateFromProps",value:function(e,t){var n=t.prevProps,r=t.clearFocusValueOnUpdate,a=t.inputIsHiddenAfterUpdate,o=t.ariaSelection,i=t.isFocused,s=t.prevWasFocused,l=t.instancePrefix,c=e.options,u=e.value,d=e.menuIsOpen,p=e.inputValue,f=e.isMulti,m=Rp(u),h={};if(n&&(u!==n.value||c!==n.options||d!==n.menuIsOpen||p!==n.inputValue)){var g=d?function(e,t){return Xf(Jf(e,t))}(e,m):[],v=d?Yf(Jf(e,m),"".concat(l,"-option")):[],b=r?function(e,t){var n=e.focusedValue,r=e.selectValue.indexOf(n);if(r>-1){if(t.indexOf(n)>-1)return n;if(r<t.length)return t[r]}return null}(t,m):null,y=function(e,t){var n=e.focusedOption;return n&&t.indexOf(n)>-1?n:t[0]}(t,g);h={selectValue:m,focusedOption:y,focusedOptionId:em(v,y),focusableOptionsWithIds:v,focusedValue:b,clearFocusValueOnUpdate:!1}}var w=null!=a&&e!==n?{inputIsHidden:a,inputIsHiddenAfterUpdate:void 0}:{},E=o,R=i&&s;return i&&!R&&(E={value:Dp(f,m,m[0]||null),options:m,action:"initial-input-focus"},R=!s),"initial-input-focus"===(null==o?void 0:o.action)&&(E=null),Id(Id(Id({},h),w),{},{prevProps:e,ariaSelection:E,prevWasFocused:R})}}]),n}(c.Component);lm.defaultProps=Kf;var cm=(0,c.forwardRef)(function(e,t){var n=function(e){var t=e.defaultInputValue,n=void 0===t?"":t,r=e.defaultMenuIsOpen,a=void 0!==r&&r,o=e.defaultValue,i=void 0===o?null:o,s=e.inputValue,l=e.menuIsOpen,u=e.onChange,d=e.onInputChange,p=e.onMenuClose,f=e.onMenuOpen,m=e.value,h=Ld(e,Dd),g=Nd((0,c.useState)(void 0!==s?s:n),2),v=g[0],b=g[1],y=Nd((0,c.useState)(void 0!==l?l:a),2),w=y[0],E=y[1],R=Nd((0,c.useState)(void 0!==m?m:i),2),x=R[0],A=R[1],C=(0,c.useCallback)(function(e,t){"function"==typeof u&&u(e,t),A(e)},[u]),S=(0,c.useCallback)(function(e,t){var n;"function"==typeof d&&(n=d(e,t)),b(void 0!==n?n:e)},[d]),k=(0,c.useCallback)(function(){"function"==typeof f&&f(),E(!0)},[f]),O=(0,c.useCallback)(function(){"function"==typeof p&&p(),E(!1)},[p]),P=void 0!==s?s:v,M=void 0!==l?l:w,I=void 0!==m?m:x;return Id(Id({},h),{},{inputValue:P,menuIsOpen:M,onChange:C,onInputChange:S,onMenuClose:O,onMenuOpen:k,value:I})}(e);return c.createElement(lm,ke({ref:t},n))}),um=cm;window.wp.blockEditor,window.wp.blocks;const dm=window.wp.htmlEntities;var pm=function(){return React.createElement("svg",{xmlns:"http://www.w3.org/2000/svg",width:"24",height:"24",viewBox:"0 0 24 24",fill:"currentColor"},React.createElement("path",{d:"M6.1443 6.15055C9.34843 2.94642 14.6518 2.94642 17.8559 6.15055L15.3147 8.69176H21.9439V2.06256L19.8446 4.16179C15.5357 -0.147191 8.46452 -0.147191 4.15554 4.16179C1.72485 6.59248 0.730475 9.90708 1.06193 13.1112H3.82408C3.49262 10.6805 4.26601 8.02884 6.1443 6.15055Z",fill:"currentColor"}),React.createElement("path",{d:"M22.9366 10.9017H20.1745C20.5059 13.3324 19.7325 15.9841 17.8542 17.8624C14.6501 21.0665 9.34676 21.0665 6.14268 17.8624L8.68389 15.3212H2.05469V21.9504L4.15392 19.8512C8.4629 24.1601 15.4236 24.1601 19.7325 19.8512C22.2737 17.4205 23.2681 14.1059 22.9366 10.9017Z",fill:"currentColor"}))},fm=function(){return React.createElement("svg",{width:"34",height:"24",viewBox:"0 0 20 20",fill:"none",stroke:"currentColor",strokeWidth:"2",xmlns:"http://www.w3.org/2000/svg"},React.createElement("path",{d:"M10 17.5l-1.45-1.32C4.4 12.36 2 10.28 2 7.5 2 5.42 3.42 4 5.5 4c1.54 0 3.04 1 3.57 2.36h1.87C11.46 5 12.96 4 14.5 4 16.58 4 18 5.42 18 7.5c0 2.78-2.4 4.86-6.55 8.68L10 17.5z",fill:"none"}))},mm=function(){return React.createElement("svg",{xmlns:"http://www.w3.org/2000/svg",width:"23",height:"21",viewBox:"0 0 23 21",fill:"currentColor"},React.createElement("path",{d:"M20.2913 2.61183C19.7805 2.10083 19.1741 1.69547 18.5066 1.41891C17.8392 1.14235 17.1238 1 16.4013 1C15.6788 1 14.9634 1.14235 14.2959 1.41891C13.6285 1.69547 13.022 2.10083 12.5113 2.61183L11.4513 3.67183L10.3913 2.61183C9.3596 1.58013 7.96032 1.00053 6.50129 1.00053C5.04226 1.00053 3.64298 1.58013 2.61129 2.61183C1.5796 3.64352 1 5.04279 1 6.50183C1 7.96086 1.5796 9.36013 2.61129 10.3918L11.4513 19.2318L20.2913 10.3918C20.8023 9.88107 21.2076 9.27464 21.4842 8.60718C21.7608 7.93972 21.9031 7.22431 21.9031 6.50183C21.9031 5.77934 21.7608 5.06393 21.4842 4.39647C21.2076 3.72901 20.8023 3.12258 20.2913 2.61183Z",fill:"currentColor",stroke:"currentColor",strokeWidth:"2",strokeLinecap:"round",strokeLinejoin:"round"}))},hm=function(){return React.createElement("svg",{xmlns:"http://www.w3.org/2000/svg",width:"16",height:"16",viewBox:"0 0 16 16",fill:"none"},React.createElement("path",{d:"M7.37544 2C7.37544 1.65482 7.65526 1.375 8.00044 1.375C8.34562 1.375 8.62544 1.65482 8.62544 2V9.49121L11.5356 6.58105C11.7797 6.33698 12.1753 6.33698 12.4194 6.58105C12.6635 6.82513 12.6635 7.22077 12.4194 7.46484L8.44282 11.4424C8.19875 11.6865 7.80214 11.6865 7.55806 11.4424L3.5815 7.46484C3.33742 7.22077 3.33742 6.82513 3.5815 6.58105C3.82557 6.33698 4.22121 6.33698 4.46528 6.58105L7.37544 9.49121V2Z",fill:"white"}),React.createElement("path",{d:"M1.375 13V10C1.375 9.65482 1.65482 9.375 2 9.375C2.34518 9.375 2.625 9.65482 2.625 10V13C2.625 13.2071 2.79289 13.375 3 13.375H13C13.2071 13.375 13.375 13.2071 13.375 13V10C13.375 9.65482 13.6548 9.375 14 9.375C14.3452 9.375 14.625 9.65482 14.625 10V13C14.625 13.8975 13.8975 14.625 13 14.625H3C2.10254 14.625 1.375 13.8975 1.375 13Z",fill:"white"}))},gm=function(){return React.createElement("svg",{xmlns:"http://www.w3.org/2000/svg",width:"16",height:"16",viewBox:"0 0 16 16",fill:"none"},React.createElement("path",{d:"M10.2168 6.01685C10.4052 6.36235 10.7221 6.62112 11.1104 6.70239C11.5047 6.7848 11.908 6.66835 12.2129 6.38892C12.6721 5.96794 13.1316 5.54719 13.5908 5.12622C13.9105 4.83318 14.2301 4.53939 14.5498 4.24634C14.2969 6.25538 14.0439 8.26462 13.791 10.2737H2.22266C1.96972 8.26422 1.71583 6.25481 1.46289 4.24536C2.24239 4.9599 3.02238 5.67449 3.80176 6.38892C4.10679 6.66852 4.50974 6.785 4.9043 6.70239C5.29249 6.62111 5.60845 6.36227 5.79688 6.01685L8.00684 1.96509L10.2168 6.01685Z",stroke:"white",strokeWidth:"1.3545"}),React.createElement("path",{d:"M13.7234 14.8507H2.29045C1.92294 14.8507 1.625 14.4866 1.625 14.0374V12.2507H14.3889V14.0374C14.3888 14.4866 14.0909 14.8507 13.7234 14.8507Z",fill:"currentColor"}))},vm=(0,i.memo)(function(){return React.createElement(React.Fragment,null,React.createElement("i",{className:"dashicons dashicons-visibility"}),(0,l.__)("Live Preview","easy-accordion-free"))}),bm="Enter",ym=function(e){var t=e.type,n=e.size,r=e.loop,a=e.unit,o=e.c_s,i=e.classes,s=function(){var e={};switch(t){case"image":case"circle":e={width:n?n+"px":"300px",height:n?n+"px":"300px"};break;case"title":e={width:"".concat(n||"100").concat(a||"%")};break;case"button":e={width:n?n+"px":"90px"};break;case"custom_size":e={width:"".concat(o.size1?o.size1:"100").concat(o.unit1?o.unit1:"%"),height:"".concat(o.size2?o.size2:"20").concat(o.unit2?o.unit2:"px"),borderRadius:o.br?o.br+"px":"0px"}}return e};return React.createElement(React.Fragment,null,r?React.createElement(React.Fragment,null,Array(parseInt(r)).fill("1").map(function(e,n){return React.createElement("div",{key:n,className:"sp_eab_patterns_skeleton__".concat(t," sp-eap_patterns_frequency loop ").concat(i||""),style:s()})})):React.createElement("div",{className:"sp_eab_patterns_skeleton__".concat(t," sp-eap_patterns_frequency ").concat(i||""),style:s()}))},wm=(0,i.memo)(function(e){var t=e.data,n=e.wishListArr,r=e.setWListAction,a=e.reload,o=e.reloadId,s=e.onImport,c=null==n?void 0:n.includes(String(t.ID)),u=a&&o===t.ID,d=t.pro,p=(0,i.useCallback)(function(){r(t.ID,c?"remove":"")},[t.ID,c,r]),f=(0,i.useCallback)(function(){d||s(t.ID,t.pro)},[t.ID,t.pro,d,s]);return React.createElement("div",{className:"sp-eab-pattern-card-body"},React.createElement("div",{className:"sp-eap-patterns-item-list"},React.createElement("div",{className:"sp-eap-patterns-item-list-overlay"},React.createElement("a",{className:"sp-eap-pattern-img"},React.createElement("img",{src:t.image,loading:"lazy",alt:t.name})),React.createElement("div",{className:"sp-eap-pattern-overlay"},React.createElement("a",{className:"sp-eap-patterns-overlay-view",href:"https://easyaccordion.io/patterns/#demo".concat(t.ID),target:"_blank",rel:"noopener noreferrer","aria-label":(0,l.__)("Preview","easy-accordion-free")+" "+t.name},React.createElement(vm,null)))),React.createElement("div",{className:"sp-eap-patterns-item-list-info"},React.createElement("div",{className:"sp-eab-patterns-item-info"},React.createElement("span",null,(0,dm.decodeEntities)((null==t?void 0:t.name)||""))),React.createElement("span",{className:"sp-eap-patterns-action-btn"},React.createElement(Uc.Tooltip,{text:c?(0,l.__)("Remove from wishlist","easy-accordion-free"):(0,l.__)("Add to wishlist","easy-accordion-free"),delay:300,placement:"top"},React.createElement("span",{className:"sp-eap-pattern-wishlist",onClick:p,role:"button",tabIndex:0,onKeyPress:function(e){e.key!==bm&&" "!==e.key||p()},"aria-label":c?(0,l.__)("Remove from wishlist","easy-accordion-free"):(0,l.__)("Add to wishlist","easy-accordion-free")},c?React.createElement(mm,null):React.createElement(fm,null))),d?React.createElement("a",{className:"sp-eap-patterns-btn-pro",target:"_blank",rel:"noopener noreferrer",href:"https://easyaccordion.io/pricing/","aria-label":(0,l.__)("Upgrade to Pro to access this pattern","easy-accordion-free")},React.createElement(gm,null)," ",(0,l.__)("PRO","easy-accordion-free")):React.createElement("span",{onClick:f,className:"sp-eap-patterns-import-btn",role:"button",tabIndex:0,onKeyPress:function(e){e.key!==bm&&" "!==e.key||f()},"aria-label":(0,l.__)("Import","easy-accordion-free")+" "+t.name,style:u?{pointerEvents:"none",opacity:.6}:{}},u?React.createElement("i",{className:" sp-rotate"},React.createElement(pm,null)):React.createElement(React.Fragment,null,React.createElement(hm,null)," ",(0,l.__)("Import","easy-accordion-free")))))))}),Em=(0,i.memo)(function(){return React.createElement("div",{className:"sp-eap-pattern-grid sp-eap-pattern-col3 skeletonOverflow"},Array(25).fill(null).map(function(e,t){return React.createElement("div",{key:t,className:"sp-eap-patterns-item-list"},React.createElement("div",{className:"sp-eap-patterns-item-list-overlay"},React.createElement(ym,{type:"custom_size",c_s:{size1:100,unit1:"%",size2:400,unit2:"px"}})),React.createElement("div",{className:"sp-eap-patterns-item-list-info"},React.createElement(ym,{type:"custom_size",c_s:{size1:50,unit1:"%",size2:25,unit2:"px",br:2}}),React.createElement("span",{className:"sp-eap-patterns-action-btn"},React.createElement("span",{className:"sp-eap-pattern-wishlist"},React.createElement(ym,{type:"custom_size",c_s:{size1:30,unit1:"px",size2:25,unit2:"px",br:2}})),React.createElement(ym,{type:"custom_size",c_s:{size1:70,unit1:"px",size2:25,unit2:"px",br:2}}))))}))}),Rm=(0,i.memo)(function(){return React.createElement("span",{className:"sp-eap-patterns-image-rotate"},(0,l.__)("No Data found...","easy-accordion-free"))});(0,i.memo)(function(e){var t=e.premadeLists,n=e.column,r=e.searchQuery,a=e.freePro,o=e.showWishList,s=e.wishListArr,l=e.setWListAction,c=e.reload,u=e.reloadId,d=e.onImport,p=e.loading,f=(0,i.useMemo)(function(){return t.filter(function(e){var t,n=!r||(null===(t=e.name)||void 0===t?void 0:t.toLowerCase().includes(r.toLowerCase())),i="all"===a||"pro"===a&&e.pro||"free"===a&&!e.pro,l=!o||(null==s?void 0:s.includes(String(e.ID)));return n&&i&&l})},[t,r,a,o,s]);return p?React.createElement(Em,null):0===f.length?React.createElement(Rm,null):React.createElement("div",{className:"sp-eap-pattern-grid sp-eap-pattern-col".concat(n)},f.map(function(e){return React.createElement(wm,{key:e.ID,data:e,wishListArr:s,setWListAction:l,reload:c,reloadId:u,onImport:d})}))});var xm=["children","className"];function Am(){return Am=Object.assign?Object.assign.bind():function(e){for(var t=1;t<arguments.length;t++){var n=arguments[t];for(var r in n)({}).hasOwnProperty.call(n,r)&&(e[r]=n[r])}return e},Am.apply(null,arguments)}const Cm=function(e){var t=e.children,n=e.className,r=function(e,t){if(null==e)return{};var n,r,a=function(e,t){if(null==e)return{};var n={};for(var r in e)if({}.hasOwnProperty.call(e,r)){if(-1!==t.indexOf(r))continue;n[r]=e[r]}return n}(e,t);if(Object.getOwnPropertySymbols){var o=Object.getOwnPropertySymbols(e);for(r=0;r<o.length;r++)n=o[r],-1===t.indexOf(n)&&{}.propertyIsEnumerable.call(e,n)&&(a[n]=e[n])}return a}(e,xm);return React.createElement("button",Am({},r,{className:"sp-eab-button-component".concat(n?" "+n:"")}),t)};var Sm=function(){return React.createElement("svg",{xmlns:"http://www.w3.org/2000/svg",width:14,height:12,fill:"none"},React.createElement("path",{d:"M12.714 0H1.286C.655 0 .143.504.143 1.125v7.5c0 .621.512 1.125 1.143 1.125h4.571l-.38 1.125H3.761a.566.566 0 0 0-.571.563c0 .311.254.562.571.562h6.476c.317 0 .572-.25.572-.563a.566.566 0 0 0-.572-.562H8.524l-.38-1.125h4.57c.631 0 1.143-.504 1.143-1.125v-7.5C13.857.504 13.346 0 12.714 0Zm-.38 8.25H1.667V1.5h10.667v6.75Z"}))},km=function(){return React.createElement("svg",{xmlns:"http://www.w3.org/2000/svg",width:12,height:12,fill:"none"},React.createElement("path",{d:"M9.428 0H2.571C1.623 0 .857.67.857 1.5v9c0 .83.766 1.5 1.714 1.5h6.857c.949 0 1.715-.67 1.715-1.5v-9c0-.83-.766-1.5-1.715-1.5ZM7.143 11H4.857v-.5h2.286v.5Zm3-1.5H1.857v-8h8.286v8Z"}))},Om=function(){return React.createElement("svg",{xmlns:"http://www.w3.org/2000/svg",width:8,height:12,fill:"none"},React.createElement("path",{d:"M6.286 0H1.714C1.082 0 .571.67.571 1.5v9c0 .83.51 1.5 1.143 1.5h4.572c.632 0 1.142-.67 1.142-1.5v-9c0-.83-.51-1.5-1.142-1.5ZM4.762 11H3.238v-.5h1.524v.5Zm2-1.5H1.238v-8h5.524v8Z"}))};const Pm=function(){var e=function(e){document.getElementsByClassName("edit-site-visual-editor__editor-canvas").length>0?(0,s.dispatch)("core/edit-site").__experimentalSetPreviewDeviceType(e.target.closest("button").value):(0,s.dispatch)("core/edit-post").__experimentalSetPreviewDeviceType(e.target.closest("button").value)},t=Wc(),n=function(){return"Desktop"===t?React.createElement(Sm,null):"Tablet"===t?React.createElement(km,null):"Mobile"===t?React.createElement(Om,null):void 0};return React.createElement("div",{className:"sp-eab-responsive-picker"},React.createElement("div",{className:"sp-eab-units-indicator"},React.createElement("span",null,React.createElement(n,null)),React.createElement("div",{className:"sp-eab-units-btn"},React.createElement(Uc.Button,{className:"Desktop"===t?"active":"",value:"Desktop",onClick:e},React.createElement(Sm,null)),React.createElement(Uc.Button,{className:"Tablet"===t?"active":"",value:"Tablet",onClick:e},React.createElement(km,null)),React.createElement(Uc.Button,{className:"Mobile"===t?"active":"",value:"Mobile",onClick:e},React.createElement(Om,null)))))};var Mm=function(){return React.createElement("svg",{xmlns:"http://www.w3.org/2000/svg",width:16,height:16,fill:"none"},React.createElement("path",{stroke:"#2F2F2F",strokeLinecap:"round",strokeLinejoin:"round",strokeWidth:1.333,d:"M8 3.333v9.333M3.333 8h9.334"}))};function Im(e){return Im="function"==typeof Symbol&&"symbol"==typeof Symbol.iterator?function(e){return typeof e}:function(e){return e&&"function"==typeof Symbol&&e.constructor===Symbol&&e!==Symbol.prototype?"symbol":typeof e},Im(e)}function Tm(e,t){var n=Object.keys(e);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(e);t&&(r=r.filter(function(t){return Object.getOwnPropertyDescriptor(e,t).enumerable})),n.push.apply(n,r)}return n}function _m(e){for(var t=1;t<arguments.length;t++){var n=null!=arguments[t]?arguments[t]:{};t%2?Tm(Object(n),!0).forEach(function(t){Nm(e,t,n[t])}):Object.getOwnPropertyDescriptors?Object.defineProperties(e,Object.getOwnPropertyDescriptors(n)):Tm(Object(n)).forEach(function(t){Object.defineProperty(e,t,Object.getOwnPropertyDescriptor(n,t))})}return e}function Nm(e,t,n){return(t=function(e){var t=function(e){if("object"!=Im(e)||!e)return e;var t=e[Symbol.toPrimitive];if(void 0!==t){var n=t.call(e,"string");if("object"!=Im(n))return n;throw new TypeError("@@toPrimitive must return a primitive value.")}return String(e)}(e);return"symbol"==Im(t)?t:t+""}(t))in e?Object.defineProperty(e,t,{value:n,enumerable:!0,configurable:!0,writable:!0}):e[t]=n,e}function Lm(){var e,t,n="function"==typeof Symbol?Symbol:{},r=n.iterator||"@@iterator",a=n.toStringTag||"@@toStringTag";function o(n,r,a,o){var l=r&&r.prototype instanceof s?r:s,c=Object.create(l.prototype);return Dm(c,"_invoke",function(n,r,a){var o,s,l,c=0,u=a||[],d=!1,p={p:0,n:0,v:e,a:f,f:f.bind(e,4),d:function(t,n){return o=t,s=0,l=e,p.n=n,i}};function f(n,r){for(s=n,l=r,t=0;!d&&c&&!a&&t<u.length;t++){var a,o=u[t],f=p.p,m=o[2];n>3?(a=m===r)&&(l=o[(s=o[4])?5:(s=3,3)],o[4]=o[5]=e):o[0]<=f&&((a=n<2&&f<o[1])?(s=0,p.v=r,p.n=o[1]):f<m&&(a=n<3||o[0]>r||r>m)&&(o[4]=n,o[5]=r,p.n=m,s=0))}if(a||n>1)return i;throw d=!0,r}return function(a,u,m){if(c>1)throw TypeError("Generator is already running");for(d&&1===u&&f(u,m),s=u,l=m;(t=s<2?e:l)||!d;){o||(s?s<3?(s>1&&(p.n=-1),f(s,l)):p.n=l:p.v=l);try{if(c=2,o){if(s||(a="next"),t=o[a]){if(!(t=t.call(o,l)))throw TypeError("iterator result is not an object");if(!t.done)return t;l=t.value,s<2&&(s=0)}else 1===s&&(t=o.return)&&t.call(o),s<2&&(l=TypeError("The iterator does not provide a '"+a+"' method"),s=1);o=e}else if((t=(d=p.n<0)?l:n.call(r,p))!==i)break}catch(t){o=e,s=1,l=t}finally{c=1}}return{value:t,done:d}}}(n,a,o),!0),c}var i={};function s(){}function l(){}function c(){}t=Object.getPrototypeOf;var u=[][r]?t(t([][r]())):(Dm(t={},r,function(){return this}),t),d=c.prototype=s.prototype=Object.create(u);function p(e){return Object.setPrototypeOf?Object.setPrototypeOf(e,c):(e.__proto__=c,Dm(e,a,"GeneratorFunction")),e.prototype=Object.create(d),e}return l.prototype=c,Dm(d,"constructor",c),Dm(c,"constructor",l),l.displayName="GeneratorFunction",Dm(c,a,"GeneratorFunction"),Dm(d),Dm(d,a,"Generator"),Dm(d,r,function(){return this}),Dm(d,"toString",function(){return"[object Generator]"}),(Lm=function(){return{w:o,m:p}})()}function Dm(e,t,n,r){var a=Object.defineProperty;try{a({},"",{})}catch(e){a=0}Dm=function(e,t,n,r){function o(t,n){Dm(e,t,function(e){return this._invoke(t,n,e)})}t?a?a(e,t,{value:n,enumerable:!r,configurable:!r,writable:!r}):e[t]=n:(o("next",0),o("throw",1),o("return",2))},Dm(e,t,n,r)}function Bm(e,t,n,r,a,o,i){try{var s=e[o](i),l=s.value}catch(e){return void n(e)}s.done?t(l):Promise.resolve(l).then(r,a)}function Fm(e){return function(e){if(Array.isArray(e))return Hm(e)}(e)||function(e){if("undefined"!=typeof Symbol&&null!=e[Symbol.iterator]||null!=e["@@iterator"])return Array.from(e)}(e)||jm(e)||function(){throw new TypeError("Invalid attempt to spread non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.")}()}function zm(e,t){return function(e){if(Array.isArray(e))return e}(e)||function(e,t){var n=null==e?null:"undefined"!=typeof Symbol&&e[Symbol.iterator]||e["@@iterator"];if(null!=n){var r,a,o,i,s=[],l=!0,c=!1;try{if(o=(n=n.call(e)).next,0===t){if(Object(n)!==n)return;l=!1}else for(;!(l=(r=o.call(n)).done)&&(s.push(r.value),s.length!==t);l=!0);}catch(e){c=!0,a=e}finally{try{if(!l&&null!=n.return&&(i=n.return(),Object(i)!==i))return}finally{if(c)throw a}}return s}}(e,t)||jm(e,t)||function(){throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.")}()}function jm(e,t){if(e){if("string"==typeof e)return Hm(e,t);var n={}.toString.call(e).slice(8,-1);return"Object"===n&&e.constructor&&(n=e.constructor.name),"Map"===n||"Set"===n?Array.from(e):"Arguments"===n||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)?Hm(e,t):void 0}}function Hm(e,t){(null==t||t>e.length)&&(t=e.length);for(var n=0,r=Array(t);n<t;n++)r[n]=e[n];return r}var Vm=function(e){var t=e.label,n=e.colors,r=void 0===n?[]:n,a=e.onChangePanelColor,o=e.showNewColorAdd,i=void 0!==o&&o,s=e.handleCustomColor,c=void 0!==s&&s,u=e.palateName,d=void 0===u?"custom":u;return React.createElement("div",{className:"sp-eab-color-picker-palette-display-container"},React.createElement("div",{className:"sp-eab-palette-title-wrapper sp-d-flex sp-justify-between"},React.createElement("span",{className:"sp-eab-color-picker-palette-title"},t)),React.createElement("ul",{className:"sp-eab-color-picker-palette sp-d-grid"},null==r?void 0:r.map(function(e,t){return React.createElement("li",{key:t,style:{backgroundColor:null==e?void 0:e.color},title:null==e?void 0:e.name},React.createElement(Uc.Button,{onClick:function(){var t=null==e?void 0:e.color,n=/^#([0-9A-Fa-f]{3}){1,2}$/.test(t),r=null==t?void 0:t.includes("color-mix");if(n||r)a(t);else{var o=t.match(/--[\w-]+/);if(o){var i=getComputedStyle(document.documentElement).getPropertyValue(o[0]).trim();a(i)}}},value:e.color}),"custom"===d&&t>3&&React.createElement("span",{onClick:function(t){t.stopPropagation(),c("remove",null==e?void 0:e.name)},className:"sp-eab-color-remove-button"},React.createElement("svg",{xmlns:"http://www.w3.org/2000/svg",fill:"none",viewBox:"0 0 24 24",height:24,width:24},React.createElement("path",{fill:"#1E1E1E",d:"m12 13.06 3.712 3.713 1.06-1.061-3.712-3.713 3.713-3.712-1.061-1.06-3.713 3.712-3.712-3.712-1.06 1.06L10.939 12l-3.712 3.713 1.06 1.06L12 13.06Z"}))))}),i&&React.createElement("li",{title:(0,l.__)("Add this color to custom colors","easy-accordion-free"),className:"sp-d-flex sp-align-center sp-justify-center sp-cursor-pointer"},React.createElement("span",{className:"sp-d-flex sp-align-center sp-justify-center",onClick:function(e){e.stopPropagation(),c("add","color-".concat((null==r?void 0:r.length)+1))}},React.createElement(Mm,null)))))};(0,i.memo)(function(e){var t=e.setAttributes,n=e.value,r=e.attributesKey,a=e.label,o=e.onChange,s=e.defaultColor,c=void 0===s?"":s,u=e.resetButton,d=void 0===u||u,p=e.showThemeColors,f=void 0===p||p,m=e.activeState,h=void 0!==m&&m,g=h?n[h]:n,v=zm((0,i.useState)(g),2),b=v[0],y=v[1],w=zm((0,i.useState)([]),2),E=w[0],R=w[1],x=zm((0,i.useState)([]),2),A=x[0],C=x[1],S=zm((0,i.useState)(!1),2),k=S[0],O=S[1],P=[{name:"color-0",color:"#FF5B2E"},{name:"color-1",color:"#FFFFFF"},{name:"color-2",color:"#2F2F2F"},{name:"color-3",color:"#757575"}].concat(Fm(A)),M=function(){var e=function(e){return function(){var t=this,n=arguments;return new Promise(function(r,a){var o=e.apply(t,n);function i(e){Bm(o,r,a,i,s,"next",e)}function s(e){Bm(o,r,a,i,s,"throw",e)}i(void 0)})}}(Lm().m(function e(t){var n,r,a,o,i;return Lm().w(function(e){for(;;)switch(e.n){case 0:return(a=new FormData).append("action","sp_eab_color_settings_ajax"),a.append("colorSettingsData",JSON.stringify(t)),a.append("spEabAjaxNonce",null===(n=sp_eab_localize_data)||void 0===n?void 0:n.spEabAjaxNonce),e.n=1,Zl.post(sp_eab_localize_data.ajaxUrl,a);case 1:return o=e.v,e.n=2,null==o||null===(r=o.data)||void 0===r?void 0:r.data;case 2:i=e.v,C((null==i?void 0:i.custom_colors)||[]),R((null==i?void 0:i.theme_colors)||[]);case 3:return e.a(2)}},e)}));return function(_x){return e.apply(this,arguments)}}(),I=function(e,t){var n;n="add"===e?[].concat(Fm(A),[{name:t,color:b}]):A.filter(function(e){return e.name!==t}),C(n),M(n),O(!1)},T=function(e){var a=[].concat(Fm(P),Fm(E)),i=null==a?void 0:a.find(function(t){return t.color===e});O(!i),y(e),o?o(e):t(Nm({},r,h?_m(_m({},n),{},Nm({},h,e)):e))};return React.createElement("div",{className:"sp-eab-color-picker sp-eab-component-mb sp-d-flex sp-justify-between sp-align-center"},React.createElement("span",{className:"sp-eab-component-title"},a),React.createElement("div",{className:"sp-eab-color-picker-right-area sp-d-flex sp-align-center"},d&&React.createElement(qm,{onClick:function(){T(c)}}),React.createElement(Uc.Dropdown,{popoverProps:{placement:"bottom-start"},renderToggle:function(e){var t=e.isOpen,n=e.onToggle;return React.createElement(Uc.Button,{onClick:n,"aria-expanded":t},React.createElement(Uc.ColorIndicator,{colorValue:g,onClick:function(){return M()}}))},onClose:function(e,t){t&&e.stopPropagation()},renderContent:function(){return React.createElement("div",{onMouseDown:function(e){e.stopPropagation()},className:"sp-eab-color-picker-renderer"},React.createElement(Uc.ColorPicker,{className:"sp-eab-color-picker",color:b,onChange:T,colors:P,enableAlpha:!0}),f&&(null==E?void 0:E.length)>0&&React.createElement(Vm,{label:(0,l.__)("Theme colors","easy-accordion-free"),colors:E,onChangePanelColor:T,palateName:"theme"}),(null==P?void 0:P.length)>0&&React.createElement(Vm,{label:(0,l.__)("Custom colors","easy-accordion-free"),colors:P,onChangePanelColor:T,showNewColorAdd:k,handleCustomColor:I}))}})))});var Gm=function(){return React.createElement("svg",{xmlns:"http://www.w3.org/2000/svg","aria-hidden":"true",width:14,height:14,viewBox:"0 0 14 14",fill:"none"},React.createElement("g",{clipPath:"url(#clip0_13968_266e)"},React.createElement("path",{d:"M2.26612 4.11595C3.37829 2.2925 5.49847 1.20166 7.74998 1.50927C10.7824 1.92355 12.9048 4.71765 12.4905 7.75006C12.0762 10.7825 9.2821 12.9049 6.24972 12.4906C3.99821 12.183 2.24836 10.5634 1.66601 8.5085M2.02244 2.49303L2.04627 4.36557L3.84791 4.2143",stroke:"#949494",strokeWidth:1.75,strokeLinecap:"round",strokeLinejoin:"round",fill:"transparent"})),React.createElement("defs",null,React.createElement("clipPath",{id:"clip0_13968_266e"},React.createElement("rect",{width:14,height:14,fill:"white"}))))};const qm=function(e){var t=e.onClick;return React.createElement(Uc.Button,{className:"sp-eab-component-header-reset",onClick:t},React.createElement(Gm,null))};function Um(e){return Um="function"==typeof Symbol&&"symbol"==typeof Symbol.iterator?function(e){return typeof e}:function(e){return e&&"function"==typeof Symbol&&e.constructor===Symbol&&e!==Symbol.prototype?"symbol":typeof e},Um(e)}function Wm(e,t){var n=Object.keys(e);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(e);t&&(r=r.filter(function(t){return Object.getOwnPropertyDescriptor(e,t).enumerable})),n.push.apply(n,r)}return n}function Qm(e){for(var t=1;t<arguments.length;t++){var n=null!=arguments[t]?arguments[t]:{};t%2?Wm(Object(n),!0).forEach(function(t){Km(e,t,n[t])}):Object.getOwnPropertyDescriptors?Object.defineProperties(e,Object.getOwnPropertyDescriptors(n)):Wm(Object(n)).forEach(function(t){Object.defineProperty(e,t,Object.getOwnPropertyDescriptor(n,t))})}return e}function Km(e,t,n){return(t=function(e){var t=function(e){if("object"!=Um(e)||!e)return e;var t=e[Symbol.toPrimitive];if(void 0!==t){var n=t.call(e,"string");if("object"!=Um(n))return n;throw new TypeError("@@toPrimitive must return a primitive value.")}return String(e)}(e);return"symbol"==Um(t)?t:t+""}(t))in e?Object.defineProperty(e,t,{value:n,enumerable:!0,configurable:!0,writable:!0}):e[t]=n,e}const Zm=(0,i.memo)(function(e){var t=e.attributes,n=e.setAttributes,r=e.attributesKey,a=e.units,o=Wc(),i="object"===Um(null==t?void 0:t.unit)?t.unit[o]:null==t?void 0:t.unit;return React.createElement("div",{className:"sp-eab-units-indicator"},React.createElement("span",{className:"sp-eab-units-label"},i),React.createElement("div",{className:"sp-eab-units-btn"},null==a?void 0:a.map(function(e,a){return React.createElement(Uc.Button,{key:a,className:i===e.toLowerCase()?"active":"",value:e,onClick:function(e){return a=e.target.value,void(t.unit[o]?n(Km({},r,Qm(Qm({},t),{},{unit:Qm(Qm({},t.unit),{},Km({},o,a.toLowerCase()))}))):n(Km({},r,Qm(Qm({},t),{},{unit:a.toLowerCase()}))));var a}}," ",e," ")})))}),Jm=(0,i.memo)(function(e){var t=e.label,n=e.attributes,r=e.setAttributes,a=e.attributesKey,o=void 0===a?"":a,i=e.units,s=void 0!==i&&i,l=e.onReset,c=void 0!==l&&l;return React.createElement("div",{className:"sp-eab-component-header sp-d-flex sp-justify-between sp-mb-8px"},React.createElement("div",{className:"sp-eab-component-header-left sp-d-flex sp-align-center"},React.createElement("span",{className:"sp-eab-component-title"},t),(null==n?void 0:n.device)&&React.createElement(Pm,null)),React.createElement("div",{className:"sp-eab-component-header-right sp-d-flex sp-align-center"},c&&React.createElement(qm,{onClick:function(){return c()}}),s&&React.createElement(Zm,{attributes:n,setAttributes:r,attributesKey:o,units:s})))});function Xm(e){return Xm="function"==typeof Symbol&&"symbol"==typeof Symbol.iterator?function(e){return typeof e}:function(e){return e&&"function"==typeof Symbol&&e.constructor===Symbol&&e!==Symbol.prototype?"symbol":typeof e},Xm(e)}function Ym(e,t){var n=Object.keys(e);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(e);t&&(r=r.filter(function(t){return Object.getOwnPropertyDescriptor(e,t).enumerable})),n.push.apply(n,r)}return n}function $m(e){for(var t=1;t<arguments.length;t++){var n=null!=arguments[t]?arguments[t]:{};t%2?Ym(Object(n),!0).forEach(function(t){eh(e,t,n[t])}):Object.getOwnPropertyDescriptors?Object.defineProperties(e,Object.getOwnPropertyDescriptors(n)):Ym(Object(n)).forEach(function(t){Object.defineProperty(e,t,Object.getOwnPropertyDescriptor(n,t))})}return e}function eh(e,t,n){return(t=function(e){var t=function(e){if("object"!=Xm(e)||!e)return e;var t=e[Symbol.toPrimitive];if(void 0!==t){var n=t.call(e,"string");if("object"!=Xm(n))return n;throw new TypeError("@@toPrimitive must return a primitive value.")}return String(e)}(e);return"symbol"==Xm(t)?t:t+""}(t))in e?Object.defineProperty(e,t,{value:n,enumerable:!0,configurable:!0,writable:!0}):e[t]=n,e}(0,i.memo)(function(e){var t,n,r=e.attributes,a=e.attributesKey,o=e.setAttributes,i=e.label,s=e.units,l=void 0===s?["px","%","em"]:s,c=e.resetIcon,u=void 0===c||c,d=e.min,p=void 0===d?0:d,f=e.max,m=void 0===f?200:f,h=e.step,g=void 0===h?1:h,v=e.defaultValue,b=void 0===v?{unit:"px",value:10}:v,y=Wc();n=null!=r&&r.device?null==r?void 0:r.device[y]:void 0!==(null==r?void 0:r.value)?null==r?void 0:r.value:r;var w=(null==r||null===(t=r.unit)||void 0===t?void 0:t[y])||(null==r?void 0:r.unit);return React.createElement("div",{className:"sp-eab-range-control sp-eab-component-mb"},React.createElement(Jm,{label:i,attributes:r,setAttributes:o,attributesKey:a,units:l,onReset:!!u&&function(){return e=null!=r&&r.device?$m($m({},r),{},{device:$m($m({},r.device),{},eh({},y,b.value)),unit:$m($m({},r.unit),{},eh({},y,b.unit))}):void 0!==(null==r?void 0:r.value)?{value:b.value,unit:b.unit}:b,void o(eh({},a,e));var e}}),React.createElement(Uc.RangeControl,{value:n,color:"#FF5B2E",onChange:function(e){return function(e){var t;t=null!=r&&r.device?$m($m({},r),{},{device:$m($m({},r.device),{},eh({},y,e))}):void 0!==(null==r?void 0:r.value)?$m($m({},r),{},{value:e}):e,o(eh({},a,t))}(e)},min:p,max:null!=r&&r.unit&&"%"===w?100:m,step:g,__next40pxDefaultSize:!0,__nextHasNoMarginBottom:!0}))});(0,l.__)("Solid","easy-accordion-free"),(0,l.__)("Gradient","easy-accordion-free"),(0,l.__)("Image","easy-accordion-free"),(0,l.__)("Video","easy-accordion-free"),(0,l.__)("Inherit","easy-accordion-free"),(0,l.__)("Bottom","easy-accordion-free"),(0,l.__)("Center","easy-accordion-free"),(0,l.__)("Top","easy-accordion-free"),(0,l.__)("Right","easy-accordion-free"),(0,l.__)("Left","easy-accordion-free"),(0,l.__)("Initial","easy-accordion-free"),(0,l.__)("Scroll","easy-accordion-free"),(0,l.__)("Fixed","easy-accordion-free"),(0,l.__)("No Repeat","easy-accordion-free"),(0,l.__)("Repeat","easy-accordion-free"),(0,l.__)("Repeat X","easy-accordion-free"),(0,l.__)("Repeat Y","easy-accordion-free"),(0,l.__)("Auto","easy-accordion-free"),(0,l.__)("Cover","easy-accordion-free"),(0,l.__)("Contain","easy-accordion-free");var th=function(){return React.createElement("svg",{xmlns:"http://www.w3.org/2000/svg",width:24,height:24,fill:"none"},React.createElement("path",{fill:"#2F2F2F",d:"M8.4 16.7h.7l-1.6 3.5.9.4 3.9-8.5H15v-1.5h-2l1.3-2.8h1.3c2 0 3.7 1.7 3.7 3.7s-1.7 3.7-3.7 3.7H14v1.5h1.6c2.9 0 5.2-2.3 5.2-5.2 0-2.9-2.3-5.2-5.2-5.2H15l1.4-3.2-.9-.4-5.7 12.5H8.4c-2 0-3.7-1.7-3.7-3.7s1.7-3.7 3.7-3.7H10V6.3H8.4c-2.9 0-5.2 2.3-5.2 5.2 0 2.9 2.4 5.2 5.2 5.2Z"}))},nh=function(){return React.createElement("svg",{xmlns:"http://www.w3.org/2000/svg",width:24,height:24,fill:"none"},React.createElement("path",{fill:"#fff",d:"M8.4 16.8H10v-1.5H8.4c-2 0-3.7-1.7-3.7-3.7s1.7-3.7 3.7-3.7H10V6.4H8.4c-2.8 0-5.2 2.3-5.2 5.2 0 2.9 2.3 5.2 5.2 5.2Zm10.9-5.2c0 2-1.7 3.7-3.7 3.7H14v1.5h1.6c2.9 0 5.2-2.3 5.2-5.2 0-2.9-2.3-5.2-5.2-5.2H14v1.5h1.6c2 0 3.7 1.7 3.7 3.7Zm-4.6-.9H9.4v1.5h5.3v-1.5Z"}))},rh=n(942),ah=n.n(rh);function oh(e){return oh="function"==typeof Symbol&&"symbol"==typeof Symbol.iterator?function(e){return typeof e}:function(e){return e&&"function"==typeof Symbol&&e.constructor===Symbol&&e!==Symbol.prototype?"symbol":typeof e},oh(e)}function ih(e,t){var n=Object.keys(e);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(e);t&&(r=r.filter(function(t){return Object.getOwnPropertyDescriptor(e,t).enumerable})),n.push.apply(n,r)}return n}function sh(e){for(var t=1;t<arguments.length;t++){var n=null!=arguments[t]?arguments[t]:{};t%2?ih(Object(n),!0).forEach(function(t){lh(e,t,n[t])}):Object.getOwnPropertyDescriptors?Object.defineProperties(e,Object.getOwnPropertyDescriptors(n)):ih(Object(n)).forEach(function(t){Object.defineProperty(e,t,Object.getOwnPropertyDescriptor(n,t))})}return e}function lh(e,t,n){return(t=function(e){var t=function(e){if("object"!=oh(e)||!e)return e;var t=e[Symbol.toPrimitive];if(void 0!==t){var n=t.call(e,"string");if("object"!=oh(n))return n;throw new TypeError("@@toPrimitive must return a primitive value.")}return String(e)}(e);return"symbol"==oh(t)?t:t+""}(t))in e?Object.defineProperty(e,t,{value:n,enumerable:!0,configurable:!0,writable:!0}):e[t]=n,e}(0,i.memo)(function(e){var t,n=e.label,r=e.attributes,a=e.attributesKey,o=e.setAttributes,i=e.units,s=void 0===i?["px","%","em"]:i,l=e.linkButton,c=void 0===l||l,u=e.labelItem,d=void 0!==u&&u,p=e.defaultValue,f=void 0===p?{unit:"px",value:{top:"0",right:"0",bottom:"0",left:"0"}}:p,m=e.radiusIndicators,h=void 0!==m&&m,g=Wc(),v=null==r?void 0:r.allChange,b=!(null==r||!r.device),y=b?null==r?void 0:r.device[g]:null==r?void 0:r.value;return React.createElement("div",{className:"sp-eab-spacing sp-eab-component-mb"},React.createElement(Jm,{label:n,attributes:r,setAttributes:o,attributesKey:a,units:s,onReset:function(){var e,t=null==f?void 0:f.value,n=null==f?void 0:f.unit;e=sh(sh({},r),{},b?{device:sh(sh({},r.device),{},lh({},g,t)),unit:sh(sh({},r.unit),{},lh({},g,n))}:{value:t,unit:n}),o(lh({},a,e))}}),React.createElement("div",{className:ah()("sp-eab-spacing-part-2 sp-d-flex",{"sp-eab-radius-indicators":h,"sp-eab-spacing-indicators":!d&&!h})},null===(t=Object.keys(y))||void 0===t?void 0:t.map(function(e){var t,n=(null===(t=y[e])||void 0===t?void 0:t.toString())||"0";return React.createElement("div",{key:e,className:ah()("sp-eab-spacing-".concat(e),{box:!c&&"left"===e})},React.createElement("input",{id:"sp-eab-".concat(a||"spacing","-").concat(e),onChange:function(t){return function(e,t){var n;n=v?{top:e,right:e,bottom:e,left:e}:sh(sh({},b?{top:(null==y?void 0:y.top)||0,right:(null==y?void 0:y.right)||0,bottom:(null==y?void 0:y.bottom)||0,left:(null==y?void 0:y.left)||0}:r.value),{},lh({},t,e));var i;i=sh(sh({},r),{},b?{device:sh(sh({},r.device),{},lh({},g,n))}:{value:n}),o(lh({},a,i))}(t.target.value,e)},type:"number",value:n}),d&&React.createElement("span",{className:"sp-eab-spacing-indicator-label sp-d-block"},d[e]))}),c&&React.createElement("div",{className:"sp-eab-spacing-all"},React.createElement(Uc.Button,{className:null!=r&&r.allChange?"active":"",onClick:function(e){e.stopPropagation(),o(lh({},a,sh(sh({},r),{},{allChange:!(null!=r&&r.allChange)})))}},v?React.createElement(nh,null):React.createElement(th,null)))))});var ch=["pro"];function uh(e){return uh="function"==typeof Symbol&&"symbol"==typeof Symbol.iterator?function(e){return typeof e}:function(e){return e&&"function"==typeof Symbol&&e.constructor===Symbol&&e!==Symbol.prototype?"symbol":typeof e},uh(e)}function dh(e,t){var n=Object.keys(e);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(e);t&&(r=r.filter(function(t){return Object.getOwnPropertyDescriptor(e,t).enumerable})),n.push.apply(n,r)}return n}function ph(e){for(var t=1;t<arguments.length;t++){var n=null!=arguments[t]?arguments[t]:{};t%2?dh(Object(n),!0).forEach(function(t){fh(e,t,n[t])}):Object.getOwnPropertyDescriptors?Object.defineProperties(e,Object.getOwnPropertyDescriptors(n)):dh(Object(n)).forEach(function(t){Object.defineProperty(e,t,Object.getOwnPropertyDescriptor(n,t))})}return e}function fh(e,t,n){return(t=function(e){var t=function(e){if("object"!=uh(e)||!e)return e;var t=e[Symbol.toPrimitive];if(void 0!==t){var n=t.call(e,"string");if("object"!=uh(n))return n;throw new TypeError("@@toPrimitive must return a primitive value.")}return String(e)}(e);return"symbol"==uh(t)?t:t+""}(t))in e?Object.defineProperty(e,t,{value:n,enumerable:!0,configurable:!0,writable:!0}):e[t]=n,e}const mh=(0,i.memo)(function(e){var t=e.attributes,n=e.attributesKey,r=e.setAttributes,a=e.items,o=e.label,i=void 0===o?"":o,s=e.flexStyle,l=void 0!==s&&s,c=e.units,u=void 0!==c&&c,d=e.onChange,p=void 0!==d&&d,f=e.showHeading,m=void 0===f||f,h=Wc(),g=a.map(function(e){var t=e.pro,n=function(e,t){if(null==e)return{};var n,r,a=function(e,t){if(null==e)return{};var n={};for(var r in e)if({}.hasOwnProperty.call(e,r)){if(-1!==t.indexOf(r))continue;n[r]=e[r]}return n}(e,t);if(Object.getOwnPropertySymbols){var o=Object.getOwnPropertySymbols(e);for(r=0;r<o.length;r++)n=o[r],-1===t.indexOf(n)&&{}.propertyIsEnumerable.call(e,n)&&(a[n]=e[n])}return a}(e,ch);return ph(ph({},n),{},{disabled:!0===t})}),v=null!=t&&t.device?null==t?void 0:t.device[h]:t;return React.createElement("div",{className:"sp-eab-select-field sp-eab-component-mb ".concat(l?"sp-d-flex sp-justify-between sp-align-center":"sp-d-block")},m&&React.createElement(Jm,{label:i,attributes:t,attributesKey:n,setAttributes:r,units:u}),React.createElement(Uc.SelectControl,{className:"custom-select-control",value:v,options:g,onChange:function(e){p?p(e):null!=t&&t.device?r(fh({},n,{device:ph(ph({},null==t?void 0:t.device),{},fh({},h,e))})):r(fh({},n,e))},__nextHasNoMarginBottom:!0,__next40pxDefaultSize:!0}))});function hh(e){return hh="function"==typeof Symbol&&"symbol"==typeof Symbol.iterator?function(e){return typeof e}:function(e){return e&&"function"==typeof Symbol&&e.constructor===Symbol&&e!==Symbol.prototype?"symbol":typeof e},hh(e)}function gh(e,t){var n=Object.keys(e);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(e);t&&(r=r.filter(function(t){return Object.getOwnPropertyDescriptor(e,t).enumerable})),n.push.apply(n,r)}return n}function vh(e){for(var t=1;t<arguments.length;t++){var n=null!=arguments[t]?arguments[t]:{};t%2?gh(Object(n),!0).forEach(function(t){bh(e,t,n[t])}):Object.getOwnPropertyDescriptors?Object.defineProperties(e,Object.getOwnPropertyDescriptors(n)):gh(Object(n)).forEach(function(t){Object.defineProperty(e,t,Object.getOwnPropertyDescriptor(n,t))})}return e}function bh(e,t,n){return(t=function(e){var t=function(e){if("object"!=hh(e)||!e)return e;var t=e[Symbol.toPrimitive];if(void 0!==t){var n=t.call(e,"string");if("object"!=hh(n))return n;throw new TypeError("@@toPrimitive must return a primitive value.")}return String(e)}(e);return"symbol"==hh(t)?t:t+""}(t))in e?Object.defineProperty(e,t,{value:n,enumerable:!0,configurable:!0,writable:!0}):e[t]=n,e}const yh=function(e){var t=e.attributes,n=e.attributesKey,r=e.setAttributes,a=e.label,o=e.flex,i=void 0!==o&&o,s=e.inputType,l=void 0===s?"text":s,c=e.placeholder,u=e.onChange,d=void 0!==u&&u,p=e.help,f=void 0!==p&&p,m=e.min,h=void 0===m?1:m,g=e.step,v=void 0===g?1:g,b=Wc(),y=null!=t&&t.device?null==t?void 0:t.device[b]:t;return React.createElement("div",{className:"sp-eab-input-control sp-eab-component-mb"},React.createElement("div",{className:"sp-eab-input-control-header ".concat(i?"sp-flex-input sp-d-flex sp-justify-between":"sp-block-input")},React.createElement("div",{className:"sp-eab-input-control-header-left ".concat(i?"sp-d-flex sp-align-center":"sp-mb-8px")},React.createElement("span",{className:"sp-eab-component-title"},a),(null==t?void 0:t.device)&&React.createElement(Pm,null)),React.createElement("div",{className:"sp-eab-input-control-field"},React.createElement(Uc.__experimentalInputControl,{type:l,value:y,step:v,onChange:function(e){return d?d(e):void function(e){null!=t&&t.device?r(bh({},n,vh(vh({},t),{},{device:vh(vh({},t.device),{},bh({},b,e))}))):r(bh({},n,e))}(e)},placeholder:c,help:f,min:h,__next40pxDefaultSize:!0}))))};var wh=function(){return React.createElement("svg",{xmlns:"http://www.w3.org/2000/svg",width:8,height:8,fill:"none"},React.createElement("path",{fill:"#2F2F2F",d:"M4 4.778 6.722 7.5l.778-.778L4.778 4 7.5 1.278 6.722.5 4 3.222 1.278.5.5 1.278 3.222 4 .5 6.722l.778.778L4 4.778Z"}))},Eh=function(){return React.createElement("svg",{xmlns:"http://www.w3.org/2000/svg",width:24,height:24,"aria-hidden":"true",className:""},React.createElement("path",{d:"M17.5 11.6 12 16l-5.5-4.4.9-1.2L12 14l4.5-3.6 1 1.2z"}))},Rh=function(){return React.createElement("svg",{xmlns:"http://www.w3.org/2000/svg",width:24,height:24,"aria-hidden":"true"},React.createElement("path",{d:"M6.5 12.4 12 8l5.5 4.4-.9 1.2L12 10l-4.5 3.6-1-1.2z"}))},xh=function(){return React.createElement("svg",{xmlns:"http://www.w3.org/2000/svg",width:16,height:16,viewBox:"0 0 1200 1200"},React.createElement("path",{fill:"#aaa",d:"M198 198c-222 222-222 582 0 804s582 222 804 0 222-582 0-804-582-222-804 0zm712.8 712.8c-171.6 171.6-451.2 171.6-622.8 0-171.6-171.6-171.6-451.2 0-622.8s451.2-171.6 622.8 0c172.8 172.8 172.8 451.2 0 622.8zM535.2 357.6c0-48 39.602-86.398 87.602-86.398s86.398 39.602 85.199 87.602c0 48-39.602 87.602-86.398 86.398-48-.004-87.602-39.602-86.402-87.602zm210 499.2c-2.398 7.2-7.2 15.602-12 20.398-31.199 32.398-69.602 50.398-114 51.602-21.602 0-42 0-63.602-3.602-34.801-4.8-79.199-48-72-93.602 4.8-31.199 9.602-62.398 14.398-93.602 9.602-54 19.199-108 28.801-162 0-3.601 1.2-7.199 1.2-10.8 0-22.802-7.2-31.2-30-33.603-9.602-1.199-19.2-2.398-28.802-4.8-10.8-3.602-15.602-13.2-15.602-21.602 1.2-9.602 7.2-15.602 19.2-18 6-1.2 13.198-1.2 19.198-1.2h163.2c20.397 0 32.397 9.602 32.397 30 0 16.801-2.398 33.602-6 50.398-10.8 62.398-22.8 123.6-33.602 186-3.601 20.398-8.398 40.801-10.8 61.2-1.2 9.601 0 20.397 2.398 30 3.601 13.198 13.199 20.397 26.398 18 10.8-1.2 21.602-4.801 32.398-9.602 8.398-3.602 15.602-9.602 24-12 15.617-5.988 26.418 3.613 22.816 16.812z"}))},Ah=function(){return React.createElement("svg",{width:16,height:16,viewBox:"0 0 16 16",fill:"none",xmlns:"http://www.w3.org/2000/svg"},React.createElement("path",{d:"M6.618 2.431a1.627 1.627 0 1 1-3.253 0 1.627 1.627 0 0 1 3.253 0",fill:"#949494"}),React.createElement("path",{d:"M6.463 2.43a1.48 1.48 0 0 1-.966 1.382 1.49 1.49 0 0 1-1.64-.449 1.48 1.48 0 0 1-.12-1.698A1.48 1.48 0 0 1 5.275.987a1.49 1.49 0 0 1 1.189 1.444c.001.201.314.201.312 0A1.81 1.81 0 0 0 5.6.754a1.79 1.79 0 0 0-1.976.538 1.8 1.8 0 0 0-.155 2.062c.39.642 1.155.969 1.889.822.82-.166 1.412-.916 1.419-1.745 0-.202-.313-.202-.314 0m.155 5.571a1.627 1.627 0 1 1-3.253 0 1.627 1.627 0 0 1 3.253 0",fill:"#949494"}),React.createElement("path",{d:"M6.463 8a1.48 1.48 0 0 1-.966 1.382 1.49 1.49 0 0 1-1.64-.448 1.48 1.48 0 0 1-.12-1.699 1.48 1.48 0 0 1 1.537-.678 1.49 1.49 0 0 1 1.189 1.444c.001.201.314.201.312 0A1.81 1.81 0 0 0 5.6 6.324a1.79 1.79 0 0 0-1.976.538 1.8 1.8 0 0 0-.155 2.062c.39.643 1.155.97 1.889.822.82-.165 1.412-.915 1.419-1.745 0-.202-.313-.202-.314 0m.155 5.571a1.627 1.627 0 1 1-3.253 0 1.627 1.627 0 0 1 3.253 0",fill:"#949494"}),React.createElement("path",{d:"M6.463 13.571a1.48 1.48 0 0 1-.966 1.381 1.49 1.49 0 0 1-1.64-.448 1.48 1.48 0 0 1-.12-1.698 1.48 1.48 0 0 1 1.537-.678 1.49 1.49 0 0 1 1.189 1.443c.001.202.314.202.312 0A1.81 1.81 0 0 0 5.6 11.895a1.79 1.79 0 0 0-1.976.537 1.8 1.8 0 0 0-.155 2.063c.39.642 1.155.968 1.889.822.82-.166 1.412-.916 1.419-1.746 0-.201-.313-.201-.314 0m6.171-11.14a1.626 1.626 0 1 1-3.253 0 1.626 1.626 0 0 1 3.253 0",fill:"#949494"}),React.createElement("path",{d:"M12.478 2.43a1.48 1.48 0 0 1-.965 1.382 1.49 1.49 0 0 1-1.641-.449 1.48 1.48 0 0 1-.119-1.698A1.48 1.48 0 0 1 11.29.987a1.49 1.49 0 0 1 1.19 1.444c0 .201.313.201.312 0A1.81 1.81 0 0 0 11.616.754a1.79 1.79 0 0 0-1.977.538 1.8 1.8 0 0 0-.154 2.062c.39.642 1.154.969 1.889.822.82-.166 1.412-.916 1.418-1.745 0-.202-.312-.202-.314 0m.156 5.571a1.626 1.626 0 1 1-3.253 0 1.626 1.626 0 0 1 3.253 0",fill:"#949494"}),React.createElement("path",{d:"M12.478 8a1.48 1.48 0 0 1-.965 1.382 1.49 1.49 0 0 1-1.641-.448 1.48 1.48 0 0 1-.119-1.699 1.48 1.48 0 0 1 1.536-.678 1.49 1.49 0 0 1 1.19 1.444c0 .201.313.201.312 0a1.81 1.81 0 0 0-1.175-1.677 1.79 1.79 0 0 0-1.977.538 1.8 1.8 0 0 0-.154 2.062c.39.643 1.154.97 1.889.822.82-.165 1.412-.915 1.418-1.745 0-.202-.312-.202-.314 0m.156 5.571a1.627 1.627 0 1 1-3.253 0 1.627 1.627 0 0 1 3.253 0",fill:"#949494"}),React.createElement("path",{d:"M12.478 13.571a1.48 1.48 0 0 1-.965 1.381 1.49 1.49 0 0 1-1.641-.448 1.48 1.48 0 0 1-.119-1.698 1.48 1.48 0 0 1 1.536-.678 1.49 1.49 0 0 1 1.19 1.443c0 .202.313.202.312 0a1.81 1.81 0 0 0-1.175-1.676 1.79 1.79 0 0 0-1.977.537 1.8 1.8 0 0 0-.154 2.063c.39.642 1.154.968 1.889.822.82-.166 1.412-.916 1.418-1.746 0-.201-.312-.201-.314 0",fill:"#949494"}))};function Ch(e){return Ch="function"==typeof Symbol&&"symbol"==typeof Symbol.iterator?function(e){return typeof e}:function(e){return e&&"function"==typeof Symbol&&e.constructor===Symbol&&e!==Symbol.prototype?"symbol":typeof e},Ch(e)}function Sh(e,t){(null==t||t>e.length)&&(t=e.length);for(var n=0,r=Array(t);n<t;n++)r[n]=e[n];return r}function kh(e,t,n){return function(e,t,n){const r=t<0?e.length+t:t;if(r>=0&&r<e.length){const r=n<0?e.length+n:n,[a]=e.splice(t,1);e.splice(r,0,a)}}(e=[...e],t,n),e}function Oh(e){return`Minified Redux error #${e}; visit https://redux.js.org/Errors?code=${e} for the full message or use the non-minified dev environment for full errors. `}(0,i.memo)(function(e){var t=e.label,n=e.attributes,r=e.setAttributes,a=void 0===r||r,o=e.attributesKey,s=e.onChange,l=void 0!==s&&s,c=e.updated,u=void 0!==c&&c,d=e.enableInfoIcon,p=void 0!==d&&d,f=e.InfoText,m=void 0===f?"":f,h=e.onlyPro,g=void 0!==h&&h,v=e.demoLink,b=void 0===v?"https://easyaccordion.io/pricing/":v,y=function(e,t){return function(e){if(Array.isArray(e))return e}(e)||function(e,t){var n=null==e?null:"undefined"!=typeof Symbol&&e[Symbol.iterator]||e["@@iterator"];if(null!=n){var r,a,o,i,s=[],l=!0,c=!1;try{if(o=(n=n.call(e)).next,0===t){if(Object(n)!==n)return;l=!1}else for(;!(l=(r=o.call(n)).done)&&(s.push(r.value),s.length!==t);l=!0);}catch(e){c=!0,a=e}finally{try{if(!l&&null!=n.return&&(i=n.return(),Object(i)!==i))return}finally{if(c)throw a}}return s}}(e,t)||function(e,t){if(e){if("string"==typeof e)return Sh(e,t);var n={}.toString.call(e).slice(8,-1);return"Object"===n&&e.constructor&&(n=e.constructor.name),"Map"===n||"Set"===n?Array.from(e):"Arguments"===n||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)?Sh(e,t):void 0}}(e,t)||function(){throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.")}()}((0,i.useState)(!1),2),w=y[0],E=y[1],R=function(){E(function(e){return!e})};return React.createElement("div",{className:"sp-eab-toggle sp-eab-component-mb".concat(u?" updated-toggle":"").concat(p?" sp-eab-toggle-info-icon":"").concat(g?" eab-only-pro-toggle":"")},g&&!u&&React.createElement("div",{className:"sp-eab-toggle-left sp-d-flex sp-align-i-center"},React.createElement("span",{className:"eab-pro-title"},t),b?React.createElement("a",{className:"eab-pro-badge",href:b,target:"_blank "},"(Pro)"):React.createElement("span",{className:"eab-pro-badge"},"(Pro)")),(u||p)&&React.createElement("div",{className:"sp-eab-toggle-left"},u&&React.createElement(Ah,null),g?React.createElement("div",{className:"sp-eab-toggle-left"},React.createElement("span",{className:"eab-pro-title"},t),g&&React.createElement("span",{className:"eab-pro-badge"},"(Pro)")):React.createElement("span",null,t),p&&React.createElement("span",{className:"toggle-info-icon",onMouseEnter:R,onMouseLeave:R},React.createElement(xh,null))),p&&React.createElement("div",{onMouseEnter:function(){return E(!0)},onMouseLeave:function(){return E(!1)},className:"toggle-info"},React.createElement("div",{className:"toggle-info-popup ".concat(w?"show":"")},React.createElement(m,null))),React.createElement(Uc.ToggleControl,{label:u||p||g?"":t,checked:n,onChange:function(e){return l?l(!e):a(function(e,t,n){return(t=function(e){var t=function(e){if("object"!=Ch(e)||!e)return e;var t=e[Symbol.toPrimitive];if(void 0!==t){var n=t.call(e,"string");if("object"!=Ch(n))return n;throw new TypeError("@@toPrimitive must return a primitive value.")}return String(e)}(e);return"symbol"==Ch(t)?t:t+""}(t))in e?Object.defineProperty(e,t,{value:n,enumerable:!0,configurable:!0,writable:!0}):e[t]=n,e}({},o,!n))},__nextHasNoMarginBottom:!0}))});var Ph=(()=>"function"==typeof Symbol&&Symbol.observable||"@@observable")(),Mh=()=>Math.random().toString(36).substring(7).split("").join("."),Ih={INIT:`@@redux/INIT${Mh()}`,REPLACE:`@@redux/REPLACE${Mh()}`,PROBE_UNKNOWN_ACTION:()=>`@@redux/PROBE_UNKNOWN_ACTION${Mh()}`};function Th(e,t,n){if("function"!=typeof e)throw new Error(Oh(2));if("function"==typeof t&&"function"==typeof n||"function"==typeof n&&"function"==typeof arguments[3])throw new Error(Oh(0));if("function"==typeof t&&void 0===n&&(n=t,t=void 0),void 0!==n){if("function"!=typeof n)throw new Error(Oh(1));return n(Th)(e,t)}let r=e,a=t,o=new Map,i=o,s=0,l=!1;function c(){i===o&&(i=new Map,o.forEach((e,t)=>{i.set(t,e)}))}function u(){if(l)throw new Error(Oh(3));return a}function d(e){if("function"!=typeof e)throw new Error(Oh(4));if(l)throw new Error(Oh(5));let t=!0;c();const n=s++;return i.set(n,e),function(){if(t){if(l)throw new Error(Oh(6));t=!1,c(),i.delete(n),o=null}}}function p(e){if(!function(e){if("object"!=typeof e||null===e)return!1;let t=e;for(;null!==Object.getPrototypeOf(t);)t=Object.getPrototypeOf(t);return Object.getPrototypeOf(e)===t||null===Object.getPrototypeOf(e)}(e))throw new Error(Oh(7));if(void 0===e.type)throw new Error(Oh(8));if("string"!=typeof e.type)throw new Error(Oh(17));if(l)throw new Error(Oh(9));try{l=!0,a=r(a,e)}finally{l=!1}return(o=i).forEach(e=>{e()}),e}return p({type:Ih.INIT}),{dispatch:p,subscribe:d,getState:u,replaceReducer:function(e){if("function"!=typeof e)throw new Error(Oh(10));r=e,p({type:Ih.REPLACE})},[Ph]:function(){const e=d;return{subscribe(t){if("object"!=typeof t||null===t)throw new Error(Oh(11));function n(){const e=t;e.next&&e.next(u())}return n(),{unsubscribe:e(n)}},[Ph](){return this}}}}}function _h(e,t){return function(...n){return t(e.apply(this,n))}}function Nh(e,t){if("function"==typeof e)return _h(e,t);if("object"!=typeof e||null===e)throw new Error(Oh(16));const n={};for(const r in e){const a=e[r];"function"==typeof a&&(n[r]=_h(a,t))}return n}function Lh(...e){return 0===e.length?e=>e:1===e.length?e[0]:e.reduce((e,t)=>(...n)=>e(t(...n)))}n(418);var Dh=c.version.startsWith("19"),Bh=Symbol.for(Dh?"react.transitional.element":"react.element"),Fh=Symbol.for("react.portal"),zh=Symbol.for("react.fragment"),jh=Symbol.for("react.strict_mode"),Hh=Symbol.for("react.profiler"),Vh=Symbol.for("react.consumer"),Gh=Symbol.for("react.context"),qh=Symbol.for("react.forward_ref"),Uh=Symbol.for("react.suspense"),Wh=Symbol.for("react.suspense_list"),Qh=Symbol.for("react.memo"),Kh=Symbol.for("react.lazy"),Zh=qh,Jh=Qh;function Xh(e,t,n,r,{areStatesEqual:a,areOwnPropsEqual:o,areStatePropsEqual:i}){let s,l,c,u,d,p=!1;return function(f,m){return p?function(p,f){const m=!o(f,l),h=!a(p,s,f,l);return s=p,l=f,m&&h?(c=e(s,l),t.dependsOnOwnProps&&(u=t(r,l)),d=n(c,u,l),d):m?(e.dependsOnOwnProps&&(c=e(s,l)),t.dependsOnOwnProps&&(u=t(r,l)),d=n(c,u,l),d):h?function(){const t=e(s,l),r=!i(t,c);return c=t,r&&(d=n(c,u,l)),d}():d}(f,m):(s=f,l=m,c=e(s,l),u=t(r,l),d=n(c,u,l),p=!0,d)}}function Yh(e){return function(t){const n=e(t);function r(){return n}return r.dependsOnOwnProps=!1,r}}function $h(e){return e.dependsOnOwnProps?Boolean(e.dependsOnOwnProps):1!==e.length}function eg(e,t){return function(t,{displayName:n}){const r=function(e,t){return r.dependsOnOwnProps?r.mapToProps(e,t):r.mapToProps(e,void 0)};return r.dependsOnOwnProps=!0,r.mapToProps=function(t,n){r.mapToProps=e,r.dependsOnOwnProps=$h(e);let a=r(t,n);return"function"==typeof a&&(r.mapToProps=a,r.dependsOnOwnProps=$h(a),a=r(t,n)),a},r}}function tg(e,t){return(n,r)=>{throw new Error(`Invalid value of type ${typeof e} for ${t} argument when connecting component ${r.wrappedComponentName}.`)}}function ng(e,t,n){return{...n,...e,...t}}var rg={notify(){},get:()=>[]};function ag(e,t){let n,r=rg,a=0,o=!1;function i(){c.onStateChange&&c.onStateChange()}function s(){a++,n||(n=t?t.addNestedSub(i):e.subscribe(i),r=function(){let e=null,t=null;return{clear(){e=null,t=null},notify(){(()=>{let t=e;for(;t;)t.callback(),t=t.next})()},get(){const t=[];let n=e;for(;n;)t.push(n),n=n.next;return t},subscribe(n){let r=!0;const a=t={callback:n,next:null,prev:t};return a.prev?a.prev.next=a:e=a,function(){r&&null!==e&&(r=!1,a.next?a.next.prev=a.prev:t=a.prev,a.prev?a.prev.next=a.next:e=a.next)}}}}())}function l(){a--,n&&0===a&&(n(),n=void 0,r.clear(),r=rg)}const c={addNestedSub:function(e){s();const t=r.subscribe(e);let n=!1;return()=>{n||(n=!0,t(),l())}},notifyNestedSubs:function(){r.notify()},handleChangeWrapper:i,isSubscribed:function(){return o},trySubscribe:function(){o||(o=!0,s())},tryUnsubscribe:function(){o&&(o=!1,l())},getListeners:()=>r};return c}var og=(()=>!("undefined"==typeof window||void 0===window.document||void 0===window.document.createElement))(),ig=(()=>"undefined"!=typeof navigator&&"ReactNative"===navigator.product)(),sg=(()=>og||ig?c.useLayoutEffect:c.useEffect)();function lg(e,t){return e===t?0!==e||0!==t||1/e==1/t:e!=e&&t!=t}function cg(e,t){if(lg(e,t))return!0;if("object"!=typeof e||null===e||"object"!=typeof t||null===t)return!1;const n=Object.keys(e),r=Object.keys(t);if(n.length!==r.length)return!1;for(let r=0;r<n.length;r++)if(!Object.prototype.hasOwnProperty.call(t,n[r])||!lg(e[n[r]],t[n[r]]))return!1;return!0}var ug={childContextTypes:!0,contextType:!0,contextTypes:!0,defaultProps:!0,displayName:!0,getDefaultProps:!0,getDerivedStateFromError:!0,getDerivedStateFromProps:!0,mixins:!0,propTypes:!0,type:!0},dg={name:!0,length:!0,prototype:!0,caller:!0,callee:!0,arguments:!0,arity:!0},pg={$$typeof:!0,compare:!0,defaultProps:!0,displayName:!0,propTypes:!0,type:!0},fg={[Zh]:{$$typeof:!0,render:!0,defaultProps:!0,displayName:!0,propTypes:!0},[Jh]:pg};function mg(e){return function(e){if("object"==typeof e&&null!==e){const{$$typeof:t}=e;switch(t){case Bh:switch(e=e.type){case zh:case Hh:case jh:case Uh:case Wh:return e;default:switch(e=e&&e.$$typeof){case Gh:case qh:case Kh:case Qh:case Vh:return e;default:return t}}case Fh:return t}}}(e)===Qh?pg:fg[e.$$typeof]||ug}var hg=Object.defineProperty,gg=Object.getOwnPropertyNames,vg=Object.getOwnPropertySymbols,bg=Object.getOwnPropertyDescriptor,yg=Object.getPrototypeOf,wg=Object.prototype;function Eg(e,t){if("string"!=typeof t){if(wg){const n=yg(t);n&&n!==wg&&Eg(e,n)}let n=gg(t);vg&&(n=n.concat(vg(t)));const r=mg(e),a=mg(t);for(let o=0;o<n.length;++o){const i=n[o];if(!(dg[i]||a&&a[i]||r&&r[i])){const n=bg(t,i);try{hg(e,i,n)}catch(e){}}}}return e}var Rg=Symbol.for("react-redux-context"),xg="undefined"!=typeof globalThis?globalThis:{};function Ag(){if(!c.createContext)return{};const e=xg[Rg]??=new Map;let t=e.get(c.createContext);return t||(t=c.createContext(null),e.set(c.createContext,t)),t}var Cg=Ag(),Sg=[null,null];function kg(e,t,n,r,a,o){e.current=r,n.current=!1,a.current&&(a.current=null,o())}function Og(e,t){return e===t}var Pg=function(e,t,n,{pure:r,areStatesEqual:a=Og,areOwnPropsEqual:o=cg,areStatePropsEqual:i=cg,areMergedPropsEqual:s=cg,forwardRef:l=!1,context:u=Cg}={}){const d=u,p=function(e){return e?"function"==typeof e?eg(e):tg(e,"mapStateToProps"):Yh(()=>({}))}(e),f=function(e){return e&&"object"==typeof e?Yh(t=>function(e,t){const n={};for(const r in e){const a=e[r];"function"==typeof a&&(n[r]=(...e)=>t(a(...e)))}return n}(e,t)):e?"function"==typeof e?eg(e):tg(e,"mapDispatchToProps"):Yh(e=>({dispatch:e}))}(t),m=function(e){return e?"function"==typeof e?function(e){return function(t,{displayName:n,areMergedPropsEqual:r}){let a,o=!1;return function(t,n,i){const s=e(t,n,i);return o?r(s,a)||(a=s):(o=!0,a=s),a}}}(e):tg(e,"mergeProps"):()=>ng}(n),h=Boolean(e);return e=>{const t=e.displayName||e.name||"Component",n=`Connect(${t})`,r={shouldHandleStateChanges:h,displayName:n,wrappedComponentName:t,WrappedComponent:e,initMapStateToProps:p,initMapDispatchToProps:f,initMergeProps:m,areStatesEqual:a,areStatePropsEqual:i,areOwnPropsEqual:o,areMergedPropsEqual:s};function u(t){const[n,a,o]=c.useMemo(()=>{const{reactReduxForwardedRef:e,...n}=t;return[t.context,e,n]},[t]),i=c.useMemo(()=>d,[n,d]),s=c.useContext(i),l=Boolean(t.store)&&Boolean(t.store.getState)&&Boolean(t.store.dispatch),u=Boolean(s)&&Boolean(s.store),p=l?t.store:s.store,f=u?s.getServerState:p.getState,m=c.useMemo(()=>function(e,{initMapStateToProps:t,initMapDispatchToProps:n,initMergeProps:r,...a}){return Xh(t(e,a),n(e,a),r(e,a),e,a)}(p.dispatch,r),[p]),[g,v]=c.useMemo(()=>{if(!h)return Sg;const e=ag(p,l?void 0:s.subscription),t=e.notifyNestedSubs.bind(e);return[e,t]},[p,l,s]),b=c.useMemo(()=>l?s:{...s,subscription:g},[l,s,g]),y=c.useRef(void 0),w=c.useRef(o),E=c.useRef(void 0),R=c.useRef(!1),x=c.useRef(!1),A=c.useRef(void 0);sg(()=>(x.current=!0,()=>{x.current=!1}),[]);const C=c.useMemo(()=>()=>E.current&&o===w.current?E.current:m(p.getState(),o),[p,o]),S=c.useMemo(()=>e=>g?function(e,t,n,r,a,o,i,s,l,c,u){if(!e)return()=>{};let d=!1,p=null;const f=()=>{if(d||!s.current)return;const e=t.getState();let n,f;try{n=r(e,a.current)}catch(e){f=e,p=e}f||(p=null),n===o.current?i.current||c():(o.current=n,l.current=n,i.current=!0,u())};return n.onStateChange=f,n.trySubscribe(),f(),()=>{if(d=!0,n.tryUnsubscribe(),n.onStateChange=null,p)throw p}}(h,p,g,m,w,y,R,x,E,v,e):()=>{},[g]);var k,O;let P;k=kg,O=[w,y,R,o,E,v],sg(()=>k(...O),void 0);try{P=c.useSyncExternalStore(S,C,f?()=>m(f(),o):C)}catch(e){throw A.current&&(e.message+=`\nThe error may be correlated with this previous error:\n${A.current.stack}\n\n`),e}sg(()=>{A.current=void 0,E.current=void 0,y.current=P});const M=c.useMemo(()=>c.createElement(e,{...P,ref:a}),[a,e,P]);return c.useMemo(()=>h?c.createElement(i.Provider,{value:b},M):M,[i,M,b])}const g=c.memo(u);if(g.WrappedComponent=e,g.displayName=u.displayName=n,l){const t=c.forwardRef(function(e,t){return c.createElement(g,{...e,reactReduxForwardedRef:t})});return t.displayName=n,t.WrappedComponent=e,Eg(t,e)}return Eg(g,e)}},Mg=function(e){const{children:t,context:n,serverState:r,store:a}=e,o=c.useMemo(()=>{const e=ag(a);return{store:a,subscription:e,getServerState:r?()=>r:void 0}},[a,r]),i=c.useMemo(()=>a.getState(),[a]);sg(()=>{const{subscription:e}=o;return e.onStateChange=e.notifyNestedSubs,e.trySubscribe(),i!==a.getState()&&e.notifyNestedSubs(),()=>{e.tryUnsubscribe(),e.onStateChange=void 0}},[o,i]);const s=n||Cg;return c.createElement(s.Provider,{value:o},t)},Ig=function(e){var t=e.top,n=e.right,r=e.bottom,a=e.left;return{top:t,right:n,bottom:r,left:a,width:n-a,height:r-t,x:a,y:t,center:{x:(n+a)/2,y:(r+t)/2}}},Tg=function(e,t){return{top:e.top-t.top,left:e.left-t.left,bottom:e.bottom+t.bottom,right:e.right+t.right}},_g=function(e,t){return{top:e.top+t.top,left:e.left+t.left,bottom:e.bottom-t.bottom,right:e.right-t.right}},Ng={top:0,right:0,bottom:0,left:0},Lg=function(e){var t=e.borderBox,n=e.margin,r=void 0===n?Ng:n,a=e.border,o=void 0===a?Ng:a,i=e.padding,s=void 0===i?Ng:i,l=Ig(Tg(t,r)),c=Ig(_g(t,o)),u=Ig(_g(c,s));return{marginBox:l,borderBox:Ig(t),paddingBox:c,contentBox:u,margin:r,border:o,padding:s}},Dg=function(e){var t=e.slice(0,-2);if("px"!==e.slice(-2))return 0;var n=Number(t);return isNaN(n)&&function(){throw new Error("Invariant failed")}(),n},Bg=function(e,t){var n,r,a=e.borderBox,o=e.border,i=e.margin,s=e.padding,l=(r=t,{top:(n=a).top+r.y,left:n.left+r.x,bottom:n.bottom+r.y,right:n.right+r.x});return Lg({borderBox:l,border:o,margin:i,padding:s})},Fg=function(e,t){return void 0===t&&(t={x:window.pageXOffset,y:window.pageYOffset}),Bg(e,t)},zg=function(e,t){var n={top:Dg(t.marginTop),right:Dg(t.marginRight),bottom:Dg(t.marginBottom),left:Dg(t.marginLeft)},r={top:Dg(t.paddingTop),right:Dg(t.paddingRight),bottom:Dg(t.paddingBottom),left:Dg(t.paddingLeft)},a={top:Dg(t.borderTopWidth),right:Dg(t.borderRightWidth),bottom:Dg(t.borderBottomWidth),left:Dg(t.borderLeftWidth)};return Lg({borderBox:e,margin:n,padding:r,border:a})},jg=function(e){var t=e.getBoundingClientRect(),n=window.getComputedStyle(e);return zg(t,n)};const Hg=function(e){var t=[],n=null,r=function(){for(var r=arguments.length,a=new Array(r),o=0;o<r;o++)a[o]=arguments[o];t=a,n||(n=requestAnimationFrame(function(){n=null,e.apply(void 0,t)}))};return r.cancel=function(){n&&(cancelAnimationFrame(n),n=null)},r};function Vg(e,t){}function Gg(){}function qg(e,t,n){const r=t.map(t=>{const r=(a=n,o=t.options,{...a,...o});var a,o;return e.addEventListener(t.eventName,t.fn,r),function(){e.removeEventListener(t.eventName,t.fn,r)}});return function(){r.forEach(e=>{e()})}}Vg.bind(null,"warn"),Vg.bind(null,"error");class Ug extends Error{}function Wg(e,t){throw new Ug("Invariant failed")}Ug.prototype.toString=function(){return this.message};class Qg extends u().Component{constructor(...e){super(...e),this.callbacks=null,this.unbind=Gg,this.onWindowError=e=>{const t=this.getCallbacks();t.isDragging()&&t.tryAbort(),e.error instanceof Ug&&e.preventDefault()},this.getCallbacks=()=>{if(!this.callbacks)throw new Error("Unable to find AppCallbacks in <ErrorBoundary/>");return this.callbacks},this.setCallbacks=e=>{this.callbacks=e}}componentDidMount(){this.unbind=qg(window,[{eventName:"error",fn:this.onWindowError}])}componentDidCatch(e){if(!(e instanceof Ug))throw e;this.setState({})}componentWillUnmount(){this.unbind()}render(){return this.props.children(this.setCallbacks)}}const Kg=e=>e+1,Zg=(e,t)=>{const n=e.droppableId===t.droppableId,r=Kg(e.index),a=Kg(t.index);return n?`\n      You have moved the item from position ${r}\n      to position ${a}\n    `:`\n    You have moved the item from position ${r}\n    in list ${e.droppableId}\n    to list ${t.droppableId}\n    in position ${a}\n  `},Jg=(e,t,n)=>t.droppableId===n.droppableId?`\n      The item ${e}\n      has been combined with ${n.draggableId}`:`\n      The item ${e}\n      in list ${t.droppableId}\n      has been combined with ${n.draggableId}\n      in list ${n.droppableId}\n    `,Xg=e=>`\n  The item has returned to its starting position\n  of ${Kg(e.index)}\n`,Yg="\n  Press space bar to start a drag.\n  When dragging you can use the arrow keys to move the item around and escape to cancel.\n  Some screen readers may require you to be in focus mode or to use your pass through key\n",$g=e=>`\n  You have lifted an item in position ${Kg(e.source.index)}\n`,ev=e=>{const t=e.destination;if(t)return Zg(e.source,t);const n=e.combine;return n?Jg(e.draggableId,e.source,n):"You are over an area that cannot be dropped on"},tv=e=>{if("CANCEL"===e.reason)return`\n      Movement cancelled.\n      ${Xg(e.source)}\n    `;const t=e.destination,n=e.combine;return t?`\n      You have dropped the item.\n      ${Zg(e.source,t)}\n    `:n?`\n      You have dropped the item.\n      ${Jg(e.draggableId,e.source,n)}\n    `:`\n    The item has been dropped while not over a drop area.\n    ${Xg(e.source)}\n  `};function nv(e,t){return e===t||!(!Number.isNaN(e)||!Number.isNaN(t))}function rv(e,t){if(e.length!==t.length)return!1;for(let n=0;n<e.length;n++)if(!nv(e[n],t[n]))return!1;return!0}function av(e,t){const n=(0,c.useState)(()=>({inputs:t,result:e()}))[0],r=(0,c.useRef)(!0),a=(0,c.useRef)(n),o=r.current||Boolean(t&&a.current.inputs&&rv(t,a.current.inputs))?a.current:{inputs:t,result:e()};return(0,c.useEffect)(()=>{r.current=!1,a.current=o},[o]),o.result}function ov(e,t){return av(()=>e,t)}const iv={x:0,y:0},sv=(e,t)=>({x:e.x+t.x,y:e.y+t.y}),lv=(e,t)=>({x:e.x-t.x,y:e.y-t.y}),cv=(e,t)=>e.x===t.x&&e.y===t.y,uv=e=>({x:0!==e.x?-e.x:0,y:0!==e.y?-e.y:0}),dv=(e,t,n=0)=>"x"===e?{x:t,y:n}:{x:n,y:t},pv=(e,t)=>Math.sqrt((t.x-e.x)**2+(t.y-e.y)**2),fv=(e,t)=>Math.min(...t.map(t=>pv(e,t))),mv=e=>t=>({x:e(t.x),y:e(t.y)}),hv=(e,t)=>({top:e.top+t.y,left:e.left+t.x,bottom:e.bottom+t.y,right:e.right+t.x}),gv=e=>[{x:e.left,y:e.top},{x:e.right,y:e.top},{x:e.left,y:e.bottom},{x:e.right,y:e.bottom}],vv=(e,t)=>t&&t.shouldClipSubject?((e,t)=>{const n=Ig({top:Math.max(t.top,e.top),right:Math.min(t.right,e.right),bottom:Math.min(t.bottom,e.bottom),left:Math.max(t.left,e.left)});return n.width<=0||n.height<=0?null:n})(t.pageMarginBox,e):Ig(e);var bv=({page:e,withPlaceholder:t,axis:n,frame:r})=>{const a=((e,t)=>t?hv(e,t.scroll.diff.displacement):e)(e.marginBox,r),o=((e,t,n)=>n&&n.increasedBy?{...e,[t.end]:e[t.end]+n.increasedBy[t.line]}:e)(a,n,t);return{page:e,withPlaceholder:t,active:vv(o,r)}},yv=(e,t)=>{e.frame||Wg();const n=e.frame,r=lv(t,n.scroll.initial),a=uv(r),o={...n,scroll:{initial:n.scroll.initial,current:t,diff:{value:r,displacement:a},max:n.scroll.max}},i=bv({page:e.subject.page,withPlaceholder:e.subject.withPlaceholder,axis:e.axis,frame:o});return{...e,frame:o,subject:i}};function wv(e,t=rv){let n=null;function r(...r){if(n&&n.lastThis===this&&t(r,n.lastArgs))return n.lastResult;const a=e.apply(this,r);return n={lastResult:a,lastArgs:r,lastThis:this},a}return r.clear=function(){n=null},r}const Ev=wv(e=>e.reduce((e,t)=>(e[t.descriptor.id]=t,e),{})),Rv=wv(e=>e.reduce((e,t)=>(e[t.descriptor.id]=t,e),{})),xv=wv(e=>Object.values(e)),Av=wv(e=>Object.values(e));var Cv=wv((e,t)=>{const n=Av(t).filter(t=>e===t.descriptor.droppableId).sort((e,t)=>e.descriptor.index-t.descriptor.index);return n});function Sv(e){return e.at&&"REORDER"===e.at.type?e.at.destination:null}function kv(e){return e.at&&"COMBINE"===e.at.type?e.at.combine:null}var Ov=wv((e,t)=>t.filter(t=>t.descriptor.id!==e.descriptor.id)),Pv=(e,t)=>e.descriptor.droppableId===t.descriptor.id;const Mv={point:iv,value:0},Iv={invisible:{},visible:{},all:[]},Tv={displaced:Iv,displacedBy:Mv,at:null};var _v=(e,t)=>n=>e<=n&&n<=t,Nv=e=>{const t=_v(e.top,e.bottom),n=_v(e.left,e.right);return r=>{if(t(r.top)&&t(r.bottom)&&n(r.left)&&n(r.right))return!0;const a=t(r.top)||t(r.bottom),o=n(r.left)||n(r.right);if(a&&o)return!0;const i=r.top<e.top&&r.bottom>e.bottom,s=r.left<e.left&&r.right>e.right;return!(!i||!s)||(i&&o||s&&a)}},Lv=e=>{const t=_v(e.top,e.bottom),n=_v(e.left,e.right);return e=>t(e.top)&&t(e.bottom)&&n(e.left)&&n(e.right)};const Dv={direction:"vertical",line:"y",crossAxisLine:"x",start:"top",end:"bottom",size:"height",crossAxisStart:"left",crossAxisEnd:"right",crossAxisSize:"width"},Bv={direction:"horizontal",line:"x",crossAxisLine:"y",start:"left",end:"right",size:"width",crossAxisStart:"top",crossAxisEnd:"bottom",crossAxisSize:"height"},Fv=({target:e,destination:t,viewport:n,withDroppableDisplacement:r,isVisibleThroughFrameFn:a})=>{const o=r?((e,t)=>{const n=t.frame?t.frame.scroll.diff.displacement:iv;return hv(e,n)})(e,t):e;return((e,t,n)=>!!t.subject.active&&n(t.subject.active)(e))(o,t,a)&&((e,t,n)=>n(t)(e))(o,n,a)},zv=e=>Fv({...e,isVisibleThroughFrameFn:Lv});function jv({afterDragging:e,destination:t,displacedBy:n,viewport:r,forceShouldAnimate:a,last:o}){return e.reduce(function(e,i){const s=function(e,t){const n=e.page.marginBox,r={top:t.point.y,right:0,bottom:0,left:t.point.x};return Ig(Tg(n,r))}(i,n),l=i.descriptor.id;var c;if(e.all.push(l),c={target:s,destination:t,viewport:r,withDroppableDisplacement:!0},!Fv({...c,isVisibleThroughFrameFn:Nv}))return e.invisible[i.descriptor.id]=!0,e;const u=((e,t,n)=>{if("boolean"==typeof n)return n;if(!t)return!0;const{invisible:r,visible:a}=t;if(r[e])return!1;const o=a[e];return!o||o.shouldAnimate})(l,o,a),d={draggableId:l,shouldAnimate:u};return e.visible[l]=d,e},{all:[],visible:{},invisible:{}})}function Hv({insideDestination:e,inHomeList:t,displacedBy:n,destination:r}){const a=function(e,t){if(!e.length)return 0;const n=e[e.length-1].descriptor.index;return t.inHomeList?n:n+1}(e,{inHomeList:t});return{displaced:Iv,displacedBy:n,at:{type:"REORDER",destination:{droppableId:r.descriptor.id,index:a}}}}function Vv({draggable:e,insideDestination:t,destination:n,viewport:r,displacedBy:a,last:o,index:i,forceShouldAnimate:s}){const l=Pv(e,n);if(null==i)return Hv({insideDestination:t,inHomeList:l,displacedBy:a,destination:n});const c=t.find(e=>e.descriptor.index===i);if(!c)return Hv({insideDestination:t,inHomeList:l,displacedBy:a,destination:n});const u=Ov(e,t),d=t.indexOf(c);return{displaced:jv({afterDragging:u.slice(d),destination:n,displacedBy:a,last:o,viewport:r.frame,forceShouldAnimate:s}),displacedBy:a,at:{type:"REORDER",destination:{droppableId:n.descriptor.id,index:i}}}}function Gv(e,t){return Boolean(t.effected[e])}const qv=(e,t)=>t.margin[e.start]+t.borderBox[e.size]/2,Uv=(e,t,n)=>t[e.crossAxisStart]+n.margin[e.crossAxisStart]+n.borderBox[e.crossAxisSize]/2,Wv=({axis:e,moveRelativeTo:t,isMoving:n})=>dv(e.line,t.marginBox[e.end]+qv(e,n),Uv(e,t.marginBox,n)),Qv=({axis:e,moveRelativeTo:t,isMoving:n})=>dv(e.line,t.marginBox[e.start]-((e,t)=>t.margin[e.end]+t.borderBox[e.size]/2)(e,n),Uv(e,t.marginBox,n));var Kv=(e,t)=>{const n=e.frame;return n?sv(t,n.scroll.diff.displacement):t},Zv=e=>{const t=(({impact:e,draggable:t,droppable:n,draggables:r,afterCritical:a})=>{const o=t.page.borderBox.center,i=e.at;return n&&i?"REORDER"===i.type?(({impact:e,draggable:t,draggables:n,droppable:r,afterCritical:a})=>{const o=Cv(r.descriptor.id,n),i=t.page,s=r.axis;if(!o.length)return(({axis:e,moveInto:t,isMoving:n})=>dv(e.line,t.contentBox[e.start]+qv(e,n),Uv(e,t.contentBox,n)))({axis:s,moveInto:r.page,isMoving:i});const{displaced:l,displacedBy:c}=e,u=l.all[0];if(u){const e=n[u];if(Gv(u,a))return Qv({axis:s,moveRelativeTo:e.page,isMoving:i});const t=Bg(e.page,c.point);return Qv({axis:s,moveRelativeTo:t,isMoving:i})}const d=o[o.length-1];if(d.descriptor.id===t.descriptor.id)return i.borderBox.center;if(Gv(d.descriptor.id,a)){const e=Bg(d.page,uv(a.displacedBy.point));return Wv({axis:s,moveRelativeTo:e,isMoving:i})}return Wv({axis:s,moveRelativeTo:d.page,isMoving:i})})({impact:e,draggable:t,draggables:r,droppable:n,afterCritical:a}):(({afterCritical:e,impact:t,draggables:n})=>{const r=kv(t);r||Wg();const a=r.draggableId,o=n[a].page.borderBox.center,i=(({displaced:e,afterCritical:t,combineWith:n,displacedBy:r})=>{const a=Boolean(e.visible[n]||e.invisible[n]);return Gv(n,t)?a?iv:uv(r.point):a?r.point:iv})({displaced:t.displaced,afterCritical:e,combineWith:a,displacedBy:t.displacedBy});return sv(o,i)})({impact:e,draggables:r,afterCritical:a}):o})(e),n=e.droppable;return n?Kv(n,t):t},Jv=(e,t)=>{const n=lv(t,e.scroll.initial),r=uv(n);return{frame:Ig({top:t.y,bottom:t.y+e.frame.height,left:t.x,right:t.x+e.frame.width}),scroll:{initial:e.scroll.initial,max:e.scroll.max,current:t,diff:{value:n,displacement:r}}}};function Xv(e,t){return e.map(e=>t[e])}var Yv=({pageBorderBoxCenter:e,draggable:t,viewport:n})=>{const r=((e,t)=>sv(e.scroll.diff.displacement,t))(n,e),a=lv(r,t.page.borderBox.center);return sv(t.client.borderBox.center,a)},$v=({draggable:e,destination:t,newPageBorderBoxCenter:n,viewport:r,withDroppableDisplacement:a,onlyOnMainAxis:o=!1})=>{const i=lv(n,e.page.borderBox.center),s={target:hv(e.page.borderBox,i),destination:t,withDroppableDisplacement:a,viewport:r};return o?(e=>{return Fv({...e,isVisibleThroughFrameFn:(t=e.destination.axis,e=>{const n=_v(e.top,e.bottom),r=_v(e.left,e.right);return e=>t===Dv?n(e.top)&&n(e.bottom):r(e.left)&&r(e.right)})});var t})(s):zv(s)},eb=({isMovingForward:e,draggable:t,destination:n,draggables:r,previousImpact:a,viewport:o,previousPageBorderBoxCenter:i,previousClientSelection:s,afterCritical:l})=>{if(!n.isEnabled)return null;const c=Cv(n.descriptor.id,r),u=Pv(t,n),d=(({isMovingForward:e,draggable:t,destination:n,insideDestination:r,previousImpact:a})=>{if(!n.isCombineEnabled)return null;if(!Sv(a))return null;function o(e){const t={type:"COMBINE",combine:{draggableId:e,droppableId:n.descriptor.id}};return{...a,at:t}}const i=a.displaced.all,s=i.length?i[0]:null;if(e)return s?o(s):null;const l=Ov(t,r);if(!s)return l.length?o(l[l.length-1].descriptor.id):null;const c=l.findIndex(e=>e.descriptor.id===s);-1===c&&Wg();const u=c-1;return u<0?null:o(l[u].descriptor.id)})({isMovingForward:e,draggable:t,destination:n,insideDestination:c,previousImpact:a})||(({isMovingForward:e,isInHomeList:t,draggable:n,draggables:r,destination:a,insideDestination:o,previousImpact:i,viewport:s,afterCritical:l})=>{const c=i.at;if(c||Wg(),"REORDER"===c.type){const r=(({isMovingForward:e,isInHomeList:t,insideDestination:n,location:r})=>{if(!n.length)return null;const a=r.index,o=e?a+1:a-1,i=n[0].descriptor.index,s=n[n.length-1].descriptor.index;return o<i||o>(t?s:s+1)?null:o})({isMovingForward:e,isInHomeList:t,location:c.destination,insideDestination:o});return null==r?null:Vv({draggable:n,insideDestination:o,destination:a,viewport:s,last:i.displaced,displacedBy:i.displacedBy,index:r})}const u=(({isMovingForward:e,destination:t,draggables:n,combine:r,afterCritical:a})=>{if(!t.isCombineEnabled)return null;const o=r.draggableId,i=n[o].descriptor.index;return Gv(o,a)?e?i:i-1:e?i+1:i})({isMovingForward:e,destination:a,displaced:i.displaced,draggables:r,combine:c.combine,afterCritical:l});return null==u?null:Vv({draggable:n,insideDestination:o,destination:a,viewport:s,last:i.displaced,displacedBy:i.displacedBy,index:u})})({isMovingForward:e,isInHomeList:u,draggable:t,draggables:r,destination:n,insideDestination:c,previousImpact:a,viewport:o,afterCritical:l});if(!d)return null;const p=Zv({impact:d,draggable:t,droppable:n,draggables:r,afterCritical:l});if($v({draggable:t,destination:n,newPageBorderBoxCenter:p,viewport:o.frame,withDroppableDisplacement:!1,onlyOnMainAxis:!0}))return{clientSelection:Yv({pageBorderBoxCenter:p,draggable:t,viewport:o}),impact:d,scrollJumpRequest:null};const f=lv(p,i),m=(({impact:e,viewport:t,destination:n,draggables:r,maxScrollChange:a})=>{const o=Jv(t,sv(t.scroll.current,a)),i=n.frame?yv(n,sv(n.frame.scroll.current,a)):n,s=e.displaced,l=jv({afterDragging:Xv(s.all,r),destination:n,displacedBy:e.displacedBy,viewport:o.frame,last:s,forceShouldAnimate:!1}),c=jv({afterDragging:Xv(s.all,r),destination:i,displacedBy:e.displacedBy,viewport:t.frame,last:s,forceShouldAnimate:!1}),u={},d={},p=[s,l,c];return s.all.forEach(e=>{const t=function(e,t){for(let n=0;n<t.length;n++){const r=t[n].visible[e];if(r)return r}return null}(e,p);t?d[e]=t:u[e]=!0}),{...e,displaced:{all:s.all,invisible:u,visible:d}}})({impact:d,viewport:o,destination:n,draggables:r,maxScrollChange:f});return{clientSelection:s,impact:m,scrollJumpRequest:f}};const tb=e=>{const t=e.subject.active;return t||Wg(),t},nb=(e,t)=>{const n=e.page.borderBox.center;return Gv(e.descriptor.id,t)?lv(n,t.displacedBy.point):n},rb=(e,t)=>{const n=e.page.borderBox;return Gv(e.descriptor.id,t)?hv(n,uv(t.displacedBy.point)):n};var ab=wv(function(e,t){const n=t[e.line];return{value:n,point:dv(e.line,n)}});const ob=(e,t)=>({...e,scroll:{...e.scroll,max:t}}),ib=(e,t,n)=>{const r=e.frame;Pv(t,e)&&Wg(),e.subject.withPlaceholder&&Wg();const a=ab(e.axis,t.displaceBy).point,o=((e,t,n)=>{const r=e.axis;if("virtual"===e.descriptor.mode)return dv(r.line,t[r.line]);const a=e.subject.page.contentBox[r.size],o=Cv(e.descriptor.id,n).reduce((e,t)=>e+t.client.marginBox[r.size],0)+t[r.line]-a;return o<=0?null:dv(r.line,o)})(e,a,n),i={placeholderSize:a,increasedBy:o,oldFrameMaxScroll:e.frame?e.frame.scroll.max:null};if(!r){const t=bv({page:e.subject.page,withPlaceholder:i,axis:e.axis,frame:e.frame});return{...e,subject:t}}const s=o?sv(r.scroll.max,o):r.scroll.max,l=ob(r,s),c=bv({page:e.subject.page,withPlaceholder:i,axis:e.axis,frame:l});return{...e,subject:c,frame:l}};var sb=e=>{const t=e.at;return t?"REORDER"===t.type?t.destination.droppableId:t.combine.droppableId:null},lb=({state:e,type:t})=>{const n=((e,t)=>{const n=sb(e);return n?t[n]:null})(e.impact,e.dimensions.droppables),r=Boolean(n),a=e.dimensions.droppables[e.critical.droppable.id],o=n||a,i=o.axis.direction,s="vertical"===i&&("MOVE_UP"===t||"MOVE_DOWN"===t)||"horizontal"===i&&("MOVE_LEFT"===t||"MOVE_RIGHT"===t);if(s&&!r)return null;const l="MOVE_DOWN"===t||"MOVE_RIGHT"===t,c=e.dimensions.draggables[e.critical.draggable.id],u=e.current.page.borderBoxCenter,{draggables:d,droppables:p}=e.dimensions;return s?eb({isMovingForward:l,previousPageBorderBoxCenter:u,draggable:c,destination:o,draggables:d,viewport:e.viewport,previousClientSelection:e.current.client.selection,previousImpact:e.impact,afterCritical:e.afterCritical}):(({isMovingForward:e,previousPageBorderBoxCenter:t,draggable:n,isOver:r,draggables:a,droppables:o,viewport:i,afterCritical:s})=>{const l=(({isMovingForward:e,pageBorderBoxCenter:t,source:n,droppables:r,viewport:a})=>{const o=n.subject.active;if(!o)return null;const i=n.axis,s=_v(o[i.start],o[i.end]),l=xv(r).filter(e=>e!==n).filter(e=>e.isEnabled).filter(e=>Boolean(e.subject.active)).filter(e=>Nv(a.frame)(tb(e))).filter(t=>{const n=tb(t);return e?o[i.crossAxisEnd]<n[i.crossAxisEnd]:n[i.crossAxisStart]<o[i.crossAxisStart]}).filter(e=>{const t=tb(e),n=_v(t[i.start],t[i.end]);return s(t[i.start])||s(t[i.end])||n(o[i.start])||n(o[i.end])}).sort((t,n)=>{const r=tb(t)[i.crossAxisStart],a=tb(n)[i.crossAxisStart];return e?r-a:a-r}).filter((e,t,n)=>tb(e)[i.crossAxisStart]===tb(n[0])[i.crossAxisStart]);if(!l.length)return null;if(1===l.length)return l[0];const c=l.filter(e=>_v(tb(e)[i.start],tb(e)[i.end])(t[i.line]));return 1===c.length?c[0]:c.length>1?c.sort((e,t)=>tb(e)[i.start]-tb(t)[i.start])[0]:l.sort((e,n)=>{const r=fv(t,gv(tb(e))),a=fv(t,gv(tb(n)));return r!==a?r-a:tb(e)[i.start]-tb(n)[i.start]})[0]})({isMovingForward:e,pageBorderBoxCenter:t,source:r,droppables:o,viewport:i});if(!l)return null;const c=Cv(l.descriptor.id,a),u=(({pageBorderBoxCenter:e,viewport:t,destination:n,insideDestination:r,afterCritical:a})=>{const o=r.filter(e=>zv({target:rb(e,a),destination:n,viewport:t.frame,withDroppableDisplacement:!0})).sort((t,r)=>{const o=pv(e,Kv(n,nb(t,a))),i=pv(e,Kv(n,nb(r,a)));return o<i?-1:i<o?1:t.descriptor.index-r.descriptor.index});return o[0]||null})({pageBorderBoxCenter:t,viewport:i,destination:l,insideDestination:c,afterCritical:s}),d=(({previousPageBorderBoxCenter:e,moveRelativeTo:t,insideDestination:n,draggable:r,draggables:a,destination:o,viewport:i,afterCritical:s})=>{if(!t){if(n.length)return null;const e={displaced:Iv,displacedBy:Mv,at:{type:"REORDER",destination:{droppableId:o.descriptor.id,index:0}}},t=Zv({impact:e,draggable:r,droppable:o,draggables:a,afterCritical:s}),l=Pv(r,o)?o:ib(o,r,a);return $v({draggable:r,destination:l,newPageBorderBoxCenter:t,viewport:i.frame,withDroppableDisplacement:!1,onlyOnMainAxis:!0})?e:null}const l=Boolean(e[o.axis.line]<=t.page.borderBox.center[o.axis.line]),c=(()=>{const e=t.descriptor.index;return t.descriptor.id===r.descriptor.id||l?e:e+1})(),u=ab(o.axis,r.displaceBy);return Vv({draggable:r,insideDestination:n,destination:o,viewport:i,displacedBy:u,last:Iv,index:c})})({previousPageBorderBoxCenter:t,destination:l,draggable:n,draggables:a,moveRelativeTo:u,insideDestination:c,viewport:i,afterCritical:s});if(!d)return null;const p=Zv({impact:d,draggable:n,droppable:l,draggables:a,afterCritical:s});return{clientSelection:Yv({pageBorderBoxCenter:p,draggable:n,viewport:i}),impact:d,scrollJumpRequest:null}})({isMovingForward:l,previousPageBorderBoxCenter:u,draggable:c,isOver:o,draggables:d,droppables:p,viewport:e.viewport,afterCritical:e.afterCritical})};function cb(e){return"DRAGGING"===e.phase||"COLLECTING"===e.phase}function ub(e){const t=_v(e.top,e.bottom),n=_v(e.left,e.right);return function(e){return t(e.y)&&n(e.x)}}const db=(e,t)=>Ig(hv(e,t));function pb({displaced:e,id:t}){return Boolean(e.visible[t]||e.invisible[t])}var fb=({pageOffset:e,draggable:t,draggables:n,droppables:r,previousImpact:a,viewport:o,afterCritical:i})=>{const s=db(t.page.borderBox,e),l=function({pageBorderBox:e,draggable:t,droppables:n}){const r=xv(n).filter(t=>{if(!t.isEnabled)return!1;const n=t.subject.active;if(!n)return!1;if(a=n,!((r=e).left<a.right&&r.right>a.left&&r.top<a.bottom&&r.bottom>a.top))return!1;var r,a;if(ub(n)(e.center))return!0;const o=t.axis,i=n.center[o.crossAxisLine],s=e[o.crossAxisStart],l=e[o.crossAxisEnd],c=_v(n[o.crossAxisStart],n[o.crossAxisEnd]),u=c(s),d=c(l);return!u&&!d||(u?s<i:l>i)});return r.length?1===r.length?r[0].descriptor.id:function({pageBorderBox:e,draggable:t,candidates:n}){const r=t.page.borderBox.center,a=n.map(t=>{const n=t.axis,a=dv(t.axis.line,e.center[n.line],t.page.borderBox.center[n.crossAxisLine]);return{id:t.descriptor.id,distance:pv(r,a)}}).sort((e,t)=>t.distance-e.distance);return a[0]?a[0].id:null}({pageBorderBox:e,draggable:t,candidates:r}):null}({pageBorderBox:s,draggable:t,droppables:r});if(!l)return Tv;const c=r[l],u=Cv(c.descriptor.id,n),d=((e,t)=>{const n=e.frame;return n?db(t,n.scroll.diff.value):t})(c,s);return(({draggable:e,pageBorderBoxWithDroppableScroll:t,previousImpact:n,destination:r,insideDestination:a,afterCritical:o})=>{if(!r.isCombineEnabled)return null;const i=r.axis,s=ab(r.axis,e.displaceBy),l=s.value,c=t[i.start],u=t[i.end],d=Ov(e,a).find(e=>{const t=e.descriptor.id,r=e.page.borderBox,a=r[i.size]/4,s=Gv(t,o),d=pb({displaced:n.displaced,id:t});return s?d?u>r[i.start]+a&&u<r[i.end]-a:c>r[i.start]-l+a&&c<r[i.end]-l-a:d?u>r[i.start]+l+a&&u<r[i.end]+l-a:c>r[i.start]+a&&c<r[i.end]-a});return d?{displacedBy:s,displaced:n.displaced,at:{type:"COMBINE",combine:{draggableId:d.descriptor.id,droppableId:r.descriptor.id}}}:null})({pageBorderBoxWithDroppableScroll:d,draggable:t,previousImpact:a,destination:c,insideDestination:u,afterCritical:i})||(({pageBorderBoxWithDroppableScroll:e,draggable:t,destination:n,insideDestination:r,last:a,viewport:o,afterCritical:i})=>{const s=n.axis,l=ab(n.axis,t.displaceBy),c=l.value,u=e[s.start],d=e[s.end],p=function({draggable:e,closest:t,inHomeList:n}){return t?n&&t.descriptor.index>e.descriptor.index?t.descriptor.index-1:t.descriptor.index:null}({draggable:t,closest:Ov(t,r).find(e=>{const t=e.descriptor.id,n=e.page.borderBox.center[s.line],r=Gv(t,i),o=pb({displaced:a,id:t});return r?o?d<=n:u<n-c:o?d<=n+c:u<n})||null,inHomeList:Pv(t,n)});return Vv({draggable:t,insideDestination:r,destination:n,viewport:o,last:a,displacedBy:l,index:p})})({pageBorderBoxWithDroppableScroll:d,draggable:t,destination:c,insideDestination:u,last:a.displaced,viewport:o,afterCritical:i})},mb=(e,t)=>({...e,[t.descriptor.id]:t});var hb=({state:e,clientSelection:t,dimensions:n,viewport:r,impact:a,scrollJumpRequest:o})=>{const i=r||e.viewport,s=n||e.dimensions,l=t||e.current.client.selection,c=lv(l,e.initial.client.selection),u={offset:c,selection:l,borderBoxCenter:sv(e.initial.client.borderBoxCenter,c)},d={selection:sv(u.selection,i.scroll.current),borderBoxCenter:sv(u.borderBoxCenter,i.scroll.current),offset:sv(u.offset,i.scroll.diff.value)},p={client:u,page:d};if("COLLECTING"===e.phase)return{...e,dimensions:s,viewport:i,current:p};const f=s.draggables[e.critical.draggable.id],m=a||fb({pageOffset:d.offset,draggable:f,draggables:s.draggables,droppables:s.droppables,previousImpact:e.impact,viewport:i,afterCritical:e.afterCritical}),h=(({draggable:e,draggables:t,droppables:n,previousImpact:r,impact:a})=>{const o=(({previousImpact:e,impact:t,droppables:n})=>{const r=sb(e),a=sb(t);if(!r)return n;if(r===a)return n;const o=n[r];if(!o.subject.withPlaceholder)return n;const i=(e=>{const t=e.subject.withPlaceholder;t||Wg();const n=e.frame;if(!n){const t=bv({page:e.subject.page,axis:e.axis,frame:null,withPlaceholder:null});return{...e,subject:t}}const r=t.oldFrameMaxScroll;r||Wg();const a=ob(n,r),o=bv({page:e.subject.page,axis:e.axis,frame:a,withPlaceholder:null});return{...e,subject:o,frame:a}})(o);return mb(n,i)})({previousImpact:r,impact:a,droppables:n}),i=sb(a);if(!i)return o;const s=n[i];if(Pv(e,s))return o;if(s.subject.withPlaceholder)return o;const l=ib(s,e,t);return mb(o,l)})({draggable:f,impact:m,previousImpact:e.impact,draggables:s.draggables,droppables:s.droppables});return{...e,current:p,dimensions:{draggables:s.draggables,droppables:h},impact:m,viewport:i,scrollJumpRequest:o||null,forceShouldAnimate:!o&&null}},gb=({impact:e,viewport:t,draggables:n,destination:r,forceShouldAnimate:a})=>{const o=e.displaced,i=function(e,t){return e.map(e=>t[e])}(o.all,n),s=jv({afterDragging:i,destination:r,displacedBy:e.displacedBy,viewport:t.frame,forceShouldAnimate:a,last:o});return{...e,displaced:s}},vb=({impact:e,draggable:t,droppable:n,draggables:r,viewport:a,afterCritical:o})=>{const i=Zv({impact:e,draggable:t,draggables:r,droppable:n,afterCritical:o});return Yv({pageBorderBoxCenter:i,draggable:t,viewport:a})},bb=({state:e,dimensions:t,viewport:n})=>{"SNAP"!==e.movementMode&&Wg();const r=e.impact,a=n||e.viewport,o=t||e.dimensions,{draggables:i,droppables:s}=o,l=i[e.critical.draggable.id],c=sb(r);c||Wg();const u=s[c],d=gb({impact:r,viewport:a,destination:u,draggables:i}),p=vb({impact:d,draggable:l,droppable:u,draggables:i,viewport:a,afterCritical:e.afterCritical});return hb({impact:d,clientSelection:p,state:e,dimensions:o,viewport:a})},yb=({draggable:e,home:t,draggables:n,viewport:r})=>{const a=ab(t.axis,e.displaceBy),o=Cv(t.descriptor.id,n),i=o.indexOf(e);-1===i&&Wg();const s=o.slice(i+1),l=s.reduce((e,t)=>(e[t.descriptor.id]=!0,e),{}),c={inVirtualList:"virtual"===t.descriptor.mode,displacedBy:a,effected:l};var u;return{impact:{displaced:jv({afterDragging:s,destination:t,displacedBy:a,last:null,viewport:r.frame,forceShouldAnimate:!1}),displacedBy:a,at:{type:"REORDER",destination:(u=e.descriptor,{index:u.index,droppableId:u.droppableId})}},afterCritical:c}};const wb=e=>"SNAP"===e.movementMode,Eb=(e,t,n)=>{const r=((e,t)=>({draggables:e.draggables,droppables:mb(e.droppables,t)}))(e.dimensions,t);return!wb(e)||n?hb({state:e,dimensions:r}):bb({state:e,dimensions:r})};function Rb(e){return e.isDragging&&"SNAP"===e.movementMode?{...e,scrollJumpRequest:null}:e}const xb={phase:"IDLE",completed:null,shouldFlush:!1};var Ab=(e=xb,t)=>{if("FLUSH"===t.type)return{...xb,shouldFlush:!0};if("INITIAL_PUBLISH"===t.type){"IDLE"!==e.phase&&Wg();const{critical:n,clientSelection:r,viewport:a,dimensions:o,movementMode:i}=t.payload,s=o.draggables[n.draggable.id],l=o.droppables[n.droppable.id],c={selection:r,borderBoxCenter:s.client.borderBox.center,offset:iv},u={client:c,page:{selection:sv(c.selection,a.scroll.initial),borderBoxCenter:sv(c.selection,a.scroll.initial),offset:sv(c.selection,a.scroll.diff.value)}},d=xv(o.droppables).every(e=>!e.isFixedOnPage),{impact:p,afterCritical:f}=yb({draggable:s,home:l,draggables:o.draggables,viewport:a});return{phase:"DRAGGING",isDragging:!0,critical:n,movementMode:i,dimensions:o,initial:u,current:u,isWindowScrollAllowed:d,impact:p,afterCritical:f,onLiftImpact:p,viewport:a,scrollJumpRequest:null,forceShouldAnimate:null}}if("COLLECTION_STARTING"===t.type)return"COLLECTING"===e.phase||"DROP_PENDING"===e.phase?e:("DRAGGING"!==e.phase&&Wg(),{...e,phase:"COLLECTING"});if("PUBLISH_WHILE_DRAGGING"===t.type)return"COLLECTING"!==e.phase&&"DROP_PENDING"!==e.phase&&Wg(),(({state:e,published:t})=>{const n=t.modified.map(t=>{const n=e.dimensions.droppables[t.droppableId];return yv(n,t.scroll)}),r={...e.dimensions.droppables,...Ev(n)},a=Rv((({additions:e,updatedDroppables:t,viewport:n})=>{const r=n.scroll.diff.value;return e.map(e=>{const a=e.descriptor.droppableId,o=(e=>{const t=e.frame;return t||Wg(),t})(t[a]),i=o.scroll.diff.value,s=(({draggable:e,offset:t,initialWindowScroll:n})=>{const r=Bg(e.client,t),a=Fg(r,n);return{...e,placeholder:{...e.placeholder,client:r},client:r,page:a}})({draggable:e,offset:sv(r,i),initialWindowScroll:n.scroll.initial});return s})})({additions:t.additions,updatedDroppables:r,viewport:e.viewport})),o={...e.dimensions.draggables,...a};t.removals.forEach(e=>{delete o[e]});const i={droppables:r,draggables:o},s=sb(e.impact),l=s?i.droppables[s]:null,c=i.draggables[e.critical.draggable.id],u=i.droppables[e.critical.droppable.id],{impact:d,afterCritical:p}=yb({draggable:c,home:u,draggables:o,viewport:e.viewport}),f=l&&l.isCombineEnabled?e.impact:d,m=fb({pageOffset:e.current.page.offset,draggable:i.draggables[e.critical.draggable.id],draggables:i.draggables,droppables:i.droppables,previousImpact:f,viewport:e.viewport,afterCritical:p}),h={...e,phase:"DRAGGING",impact:m,onLiftImpact:d,dimensions:i,afterCritical:p,forceShouldAnimate:!1};return"COLLECTING"===e.phase?h:{...h,phase:"DROP_PENDING",reason:e.reason,isWaiting:!1}})({state:e,published:t.payload});if("MOVE"===t.type){if("DROP_PENDING"===e.phase)return e;cb(e)||Wg();const{client:n}=t.payload;return cv(n,e.current.client.selection)?e:hb({state:e,clientSelection:n,impact:wb(e)?e.impact:null})}if("UPDATE_DROPPABLE_SCROLL"===t.type){if("DROP_PENDING"===e.phase)return Rb(e);if("COLLECTING"===e.phase)return Rb(e);cb(e)||Wg();const{id:n,newScroll:r}=t.payload,a=e.dimensions.droppables[n];if(!a)return e;const o=yv(a,r);return Eb(e,o,!1)}if("UPDATE_DROPPABLE_IS_ENABLED"===t.type){if("DROP_PENDING"===e.phase)return e;cb(e)||Wg();const{id:n,isEnabled:r}=t.payload,a=e.dimensions.droppables[n];a||Wg(),a.isEnabled===r&&Wg();const o={...a,isEnabled:r};return Eb(e,o,!0)}if("UPDATE_DROPPABLE_IS_COMBINE_ENABLED"===t.type){if("DROP_PENDING"===e.phase)return e;cb(e)||Wg();const{id:n,isCombineEnabled:r}=t.payload,a=e.dimensions.droppables[n];a||Wg(),a.isCombineEnabled===r&&Wg();const o={...a,isCombineEnabled:r};return Eb(e,o,!0)}if("MOVE_BY_WINDOW_SCROLL"===t.type){if("DROP_PENDING"===e.phase||"DROP_ANIMATING"===e.phase)return e;cb(e)||Wg(),e.isWindowScrollAllowed||Wg();const n=t.payload.newScroll;if(cv(e.viewport.scroll.current,n))return Rb(e);const r=Jv(e.viewport,n);return wb(e)?bb({state:e,viewport:r}):hb({state:e,viewport:r})}if("UPDATE_VIEWPORT_MAX_SCROLL"===t.type){if(!cb(e))return e;const n=t.payload.maxScroll;if(cv(n,e.viewport.scroll.max))return e;const r={...e.viewport,scroll:{...e.viewport.scroll,max:n}};return{...e,viewport:r}}if("MOVE_UP"===t.type||"MOVE_DOWN"===t.type||"MOVE_LEFT"===t.type||"MOVE_RIGHT"===t.type){if("COLLECTING"===e.phase||"DROP_PENDING"===e.phase)return e;"DRAGGING"!==e.phase&&Wg();const n=lb({state:e,type:t.type});return n?hb({state:e,impact:n.impact,clientSelection:n.clientSelection,scrollJumpRequest:n.scrollJumpRequest}):e}if("DROP_PENDING"===t.type){const n=t.payload.reason;return"COLLECTING"!==e.phase&&Wg(),{...e,phase:"DROP_PENDING",isWaiting:!0,reason:n}}if("DROP_ANIMATE"===t.type){const{completed:n,dropDuration:r,newHomeClientOffset:a}=t.payload;return"DRAGGING"!==e.phase&&"DROP_PENDING"!==e.phase&&Wg(),{phase:"DROP_ANIMATING",completed:n,dropDuration:r,newHomeClientOffset:a,dimensions:e.dimensions}}if("DROP_COMPLETE"===t.type){const{completed:e}=t.payload;return{phase:"IDLE",completed:e,shouldFlush:!1}}return e};function Cb(e,t){return e instanceof Object&&"type"in e&&e.type===t}const Sb=e=>({type:"PUBLISH_WHILE_DRAGGING",payload:e}),kb=()=>({type:"COLLECTION_STARTING",payload:null}),Ob=e=>({type:"UPDATE_DROPPABLE_SCROLL",payload:e}),Pb=e=>({type:"UPDATE_DROPPABLE_IS_ENABLED",payload:e}),Mb=e=>({type:"UPDATE_DROPPABLE_IS_COMBINE_ENABLED",payload:e}),Ib=e=>({type:"MOVE",payload:e}),Tb=()=>({type:"MOVE_UP",payload:null}),_b=()=>({type:"MOVE_DOWN",payload:null}),Nb=()=>({type:"MOVE_RIGHT",payload:null}),Lb=()=>({type:"MOVE_LEFT",payload:null}),Db=e=>({type:"DROP_COMPLETE",payload:e}),Bb=e=>({type:"DROP",payload:e}),Fb="cubic-bezier(.2,1,.1,1)",zb=0,jb=.7,Hb=.75,Vb={outOfTheWay:.2,minDropTime:.33,maxDropTime:.55},Gb=`${Vb.outOfTheWay}s cubic-bezier(0.2, 0, 0, 1)`,qb={fluid:`opacity ${Gb}`,snap:`transform ${Gb}, opacity ${Gb}`,drop:e=>{const t=`${e}s ${Fb}`;return`transform ${t}, opacity ${t}`},outOfTheWay:`transform ${Gb}`,placeholder:`height ${Gb}, width ${Gb}, margin ${Gb}`},Ub=e=>cv(e,iv)?void 0:`translate(${e.x}px, ${e.y}px)`,Wb=Ub,{minDropTime:Qb,maxDropTime:Kb}=Vb,Zb=Kb-Qb,Jb=({getState:e,dispatch:t})=>n=>r=>{if(!Cb(r,"DROP"))return void n(r);const a=e(),o=r.payload.reason;if("COLLECTING"===a.phase)return void t((i={reason:o},{type:"DROP_PENDING",payload:i}));var i;if("IDLE"===a.phase)return;"DROP_PENDING"===a.phase&&a.isWaiting&&Wg(),"DRAGGING"!==a.phase&&"DROP_PENDING"!==a.phase&&Wg();const s=a.critical,l=a.dimensions,c=l.draggables[a.critical.draggable.id],{impact:u,didDropInsideDroppable:d}=(({draggables:e,reason:t,lastImpact:n,home:r,viewport:a,onLiftImpact:o})=>n.at&&"DROP"===t?"REORDER"===n.at.type?{impact:n,didDropInsideDroppable:!0}:{impact:{...n,displaced:Iv},didDropInsideDroppable:!0}:{impact:gb({draggables:e,impact:o,destination:r,viewport:a,forceShouldAnimate:!0}),didDropInsideDroppable:!1})({reason:o,lastImpact:a.impact,afterCritical:a.afterCritical,onLiftImpact:a.onLiftImpact,home:a.dimensions.droppables[a.critical.droppable.id],viewport:a.viewport,draggables:a.dimensions.draggables}),p=d?Sv(u):null,f=d?kv(u):null,m={index:s.draggable.index,droppableId:s.droppable.id},h={draggableId:c.descriptor.id,type:c.descriptor.type,source:m,reason:o,mode:a.movementMode,destination:p,combine:f},g=(({impact:e,draggable:t,dimensions:n,viewport:r,afterCritical:a})=>{const{draggables:o,droppables:i}=n,s=sb(e),l=s?i[s]:null,c=i[t.descriptor.droppableId],u=vb({impact:e,draggable:t,draggables:o,afterCritical:a,droppable:l||c,viewport:r});return lv(u,t.client.borderBox.center)})({impact:u,draggable:c,dimensions:l,viewport:a.viewport,afterCritical:a.afterCritical}),v={critical:a.critical,afterCritical:a.afterCritical,result:h,impact:u};if(cv(a.current.client.offset,g)&&!Boolean(h.combine))return void t(Db({completed:v}));const b=(({current:e,destination:t,reason:n})=>{const r=pv(e,t);if(r<=0)return Qb;if(r>=1500)return Kb;const a=Qb+Zb*(r/1500);return Number(("CANCEL"===n?.6*a:a).toFixed(2))})({current:a.current.client.offset,destination:g,reason:o});t((e=>({type:"DROP_ANIMATE",payload:e}))({newHomeClientOffset:g,dropDuration:b,completed:v}))};var Xb=()=>({x:window.pageXOffset,y:window.pageYOffset});const Yb=e=>{const t=function({onWindowScroll:e}){const t=Hg(function(){e(Xb())}),n=function(e){return{eventName:"scroll",options:{passive:!0,capture:!1},fn:t=>{t.target!==window&&t.target!==window.document||e()}}}(t);let r=Gg;function a(){return r!==Gg}return{start:function(){a()&&Wg(),r=qg(window,[n])},stop:function(){a()||Wg(),t.cancel(),r(),r=Gg},isActive:a}}({onWindowScroll:t=>{e.dispatch({type:"MOVE_BY_WINDOW_SCROLL",payload:{newScroll:t}})}});return e=>n=>{!t.isActive()&&Cb(n,"INITIAL_PUBLISH")&&t.start(),t.isActive()&&(e=>Cb(e,"DROP_COMPLETE")||Cb(e,"DROP_ANIMATE")||Cb(e,"FLUSH"))(n)&&t.stop(),e(n)}};const $b=(e,t)=>{t()},ey=(e,t)=>({draggableId:e.draggable.id,type:e.droppable.type,source:{droppableId:e.droppable.id,index:e.draggable.index},mode:t});function ty(e,t,n,r){if(!e)return void n(r(t));const a=(e=>{let t=!1,n=!1;const r=setTimeout(()=>{n=!0}),a=a=>{t||n||(t=!0,e(a),clearTimeout(r))};return a.wasCalled=()=>t,a})(n);e(t,{announce:a}),a.wasCalled()||n(r(t))}var ny=(e,t)=>{const n=((e,t)=>{const n=(()=>{const e=[];return{add:t=>{const n=setTimeout(()=>(t=>{const n=e.findIndex(e=>e.timerId===t);-1===n&&Wg();const[r]=e.splice(n,1);r.callback()})(n)),r={timerId:n,callback:t};e.push(r)},flush:()=>{if(!e.length)return;const t=[...e];e.length=0,t.forEach(e=>{clearTimeout(e.timerId),e.callback()})}}})();let r=null;const a=n=>{r||Wg(),r=null,$b(0,()=>ty(e().onDragEnd,n,t,tv))};return{beforeCapture:(t,n)=>{r&&Wg(),$b(0,()=>{const r=e().onBeforeCapture;r&&r({draggableId:t,mode:n})})},beforeStart:(t,n)=>{r&&Wg(),$b(0,()=>{const r=e().onBeforeDragStart;r&&r(ey(t,n))})},start:(a,o)=>{r&&Wg();const i=ey(a,o);r={mode:o,lastCritical:a,lastLocation:i.source,lastCombine:null},n.add(()=>{$b(0,()=>ty(e().onDragStart,i,t,$g))})},update:(a,o)=>{const i=Sv(o),s=kv(o);r||Wg();const l=!((e,t)=>{if(e===t)return!0;const n=e.draggable.id===t.draggable.id&&e.draggable.droppableId===t.draggable.droppableId&&e.draggable.type===t.draggable.type&&e.draggable.index===t.draggable.index,r=e.droppable.id===t.droppable.id&&e.droppable.type===t.droppable.type;return n&&r})(a,r.lastCritical);l&&(r.lastCritical=a);const c=(d=i,!(null==(u=r.lastLocation)&&null==d||null!=u&&null!=d&&u.droppableId===d.droppableId&&u.index===d.index));var u,d;c&&(r.lastLocation=i);const p=!((e,t)=>null==e&&null==t||null!=e&&null!=t&&e.draggableId===t.draggableId&&e.droppableId===t.droppableId)(r.lastCombine,s);if(p&&(r.lastCombine=s),!l&&!c&&!p)return;const f={...ey(a,r.mode),combine:s,destination:i};n.add(()=>{$b(0,()=>ty(e().onDragUpdate,f,t,ev))})},flush:()=>{r||Wg(),n.flush()},drop:a,abort:()=>{if(!r)return;const e={...ey(r.lastCritical,r.mode),combine:null,destination:null,reason:"CANCEL"};a(e)}}})(e,t);return e=>t=>r=>{if(Cb(r,"BEFORE_INITIAL_CAPTURE"))return void n.beforeCapture(r.payload.draggableId,r.payload.movementMode);if(Cb(r,"INITIAL_PUBLISH")){const e=r.payload.critical;return n.beforeStart(e,r.payload.movementMode),t(r),void n.start(e,r.payload.movementMode)}if(Cb(r,"DROP_COMPLETE")){const e=r.payload.completed.result;return n.flush(),t(r),void n.drop(e)}if(t(r),Cb(r,"FLUSH"))return void n.abort();const a=e.getState();"DRAGGING"===a.phase&&n.update(a.critical,a.impact)}};const ry=e=>t=>n=>{if(!Cb(n,"DROP_ANIMATION_FINISHED"))return void t(n);const r=e.getState();"DROP_ANIMATING"!==r.phase&&Wg(),e.dispatch(Db({completed:r.completed}))},ay=e=>{let t=null,n=null;return r=>a=>{if((Cb(a,"FLUSH")||Cb(a,"DROP_COMPLETE")||Cb(a,"DROP_ANIMATION_FINISHED"))&&(n&&(cancelAnimationFrame(n),n=null),t&&(t(),t=null)),r(a),!Cb(a,"DROP_ANIMATE"))return;const o={eventName:"scroll",options:{capture:!0,passive:!1,once:!0},fn:function(){"DROP_ANIMATING"===e.getState().phase&&e.dispatch({type:"DROP_ANIMATION_FINISHED",payload:null})}};n=requestAnimationFrame(()=>{n=null,t=qg(window,[o])})}};const oy=e=>t=>n=>{if(t(n),!Cb(n,"PUBLISH_WHILE_DRAGGING"))return;const r=e.getState();"DROP_PENDING"===r.phase&&(r.isWaiting||e.dispatch(Bb({reason:r.reason})))},iy=Lh;var sy=({dimensionMarshal:e,focusMarshal:t,styleMarshal:n,getResponders:r,announce:a,autoScroller:o})=>{return Th(Ab,iy(function(...e){return t=>(n,r)=>{const a=t(n,r);let o=()=>{throw new Error(Oh(15))};const i={getState:a.getState,dispatch:(e,...t)=>o(e,...t)},s=e.map(e=>e(i));return o=Lh(...s)(a.dispatch),{...a,dispatch:o}}}((i=n,()=>e=>t=>{Cb(t,"INITIAL_PUBLISH")&&i.dragging(),Cb(t,"DROP_ANIMATE")&&i.dropping(t.payload.completed.result.reason),(Cb(t,"FLUSH")||Cb(t,"DROP_COMPLETE"))&&i.resting(),e(t)}),(e=>()=>t=>n=>{(Cb(n,"DROP_COMPLETE")||Cb(n,"FLUSH")||Cb(n,"DROP_ANIMATE"))&&e.stopPublishing(),t(n)})(e),(e=>({getState:t,dispatch:n})=>r=>a=>{if(!Cb(a,"LIFT"))return void r(a);const{id:o,clientSelection:i,movementMode:s}=a.payload,l=t();"DROP_ANIMATING"===l.phase&&n(Db({completed:l.completed})),"IDLE"!==t().phase&&Wg(),n({type:"FLUSH",payload:null}),n({type:"BEFORE_INITIAL_CAPTURE",payload:{draggableId:o,movementMode:s}});const c={draggableId:o,scrollOptions:{shouldPublishImmediately:"SNAP"===s}},{critical:u,dimensions:d,viewport:p}=e.startPublishing(c);n({type:"INITIAL_PUBLISH",payload:{critical:u,dimensions:d,clientSelection:i,movementMode:s,viewport:p}})})(e),Jb,ry,ay,oy,(e=>t=>n=>r=>{if((e=>Cb(e,"DROP_COMPLETE")||Cb(e,"DROP_ANIMATE")||Cb(e,"FLUSH"))(r))return e.stop(),void n(r);if(Cb(r,"INITIAL_PUBLISH")){n(r);const a=t.getState();return"DRAGGING"!==a.phase&&Wg(),void e.start(a)}n(r),e.scroll(t.getState())})(o),Yb,(e=>{let t=!1;return()=>n=>r=>{if(Cb(r,"INITIAL_PUBLISH"))return t=!0,e.tryRecordFocus(r.payload.critical.draggable.id),n(r),void e.tryRestoreFocusRecorded();if(n(r),t){if(Cb(r,"FLUSH"))return t=!1,void e.tryRestoreFocusRecorded();if(Cb(r,"DROP_COMPLETE")){t=!1;const n=r.payload.completed.result;n.combine&&e.tryShiftRecord(n.draggableId,n.combine.draggableId),e.tryRestoreFocusRecorded()}}}})(t),ny(r,a))));var i},ly=({scrollHeight:e,scrollWidth:t,height:n,width:r})=>{const a=lv({x:t,y:e},{x:r,y:n});return{x:Math.max(0,a.x),y:Math.max(0,a.y)}},cy=()=>{const e=document.documentElement;return e||Wg(),e},uy=()=>{const e=cy();return ly({scrollHeight:e.scrollHeight,scrollWidth:e.scrollWidth,width:e.clientWidth,height:e.clientHeight})};function dy(e,t,n){return n.descriptor.id!==t.id&&(n.descriptor.type===t.type&&"virtual"===e.droppable.getById(n.descriptor.droppableId).descriptor.mode)}var py=(e,t)=>{let n=null;const r=function({registry:e,callbacks:t}){let n={additions:{},removals:{},modified:{}},r=null;const a=()=>{r||(t.collectionStarting(),r=requestAnimationFrame(()=>{r=null;const{additions:a,removals:o,modified:i}=n,s=Object.keys(a).map(t=>e.draggable.getById(t).getDimension(iv)).sort((e,t)=>e.descriptor.index-t.descriptor.index),l=Object.keys(i).map(t=>({droppableId:t,scroll:e.droppable.getById(t).callbacks.getScrollWhileDragging()})),c={additions:s,removals:Object.keys(o),modified:l};n={additions:{},removals:{},modified:{}},t.publish(c)}))};return{add:e=>{const t=e.descriptor.id;n.additions[t]=e,n.modified[e.descriptor.droppableId]=!0,n.removals[t]&&delete n.removals[t],a()},remove:e=>{const t=e.descriptor;n.removals[t.id]=!0,n.modified[t.droppableId]=!0,n.additions[t.id]&&delete n.additions[t.id],a()},stop:()=>{r&&(cancelAnimationFrame(r),r=null,n={additions:{},removals:{},modified:{}})}}}({callbacks:{publish:t.publishWhileDragging,collectionStarting:t.collectionStarting},registry:e}),a=t=>{n||Wg();const a=n.critical.draggable;"ADDITION"===t.type&&dy(e,a,t.value)&&r.add(t.value),"REMOVAL"===t.type&&dy(e,a,t.value)&&r.remove(t.value)},o={updateDroppableIsEnabled:(r,a)=>{e.droppable.exists(r)||Wg(),n&&t.updateDroppableIsEnabled({id:r,isEnabled:a})},updateDroppableIsCombineEnabled:(r,a)=>{n&&(e.droppable.exists(r)||Wg(),t.updateDroppableIsCombineEnabled({id:r,isCombineEnabled:a}))},scrollDroppable:(t,r)=>{n&&e.droppable.getById(t).callbacks.scroll(r)},updateDroppableScroll:(r,a)=>{n&&(e.droppable.exists(r)||Wg(),t.updateDroppableScroll({id:r,newScroll:a}))},startPublishing:t=>{n&&Wg();const r=e.draggable.getById(t.draggableId),o=e.droppable.getById(r.descriptor.droppableId),i={draggable:r.descriptor,droppable:o.descriptor},s=e.subscribe(a);return n={critical:i,unsubscribe:s},(({critical:e,scrollOptions:t,registry:n})=>{const r=(()=>{const e=Xb(),t=uy(),n=e.y,r=e.x,a=cy(),o=a.clientWidth,i=a.clientHeight;return{frame:Ig({top:n,left:r,right:r+o,bottom:n+i}),scroll:{initial:e,current:e,max:t,diff:{value:iv,displacement:iv}}}})(),a=r.scroll.current,o=e.droppable,i=n.droppable.getAllByType(o.type).map(e=>e.callbacks.getDimensionAndWatchScroll(a,t)),s=n.draggable.getAllByType(e.draggable.type).map(e=>e.getDimension(a));return{dimensions:{draggables:Rv(s),droppables:Ev(i)},critical:e,viewport:r}})({critical:i,registry:e,scrollOptions:t.scrollOptions})},stopPublishing:()=>{if(!n)return;r.stop();const t=n.critical.droppable;e.droppable.getAllByType(t.type).forEach(e=>e.callbacks.dragStopped()),n.unsubscribe(),n=null}};return o},fy=(e,t)=>"IDLE"===e.phase||"DROP_ANIMATING"===e.phase&&e.completed.result.draggableId!==t&&"DROP"===e.completed.result.reason,my=e=>{window.scrollBy(e.x,e.y)};const hy=wv(e=>xv(e).filter(e=>!!e.isEnabled&&!!e.frame));const gy={startFromPercentage:.25,maxScrollAtPercentage:.05,maxPixelScroll:28,ease:e=>e**2,durationDampening:{stopDampeningAt:1200,accelerateAt:360},disabled:!1};var vy=({startOfRange:e,endOfRange:t,current:n})=>{const r=t-e;return 0===r?0:(n-e)/r},by=({distanceToEdge:e,thresholds:t,dragStartTime:n,shouldUseTimeDampening:r,getAutoScrollerOptions:a})=>{const o=((e,t,n=()=>gy)=>{const r=n();if(e>t.startScrollingFrom)return 0;if(e<=t.maxScrollValueAt)return r.maxPixelScroll;if(e===t.startScrollingFrom)return 1;const a=1-vy({startOfRange:t.maxScrollValueAt,endOfRange:t.startScrollingFrom,current:e}),o=r.maxPixelScroll*r.ease(a);return Math.ceil(o)})(e,t,a);return 0===o?0:r?Math.max(((e,t,n)=>{const r=n(),a=r.durationDampening.accelerateAt,o=r.durationDampening.stopDampeningAt,i=t,s=o,l=Date.now()-i;if(l>=o)return e;if(l<a)return 1;const c=vy({startOfRange:a,endOfRange:s,current:l}),u=e*r.ease(c);return Math.ceil(u)})(o,n,a),1):o},yy=({container:e,distanceToEdges:t,dragStartTime:n,axis:r,shouldUseTimeDampening:a,getAutoScrollerOptions:o})=>{const i=((e,t,n=()=>gy)=>{const r=n();return{startScrollingFrom:e[t.size]*r.startFromPercentage,maxScrollValueAt:e[t.size]*r.maxScrollAtPercentage}})(e,r,o);return t[r.end]<t[r.start]?by({distanceToEdge:t[r.end],thresholds:i,dragStartTime:n,shouldUseTimeDampening:a,getAutoScrollerOptions:o}):-1*by({distanceToEdge:t[r.start],thresholds:i,dragStartTime:n,shouldUseTimeDampening:a,getAutoScrollerOptions:o})};const wy=mv(e=>0===e?0:e);var Ey=({dragStartTime:e,container:t,subject:n,center:r,shouldUseTimeDampening:a,getAutoScrollerOptions:o})=>{const i={top:r.y-t.top,right:t.right-r.x,bottom:t.bottom-r.y,left:r.x-t.left},s=yy({container:t,distanceToEdges:i,dragStartTime:e,axis:Dv,shouldUseTimeDampening:a,getAutoScrollerOptions:o}),l=yy({container:t,distanceToEdges:i,dragStartTime:e,axis:Bv,shouldUseTimeDampening:a,getAutoScrollerOptions:o}),c=wy({x:l,y:s});if(cv(c,iv))return null;const u=(({container:e,subject:t,proposedScroll:n})=>{const r=t.height>e.height,a=t.width>e.width;return a||r?a&&r?null:{x:a?0:n.x,y:r?0:n.y}:n})({container:t,subject:n,proposedScroll:c});return u?cv(u,iv)?null:u:null};const Ry=mv(e=>0===e?0:e>0?1:-1),xy=(()=>{const e=(e,t)=>e<0?e:e>t?e-t:0;return({current:t,max:n,change:r})=>{const a=sv(t,r),o={x:e(a.x,n.x),y:e(a.y,n.y)};return cv(o,iv)?null:o}})(),Ay=({max:e,current:t,change:n})=>{const r={x:Math.max(t.x,e.x),y:Math.max(t.y,e.y)},a=Ry(n),o=xy({max:r,current:t,change:a});return!o||0!==a.x&&0===o.x||0!==a.y&&0===o.y},Cy=(e,t)=>Ay({current:e.scroll.current,max:e.scroll.max,change:t}),Sy=(e,t)=>{const n=e.frame;return!!n&&Ay({current:n.scroll.current,max:n.scroll.max,change:t})};var ky=({state:e,dragStartTime:t,shouldUseTimeDampening:n,scrollWindow:r,scrollDroppable:a,getAutoScrollerOptions:o})=>{const i=e.current.page.borderBoxCenter,s=e.dimensions.draggables[e.critical.draggable.id].page.marginBox;if(e.isWindowScrollAllowed){const a=(({viewport:e,subject:t,center:n,dragStartTime:r,shouldUseTimeDampening:a,getAutoScrollerOptions:o})=>{const i=Ey({dragStartTime:r,container:e.frame,subject:t,center:n,shouldUseTimeDampening:a,getAutoScrollerOptions:o});return i&&Cy(e,i)?i:null})({dragStartTime:t,viewport:e.viewport,subject:s,center:i,shouldUseTimeDampening:n,getAutoScrollerOptions:o});if(a)return void r(a)}const l=(({center:e,destination:t,droppables:n})=>{if(t){const e=n[t];return e.frame?e:null}const r=((e,t)=>{const n=hy(t).find(t=>(t.frame||Wg(),ub(t.frame.pageMarginBox)(e)))||null;return n})(e,n);return r})({center:i,destination:sb(e.impact),droppables:e.dimensions.droppables});if(!l)return;const c=(({droppable:e,subject:t,center:n,dragStartTime:r,shouldUseTimeDampening:a,getAutoScrollerOptions:o})=>{const i=e.frame;if(!i)return null;const s=Ey({dragStartTime:r,container:i.pageMarginBox,subject:t,center:n,shouldUseTimeDampening:a,getAutoScrollerOptions:o});return s&&Sy(e,s)?s:null})({dragStartTime:t,droppable:l,subject:s,center:i,shouldUseTimeDampening:n,getAutoScrollerOptions:o});c&&a(l.descriptor.id,c)},Oy=({move:e,scrollDroppable:t,scrollWindow:n})=>r=>{const a=r.scrollJumpRequest;if(!a)return;const o=sb(r.impact);o||Wg();const i=((e,n)=>{if(!Sy(e,n))return n;const r=((e,t)=>{const n=e.frame;return n&&Sy(e,t)?xy({current:n.scroll.current,max:n.scroll.max,change:t}):null})(e,n);if(!r)return t(e.descriptor.id,n),null;const a=lv(n,r);return t(e.descriptor.id,a),lv(n,a)})(r.dimensions.droppables[o],a);if(!i)return;const s=r.viewport,l=((e,t,r)=>{if(!e)return r;if(!Cy(t,r))return r;const a=((e,t)=>{if(!Cy(e,t))return null;const n=e.scroll.max,r=e.scroll.current;return xy({current:r,max:n,change:t})})(t,r);if(!a)return n(r),null;const o=lv(r,a);return n(o),lv(r,o)})(r.isWindowScrollAllowed,s,i);l&&((t,n)=>{const r=sv(t.current.client.selection,n);e({client:r})})(r,l)};const Py="data-rfd",My=(()=>{const e=`${Py}-drag-handle`;return{base:e,draggableId:`${e}-draggable-id`,contextId:`${e}-context-id`}})(),Iy=(()=>{const e=`${Py}-draggable`;return{base:e,contextId:`${e}-context-id`,id:`${e}-id`}})(),Ty=(()=>{const e=`${Py}-droppable`;return{base:e,contextId:`${e}-context-id`,id:`${e}-id`}})(),_y={contextId:`${Py}-scroll-container-context-id`},Ny=(e,t)=>e.map(e=>{const n=e.styles[t];return n?`${e.selector} { ${n} }`:""}).join(" "),Ly="undefined"!=typeof window&&void 0!==window.document&&void 0!==window.document.createElement?c.useLayoutEffect:c.useEffect,Dy=()=>{const e=document.querySelector("head");return e||Wg(),e},By=e=>{const t=document.createElement("style");return e&&t.setAttribute("nonce",e),t.type="text/css",t};function Fy(e,t){return Array.from(e.querySelectorAll(t))}var zy=e=>e&&e.ownerDocument&&e.ownerDocument.defaultView?e.ownerDocument.defaultView:window;function jy(e){return e instanceof zy(e).HTMLElement}function Hy(){const e={draggables:{},droppables:{}},t=[];function n(e){t.length&&t.forEach(t=>t(e))}function r(t){return e.draggables[t]||null}function a(t){return e.droppables[t]||null}return{draggable:{register:t=>{e.draggables[t.descriptor.id]=t,n({type:"ADDITION",value:t})},update:(t,n)=>{const r=e.draggables[n.descriptor.id];r&&r.uniqueId===t.uniqueId&&(delete e.draggables[n.descriptor.id],e.draggables[t.descriptor.id]=t)},unregister:t=>{const a=t.descriptor.id,o=r(a);o&&t.uniqueId===o.uniqueId&&(delete e.draggables[a],e.droppables[t.descriptor.droppableId]&&n({type:"REMOVAL",value:t}))},getById:function(e){const t=r(e);return t||Wg(),t},findById:r,exists:e=>Boolean(r(e)),getAllByType:t=>Object.values(e.draggables).filter(e=>e.descriptor.type===t)},droppable:{register:t=>{e.droppables[t.descriptor.id]=t},unregister:t=>{const n=a(t.descriptor.id);n&&t.uniqueId===n.uniqueId&&delete e.droppables[t.descriptor.id]},getById:function(e){const t=a(e);return t||Wg(),t},findById:a,exists:e=>Boolean(a(e)),getAllByType:t=>Object.values(e.droppables).filter(e=>e.descriptor.type===t)},subscribe:function(e){return t.push(e),function(){const n=t.indexOf(e);-1!==n&&t.splice(n,1)}},clean:function(){e.draggables={},e.droppables={},t.length=0}}}var Vy=u().createContext(null),Gy=()=>{const e=document.body;return e||Wg(),e};const qy={position:"absolute",width:"1px",height:"1px",margin:"-1px",border:"0",padding:"0",overflow:"hidden",clip:"rect(0 0 0 0)","clip-path":"inset(100%)"},Uy={separator:"::"};function Wy(e,t=Uy){const n=u().useId();return av(()=>`${e}${t.separator}${n}`,[t.separator,e,n])}var Qy=u().createContext(null);function Ky(e){const t=(0,c.useRef)(e);return(0,c.useEffect)(()=>{t.current=e}),t}function Zy(e){return"IDLE"!==e.phase&&"DROP_ANIMATING"!==e.phase&&e.isDragging}const Jy=9,Xy=13,Yy=33,$y=34,ew=35,tw=36,nw={[Xy]:!0,[Jy]:!0};var rw=e=>{nw[e.keyCode]&&e.preventDefault()};const aw=(()=>{const e="visibilitychange";return"undefined"==typeof document?e:[e,`ms${e}`,`webkit${e}`,`moz${e}`,`o${e}`].find(e=>`on${e}`in document)||e})(),ow={type:"IDLE"};function iw(){}const sw={[$y]:!0,[Yy]:!0,[tw]:!0,[ew]:!0};const lw={type:"IDLE"},cw=["input","button","textarea","select","option","optgroup","video","audio"];function uw(e,t){if(null==t)return!1;if(cw.includes(t.tagName.toLowerCase()))return!0;const n=t.getAttribute("contenteditable");return"true"===n||""===n||t!==e&&uw(e,t.parentElement)}function dw(e,t){const n=t.target;return!!jy(n)&&uw(e,n)}var pw=e=>Ig(e.getBoundingClientRect()).center;const fw=(()=>{const e="matches";return"undefined"==typeof document?e:[e,"msMatchesSelector","webkitMatchesSelector"].find(e=>e in Element.prototype)||e})();function mw(e,t){return null==e?null:e[fw](t)?e:mw(e.parentElement,t)}function hw(e,t){return e.closest?e.closest(t):mw(e,t)}function gw(e){e.preventDefault()}function vw({expected:e,phase:t,isLockActive:n,shouldWarn:r}){return!!n()&&e===t}function bw({lockAPI:e,store:t,registry:n,draggableId:r}){if(e.isClaimed())return!1;const a=n.draggable.findById(r);return!!a&&!!a.options.isEnabled&&!!fy(t.getState(),r)}const yw=[function(e){const t=(0,c.useRef)(ow),n=(0,c.useRef)(Gg),r=av(()=>({eventName:"mousedown",fn:function(t){if(t.defaultPrevented)return;if(0!==t.button)return;if(t.ctrlKey||t.metaKey||t.shiftKey||t.altKey)return;const r=e.findClosestDraggableId(t);if(!r)return;const a=e.tryGetLock(r,i,{sourceEvent:t});if(!a)return;t.preventDefault();const o={x:t.clientX,y:t.clientY};n.current(),u(a,o)}}),[e]),a=av(()=>({eventName:"webkitmouseforcewillbegin",fn:t=>{if(t.defaultPrevented)return;const n=e.findClosestDraggableId(t);if(!n)return;const r=e.findOptionsForDraggable(n);r&&(r.shouldRespectForcePress||e.canGetLock(n)&&t.preventDefault())}}),[e]),o=ov(function(){n.current=qg(window,[a,r],{passive:!1,capture:!0})},[a,r]),i=ov(()=>{"IDLE"!==t.current.type&&(t.current=ow,n.current(),o())},[o]),s=ov(()=>{const e=t.current;i(),"DRAGGING"===e.type&&e.actions.cancel({shouldBlockNextClick:!0}),"PENDING"===e.type&&e.actions.abort()},[i]),l=ov(function(){const e=function({cancel:e,completed:t,getPhase:n,setPhase:r}){return[{eventName:"mousemove",fn:e=>{const{button:t,clientX:a,clientY:o}=e;if(0!==t)return;const i={x:a,y:o},s=n();if("DRAGGING"===s.type)return e.preventDefault(),void s.actions.move(i);if("PENDING"!==s.type&&Wg(),l=s.point,c=i,!(Math.abs(c.x-l.x)>=5||Math.abs(c.y-l.y)>=5))return;var l,c;e.preventDefault();const u=s.actions.fluidLift(i);r({type:"DRAGGING",actions:u})}},{eventName:"mouseup",fn:r=>{const a=n();"DRAGGING"===a.type?(r.preventDefault(),a.actions.drop({shouldBlockNextClick:!0}),t()):e()}},{eventName:"mousedown",fn:t=>{"DRAGGING"===n().type&&t.preventDefault(),e()}},{eventName:"keydown",fn:t=>{if("PENDING"!==n().type)return 27===t.keyCode?(t.preventDefault(),void e()):void rw(t);e()}},{eventName:"resize",fn:e},{eventName:"scroll",options:{passive:!0,capture:!1},fn:()=>{"PENDING"===n().type&&e()}},{eventName:"webkitmouseforcedown",fn:t=>{const r=n();"IDLE"===r.type&&Wg(),r.actions.shouldRespectForcePress()?e():t.preventDefault()}},{eventName:aw,fn:e}]}({cancel:s,completed:i,getPhase:()=>t.current,setPhase:e=>{t.current=e}});n.current=qg(window,e,{capture:!0,passive:!1})},[s,i]),u=ov(function(e,n){"IDLE"!==t.current.type&&Wg(),t.current={type:"PENDING",point:n,actions:e},l()},[l]);Ly(function(){return o(),function(){n.current()}},[o])},function(e){const t=(0,c.useRef)(iw),n=av(()=>({eventName:"keydown",fn:function(n){if(n.defaultPrevented)return;if(32!==n.keyCode)return;const a=e.findClosestDraggableId(n);if(!a)return;const o=e.tryGetLock(a,l,{sourceEvent:n});if(!o)return;n.preventDefault();let i=!0;const s=o.snapLift();function l(){i||Wg(),i=!1,t.current(),r()}t.current(),t.current=qg(window,function(e,t){function n(){t(),e.cancel()}return[{eventName:"keydown",fn:r=>27===r.keyCode?(r.preventDefault(),void n()):32===r.keyCode?(r.preventDefault(),t(),void e.drop()):40===r.keyCode?(r.preventDefault(),void e.moveDown()):38===r.keyCode?(r.preventDefault(),void e.moveUp()):39===r.keyCode?(r.preventDefault(),void e.moveRight()):37===r.keyCode?(r.preventDefault(),void e.moveLeft()):void(sw[r.keyCode]?r.preventDefault():rw(r))},{eventName:"mousedown",fn:n},{eventName:"mouseup",fn:n},{eventName:"click",fn:n},{eventName:"touchstart",fn:n},{eventName:"resize",fn:n},{eventName:"wheel",fn:n,options:{passive:!0}},{eventName:aw,fn:n}]}(s,l),{capture:!0,passive:!1})}}),[e]),r=ov(function(){t.current=qg(window,[n],{passive:!1,capture:!0})},[n]);Ly(function(){return r(),function(){t.current()}},[r])},function(e){const t=(0,c.useRef)(lw),n=(0,c.useRef)(Gg),r=ov(function(){return t.current},[]),a=ov(function(e){t.current=e},[]),o=av(()=>({eventName:"touchstart",fn:function(t){if(t.defaultPrevented)return;const r=e.findClosestDraggableId(t);if(!r)return;const a=e.tryGetLock(r,s,{sourceEvent:t});if(!a)return;const o=t.touches[0],{clientX:i,clientY:l}=o,c={x:i,y:l};n.current(),p(a,c)}}),[e]),i=ov(function(){n.current=qg(window,[o],{capture:!0,passive:!1})},[o]),s=ov(()=>{const e=t.current;"IDLE"!==e.type&&("PENDING"===e.type&&clearTimeout(e.longPressTimerId),a(lw),n.current(),i())},[i,a]),l=ov(()=>{const e=t.current;s(),"DRAGGING"===e.type&&e.actions.cancel({shouldBlockNextClick:!0}),"PENDING"===e.type&&e.actions.abort()},[s]),u=ov(function(){const e={capture:!0,passive:!1},t={cancel:l,completed:s,getPhase:r},a=qg(window,function({cancel:e,completed:t,getPhase:n}){return[{eventName:"touchmove",options:{capture:!1},fn:t=>{const r=n();if("DRAGGING"!==r.type)return void e();r.hasMoved=!0;const{clientX:a,clientY:o}=t.touches[0],i={x:a,y:o};t.preventDefault(),r.actions.move(i)}},{eventName:"touchend",fn:r=>{const a=n();"DRAGGING"===a.type?(r.preventDefault(),a.actions.drop({shouldBlockNextClick:!0}),t()):e()}},{eventName:"touchcancel",fn:t=>{"DRAGGING"===n().type?(t.preventDefault(),e()):e()}},{eventName:"touchforcechange",fn:t=>{const r=n();"IDLE"===r.type&&Wg();const a=t.touches[0];if(!a)return;if(!(a.force>=.15))return;const o=r.actions.shouldRespectForcePress();if("PENDING"!==r.type)return o?r.hasMoved?void t.preventDefault():void e():void t.preventDefault();o&&e()}},{eventName:aw,fn:e}]}(t),e),o=qg(window,function({cancel:e,getPhase:t}){return[{eventName:"orientationchange",fn:e},{eventName:"resize",fn:e},{eventName:"contextmenu",fn:e=>{e.preventDefault()}},{eventName:"keydown",fn:n=>{"DRAGGING"===t().type?(27===n.keyCode&&n.preventDefault(),e()):e()}},{eventName:aw,fn:e}]}(t),e);n.current=function(){a(),o()}},[l,r,s]),d=ov(function(){const e=r();"PENDING"!==e.type&&Wg();const t=e.actions.fluidLift(e.point);a({type:"DRAGGING",actions:t,hasMoved:!1})},[r,a]),p=ov(function(e,t){"IDLE"!==r().type&&Wg();const n=setTimeout(d,120);a({type:"PENDING",point:t,actions:e,longPressTimerId:n}),u()},[u,r,a,d]);Ly(function(){return i(),function(){n.current();const e=r();"PENDING"===e.type&&(clearTimeout(e.longPressTimerId),a(lw))}},[r,i,a]),Ly(function(){return qg(window,[{eventName:"touchmove",fn:()=>{},options:{capture:!1,passive:!1}}])},[])}];function ww({contextId:e,store:t,registry:n,customSensors:r,enableDefaultSensors:a}){const o=[...a?yw:[],...r||[]],i=(0,c.useState)(()=>function(){let e=null;function t(){e||Wg(),e=null}return{isClaimed:function(){return Boolean(e)},isActive:function(t){return t===e},claim:function(t){e&&Wg();const n={abandon:t};return e=n,n},release:t,tryAbandon:function(){e&&(e.abandon(),t())}}}())[0],s=ov(function(e,t){Zy(e)&&!Zy(t)&&i.tryAbandon()},[i]);Ly(function(){let e=t.getState();return t.subscribe(()=>{const n=t.getState();s(e,n),e=n})},[i,t,s]),Ly(()=>i.tryAbandon,[i.tryAbandon]);const l=ov(e=>bw({lockAPI:i,registry:n,store:t,draggableId:e}),[i,n,t]),u=ov((r,a,o)=>function({lockAPI:e,contextId:t,store:n,registry:r,draggableId:a,forceSensorStop:o,sourceEvent:i}){if(!bw({lockAPI:e,store:n,registry:r,draggableId:a}))return null;const s=r.draggable.getById(a),l=function(e,t){const n=`[${Iy.contextId}="${e}"]`,r=Fy(document,n).find(e=>e.getAttribute(Iy.id)===t);return r&&jy(r)?r:null}(t,s.descriptor.id);if(!l)return null;if(i&&!s.options.canDragInteractiveElements&&dw(l,i))return null;const c=e.claim(o||Gg);let u="PRE_DRAG";function d(){return s.options.shouldRespectForcePress}function p(){return e.isActive(c)}const f=function(e,t){vw({expected:e,phase:u,isLockActive:p,shouldWarn:!0})&&n.dispatch(t())}.bind(null,"DRAGGING");function m(t){function r(){e.release(),u="COMPLETED"}function a(e,a={shouldBlockNextClick:!1}){if(t.cleanup(),a.shouldBlockNextClick){const e=qg(window,[{eventName:"click",fn:gw,options:{once:!0,passive:!1,capture:!0}}]);setTimeout(e)}r(),n.dispatch(Bb({reason:e}))}return"PRE_DRAG"!==u&&(r(),Wg()),n.dispatch((e=>({type:"LIFT",payload:e}))(t.liftActionArgs)),u="DRAGGING",{isActive:()=>vw({expected:"DRAGGING",phase:u,isLockActive:p,shouldWarn:!1}),shouldRespectForcePress:d,drop:e=>a("DROP",e),cancel:e=>a("CANCEL",e),...t.actions}}return{isActive:()=>vw({expected:"PRE_DRAG",phase:u,isLockActive:p,shouldWarn:!1}),shouldRespectForcePress:d,fluidLift:function(e){const t=Hg(e=>{f(()=>Ib({client:e}))});return{...m({liftActionArgs:{id:a,clientSelection:e,movementMode:"FLUID"},cleanup:()=>t.cancel(),actions:{move:t}}),move:t}},snapLift:function(){const e={moveUp:()=>f(Tb),moveRight:()=>f(Nb),moveDown:()=>f(_b),moveLeft:()=>f(Lb)};return m({liftActionArgs:{id:a,clientSelection:pw(l),movementMode:"SNAP"},cleanup:Gg,actions:e})},abort:function(){vw({expected:"PRE_DRAG",phase:u,isLockActive:p,shouldWarn:!0})&&e.release()}}}({lockAPI:i,registry:n,contextId:e,store:t,draggableId:r,forceSensorStop:a||null,sourceEvent:o&&o.sourceEvent?o.sourceEvent:null}),[e,i,n,t]),d=ov(t=>function(e,t){const n=function(e,t){const n=t.target;if(!((r=n)instanceof zy(r).Element))return null;var r;const a=function(e){return`[${My.contextId}="${e}"]`}(e),o=hw(n,a);return o&&jy(o)?o:null}(e,t);return n?n.getAttribute(My.draggableId):null}(e,t),[e]),p=ov(e=>{const t=n.draggable.findById(e);return t?t.options:null},[n.draggable]),f=ov(function(){i.isClaimed()&&(i.tryAbandon(),"IDLE"!==t.getState().phase&&t.dispatch({type:"FLUSH",payload:null}))},[i,t]),m=ov(()=>i.isClaimed(),[i]),h=av(()=>({canGetLock:l,tryGetLock:u,findClosestDraggableId:d,findOptionsForDraggable:p,tryReleaseLock:f,isLockClaimed:m}),[l,u,d,p,f,m]);for(let e=0;e<o.length;e++)o[e](h)}function Ew(e){return e.current||Wg(),e.current}function Rw(e){const{contextId:t,setCallbacks:n,sensors:r,nonce:a,dragHandleUsageInstructions:o}=e,i=(0,c.useRef)(null),s=Ky(e),l=ov(()=>(e=>({onBeforeCapture:t=>{(0,Re.flushSync)(()=>{e.onBeforeCapture&&e.onBeforeCapture(t)})},onBeforeDragStart:e.onBeforeDragStart,onDragStart:e.onDragStart,onDragEnd:e.onDragEnd,onDragUpdate:e.onDragUpdate}))(s.current),[s]),d=ov(()=>(e=>({...gy,...e.autoScrollerOptions,durationDampening:{...gy.durationDampening,...e.autoScrollerOptions}}))(s.current),[s]),p=function(e){const t=av(()=>(e=>`rfd-announcement-${e}`)(e),[e]),n=(0,c.useRef)(null);return(0,c.useEffect)(function(){const e=document.createElement("div");return n.current=e,e.id=t,e.setAttribute("aria-live","assertive"),e.setAttribute("aria-atomic","true"),ke(e.style,qy),Gy().appendChild(e),function(){setTimeout(function(){const t=Gy();t.contains(e)&&t.removeChild(e),e===n.current&&(n.current=null)})}},[t]),ov(e=>{const t=n.current;t&&(t.textContent=e)},[])}(t),f=function({contextId:e,text:t}){const n=Wy("hidden-text",{separator:"-"}),r=av(()=>function({contextId:e,uniqueId:t}){return`rfd-hidden-text-${e}-${t}`}({contextId:e,uniqueId:n}),[n,e]);return(0,c.useEffect)(function(){const e=document.createElement("div");return e.id=r,e.textContent=t,e.style.display="none",Gy().appendChild(e),function(){const t=Gy();t.contains(e)&&t.removeChild(e)}},[r,t]),r}({contextId:t,text:o}),m=function(e,t){const n=av(()=>(e=>{const t=(n=e,e=>`[${e}="${n}"]`);var n;const r=(()=>{const e="\n      cursor: -webkit-grab;\n      cursor: grab;\n    ";return{selector:t(My.contextId),styles:{always:"\n          -webkit-touch-callout: none;\n          -webkit-tap-highlight-color: rgba(0,0,0,0);\n          touch-action: manipulation;\n        ",resting:e,dragging:"pointer-events: none;",dropAnimating:e}}})(),a=(()=>{const e=`\n      transition: ${qb.outOfTheWay};\n    `;return{selector:t(Iy.contextId),styles:{dragging:e,dropAnimating:e,userCancel:e}}})(),o=[a,r,{selector:t(Ty.contextId),styles:{always:"overflow-anchor: none;"}},{selector:"body",styles:{dragging:"\n        cursor: grabbing;\n        cursor: -webkit-grabbing;\n        user-select: none;\n        -webkit-user-select: none;\n        -moz-user-select: none;\n        -ms-user-select: none;\n        overflow-anchor: none;\n      "}}];return{always:Ny(o,"always"),resting:Ny(o,"resting"),dragging:Ny(o,"dragging"),dropAnimating:Ny(o,"dropAnimating"),userCancel:Ny(o,"userCancel")}})(e),[e]),r=(0,c.useRef)(null),a=(0,c.useRef)(null),o=ov(wv(e=>{const t=a.current;t||Wg(),t.textContent=e}),[]),i=ov(e=>{const t=r.current;t||Wg(),t.textContent=e},[]);Ly(()=>{(r.current||a.current)&&Wg();const s=By(t),l=By(t);return r.current=s,a.current=l,s.setAttribute(`${Py}-always`,e),l.setAttribute(`${Py}-dynamic`,e),Dy().appendChild(s),Dy().appendChild(l),i(n.always),o(n.resting),()=>{const e=e=>{const t=e.current;t||Wg(),Dy().removeChild(t),e.current=null};e(r),e(a)}},[t,i,o,n.always,n.resting,e]);const s=ov(()=>o(n.dragging),[o,n.dragging]),l=ov(e=>{o("DROP"!==e?n.userCancel:n.dropAnimating)},[o,n.dropAnimating,n.userCancel]),u=ov(()=>{a.current&&o(n.resting)},[o,n.resting]);return av(()=>({dragging:s,dropping:l,resting:u}),[s,l,u])}(t,a),h=ov(e=>{Ew(i).dispatch(e)},[]),g=av(()=>Nh({publishWhileDragging:Sb,updateDroppableScroll:Ob,updateDroppableIsEnabled:Pb,updateDroppableIsCombineEnabled:Mb,collectionStarting:kb},h),[h]),v=function(){const e=av(Hy,[]);return(0,c.useEffect)(()=>function(){e.clean()},[e]),e}(),b=av(()=>py(v,g),[v,g]),y=av(()=>(({scrollDroppable:e,scrollWindow:t,move:n,getAutoScrollerOptions:r})=>{const a=(({scrollWindow:e,scrollDroppable:t,getAutoScrollerOptions:n=()=>gy})=>{const r=Hg(e),a=Hg(t);let o=null;const i=e=>{o||Wg();const{shouldUseTimeDampening:t,dragStartTime:i}=o;ky({state:e,scrollWindow:r,scrollDroppable:a,dragStartTime:i,shouldUseTimeDampening:t,getAutoScrollerOptions:n})};return{start:e=>{o&&Wg();const t=Date.now();let r=!1;const a=()=>{r=!0};ky({state:e,dragStartTime:0,shouldUseTimeDampening:!1,scrollWindow:a,scrollDroppable:a,getAutoScrollerOptions:n}),o={dragStartTime:t,shouldUseTimeDampening:r},r&&i(e)},stop:()=>{o&&(r.cancel(),a.cancel(),o=null)},scroll:i}})({scrollWindow:t,scrollDroppable:e,getAutoScrollerOptions:r}),o=Oy({move:n,scrollWindow:t,scrollDroppable:e});return{scroll:e=>{r().disabled||"DRAGGING"!==e.phase||("FLUID"!==e.movementMode?e.scrollJumpRequest&&o(e):a.scroll(e))},start:a.start,stop:a.stop}})({scrollWindow:my,scrollDroppable:b.scrollDroppable,getAutoScrollerOptions:d,...Nh({move:Ib},h)}),[b.scrollDroppable,h,d]),w=function(e){const t=(0,c.useRef)({}),n=(0,c.useRef)(null),r=(0,c.useRef)(null),a=(0,c.useRef)(!1),o=ov(function(e,n){const r={id:e,focus:n};return t.current[e]=r,function(){const n=t.current;n[e]!==r&&delete n[e]}},[]),i=ov(function(t){const n=function(e,t){const n=`[${My.contextId}="${e}"]`,r=Fy(document,n);if(!r.length)return null;const a=r.find(e=>e.getAttribute(My.draggableId)===t);return a&&jy(a)?a:null}(e,t);n&&n!==document.activeElement&&n.focus()},[e]),s=ov(function(e,t){n.current===e&&(n.current=t)},[]),l=ov(function(){r.current||a.current&&(r.current=requestAnimationFrame(()=>{r.current=null;const e=n.current;e&&i(e)}))},[i]),u=ov(function(e){n.current=null;const t=document.activeElement;t&&t.getAttribute(My.draggableId)===e&&(n.current=e)},[]);return Ly(()=>(a.current=!0,function(){a.current=!1;const e=r.current;e&&cancelAnimationFrame(e)}),[]),av(()=>({register:o,tryRecordFocus:u,tryRestoreFocusRecorded:l,tryShiftRecord:s}),[o,u,l,s])}(t),E=av(()=>sy({announce:p,autoScroller:y,dimensionMarshal:b,focusMarshal:w,getResponders:l,styleMarshal:m}),[p,y,b,w,l,m]);i.current=E;const R=ov(()=>{const e=Ew(i);"IDLE"!==e.getState().phase&&e.dispatch({type:"FLUSH",payload:null})},[]),x=ov(()=>{const e=Ew(i).getState();return"DROP_ANIMATING"===e.phase||"IDLE"!==e.phase&&e.isDragging},[]);n(av(()=>({isDragging:x,tryAbort:R}),[x,R]));const A=ov(e=>fy(Ew(i).getState(),e),[]),C=ov(()=>cb(Ew(i).getState()),[]),S=av(()=>({marshal:b,focus:w,contextId:t,canLift:A,isMovementAllowed:C,dragHandleUsageInstructionsId:f,registry:v}),[t,b,f,w,A,C,v]);return ww({contextId:t,store:E,registry:v,customSensors:r||null,enableDefaultSensors:!1!==e.enableDefaultSensors}),(0,c.useEffect)(()=>R,[R]),u().createElement(Qy.Provider,{value:S},u().createElement(Mg,{context:Vy,store:E},e.children))}function xw(e){const t=u().useId(),n=e.dragHandleUsageInstructions||Yg;return u().createElement(Qg,null,r=>u().createElement(Rw,{nonce:e.nonce,contextId:t,setCallbacks:r,dragHandleUsageInstructions:n,enableDefaultSensors:e.enableDefaultSensors,sensors:e.sensors,onBeforeCapture:e.onBeforeCapture,onBeforeDragStart:e.onBeforeDragStart,onDragStart:e.onDragStart,onDragUpdate:e.onDragUpdate,onDragEnd:e.onDragEnd,autoScrollerOptions:e.autoScrollerOptions},e.children))}const Aw=(e,t)=>t?qb.drop(t.duration):e?qb.snap:qb.fluid,Cw=(e,t)=>{if(e)return t?zb:jb};function Sw(e){return"DRAGGING"===e.type?function(e){const t=e.dimension.client,{offset:n,combineWith:r,dropping:a}=e,o=Boolean(r),i=(e=>null!=e.forceShouldAnimate?e.forceShouldAnimate:"SNAP"===e.mode)(e),s=Boolean(a),l=s?((e,t)=>{const n=Ub(e);if(n)return t?`${n} scale(${Hb})`:n})(n,o):Wb(n);return{position:"fixed",top:t.marginBox.top,left:t.marginBox.left,boxSizing:"border-box",width:t.borderBox.width,height:t.borderBox.height,transition:Aw(i,a),transform:l,opacity:Cw(o,s),zIndex:s?4500:5e3,pointerEvents:"none"}}(e):{transform:Wb((t=e).offset),transition:t.shouldAnimateDisplacement?void 0:"none"};var t}var kw=u().createContext(null);function Ow(e){const t=(0,c.useContext)(e);return t||Wg(),t}function Pw(e){e.preventDefault()}var Mw=(e,t)=>e===t,Iw=e=>{const{combine:t,destination:n}=e;return n?n.droppableId:t?t.droppableId:null};function Tw(e=null){return{isDragging:!1,isDropAnimating:!1,isClone:!1,dropAnimation:null,mode:null,draggingOver:null,combineTargetFor:e,combineWith:null}}const _w={mapped:{type:"SECONDARY",offset:iv,combineTargetFor:null,shouldAnimateDisplacement:!0,snapshot:Tw(null)}},Nw=Pg(()=>{const e=function(){const e=wv((e,t)=>({x:e,y:t})),t=wv((e,t,n=null,r=null,a=null)=>({isDragging:!0,isClone:t,isDropAnimating:Boolean(a),dropAnimation:a,mode:e,draggingOver:n,combineWith:r,combineTargetFor:null})),n=wv((e,n,r,a,o=null,i=null,s=null)=>({mapped:{type:"DRAGGING",dropping:null,draggingOver:o,combineWith:i,mode:n,offset:e,dimension:r,forceShouldAnimate:s,snapshot:t(n,a,o,i,null)}}));return(r,a)=>{if(Zy(r)){if(r.critical.draggable.id!==a.draggableId)return null;const t=r.current.client.offset,i=r.dimensions.draggables[a.draggableId],s=sb(r.impact),l=(o=r.impact).at&&"COMBINE"===o.at.type?o.at.combine.draggableId:null,c=r.forceShouldAnimate;return n(e(t.x,t.y),r.movementMode,i,a.isClone,s,l,c)}var o;if("DROP_ANIMATING"===r.phase){const e=r.completed;if(e.result.draggableId!==a.draggableId)return null;const n=a.isClone,o=r.dimensions.draggables[a.draggableId],i=e.result,s=i.mode,l=Iw(i),c=(e=>e.combine?e.combine.draggableId:null)(i),u={duration:r.dropDuration,curve:Fb,moveTo:r.newHomeClientOffset,opacity:c?zb:null,scale:c?Hb:null};return{mapped:{type:"DRAGGING",offset:r.newHomeClientOffset,dimension:o,dropping:u,draggingOver:l,combineWith:c,mode:s,forceShouldAnimate:null,snapshot:t(s,n,l,c,u)}}}return null}}(),t=function(){const e=wv((e,t)=>({x:e,y:t})),t=wv(Tw),n=wv((e,n=null,r)=>({mapped:{type:"SECONDARY",offset:e,combineTargetFor:n,shouldAnimateDisplacement:r,snapshot:t(n)}})),r=e=>e?n(iv,e,!0):null,a=(t,a,o,i)=>{const s=o.displaced.visible[t],l=Boolean(i.inVirtualList&&i.effected[t]),c=kv(o),u=c&&c.draggableId===t?a:null;if(!s){if(!l)return r(u);if(o.displaced.invisible[t])return null;const a=uv(i.displacedBy.point),s=e(a.x,a.y);return n(s,u,!0)}if(l)return r(u);const d=o.displacedBy.point,p=e(d.x,d.y);return n(p,u,s.shouldAnimate)};return(e,t)=>{if(Zy(e))return e.critical.draggable.id===t.draggableId?null:a(t.draggableId,e.critical.draggable.id,e.impact,e.afterCritical);if("DROP_ANIMATING"===e.phase){const n=e.completed;return n.result.draggableId===t.draggableId?null:a(t.draggableId,n.result.draggableId,n.impact,n.afterCritical)}return null}}();return(n,r)=>e(n,r)||t(n,r)||_w},{dropAnimationFinished:()=>({type:"DROP_ANIMATION_FINISHED",payload:null})},null,{context:Vy,areStatePropsEqual:Mw})(e=>{const t=(0,c.useRef)(null),n=ov((e=null)=>{t.current=e},[]),r=ov(()=>t.current,[]),{contextId:a,dragHandleUsageInstructionsId:o,registry:i}=Ow(Qy),{type:s,droppableId:l}=Ow(kw),d=av(()=>({id:e.draggableId,index:e.index,type:s,droppableId:l}),[e.draggableId,e.index,s,l]),{children:p,draggableId:f,isEnabled:m,shouldRespectForcePress:h,canDragInteractiveElements:g,isClone:v,mapped:b,dropAnimationFinished:y}=e;v||function(e){const t=Wy("draggable"),{descriptor:n,registry:r,getDraggableRef:a,canDragInteractiveElements:o,shouldRespectForcePress:i,isEnabled:s}=e,l=av(()=>({canDragInteractiveElements:o,shouldRespectForcePress:i,isEnabled:s}),[o,s,i]),u=ov(e=>{const t=a();return t||Wg(),function(e,t,n=iv){const r=window.getComputedStyle(t),a=t.getBoundingClientRect(),o=zg(a,r),i=Fg(o,n);return{descriptor:e,placeholder:{client:o,tagName:t.tagName.toLowerCase(),display:r.display},displaceBy:{x:o.marginBox.width,y:o.marginBox.height},client:o,page:i}}(n,t,e)},[n,a]),d=av(()=>({uniqueId:t,descriptor:n,options:l,getDimension:u}),[n,u,l,t]),p=(0,c.useRef)(d),f=(0,c.useRef)(!0);Ly(()=>(r.draggable.register(p.current),()=>r.draggable.unregister(p.current)),[r.draggable]),Ly(()=>{if(f.current)return void(f.current=!1);const e=p.current;p.current=d,r.draggable.update(d,e)},[d,r.draggable])}(av(()=>({descriptor:d,registry:i,getDraggableRef:r,canDragInteractiveElements:g,shouldRespectForcePress:h,isEnabled:m}),[d,i,r,g,h,m]));const w=av(()=>m?{tabIndex:0,role:"button","aria-describedby":o,"data-rfd-drag-handle-draggable-id":f,"data-rfd-drag-handle-context-id":a,draggable:!1,onDragStart:Pw}:null,[a,o,f,m]),E=ov(e=>{"DRAGGING"===b.type&&b.dropping&&"transform"===e.propertyName&&(0,Re.flushSync)(y)},[y,b]),R=av(()=>{const e=Sw(b),t="DRAGGING"===b.type&&b.dropping?E:void 0;return{innerRef:n,draggableProps:{"data-rfd-draggable-context-id":a,"data-rfd-draggable-id":f,style:e,onTransitionEnd:t},dragHandleProps:w}},[a,w,f,b,E,n]),x=av(()=>({draggableId:d.id,type:d.type,source:{index:d.index,droppableId:d.droppableId}}),[d.droppableId,d.id,d.index,d.type]);return u().createElement(u().Fragment,null,p(R,b.snapshot,x))});function Lw(e){return Ow(kw).isUsingCloneFor!==e.draggableId||e.isClone?u().createElement(Nw,e):null}function Dw(e){const t="boolean"!=typeof e.isDragDisabled||!e.isDragDisabled,n=Boolean(e.disableInteractiveElementBlocking),r=Boolean(e.shouldRespectForcePress);return u().createElement(Lw,ke({},e,{isClone:!1,isEnabled:t,canDragInteractiveElements:n,shouldRespectForcePress:r}))}const Bw=e=>t=>e===t,Fw=Bw("scroll"),zw=Bw("auto"),jw=(Bw("visible"),(e,t)=>t(e.overflowX)||t(e.overflowY)),Hw=e=>null==e||e===document.body||e===document.documentElement?null:(e=>{const t=window.getComputedStyle(e),n={overflowX:t.overflowX,overflowY:t.overflowY};return jw(n,Fw)||jw(n,zw)})(e)?e:Hw(e.parentElement);var Vw=e=>({x:e.scrollLeft,y:e.scrollTop});const Gw=e=>!!e&&("fixed"===window.getComputedStyle(e).position||Gw(e.parentElement));const qw={passive:!1},Uw={passive:!0};var Ww=e=>e.shouldPublishImmediately?qw:Uw;const Qw=e=>e&&e.env.closestScrollable||null;function Kw(e){const t=(0,c.useRef)(null),n=Ow(Qy),r=Wy("droppable"),{registry:a,marshal:o}=n,i=Ky(e),s=av(()=>({id:e.droppableId,type:e.type,mode:e.mode}),[e.droppableId,e.mode,e.type]),l=(0,c.useRef)(s),u=av(()=>wv((e,n)=>{t.current||Wg();const r={x:e,y:n};o.updateDroppableScroll(s.id,r)}),[s.id,o]),d=ov(()=>{const e=t.current;return e&&e.env.closestScrollable?Vw(e.env.closestScrollable):iv},[]),p=ov(()=>{const e=d();u(e.x,e.y)},[d,u]),f=av(()=>Hg(p),[p]),m=ov(()=>{const e=t.current,n=Qw(e);e&&n||Wg(),e.scrollOptions.shouldPublishImmediately?p():f()},[f,p]),h=ov((e,r)=>{t.current&&Wg();const a=i.current,o=a.getDroppableRef();o||Wg();const l=(e=>({closestScrollable:Hw(e),isFixedOnPage:Gw(e)}))(o),c={ref:o,descriptor:s,env:l,scrollOptions:r};t.current=c;const u=(({ref:e,descriptor:t,env:n,windowScroll:r,direction:a,isDropDisabled:o,isCombineEnabled:i,shouldClipSubject:s})=>{const l=n.closestScrollable,c=((e,t)=>{const n=jg(e);if(!t)return n;if(e!==t)return n;const r=n.paddingBox.top-t.scrollTop,a=n.paddingBox.left-t.scrollLeft,o=r+t.scrollHeight,i=a+t.scrollWidth,s=Tg({top:r,right:i,bottom:o,left:a},n.border);return Lg({borderBox:s,margin:n.margin,border:n.border,padding:n.padding})})(e,l),u=Fg(c,r),d=(()=>{if(!l)return null;const e=jg(l),t={scrollHeight:l.scrollHeight,scrollWidth:l.scrollWidth};return{client:e,page:Fg(e,r),scroll:Vw(l),scrollSize:t,shouldClipSubject:s}})(),p=(({descriptor:e,isEnabled:t,isCombineEnabled:n,isFixedOnPage:r,direction:a,client:o,page:i,closest:s})=>{const l=(()=>{if(!s)return null;const{scrollSize:e,client:t}=s,n=ly({scrollHeight:e.scrollHeight,scrollWidth:e.scrollWidth,height:t.paddingBox.height,width:t.paddingBox.width});return{pageMarginBox:s.page.marginBox,frameClient:t,scrollSize:e,shouldClipSubject:s.shouldClipSubject,scroll:{initial:s.scroll,current:s.scroll,max:n,diff:{value:iv,displacement:iv}}}})(),c="vertical"===a?Dv:Bv;return{descriptor:e,isCombineEnabled:n,isFixedOnPage:r,axis:c,isEnabled:t,client:o,page:i,frame:l,subject:bv({page:i,withPlaceholder:null,axis:c,frame:l})}})({descriptor:t,isEnabled:!o,isCombineEnabled:i,isFixedOnPage:n.isFixedOnPage,direction:a,client:c,page:u,closest:d});return p})({ref:o,descriptor:s,env:l,windowScroll:e,direction:a.direction,isDropDisabled:a.isDropDisabled,isCombineEnabled:a.isCombineEnabled,shouldClipSubject:!a.ignoreContainerClipping}),d=l.closestScrollable;return d&&(d.setAttribute(_y.contextId,n.contextId),d.addEventListener("scroll",m,Ww(c.scrollOptions))),u},[n.contextId,s,m,i]),g=ov(()=>{const e=t.current,n=Qw(e);return e&&n||Wg(),Vw(n)},[]),v=ov(()=>{const e=t.current;e||Wg();const n=Qw(e);t.current=null,n&&(f.cancel(),n.removeAttribute(_y.contextId),n.removeEventListener("scroll",m,Ww(e.scrollOptions)))},[m,f]),b=ov(e=>{const n=t.current;n||Wg();const r=Qw(n);r||Wg(),r.scrollTop+=e.y,r.scrollLeft+=e.x},[]),y=av(()=>({getDimensionAndWatchScroll:h,getScrollWhileDragging:g,dragStopped:v,scroll:b}),[v,h,g,b]),w=av(()=>({uniqueId:r,descriptor:s,callbacks:y}),[y,s,r]);Ly(()=>(l.current=w.descriptor,a.droppable.register(w),()=>{t.current&&v(),a.droppable.unregister(w)}),[y,s,v,w,o,a.droppable]),Ly(()=>{t.current&&o.updateDroppableIsEnabled(l.current.id,!e.isDropDisabled)},[e.isDropDisabled,o]),Ly(()=>{t.current&&o.updateDroppableIsCombineEnabled(l.current.id,e.isCombineEnabled)},[e.isCombineEnabled,o])}function Zw(){}const Jw={width:0,height:0,margin:{top:0,right:0,bottom:0,left:0}};var Xw=u().memo(e=>{const t=(0,c.useRef)(null),n=ov(()=>{t.current&&(clearTimeout(t.current),t.current=null)},[]),{animate:r,onTransitionEnd:a,onClose:o,contextId:i}=e,[s,l]=(0,c.useState)("open"===e.animate);(0,c.useEffect)(()=>s?"open"!==r?(n(),l(!1),Zw):t.current?Zw:(t.current=setTimeout(()=>{t.current=null,l(!1)}),n):Zw,[r,s,n]);const d=ov(e=>{"height"===e.propertyName&&(a(),"close"===r&&o())},[r,o,a]),p=(({isAnimatingOpenOnMount:e,placeholder:t,animate:n})=>{const r=(({isAnimatingOpenOnMount:e,placeholder:t,animate:n})=>e||"close"===n?Jw:{height:t.client.borderBox.height,width:t.client.borderBox.width,margin:t.client.margin})({isAnimatingOpenOnMount:e,placeholder:t,animate:n});return{display:t.display,boxSizing:"border-box",width:r.width,height:r.height,marginTop:r.margin.top,marginRight:r.margin.right,marginBottom:r.margin.bottom,marginLeft:r.margin.left,flexShrink:"0",flexGrow:"0",pointerEvents:"none",transition:"none"!==n?qb.placeholder:null}})({isAnimatingOpenOnMount:s,animate:e.animate,placeholder:e.placeholder});return u().createElement(e.placeholder.tagName,{style:p,"data-rfd-placeholder-context-id":i,onTransitionEnd:d,ref:e.innerRef})});class Yw extends u().PureComponent{constructor(...e){super(...e),this.state={isVisible:Boolean(this.props.on),data:this.props.on,animate:this.props.shouldAnimate&&this.props.on?"open":"none"},this.onClose=()=>{"close"===this.state.animate&&this.setState({isVisible:!1})}}static getDerivedStateFromProps(e,t){return e.shouldAnimate?e.on?{isVisible:!0,data:e.on,animate:"open"}:t.isVisible?{isVisible:!0,data:t.data,animate:"close"}:{isVisible:!1,animate:"close",data:null}:{isVisible:Boolean(e.on),data:e.on,animate:"none"}}render(){if(!this.state.isVisible)return null;const e={onClose:this.onClose,data:this.state.data,animate:this.state.animate};return this.props.children(e)}}const $w={mode:"standard",type:"DEFAULT",direction:"vertical",isDropDisabled:!1,isCombineEnabled:!1,ignoreContainerClipping:!1,renderClone:null,getContainerForClone:function(){return document.body||Wg(),document.body}},eE=e=>{let t,n={...e};for(t in $w)void 0===e[t]&&(n={...n,[t]:$w[t]});return n},tE=(e,t)=>e===t.droppable.type,nE=(e,t)=>t.draggables[e.draggable.id],rE=Pg(()=>{const e={placeholder:null,shouldAnimatePlaceholder:!0,snapshot:{isDraggingOver:!1,draggingOverWith:null,draggingFromThisWith:null,isUsingPlaceholder:!1},useClone:null},t={...e,shouldAnimatePlaceholder:!1},n=wv(e=>({draggableId:e.id,type:e.type,source:{index:e.index,droppableId:e.droppableId}})),r=wv((r,a,o,i,s,l)=>{const c=s.descriptor.id;if(s.descriptor.droppableId===r){const e=l?{render:l,dragging:n(s.descriptor)}:null,t={isDraggingOver:o,draggingOverWith:o?c:null,draggingFromThisWith:c,isUsingPlaceholder:!0};return{placeholder:s.placeholder,shouldAnimatePlaceholder:!1,snapshot:t,useClone:e}}if(!a)return t;if(!i)return e;const u={isDraggingOver:o,draggingOverWith:c,draggingFromThisWith:null,isUsingPlaceholder:!0};return{placeholder:s.placeholder,shouldAnimatePlaceholder:!0,snapshot:u,useClone:null}});return(n,a)=>{const o=eE(a),i=o.droppableId,s=o.type,l=!o.isDropDisabled,c=o.renderClone;if(Zy(n)){const e=n.critical;if(!tE(s,e))return t;const a=nE(e,n.dimensions),o=sb(n.impact)===i;return r(i,l,o,o,a,c)}if("DROP_ANIMATING"===n.phase){const e=n.completed;if(!tE(s,e.critical))return t;const a=nE(e.critical,n.dimensions);return r(i,l,Iw(e.result)===i,sb(e.impact)===i,a,c)}if("IDLE"===n.phase&&n.completed&&!n.shouldFlush){const r=n.completed;if(!tE(s,r.critical))return t;const a=sb(r.impact)===i,o=Boolean(r.impact.at&&"COMBINE"===r.impact.at.type),l=r.critical.droppable.id===i;return a?o?e:t:l?e:t}return t}},{updateViewportMaxScroll:e=>({type:"UPDATE_VIEWPORT_MAX_SCROLL",payload:e})},(e,t,n)=>({...eE(n),...e,...t}),{context:Vy,areStatePropsEqual:Mw})(e=>{const t=(0,c.useContext)(Qy);t||Wg();const{contextId:n,isMovementAllowed:r}=t,a=(0,c.useRef)(null),o=(0,c.useRef)(null),{children:i,droppableId:s,type:l,mode:d,direction:p,ignoreContainerClipping:f,isDropDisabled:m,isCombineEnabled:h,snapshot:g,useClone:v,updateViewportMaxScroll:b,getContainerForClone:y}=e,w=ov(()=>a.current,[]),E=ov((e=null)=>{a.current=e},[]),R=(ov(()=>o.current,[]),ov((e=null)=>{o.current=e},[])),x=ov(()=>{r()&&b({maxScroll:uy()})},[r,b]);Kw({droppableId:s,type:l,mode:d,direction:p,isDropDisabled:m,isCombineEnabled:h,ignoreContainerClipping:f,getDroppableRef:w});const A=av(()=>u().createElement(Yw,{on:e.placeholder,shouldAnimate:e.shouldAnimatePlaceholder},({onClose:e,data:t,animate:r})=>u().createElement(Xw,{placeholder:t,onClose:e,innerRef:R,animate:r,contextId:n,onTransitionEnd:x})),[n,x,e.placeholder,e.shouldAnimatePlaceholder,R]),C=av(()=>({innerRef:E,placeholder:A,droppableProps:{"data-rfd-droppable-id":s,"data-rfd-droppable-context-id":n}}),[n,s,A,E]),S=v?v.dragging.draggableId:null,k=av(()=>({droppableId:s,type:l,isUsingCloneFor:S}),[s,S,l]);return u().createElement(kw.Provider,{value:k},i(C,g),function(){if(!v)return null;const{dragging:e,render:t}=v,n=u().createElement(Lw,{draggableId:e.draggableId,index:e.source.index,isClone:!0,isEnabled:!0,shouldRespectForcePress:!1,canDragInteractiveElements:!0},(n,r)=>t(n,r,e));return xe().createPortal(n,y())}())});function aE(){return aE=Object.assign?Object.assign.bind():function(e){for(var t=1;t<arguments.length;t++){var n=arguments[t];for(var r in n)({}).hasOwnProperty.call(n,r)&&(e[r]=n[r])}return e},aE.apply(null,arguments)}function oE(e,t){return function(e){if(Array.isArray(e))return e}(e)||function(e,t){var n=null==e?null:"undefined"!=typeof Symbol&&e[Symbol.iterator]||e["@@iterator"];if(null!=n){var r,a,o,i,s=[],l=!0,c=!1;try{if(o=(n=n.call(e)).next,0===t){if(Object(n)!==n)return;l=!1}else for(;!(l=(r=o.call(n)).done)&&(s.push(r.value),s.length!==t);l=!0);}catch(e){c=!0,a=e}finally{try{if(!l&&null!=n.return&&(i=n.return(),Object(i)!==i))return}finally{if(c)throw a}}return s}}(e,t)||iE(e,t)||function(){throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.")}()}function iE(e,t){if(e){if("string"==typeof e)return sE(e,t);var n={}.toString.call(e).slice(8,-1);return"Object"===n&&e.constructor&&(n=e.constructor.name),"Map"===n||"Set"===n?Array.from(e):"Arguments"===n||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)?sE(e,t):void 0}}function sE(e,t){(null==t||t>e.length)&&(t=e.length);for(var n=0,r=Array(t);n<t;n++)r[n]=e[n];return r}const lE=function(e){var t=e.label,n=void 0===t?"":t,r=e.items,a=e.values,o=e.onChange,s=e.onInputChange,l=void 0!==s&&s,c=e.searchable,u=void 0!==c&&c,d=e.uniqueId,p=void 0===d?"":d,f=oE((0,i.useState)([]),2),m=f[0],h=f[1],g=oE((0,i.useState)(""),2),v=g[0],b=g[1],y=oE((0,i.useState)(!1),2),w=y[0],E=y[1],R=null==a?void 0:a.map(function(e){return e.value}),x=(0,i.useRef)(null),A=function(e){return null==e?void 0:e.filter(function(e){return!R.includes(e.value)})};(0,i.useEffect)(function(){var e;e=w?A(r):[],h(e)},[r,a,w]);var C=32*(null==a?void 0:a.length)+2+"px";return React.createElement("div",{className:"shaped-plugin-multiple-select sp-eab-component-mb"},React.createElement("div",{className:"sp-multiple-select-dnd-label"},React.createElement("p",null," ",n)),React.createElement("div",{className:"sp-multiple-select-dnd-container",ref:x},React.createElement("div",{onClick:function(){E(function(e){return!e})},className:"sp-select-header"},React.createElement("div",{className:"sp-selected-options",style:{height:C}},React.createElement(xw,{onDragEnd:function(e){var t=e.source,n=e.destination;if(n){var r=t.index,i=n.index,s=kh(a,r,i);o(s)}}},React.createElement(rE,{droppableId:"select-field-dnd-".concat(p),direction:"vertical"},function(e){return React.createElement("div",aE({ref:e.innerRef},e.droppableProps),null==a?void 0:a.map(function(e,t){var n;return React.createElement(Dw,{key:null==e?void 0:e.id,draggableId:null==e||null===(n=e.id)||void 0===n?void 0:n.toString(),index:t},function(t){return React.createElement("div",aE({ref:t.innerRef},t.draggableProps,t.dragHandleProps),React.createElement("div",{className:"sp-selected-option"},React.createElement("span",{className:"sp-select-label"},null==e?void 0:e.label),React.createElement("span",{className:"sp-select-remove-button",onClick:function(){return t=e.id,n=null==a?void 0:a.filter(function(e){return e.id!==t}),void o(n);var t,n}},React.createElement(wh,null))))})}))}))),React.createElement("span",{className:"custom-select-arrow"},w?React.createElement(Rh,null):React.createElement(Eh,null))),w&&React.createElement("div",{className:"sp-select-options"},u&&React.createElement("input",{placeholder:"Search here for more...",value:v,onChange:function(e){return function(e){var t=e.target.value.toLowerCase();b(t);var n=A(r).filter(function(e){return e.label.toLowerCase().includes(t)});l?l(t):h(n)}(e)},className:"sp-select-search-field"}),(null==m?void 0:m.length)>0&&(null==m?void 0:m.map(function(e,t){return React.createElement("div",{key:t},e.label&&e.value&&React.createElement("div",{onClick:function(){return function(e){var t,n=e.id,r=e.value,i=e.label,s=[].concat(function(e){if(Array.isArray(e))return sE(e)}(t=a)||function(e){if("undefined"!=typeof Symbol&&null!=e[Symbol.iterator]||null!=e["@@iterator"])return Array.from(e)}(t)||iE(t)||function(){throw new TypeError("Invalid attempt to spread non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.")}(),[{id:n,value:r,label:i}]);b(""),o(s)}(e)},className:"sp-select-option ".concat(a===e.value?"selected":"")},e.label))})))))};var cE=function(){return React.createElement("svg",{xmlns:"http://www.w3.org/2000/svg",width:25,height:24,fill:"none"},React.createElement("path",{fill:"#757575",d:"M12.25 17c3.3 0 6-2.7 6-6V3h-2.5v8c0 1.95-1.55 3.5-3.5 3.5s-3.5-1.55-3.5-3.5V3h-2.5v8c0 3.3 2.7 6 6 6Zm-7 2v2h14v-2h-14Z"}))},uE=function(){return React.createElement("svg",{xmlns:"http://www.w3.org/2000/svg",width:25,height:24,fill:"none"},React.createElement("path",{fill:"#757575",fillRule:"evenodd",d:"M12.154 19c-.795 0-1.603-.09-2.423-.27-.82-.166-1.481-.365-1.981-.595L8 16.192c.641.308 1.365.577 2.173.808.808.23 1.61.346 2.404.346.897 0 1.59-.16 2.077-.48.5-.334.75-.828.75-1.481 0-.488-.128-.891-.385-1.212-.243-.333-.609-.609-1.096-.827a9.075 9.075 0 0 0-.83-.346H4.75v-1h16v1h-4.094c.499.587.748 1.337.748 2.25 0 1.18-.442 2.103-1.327 2.77-.885.653-2.192.98-3.923.98ZM7.84 9a4.884 4.884 0 0 1-.013-.365c0-1.09.417-1.968 1.25-2.635.846-.667 2.032-1 3.558-1 .82 0 1.596.09 2.326.27.744.179 1.392.397 1.943.653l-.192 1.942c-.718-.423-1.41-.73-2.077-.923a7.456 7.456 0 0 0-2.077-.288c-.834 0-1.5.154-2 .461-.488.308-.731.782-.731 1.423 0 .165.016.32.047.462H7.84Z",clipRule:"evenodd"}))},dE=function(){return React.createElement("svg",{xmlns:"http://www.w3.org/2000/svg",width:25,height:24,fill:"none"},React.createElement("path",{fill:"#757575",d:"M12.358 17.5h-1.911l2.248-10.569h1.912L12.358 17.5Z"}))},pE=function(){return React.createElement("svg",{xmlns:"http://www.w3.org/2000/svg",width:24,height:24,viewBox:"0 0 24 24",fill:"none"},React.createElement("rect",{x:.8,y:.8,width:22.4,height:22.4,rx:3.2,stroke:"#2F2F2F",strokeWidth:1.6}),React.createElement("path",{d:"M13.0315 16.75L11.0684 11.1504C10.1567 8.55012 9.70094 7.25 8.9601 7.25C8.21926 7.25 7.76345 8.55012 6.85184 11.1504L4.88867 16.75M6.5851 12H11.3351",stroke:"#2F2F2F",strokeWidth:1.5,strokeLinecap:"round",strokeLinejoin:"round"}),React.createElement("path",{d:"M19.0884 13.3159V16.3695M19.0884 13.3159C19.1204 12.7574 19.1217 12.3319 19.0546 11.9846C18.8965 11.166 18.0411 10.6727 17.2134 10.5723C16.4212 10.4763 15.7853 10.6802 15.142 11.6175M19.0884 13.3159H17.1588C16.8624 13.3159 16.5634 13.3302 16.2778 13.4096C14.532 13.8949 14.66 16.3431 16.4108 16.6449C16.6053 16.6784 16.8039 16.6928 17.0008 16.6839C17.4606 16.6634 17.8848 16.4413 18.249 16.1597C18.6754 15.8299 19.0884 15.3695 19.0884 14.6731V13.3159Z",stroke:"#2F2F2F",strokeWidth:1.5,strokeLinecap:"round",strokeLinejoin:"round"}))};function fE(){var e,t,n="function"==typeof Symbol?Symbol:{},r=n.iterator||"@@iterator",a=n.toStringTag||"@@toStringTag";function o(n,r,a,o){var l=r&&r.prototype instanceof s?r:s,c=Object.create(l.prototype);return mE(c,"_invoke",function(n,r,a){var o,s,l,c=0,u=a||[],d=!1,p={p:0,n:0,v:e,a:f,f:f.bind(e,4),d:function(t,n){return o=t,s=0,l=e,p.n=n,i}};function f(n,r){for(s=n,l=r,t=0;!d&&c&&!a&&t<u.length;t++){var a,o=u[t],f=p.p,m=o[2];n>3?(a=m===r)&&(l=o[(s=o[4])?5:(s=3,3)],o[4]=o[5]=e):o[0]<=f&&((a=n<2&&f<o[1])?(s=0,p.v=r,p.n=o[1]):f<m&&(a=n<3||o[0]>r||r>m)&&(o[4]=n,o[5]=r,p.n=m,s=0))}if(a||n>1)return i;throw d=!0,r}return function(a,u,m){if(c>1)throw TypeError("Generator is already running");for(d&&1===u&&f(u,m),s=u,l=m;(t=s<2?e:l)||!d;){o||(s?s<3?(s>1&&(p.n=-1),f(s,l)):p.n=l:p.v=l);try{if(c=2,o){if(s||(a="next"),t=o[a]){if(!(t=t.call(o,l)))throw TypeError("iterator result is not an object");if(!t.done)return t;l=t.value,s<2&&(s=0)}else 1===s&&(t=o.return)&&t.call(o),s<2&&(l=TypeError("The iterator does not provide a '"+a+"' method"),s=1);o=e}else if((t=(d=p.n<0)?l:n.call(r,p))!==i)break}catch(t){o=e,s=1,l=t}finally{c=1}}return{value:t,done:d}}}(n,a,o),!0),c}var i={};function s(){}function l(){}function c(){}t=Object.getPrototypeOf;var u=[][r]?t(t([][r]())):(mE(t={},r,function(){return this}),t),d=c.prototype=s.prototype=Object.create(u);function p(e){return Object.setPrototypeOf?Object.setPrototypeOf(e,c):(e.__proto__=c,mE(e,a,"GeneratorFunction")),e.prototype=Object.create(d),e}return l.prototype=c,mE(d,"constructor",c),mE(c,"constructor",l),l.displayName="GeneratorFunction",mE(c,a,"GeneratorFunction"),mE(d),mE(d,a,"Generator"),mE(d,r,function(){return this}),mE(d,"toString",function(){return"[object Generator]"}),(fE=function(){return{w:o,m:p}})()}function mE(e,t,n,r){var a=Object.defineProperty;try{a({},"",{})}catch(e){a=0}mE=function(e,t,n,r){function o(t,n){mE(e,t,function(e){return this._invoke(t,n,e)})}t?a?a(e,t,{value:n,enumerable:!r,configurable:!r,writable:!r}):e[t]=n:(o("next",0),o("throw",1),o("return",2))},mE(e,t,n,r)}function hE(e,t,n,r,a,o,i){try{var s=e[o](i),l=s.value}catch(e){return void n(e)}s.done?t(l):Promise.resolve(l).then(r,a)}var gE=function(){var e=function(e){return function(){var t=this,n=arguments;return new Promise(function(r,a){var o=e.apply(t,n);function i(e){hE(o,r,a,i,s,"next",e)}function s(e){hE(o,r,a,i,s,"throw",e)}i(void 0)})}}(fE().m(function e(){var t,n;return fE().w(function(e){for(;;)switch(e.p=e.n){case 0:return e.p=0,e.n=1,fetch("https://www.googleapis.com/webfonts/v1/webfonts?key=AIzaSyCJIzfKoHlACqsmK1zDzl-OAsgtJPk8BtI");case 1:if(200!==(t=e.v).status){e.n=2;break}return e.a(2,t.json());case 2:e.n=4;break;case 3:e.p=3,n=e.v,console.error("Error fetching Google Fonts:",n);case 4:return e.a(2)}},e,null,[[0,3]])}));return function(){return e.apply(this,arguments)}}(),vE={100:"Thin 100",200:"Extra Light 200",300:"Light 300",400:"Regular 400",500:"Medium 500",600:"Semi Bold 600",700:"Bold 700",800:"Extra Bold 800",900:"Black 900","100italic":"italic 100","200italic":"italic 200","300italic":"italic 300",italic:"italic 400","400italic":"italic 400","500italic":"italic 500","600italic":"italic 600","700italic":"italic 700","800italic":"italic 800","900italic":"italic 900"},bE=[{label:React.createElement(dE,null),key:"style",value:"italic"},{label:React.createElement(cE,null),key:"decoration",value:"underline"},{label:React.createElement(uE,null),key:"decoration",value:"line-through"},{label:"AB",key:"transform",value:"uppercase"},{label:"ab",key:"transform",value:"lowercase"},{label:"Ab",key:"transform",value:"capitalize"}],yE=function(e){return(0,i.useMemo)(function(){var t;return null==e||null===(t=e.font)||void 0===t||null===(t=t.variants)||void 0===t?void 0:t.map(function(e){if("regular"===e&&(e="400"),vE[e])return{label:vE[e],value:e}})},[e])};function wE(e){return wE="function"==typeof Symbol&&"symbol"==typeof Symbol.iterator?function(e){return typeof e}:function(e){return e&&"function"==typeof Symbol&&e.constructor===Symbol&&e!==Symbol.prototype?"symbol":typeof e},wE(e)}function EE(e,t){var n=Object.keys(e);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(e);t&&(r=r.filter(function(t){return Object.getOwnPropertyDescriptor(e,t).enumerable})),n.push.apply(n,r)}return n}function RE(e){for(var t=1;t<arguments.length;t++){var n=null!=arguments[t]?arguments[t]:{};t%2?EE(Object(n),!0).forEach(function(t){xE(e,t,n[t])}):Object.getOwnPropertyDescriptors?Object.defineProperties(e,Object.getOwnPropertyDescriptors(n)):EE(Object(n)).forEach(function(t){Object.defineProperty(e,t,Object.getOwnPropertyDescriptor(n,t))})}return e}function xE(e,t,n){return(t=function(e){var t=function(e){if("object"!=wE(e)||!e)return e;var t=e[Symbol.toPrimitive];if(void 0!==t){var n=t.call(e,"string");if("object"!=wE(n))return n;throw new TypeError("@@toPrimitive must return a primitive value.")}return String(e)}(e);return"symbol"==wE(t)?t:t+""}(t))in e?Object.defineProperty(e,t,{value:n,enumerable:!0,configurable:!0,writable:!0}):e[t]=n,e}function AE(e){return function(e){if(Array.isArray(e))return kE(e)}(e)||function(e){if("undefined"!=typeof Symbol&&null!=e[Symbol.iterator]||null!=e["@@iterator"])return Array.from(e)}(e)||SE(e)||function(){throw new TypeError("Invalid attempt to spread non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.")}()}function CE(e,t){return function(e){if(Array.isArray(e))return e}(e)||function(e,t){var n=null==e?null:"undefined"!=typeof Symbol&&e[Symbol.iterator]||e["@@iterator"];if(null!=n){var r,a,o,i,s=[],l=!0,c=!1;try{if(o=(n=n.call(e)).next,0===t){if(Object(n)!==n)return;l=!1}else for(;!(l=(r=o.call(n)).done)&&(s.push(r.value),s.length!==t);l=!0);}catch(e){c=!0,a=e}finally{try{if(!l&&null!=n.return&&(i=n.return(),Object(i)!==i))return}finally{if(c)throw a}}return s}}(e,t)||SE(e,t)||function(){throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.")}()}function SE(e,t){if(e){if("string"==typeof e)return kE(e,t);var n={}.toString.call(e).slice(8,-1);return"Object"===n&&e.constructor&&(n=e.constructor.name),"Map"===n||"Set"===n?Array.from(e):"Arguments"===n||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)?kE(e,t):void 0}}function kE(e,t){(null==t||t>e.length)&&(t=e.length);for(var n=0,r=Array(t);n<t;n++)r[n]=e[n];return r}(0,i.memo)(function(e){var t,n,r,a=e.attributes,o=e.setAttributes,s=e.label,c=void 0===s?(0,l.__)("Typography","easy-accordion-free"):s,u=e.fontSizeDefault,d=void 0===u?{unit:"px",value:16}:u,p=CE((0,i.useState)([]),2),f=p[0],m=p[1],h=CE((0,i.useState)([]),2),g=h[0],v=h[1],b=a.typography,y=a.typographyKey,w=a.fontSize,E=a.fontSizeKey,R=a.letterSpacing,x=a.letterSpacingKey,A=a.lineHeight,C=a.lineHeightKey,S=Wc();(0,i.useEffect)(function(){0===f.length&&gE().then(function(e){var t=e.items.map(function(e){return{label:e.family,value:e.family,font:{family:e.family,variants:e.variants}}});m(t),v(t.filter(function(e,t){return t<50&&e}))})},[]);var k=b.family,O=b.fontWeight,P=b.style,M={label:"Default",value:"Default",font:{family:"Default",variants:["300","400","500","600","700","800"]}},I=""===k?M:null==f?void 0:f.find(function(e){return e.value===k}),T=[M].concat(AE(g)),_=(null==T?void 0:T.find(function(e){return e.value===(null==I?void 0:I.value)}))?T:[M,I].concat(AE(g)),N=function(e){o(xE({},E,RE(RE({},w),{},{device:RE(RE({},null==w?void 0:w.device),{},xE({},S,e))})))};return React.createElement(lR,{label:c,toggleIcon:React.createElement("span",{className:"sp-eab-typography-icon"},React.createElement(pE,null))},React.createElement("div",{className:"sp-eab-typography"},React.createElement("div",{className:"sp-eab-typography-header sp-eab-component-mb sp-d-flex sp-align-center"},React.createElement("span",null,"Typography")),React.createElement("div",{className:"sp-eab-typography-select-fields sp-d-flex sp-justify-between sp-align-center"},React.createElement("div",{className:"sp-eab-typography-family sp-eab-select-field sp-eab-component-mb"},React.createElement("div",{className:"sp-eab-font-family-header sp-mb-8px"},React.createElement("span",{className:"sp-eab-component-title"},"Font family")),React.createElement(um,{classNamePrefix:"sp-eab-font-family-select",options:_,value:I,placeholder:null==I?void 0:I.label,onChange:function(e){var t,n,r,a;o(xE({},y,RE(RE({},b),{},{family:"Default"!==(null==e||null===(t=e.font)||void 0===t?void 0:t.family)?null==e||null===(n=e.font)||void 0===n?void 0:n.family:"",fontWeight:"regular"===(null==e||null===(r=e.font)||void 0===r?void 0:r.variants[0])?"400":null==e||null===(a=e.font)||void 0===a?void 0:a.variants[0]})))},onInputChange:function(e){return function(e){var t=f.filter(function(t){return t.label.toLowerCase().includes(e.toLowerCase())}).filter(function(e,t){return t<30&&e});v(t)}(e)}})),React.createElement(mh,{label:(0,l.__)("Font Style","easy-accordion-free"),attributes:null!=I&&null!==(t=I.font)&&void 0!==t&&t.variants.includes("".concat(O).concat(P))?"".concat(O).concat(P):O,items:yE(I),onChange:function(e){return function(e){var t,n=null===(t=vE[e])||void 0===t?void 0:t.split(" "),r=vE[e].includes("italic")?"italic":"",a=n[(null==n?void 0:n.length)-1];o(xE({},y,RE(RE({},b),{},{fontWeight:a,style:r})))}(e)},__nextHasNoMarginBottom:!0})),React.createElement("div",{className:"sp-eab-typography-font-size-picker sp-eab-component-mb"},React.createElement(Jm,{label:(0,l.__)("Font Size","easy-accordion-free"),attributes:w,attributesKey:E,setAttributes:o,units:["px","%","em"],onReset:function(){o(xE({},E,RE(RE({},w),{},{unit:RE(RE({},w.unit),{},xE({},S,null==d?void 0:d.unit))}))),N(null==d?void 0:d.value)}}),React.createElement(Uc.RangeControl,{color:"#f26c0d",value:null==w?void 0:w.device[S],onChange:function(e){return N(e)},__next40pxDefaultSize:!0,__nextHasNoMarginBottom:!0})),React.createElement("div",{className:"sp-eab-typography-select-fields sp-d-flex sp-justify-between sp-align-center"},React.createElement("div",{className:"sp-eab-typography-line-height-picker"},React.createElement(Jm,{label:(0,l.__)("Line Height","easy-accordion-free"),attributes:A,attributesKey:C,setAttributes:o,units:!1}),React.createElement(yh,{attributes:null==A?void 0:A.device[S],mb:!1,step:.1,min:0,inputType:"number",onChange:function(e){return t=e,void o(xE({},C,RE(RE({},A),{},{device:RE(RE({},null==A?void 0:A.device),{},xE({},S,t))})));var t},__next40pxDefaultSize:!0})),React.createElement("div",{className:"sp-eab-typography-letter-spacing-picker"},React.createElement(Jm,{label:(0,l.__)("Letter Spacing","easy-accordion-free"),attributes:R,attributesKey:x,setAttributes:o,units:["px","%","em"]}),React.createElement(yh,{attributes:null!==(n=null==R||null===(r=R.device)||void 0===r?void 0:r[S])&&void 0!==n?n:0,mb:!1,inputType:"number",onChange:function(e){o(xE({},x,RE(RE({},R||{}),{},{device:RE(RE({},(null==R?void 0:R.device)||{}),{},xE({},S,null!=e?e:0))})))},__next40pxDefaultSize:!0}))),React.createElement("div",{className:"sp-eab-button-group sp-eab-component-mb"},React.createElement("span",{className:"sp-eab-component-title sp-mb-8px"},(0,l.__)("Text Format","easy-accordion-free")),React.createElement("div",{className:"sp-eab-button-group-items sp-d-flex sp-align-center",style:{"--total-buttons":null==bE?void 0:bE.length}},null==bE?void 0:bE.map(function(e,t){var n=e.label,r=e.key,a=e.value;return React.createElement(Cm,{key:t,className:"".concat(b[r]===a?" active":""),onClick:function(){return function(e,t){var n=b[e]===t?"":t;o(xE({},y,RE(RE({},b),{},xE({},e,n))))}(r,a)}},React.createElement("span",{title:a},n))})))))});"undefined"!=typeof window&&void 0!==window.document&&window.document.createElement;function OE(e){const t=Object.prototype.toString.call(e);return"[object Window]"===t||"[object global]"===t}function PE(e){return"nodeType"in e}function ME(e){var t,n;return e?OE(e)?e:PE(e)&&null!=(t=null==(n=e.ownerDocument)?void 0:n.defaultView)?t:window:window}function IE(e){const{Document:t}=ME(e);return e instanceof t}function TE(e){return!OE(e)&&e instanceof ME(e).HTMLElement}function _E(e){return e instanceof ME(e).SVGElement}function NE(e){return e?OE(e)?e.document:PE(e)?IE(e)?e:TE(e)||_E(e)?e.ownerDocument:document:document:document}function LE(e){return function(t){for(var n=arguments.length,r=new Array(n>1?n-1:0),a=1;a<n;a++)r[a-1]=arguments[a];return r.reduce((t,n)=>{const r=Object.entries(n);for(const[n,a]of r){const r=t[n];null!=r&&(t[n]=r+e*a)}return t},{...t})}}const DE=LE(-1);function BE(e){if(function(e){if(!e)return!1;const{TouchEvent:t}=ME(e.target);return t&&e instanceof t}(e)){if(e.touches&&e.touches.length){const{clientX:t,clientY:n}=e.touches[0];return{x:t,y:n}}if(e.changedTouches&&e.changedTouches.length){const{clientX:t,clientY:n}=e.changedTouches[0];return{x:t,y:n}}}return function(e){return"clientX"in e&&"clientY"in e}(e)?{x:e.clientX,y:e.clientY}:null}var FE;!function(e){e.DragStart="dragStart",e.DragMove="dragMove",e.DragEnd="dragEnd",e.DragCancel="dragCancel",e.DragOver="dragOver",e.RegisterDroppable="registerDroppable",e.SetDroppableDisabled="setDroppableDisabled",e.UnregisterDroppable="unregisterDroppable"}(FE||(FE={}));const zE=Object.freeze({x:0,y:0});var jE,HE,VE;!function(e){e[e.Forward=1]="Forward",e[e.Backward=-1]="Backward"}(jE||(jE={}));class GE{constructor(e){this.target=void 0,this.listeners=[],this.removeAll=()=>{this.listeners.forEach(e=>{var t;return null==(t=this.target)?void 0:t.removeEventListener(...e)})},this.target=e}add(e,t,n){var r;null==(r=this.target)||r.addEventListener(e,t,n),this.listeners.push([e,t,n])}}function qE(e,t){const n=Math.abs(e.x),r=Math.abs(e.y);return"number"==typeof t?Math.sqrt(n**2+r**2)>t:"x"in t&&"y"in t?n>t.x&&r>t.y:"x"in t?n>t.x:"y"in t&&r>t.y}function UE(e){e.preventDefault()}function WE(e){e.stopPropagation()}!function(e){e.Click="click",e.DragStart="dragstart",e.Keydown="keydown",e.ContextMenu="contextmenu",e.Resize="resize",e.SelectionChange="selectionchange",e.VisibilityChange="visibilitychange"}(HE||(HE={})),function(e){e.Space="Space",e.Down="ArrowDown",e.Right="ArrowRight",e.Left="ArrowLeft",e.Up="ArrowUp",e.Esc="Escape",e.Enter="Enter",e.Tab="Tab"}(VE||(VE={}));VE.Space,VE.Enter,VE.Esc,VE.Space,VE.Enter,VE.Tab;function QE(e){return Boolean(e&&"distance"in e)}function KE(e){return Boolean(e&&"delay"in e)}class ZE{constructor(e,t,n){var r;void 0===n&&(n=function(e){const{EventTarget:t}=ME(e);return e instanceof t?e:NE(e)}(e.event.target)),this.props=void 0,this.events=void 0,this.autoScrollEnabled=!0,this.document=void 0,this.activated=!1,this.initialCoordinates=void 0,this.timeoutId=null,this.listeners=void 0,this.documentListeners=void 0,this.windowListeners=void 0,this.props=e,this.events=t;const{event:a}=e,{target:o}=a;this.props=e,this.events=t,this.document=NE(o),this.documentListeners=new GE(this.document),this.listeners=new GE(n),this.windowListeners=new GE(ME(o)),this.initialCoordinates=null!=(r=BE(a))?r:zE,this.handleStart=this.handleStart.bind(this),this.handleMove=this.handleMove.bind(this),this.handleEnd=this.handleEnd.bind(this),this.handleCancel=this.handleCancel.bind(this),this.handleKeydown=this.handleKeydown.bind(this),this.removeTextSelection=this.removeTextSelection.bind(this),this.attach()}attach(){const{events:e,props:{options:{activationConstraint:t,bypassActivationConstraint:n}}}=this;if(this.listeners.add(e.move.name,this.handleMove,{passive:!1}),this.listeners.add(e.end.name,this.handleEnd),e.cancel&&this.listeners.add(e.cancel.name,this.handleCancel),this.windowListeners.add(HE.Resize,this.handleCancel),this.windowListeners.add(HE.DragStart,UE),this.windowListeners.add(HE.VisibilityChange,this.handleCancel),this.windowListeners.add(HE.ContextMenu,UE),this.documentListeners.add(HE.Keydown,this.handleKeydown),t){if(null!=n&&n({event:this.props.event,activeNode:this.props.activeNode,options:this.props.options}))return this.handleStart();if(KE(t))return this.timeoutId=setTimeout(this.handleStart,t.delay),void this.handlePending(t);if(QE(t))return void this.handlePending(t)}this.handleStart()}detach(){this.listeners.removeAll(),this.windowListeners.removeAll(),setTimeout(this.documentListeners.removeAll,50),null!==this.timeoutId&&(clearTimeout(this.timeoutId),this.timeoutId=null)}handlePending(e,t){const{active:n,onPending:r}=this.props;r(n,e,this.initialCoordinates,t)}handleStart(){const{initialCoordinates:e}=this,{onStart:t}=this.props;e&&(this.activated=!0,this.documentListeners.add(HE.Click,WE,{capture:!0}),this.removeTextSelection(),this.documentListeners.add(HE.SelectionChange,this.removeTextSelection),t(e))}handleMove(e){var t;const{activated:n,initialCoordinates:r,props:a}=this,{onMove:o,options:{activationConstraint:i}}=a;if(!r)return;const s=null!=(t=BE(e))?t:zE,l=DE(r,s);if(!n&&i){if(QE(i)){if(null!=i.tolerance&&qE(l,i.tolerance))return this.handleCancel();if(qE(l,i.distance))return this.handleStart()}return KE(i)&&qE(l,i.tolerance)?this.handleCancel():void this.handlePending(i,l)}e.cancelable&&e.preventDefault(),o(s)}handleEnd(){const{onAbort:e,onEnd:t}=this.props;this.detach(),this.activated||e(this.props.active),t()}handleCancel(){const{onAbort:e,onCancel:t}=this.props;this.detach(),this.activated||e(this.props.active),t()}handleKeydown(e){e.code===VE.Esc&&this.handleCancel()}removeTextSelection(){var e;null==(e=this.document.getSelection())||e.removeAllRanges()}}const JE={cancel:{name:"pointercancel"},move:{name:"pointermove"},end:{name:"pointerup"}};(class extends ZE{constructor(e){const{event:t}=e,n=NE(t.target);super(e,JE,n)}}).activators=[{eventName:"onPointerDown",handler:(e,t)=>{let{nativeEvent:n}=e,{onActivation:r}=t;return!(!n.isPrimary||0!==n.button||(null==r||r({event:n}),0))}}];const XE={move:{name:"mousemove"},end:{name:"mouseup"}};var YE;!function(e){e[e.RightClick=2]="RightClick"}(YE||(YE={})),class extends ZE{constructor(e){super(e,XE,NE(e.event.target))}}.activators=[{eventName:"onMouseDown",handler:(e,t)=>{let{nativeEvent:n}=e,{onActivation:r}=t;return n.button!==YE.RightClick&&(null==r||r({event:n}),!0)}}];const $E={cancel:{name:"touchcancel"},move:{name:"touchmove"},end:{name:"touchend"}};var eR,tR,nR,rR,aR;(class extends ZE{constructor(e){super(e,$E)}static setup(){return window.addEventListener($E.move.name,e,{capture:!1,passive:!1}),function(){window.removeEventListener($E.move.name,e)};function e(){}}}).activators=[{eventName:"onTouchStart",handler:(e,t)=>{let{nativeEvent:n}=e,{onActivation:r}=t;const{touches:a}=n;return!(a.length>1||(null==r||r({event:n}),0))}}],function(e){e[e.Pointer=0]="Pointer",e[e.DraggableRect=1]="DraggableRect"}(eR||(eR={})),function(e){e[e.TreeOrder=0]="TreeOrder",e[e.ReversedTreeOrder=1]="ReversedTreeOrder"}(tR||(tR={})),jE.Backward,jE.Forward,jE.Backward,jE.Forward,function(e){e[e.Always=0]="Always",e[e.BeforeDragging=1]="BeforeDragging",e[e.WhileDragging=2]="WhileDragging"}(nR||(nR={})),function(e){e.Optimized="optimized"}(rR||(rR={})),nR.WhileDragging,rR.Optimized,Map,function(e){e[e.Uninitialized=0]="Uninitialized",e[e.Initializing=1]="Initializing",e[e.Initialized=2]="Initialized"}(aR||(aR={})),VE.Down,VE.Right,VE.Up,VE.Left;var oR=function(){return React.createElement("svg",{xmlns:"http://www.w3.org/2000/svg",width:24,height:24,fill:"none"},React.createElement("rect",{width:22.4,height:22.4,x:.8,y:.8,fill:"#fff",rx:3.2}),React.createElement("rect",{width:22.4,height:22.4,x:.8,y:.8,stroke:"#2F2F2F",strokeWidth:1.6,rx:3.2}),React.createElement("path",{fill:"#2F2F2F",d:"M19.584 7.938a.813.813 0 0 0-.813-.813H11.32a2.439 2.439 0 0 0-4.598 0H5.23a.813.813 0 0 0 0 1.625h1.493a2.439 2.439 0 0 0 4.598 0h7.451a.813.813 0 0 0 .813-.813ZM19.584 16.063a.813.813 0 0 0-.813-.813h-1.493a2.439 2.439 0 0 0-4.597 0H5.229a.813.813 0 0 0 0 1.625h7.452a2.439 2.439 0 0 0 4.597 0h1.493a.813.813 0 0 0 .813-.813Z"}))};function iR(e,t){(null==t||t>e.length)&&(t=e.length);for(var n=0,r=Array(t);n<t;n++)r[n]=e[n];return r}var sR=function(e){var t=e.children,n=e.label,r=void 0===n?"popover":n,a=e.toggleIcon,o=void 0!==a&&a,s=e.className,l=void 0===s?"":s,c=function(e,t){return function(e){if(Array.isArray(e))return e}(e)||function(e,t){var n=null==e?null:"undefined"!=typeof Symbol&&e[Symbol.iterator]||e["@@iterator"];if(null!=n){var r,a,o,i,s=[],l=!0,c=!1;try{if(o=(n=n.call(e)).next,0===t){if(Object(n)!==n)return;l=!1}else for(;!(l=(r=o.call(n)).done)&&(s.push(r.value),s.length!==t);l=!0);}catch(e){c=!0,a=e}finally{try{if(!l&&null!=n.return&&(i=n.return(),Object(i)!==i))return}finally{if(c)throw a}}return s}}(e,t)||function(e,t){if(e){if("string"==typeof e)return iR(e,t);var n={}.toString.call(e).slice(8,-1);return"Object"===n&&e.constructor&&(n=e.constructor.name),"Map"===n||"Set"===n?Array.from(e):"Arguments"===n||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)?iR(e,t):void 0}}(e,t)||function(){throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.")}()}((0,i.useState)(!1),2),u=c[0],d=c[1],p="".concat(function(){var e=arguments.length>0&&void 0!==arguments[0]?arguments[0]:"",t=Math.floor(1e7+9e7*Math.random());return"".concat(e).concat(t)}("sp-eab"),"popover");return(0,i.useEffect)(function(){var e=function(e){var t=e.target.closest(".sp-eab-popover__content-visible"),n=e.target.closest(".sp-eab-color-picker-renderer"),r=e.target.closest(".sp-eab-popover-toggle-button.".concat(p)),a=e.target.closest(".css-1nmdiq5-menu");!u||t||r||a||n||d(!1)};return window.addEventListener("click",e),function(){return window.removeEventListener("click",e)}}),React.createElement("div",{className:"sp-eab-popover-component sp-eab-component-mb".concat(l?" ".concat(l):"")},r&&React.createElement("div",{className:"sp-eab-popover-toggle-wrapper sp-d-flex sp-justify-between"},React.createElement("span",{className:"sp-eab-component-title"},r),React.createElement("button",{onClick:function(){return d(function(e){return!e})},className:"sp-eab-popover-toggle-button ".concat(p," sp-cursor-pointer").concat(u?" active":"")},o||React.createElement(oR,null))),u&&React.createElement(Uc.Popover,{shift:!0},React.createElement("div",{className:"sp-eab-popover__content-visible sp-easy-accordion-tabs-panel"},React.createElement("div",{className:"sp-eab-popover__content-visible-content"},t))))};sR.Header=function(e){var t=e.children;return React.createElement("div",{className:"sp-eab-popover__content-visible-label"},t)},sR.Content=function(e){var t=e.children;return React.createElement("div",{className:"sp-eab-popover__content"},t)};const lR=sR;function cR(e){return null!==e&&"object"==typeof e&&"constructor"in e&&e.constructor===Object}function uR(e={},t={}){const n=["__proto__","constructor","prototype"];Object.keys(t).filter(e=>n.indexOf(e)<0).forEach(n=>{void 0===e[n]?e[n]=t[n]:cR(t[n])&&cR(e[n])&&Object.keys(t[n]).length>0&&uR(e[n],t[n])})}const dR={body:{},addEventListener(){},removeEventListener(){},activeElement:{blur(){},nodeName:""},querySelector:()=>null,querySelectorAll:()=>[],getElementById:()=>null,createEvent:()=>({initEvent(){}}),createElement:()=>({children:[],childNodes:[],style:{},setAttribute(){},getElementsByTagName:()=>[]}),createElementNS:()=>({}),importNode:()=>null,location:{hash:"",host:"",hostname:"",href:"",origin:"",pathname:"",protocol:"",search:""}};function pR(){const e="undefined"!=typeof document?document:{};return uR(e,dR),e}const fR={document:dR,navigator:{userAgent:""},location:{hash:"",host:"",hostname:"",href:"",origin:"",pathname:"",protocol:"",search:""},history:{replaceState(){},pushState(){},go(){},back(){}},CustomEvent:function(){return this},addEventListener(){},removeEventListener(){},getComputedStyle:()=>({getPropertyValue:()=>""}),Image(){},Date(){},screen:{},setTimeout(){},clearTimeout(){},matchMedia:()=>({}),requestAnimationFrame:e=>"undefined"==typeof setTimeout?(e(),null):setTimeout(e,0),cancelAnimationFrame(e){"undefined"!=typeof setTimeout&&clearTimeout(e)}};function mR(){const e="undefined"!=typeof window?window:{};return uR(e,fR),e}function hR(e,t=0){return setTimeout(e,t)}function gR(){return Date.now()}function vR(e){return"object"==typeof e&&null!==e&&e.constructor&&"Object"===Object.prototype.toString.call(e).slice(8,-1)}function bR(e){return"undefined"!=typeof window&&void 0!==window.HTMLElement?e instanceof HTMLElement:e&&(1===e.nodeType||11===e.nodeType)}function yR(...e){const t=Object(e[0]);for(let n=1;n<e.length;n+=1){const r=e[n];if(null!=r&&!bR(r)){const e=Object.keys(Object(r)).filter(e=>"__proto__"!==e&&"constructor"!==e&&"prototype"!==e);for(let n=0,a=e.length;n<a;n+=1){const a=e[n],o=Object.getOwnPropertyDescriptor(r,a);void 0!==o&&o.enumerable&&(vR(t[a])&&vR(r[a])?r[a].__swiper__?t[a]=r[a]:yR(t[a],r[a]):!vR(t[a])&&vR(r[a])?(t[a]={},r[a].__swiper__?t[a]=r[a]:yR(t[a],r[a])):t[a]=r[a])}}}return t}function wR(e,t,n){e.style.setProperty(t,n)}function ER({swiper:e,targetPosition:t,side:n}){const r=mR(),a=-e.translate;let o,i=null;const s=e.params.speed;e.wrapperEl.style.scrollSnapType="none",r.cancelAnimationFrame(e.cssModeFrameID);const l=t>a?"next":"prev",c=(e,t)=>"next"===l&&e>=t||"prev"===l&&e<=t,u=()=>{o=(new Date).getTime(),null===i&&(i=o);const l=Math.max(Math.min((o-i)/s,1),0),d=.5-Math.cos(l*Math.PI)/2;let p=a+d*(t-a);if(c(p,t)&&(p=t),e.wrapperEl.scrollTo({[n]:p}),c(p,t))return e.wrapperEl.style.overflow="hidden",e.wrapperEl.style.scrollSnapType="",setTimeout(()=>{e.wrapperEl.style.overflow="",e.wrapperEl.scrollTo({[n]:p})}),void r.cancelAnimationFrame(e.cssModeFrameID);e.cssModeFrameID=r.requestAnimationFrame(u)};u()}function RR(e,t=""){const n=mR(),r=[...e.children];return n.HTMLSlotElement&&e instanceof HTMLSlotElement&&r.push(...e.assignedElements()),t?r.filter(e=>e.matches(t)):r}function xR(e){try{return void console.warn(e)}catch(e){}}function AR(e,t=[]){const n=document.createElement(e);return n.classList.add(...Array.isArray(t)?t:function(e=""){return e.trim().split(" ").filter(e=>!!e.trim())}(t)),n}function CR(e,t){return mR().getComputedStyle(e,null).getPropertyValue(t)}function SR(e){let t,n=e;if(n){for(t=0;null!==(n=n.previousSibling);)1===n.nodeType&&(t+=1);return t}}function kR(e,t){const n=[];let r=e.parentElement;for(;r;)t?r.matches(t)&&n.push(r):n.push(r),r=r.parentElement;return n}function OR(e,t,n){const r=mR();return n?e["width"===t?"offsetWidth":"offsetHeight"]+parseFloat(r.getComputedStyle(e,null).getPropertyValue("width"===t?"margin-right":"margin-top"))+parseFloat(r.getComputedStyle(e,null).getPropertyValue("width"===t?"margin-left":"margin-bottom")):e.offsetWidth}function PR(e){return(Array.isArray(e)?e:[e]).filter(e=>!!e)}function MR(e,t=""){"undefined"!=typeof trustedTypes?e.innerHTML=trustedTypes.createPolicy("html",{createHTML:e=>e}).createHTML(t):e.innerHTML=t}let IR,TR,_R;function NR(){return IR||(IR=function(){const e=mR(),t=pR();return{smoothScroll:t.documentElement&&t.documentElement.style&&"scrollBehavior"in t.documentElement.style,touch:!!("ontouchstart"in e||e.DocumentTouch&&t instanceof e.DocumentTouch)}}()),IR}function LR(e={}){return TR||(TR=function({userAgent:e}={}){const t=NR(),n=mR(),r=n.navigator.platform,a=e||n.navigator.userAgent,o={ios:!1,android:!1},i=n.screen.width,s=n.screen.height,l=a.match(/(Android);?[\s\/]+([\d.]+)?/);let c=a.match(/(iPad)(?!\1).*OS\s([\d_]+)/);const u=a.match(/(iPod)(.*OS\s([\d_]+))?/),d=!c&&a.match(/(iPhone\sOS|iOS)\s([\d_]+)/),p="Win32"===r;let f="MacIntel"===r;return!c&&f&&t.touch&&["1024x1366","1366x1024","834x1194","1194x834","834x1112","1112x834","768x1024","1024x768","820x1180","1180x820","810x1080","1080x810"].indexOf(`${i}x${s}`)>=0&&(c=a.match(/(Version)\/([\d.]+)/),c||(c=[0,1,"13_0_0"]),f=!1),l&&!p&&(o.os="android",o.android=!0),(c||d||u)&&(o.os="ios",o.ios=!0),o}(e)),TR}function DR(){return _R||(_R=function(){const e=mR(),t=LR();let n=!1;function r(){const t=e.navigator.userAgent.toLowerCase();return t.indexOf("safari")>=0&&t.indexOf("chrome")<0&&t.indexOf("android")<0}if(r()){const t=String(e.navigator.userAgent);if(t.includes("Version/")){const[e,r]=t.split("Version/")[1].split(" ")[0].split(".").map(e=>Number(e));n=e<16||16===e&&r<2}}const a=/(iPhone|iPod|iPad).*AppleWebKit(?!.*Safari)/i.test(e.navigator.userAgent),o=r();return{isSafari:n||o,needPerspectiveFix:n,need3dFix:o||a&&t.ios,isWebView:a}}()),_R}var BR={on(e,t,n){const r=this;if(!r.eventsListeners||r.destroyed)return r;if("function"!=typeof t)return r;const a=n?"unshift":"push";return e.split(" ").forEach(e=>{r.eventsListeners[e]||(r.eventsListeners[e]=[]),r.eventsListeners[e][a](t)}),r},once(e,t,n){const r=this;if(!r.eventsListeners||r.destroyed)return r;if("function"!=typeof t)return r;function a(...n){r.off(e,a),a.__emitterProxy&&delete a.__emitterProxy,t.apply(r,n)}return a.__emitterProxy=t,r.on(e,a,n)},onAny(e,t){const n=this;if(!n.eventsListeners||n.destroyed)return n;if("function"!=typeof e)return n;const r=t?"unshift":"push";return n.eventsAnyListeners.indexOf(e)<0&&n.eventsAnyListeners[r](e),n},offAny(e){const t=this;if(!t.eventsListeners||t.destroyed)return t;if(!t.eventsAnyListeners)return t;const n=t.eventsAnyListeners.indexOf(e);return n>=0&&t.eventsAnyListeners.splice(n,1),t},off(e,t){const n=this;return!n.eventsListeners||n.destroyed?n:n.eventsListeners?(e.split(" ").forEach(e=>{void 0===t?n.eventsListeners[e]=[]:n.eventsListeners[e]&&n.eventsListeners[e].forEach((r,a)=>{(r===t||r.__emitterProxy&&r.__emitterProxy===t)&&n.eventsListeners[e].splice(a,1)})}),n):n},emit(...e){const t=this;if(!t.eventsListeners||t.destroyed)return t;if(!t.eventsListeners)return t;let n,r,a;return"string"==typeof e[0]||Array.isArray(e[0])?(n=e[0],r=e.slice(1,e.length),a=t):(n=e[0].events,r=e[0].data,a=e[0].context||t),r.unshift(a),(Array.isArray(n)?n:n.split(" ")).forEach(e=>{t.eventsAnyListeners&&t.eventsAnyListeners.length&&t.eventsAnyListeners.forEach(t=>{t.apply(a,[e,...r])}),t.eventsListeners&&t.eventsListeners[e]&&t.eventsListeners[e].forEach(e=>{e.apply(a,r)})}),t}};const FR=(e,t,n)=>{t&&!e.classList.contains(n)?e.classList.add(n):!t&&e.classList.contains(n)&&e.classList.remove(n)},zR=(e,t,n)=>{t&&!e.classList.contains(n)?e.classList.add(n):!t&&e.classList.contains(n)&&e.classList.remove(n)},jR=(e,t)=>{if(!e||e.destroyed||!e.params)return;const n=t.closest(e.isElement?"swiper-slide":`.${e.params.slideClass}`);if(n){let t=n.querySelector(`.${e.params.lazyPreloaderClass}`);!t&&e.isElement&&(n.shadowRoot?t=n.shadowRoot.querySelector(`.${e.params.lazyPreloaderClass}`):requestAnimationFrame(()=>{n.shadowRoot&&(t=n.shadowRoot.querySelector(`.${e.params.lazyPreloaderClass}`),t&&!t.lazyPreloaderManaged&&t.remove())})),t&&!t.lazyPreloaderManaged&&t.remove()}},HR=(e,t)=>{if(!e.slides[t])return;const n=e.slides[t].querySelector('[loading="lazy"]');n&&n.removeAttribute("loading")},VR=e=>{if(!e||e.destroyed||!e.params)return;let t=e.params.lazyPreloadPrevNext;const n=e.slides.length;if(!n||!t||t<0)return;t=Math.min(t,n);const r="auto"===e.params.slidesPerView?e.slidesPerViewDynamic():Math.ceil(e.params.slidesPerView),a=e.activeIndex;if(e.params.grid&&e.params.grid.rows>1){const n=a,o=[n-t];return o.push(...Array.from({length:t}).map((e,t)=>n+r+t)),void e.slides.forEach((t,n)=>{o.includes(t.column)&&HR(e,n)})}const o=a+r-1;if(e.params.rewind||e.params.loop)for(let r=a-t;r<=o+t;r+=1){const t=(r%n+n)%n;(t<a||t>o)&&HR(e,t)}else for(let r=Math.max(a-t,0);r<=Math.min(o+t,n-1);r+=1)r!==a&&(r>o||r<a)&&HR(e,r)};var GR={updateSize:function(){const e=this;let t,n;const r=e.el;t=void 0!==e.params.width&&null!==e.params.width?e.params.width:r.clientWidth,n=void 0!==e.params.height&&null!==e.params.height?e.params.height:r.clientHeight,0===t&&e.isHorizontal()||0===n&&e.isVertical()||(t=t-parseInt(CR(r,"padding-left")||0,10)-parseInt(CR(r,"padding-right")||0,10),n=n-parseInt(CR(r,"padding-top")||0,10)-parseInt(CR(r,"padding-bottom")||0,10),Number.isNaN(t)&&(t=0),Number.isNaN(n)&&(n=0),Object.assign(e,{width:t,height:n,size:e.isHorizontal()?t:n}))},updateSlides:function(){const e=this;function t(t,n){return parseFloat(t.getPropertyValue(e.getDirectionLabel(n))||0)}const n=e.params,{wrapperEl:r,slidesEl:a,rtlTranslate:o,wrongRTL:i}=e,s=e.virtual&&n.virtual.enabled,l=s?e.virtual.slides.length:e.slides.length,c=RR(a,`.${e.params.slideClass}, swiper-slide`),u=s?e.virtual.slides.length:c.length;let d=[];const p=[],f=[];let m=n.slidesOffsetBefore;"function"==typeof m&&(m=n.slidesOffsetBefore.call(e));let h=n.slidesOffsetAfter;"function"==typeof h&&(h=n.slidesOffsetAfter.call(e));const g=e.snapGrid.length,v=e.slidesGrid.length,b=e.size-m-h;let y=n.spaceBetween,w=-m,E=0,R=0;if(void 0===b)return;"string"==typeof y&&y.indexOf("%")>=0?y=parseFloat(y.replace("%",""))/100*b:"string"==typeof y&&(y=parseFloat(y)),e.virtualSize=-y-m-h,c.forEach(e=>{o?e.style.marginLeft="":e.style.marginRight="",e.style.marginBottom="",e.style.marginTop=""}),n.centeredSlides&&n.cssMode&&(wR(r,"--swiper-centered-offset-before",""),wR(r,"--swiper-centered-offset-after","")),n.cssMode&&(wR(r,"--swiper-slides-offset-before",`${m}px`),wR(r,"--swiper-slides-offset-after",`${h}px`));const x=n.grid&&n.grid.rows>1&&e.grid;let A;x?e.grid.initSlides(c):e.grid&&e.grid.unsetSlides();const C="auto"===n.slidesPerView&&n.breakpoints&&Object.keys(n.breakpoints).filter(e=>void 0!==n.breakpoints[e].slidesPerView).length>0;for(let r=0;r<u;r+=1){A=0;const a=c[r];if(!a||(x&&e.grid.updateSlide(r,a,c),"none"!==CR(a,"display"))){if(s&&"auto"===n.slidesPerView)n.virtual.slidesPerViewAutoSlideSize&&(A=n.virtual.slidesPerViewAutoSlideSize),A&&a&&(n.roundLengths&&(A=Math.floor(A)),a.style[e.getDirectionLabel("width")]=`${A}px`);else if("auto"===n.slidesPerView){C&&(a.style[e.getDirectionLabel("width")]="");const r=getComputedStyle(a),o=a.style.transform,i=a.style.webkitTransform;if(o&&(a.style.transform="none"),i&&(a.style.webkitTransform="none"),n.roundLengths)A=e.isHorizontal()?OR(a,"width",!0):OR(a,"height",!0);else{const e=t(r,"width"),n=t(r,"padding-left"),o=t(r,"padding-right"),i=t(r,"margin-left"),s=t(r,"margin-right"),l=r.getPropertyValue("box-sizing");if(l&&"border-box"===l)A=e+i+s;else{const{clientWidth:t,offsetWidth:r}=a;A=e+n+o+i+s+(r-t)}}o&&(a.style.transform=o),i&&(a.style.webkitTransform=i),n.roundLengths&&(A=Math.floor(A))}else A=(b-(n.slidesPerView-1)*y)/n.slidesPerView,n.roundLengths&&(A=Math.floor(A)),a&&(a.style[e.getDirectionLabel("width")]=`${A}px`);a&&(a.swiperSlideSize=A),f.push(A),n.centeredSlides?(w=w+A/2+E/2+y,0===E&&0!==r&&(w=w-b/2-y),0===r&&(w=w-b/2-y),Math.abs(w)<.001&&(w=0),n.roundLengths&&(w=Math.floor(w)),R%n.slidesPerGroup===0&&d.push(w),p.push(w)):(n.roundLengths&&(w=Math.floor(w)),(R-Math.min(e.params.slidesPerGroupSkip,R))%e.params.slidesPerGroup===0&&d.push(w),p.push(w),w=w+A+y),e.virtualSize+=A+y,E=A,R+=1}}if(e.virtualSize=Math.max(e.virtualSize,b)+h,o&&i&&("slide"===n.effect||"coverflow"===n.effect)&&(r.style.width=`${e.virtualSize+y}px`),n.setWrapperSize&&(r.style[e.getDirectionLabel("width")]=`${e.virtualSize+y}px`),x&&e.grid.updateWrapperSize(A,d),!n.centeredSlides){const t="auto"!==n.slidesPerView&&n.slidesPerView%1!=0,r=n.snapToSlideEdge&&!n.loop&&("auto"===n.slidesPerView||t);let a=d.length;if(r){let e;if("auto"===n.slidesPerView){e=1;let t=0;for(let n=f.length-1;n>=0&&(t+=f[n]+(n<f.length-1?y:0),t<=b);n-=1)e=f.length-n}else e=Math.floor(n.slidesPerView);a=Math.max(u-e,0)}const o=[];for(let t=0;t<d.length;t+=1){let i=d[t];n.roundLengths&&(i=Math.floor(i)),r?t<=a&&o.push(i):d[t]<=e.virtualSize-b&&o.push(i)}d=o,Math.floor(e.virtualSize-b)-Math.floor(d[d.length-1])>1&&(r||d.push(e.virtualSize-b))}if(s&&n.loop){const t=f[0]+y;if(n.slidesPerGroup>1){const r=Math.ceil((e.virtual.slidesBefore+e.virtual.slidesAfter)/n.slidesPerGroup),a=t*n.slidesPerGroup;for(let e=0;e<r;e+=1)d.push(d[d.length-1]+a)}for(let r=0;r<e.virtual.slidesBefore+e.virtual.slidesAfter;r+=1)1===n.slidesPerGroup&&d.push(d[d.length-1]+t),p.push(p[p.length-1]+t),e.virtualSize+=t}if(0===d.length&&(d=[0]),0!==y){const t=e.isHorizontal()&&o?"marginLeft":e.getDirectionLabel("marginRight");c.filter((e,t)=>!(n.cssMode&&!n.loop)||t!==c.length-1).forEach(e=>{e.style[t]=`${y}px`})}if(n.centeredSlides&&n.centeredSlidesBounds){let e=0;f.forEach(t=>{e+=t+(y||0)}),e-=y;const t=e>b?e-b:0;d=d.map(e=>e<=0?-m:e>t?t+h:e)}if(n.centerInsufficientSlides){let e=0;if(f.forEach(t=>{e+=t+(y||0)}),e-=y,e<b){const t=(b-e)/2;d.forEach((e,n)=>{d[n]=e-t}),p.forEach((e,n)=>{p[n]=e+t})}}if(Object.assign(e,{slides:c,snapGrid:d,slidesGrid:p,slidesSizesGrid:f}),n.centeredSlides&&n.cssMode&&!n.centeredSlidesBounds){wR(r,"--swiper-centered-offset-before",-d[0]+"px"),wR(r,"--swiper-centered-offset-after",e.size/2-f[f.length-1]/2+"px");const t=-e.snapGrid[0],n=-e.slidesGrid[0];e.snapGrid=e.snapGrid.map(e=>e+t),e.slidesGrid=e.slidesGrid.map(e=>e+n)}if(u!==l&&e.emit("slidesLengthChange"),d.length!==g&&(e.params.watchOverflow&&e.checkOverflow(),e.emit("snapGridLengthChange")),p.length!==v&&e.emit("slidesGridLengthChange"),n.watchSlidesProgress&&e.updateSlidesOffset(),e.emit("slidesUpdated"),!(s||n.cssMode||"slide"!==n.effect&&"fade"!==n.effect)){const t=`${n.containerModifierClass}backface-hidden`,r=e.el.classList.contains(t);u<=n.maxBackfaceHiddenSlides?r||e.el.classList.add(t):r&&e.el.classList.remove(t)}},updateAutoHeight:function(e){const t=this,n=[],r=t.virtual&&t.params.virtual.enabled;let a,o=0;"number"==typeof e?t.setTransition(e):!0===e&&t.setTransition(t.params.speed);const i=e=>r?t.slides[t.getSlideIndexByData(e)]:t.slides[e];if("auto"!==t.params.slidesPerView&&t.params.slidesPerView>1)if(t.params.centeredSlides)(t.visibleSlides||[]).forEach(e=>{n.push(e)});else for(a=0;a<Math.ceil(t.params.slidesPerView);a+=1){const e=t.activeIndex+a;if(e>t.slides.length&&!r)break;n.push(i(e))}else n.push(i(t.activeIndex));for(a=0;a<n.length;a+=1)if(void 0!==n[a]){const e=n[a].offsetHeight;o=e>o?e:o}(o||0===o)&&(t.wrapperEl.style.height=`${o}px`)},updateSlidesOffset:function(){const e=this,t=e.slides,n=e.isElement?e.isHorizontal()?e.wrapperEl.offsetLeft:e.wrapperEl.offsetTop:0;for(let r=0;r<t.length;r+=1)t[r].swiperSlideOffset=(e.isHorizontal()?t[r].offsetLeft:t[r].offsetTop)-n-e.cssOverflowAdjustment()},updateSlidesProgress:function(e=this&&this.translate||0){const t=this,n=t.params,{slides:r,rtlTranslate:a,snapGrid:o}=t;if(0===r.length)return;void 0===r[0].swiperSlideOffset&&t.updateSlidesOffset();let i=-e;a&&(i=e),t.visibleSlidesIndexes=[],t.visibleSlides=[];let s=n.spaceBetween;"string"==typeof s&&s.indexOf("%")>=0?s=parseFloat(s.replace("%",""))/100*t.size:"string"==typeof s&&(s=parseFloat(s));for(let e=0;e<r.length;e+=1){const l=r[e];let c=l.swiperSlideOffset;n.cssMode&&n.centeredSlides&&(c-=r[0].swiperSlideOffset);const u=(i+(n.centeredSlides?t.minTranslate():0)-c)/(l.swiperSlideSize+s),d=(i-o[0]+(n.centeredSlides?t.minTranslate():0)-c)/(l.swiperSlideSize+s),p=-(i-c),f=p+t.slidesSizesGrid[e],m=p>=0&&p<=t.size-t.slidesSizesGrid[e],h=p>=0&&p<t.size-1||f>1&&f<=t.size||p<=0&&f>=t.size;h&&(t.visibleSlides.push(l),t.visibleSlidesIndexes.push(e)),FR(l,h,n.slideVisibleClass),FR(l,m,n.slideFullyVisibleClass),l.progress=a?-u:u,l.originalProgress=a?-d:d}},updateProgress:function(e){const t=this;if(void 0===e){const n=t.rtlTranslate?-1:1;e=t&&t.translate&&t.translate*n||0}const n=t.params,r=t.maxTranslate()-t.minTranslate();let{progress:a,isBeginning:o,isEnd:i,progressLoop:s}=t;const l=o,c=i;if(0===r)a=0,o=!0,i=!0;else{a=(e-t.minTranslate())/r;const n=Math.abs(e-t.minTranslate())<1,s=Math.abs(e-t.maxTranslate())<1;o=n||a<=0,i=s||a>=1,n&&(a=0),s&&(a=1)}if(n.loop){const n=t.getSlideIndexByData(0),r=t.getSlideIndexByData(t.slides.length-1),a=t.slidesGrid[n],o=t.slidesGrid[r],i=t.slidesGrid[t.slidesGrid.length-1],l=Math.abs(e);s=l>=a?(l-a)/i:(l+i-o)/i,s>1&&(s-=1)}Object.assign(t,{progress:a,progressLoop:s,isBeginning:o,isEnd:i}),(n.watchSlidesProgress||n.centeredSlides&&n.autoHeight)&&t.updateSlidesProgress(e),o&&!l&&t.emit("reachBeginning toEdge"),i&&!c&&t.emit("reachEnd toEdge"),(l&&!o||c&&!i)&&t.emit("fromEdge"),t.emit("progress",a)},updateSlidesClasses:function(){const e=this,{slides:t,params:n,slidesEl:r,activeIndex:a}=e,o=e.virtual&&n.virtual.enabled,i=e.grid&&n.grid&&n.grid.rows>1,s=e=>RR(r,`.${n.slideClass}${e}, swiper-slide${e}`)[0];let l,c,u;if(o)if(n.loop){let t=a-e.virtual.slidesBefore;t<0&&(t=e.virtual.slides.length+t),t>=e.virtual.slides.length&&(t-=e.virtual.slides.length),l=s(`[data-swiper-slide-index="${t}"]`)}else l=s(`[data-swiper-slide-index="${a}"]`);else i?(l=t.find(e=>e.column===a),u=t.find(e=>e.column===a+1),c=t.find(e=>e.column===a-1)):l=t[a];l&&(i||(u=function(e,t){const n=[];for(;e.nextElementSibling;){const r=e.nextElementSibling;t?r.matches(t)&&n.push(r):n.push(r),e=r}return n}(l,`.${n.slideClass}, swiper-slide`)[0],n.loop&&!u&&(u=t[0]),c=function(e,t){const n=[];for(;e.previousElementSibling;){const r=e.previousElementSibling;t?r.matches(t)&&n.push(r):n.push(r),e=r}return n}(l,`.${n.slideClass}, swiper-slide`)[0],n.loop&&0===!c&&(c=t[t.length-1]))),t.forEach(e=>{zR(e,e===l,n.slideActiveClass),zR(e,e===u,n.slideNextClass),zR(e,e===c,n.slidePrevClass)}),e.emitSlidesClasses()},updateActiveIndex:function(e){const t=this,n=t.rtlTranslate?t.translate:-t.translate,{snapGrid:r,params:a,activeIndex:o,realIndex:i,snapIndex:s}=t;let l,c=e;const u=e=>{let n=e-t.virtual.slidesBefore;return n<0&&(n=t.virtual.slides.length+n),n>=t.virtual.slides.length&&(n-=t.virtual.slides.length),n};if(void 0===c&&(c=function(e){const{slidesGrid:t,params:n}=e,r=e.rtlTranslate?e.translate:-e.translate;let a;for(let e=0;e<t.length;e+=1)void 0!==t[e+1]?r>=t[e]&&r<t[e+1]-(t[e+1]-t[e])/2?a=e:r>=t[e]&&r<t[e+1]&&(a=e+1):r>=t[e]&&(a=e);return n.normalizeSlideIndex&&(a<0||void 0===a)&&(a=0),a}(t)),r.indexOf(n)>=0)l=r.indexOf(n);else{const e=Math.min(a.slidesPerGroupSkip,c);l=e+Math.floor((c-e)/a.slidesPerGroup)}if(l>=r.length&&(l=r.length-1),c===o&&!t.params.loop)return void(l!==s&&(t.snapIndex=l,t.emit("snapIndexChange")));if(c===o&&t.params.loop&&t.virtual&&t.params.virtual.enabled)return void(t.realIndex=u(c));const d=t.grid&&a.grid&&a.grid.rows>1;let p;if(t.virtual&&a.virtual.enabled)p=a.loop?u(c):c;else if(d){const e=t.slides.find(e=>e.column===c);let n=parseInt(e.getAttribute("data-swiper-slide-index"),10);Number.isNaN(n)&&(n=Math.max(t.slides.indexOf(e),0)),p=Math.floor(n/a.grid.rows)}else if(t.slides[c]){const e=t.slides[c].getAttribute("data-swiper-slide-index");p=e?parseInt(e,10):c}else p=c;Object.assign(t,{previousSnapIndex:s,snapIndex:l,previousRealIndex:i,realIndex:p,previousIndex:o,activeIndex:c}),t.initialized&&VR(t),t.emit("activeIndexChange"),t.emit("snapIndexChange"),(t.initialized||t.params.runCallbacksOnInit)&&(i!==p&&t.emit("realIndexChange"),t.emit("slideChange"))},updateClickedSlide:function(e,t){const n=this,r=n.params;let a=e.closest(`.${r.slideClass}, swiper-slide`);!a&&n.isElement&&t&&t.length>1&&t.includes(e)&&[...t.slice(t.indexOf(e)+1,t.length)].forEach(e=>{!a&&e.matches&&e.matches(`.${r.slideClass}, swiper-slide`)&&(a=e)});let o,i=!1;if(a)for(let e=0;e<n.slides.length;e+=1)if(n.slides[e]===a){i=!0,o=e;break}if(!a||!i)return n.clickedSlide=void 0,void(n.clickedIndex=void 0);n.clickedSlide=a,n.virtual&&n.params.virtual.enabled?n.clickedIndex=parseInt(a.getAttribute("data-swiper-slide-index"),10):n.clickedIndex=o,r.slideToClickedSlide&&void 0!==n.clickedIndex&&n.clickedIndex!==n.activeIndex&&n.slideToClickedSlide()}},qR={getTranslate:function(e=(this.isHorizontal()?"x":"y")){const{params:t,rtlTranslate:n,translate:r,wrapperEl:a}=this;if(t.virtualTranslate)return n?-r:r;if(t.cssMode)return r;let o=function(e,t="x"){const n=mR();let r,a,o;const i=function(e){const t=mR();let n;return t.getComputedStyle&&(n=t.getComputedStyle(e,null)),!n&&e.currentStyle&&(n=e.currentStyle),n||(n=e.style),n}(e);return n.WebKitCSSMatrix?(a=i.transform||i.webkitTransform,a.split(",").length>6&&(a=a.split(", ").map(e=>e.replace(",",".")).join(", ")),o=new n.WebKitCSSMatrix("none"===a?"":a)):(o=i.MozTransform||i.OTransform||i.MsTransform||i.msTransform||i.transform||i.getPropertyValue("transform").replace("translate(","matrix(1, 0, 0, 1,"),r=o.toString().split(",")),"x"===t&&(a=n.WebKitCSSMatrix?o.m41:16===r.length?parseFloat(r[12]):parseFloat(r[4])),"y"===t&&(a=n.WebKitCSSMatrix?o.m42:16===r.length?parseFloat(r[13]):parseFloat(r[5])),a||0}(a,e);return o+=this.cssOverflowAdjustment(),n&&(o=-o),o||0},setTranslate:function(e,t){const n=this,{rtlTranslate:r,params:a,wrapperEl:o,progress:i}=n;let s,l=0,c=0;n.isHorizontal()?l=r?-e:e:c=e,a.roundLengths&&(l=Math.floor(l),c=Math.floor(c)),n.previousTranslate=n.translate,n.translate=n.isHorizontal()?l:c,a.cssMode?o[n.isHorizontal()?"scrollLeft":"scrollTop"]=n.isHorizontal()?-l:-c:a.virtualTranslate||(n.isHorizontal()?l-=n.cssOverflowAdjustment():c-=n.cssOverflowAdjustment(),o.style.transform=`translate3d(${l}px, ${c}px, 0px)`);const u=n.maxTranslate()-n.minTranslate();s=0===u?0:(e-n.minTranslate())/u,s!==i&&n.updateProgress(e),n.emit("setTranslate",n.translate,t)},minTranslate:function(){return-this.snapGrid[0]},maxTranslate:function(){return-this.snapGrid[this.snapGrid.length-1]},translateTo:function(e=0,t=this.params.speed,n=!0,r=!0,a){const o=this,{params:i,wrapperEl:s}=o;if(o.animating&&i.preventInteractionOnTransition)return!1;const l=o.minTranslate(),c=o.maxTranslate();let u;if(u=r&&e>l?l:r&&e<c?c:e,o.updateProgress(u),i.cssMode){const e=o.isHorizontal();if(0===t)s[e?"scrollLeft":"scrollTop"]=-u;else{if(!o.support.smoothScroll)return ER({swiper:o,targetPosition:-u,side:e?"left":"top"}),!0;s.scrollTo({[e?"left":"top"]:-u,behavior:"smooth"})}return!0}return 0===t?(o.setTransition(0),o.setTranslate(u),n&&(o.emit("beforeTransitionStart",t,a),o.emit("transitionEnd"))):(o.setTransition(t),o.setTranslate(u),n&&(o.emit("beforeTransitionStart",t,a),o.emit("transitionStart")),o.animating||(o.animating=!0,o.onTranslateToWrapperTransitionEnd||(o.onTranslateToWrapperTransitionEnd=function(e){o&&!o.destroyed&&e.target===this&&(o.wrapperEl.removeEventListener("transitionend",o.onTranslateToWrapperTransitionEnd),o.onTranslateToWrapperTransitionEnd=null,delete o.onTranslateToWrapperTransitionEnd,o.animating=!1,n&&o.emit("transitionEnd"))}),o.wrapperEl.addEventListener("transitionend",o.onTranslateToWrapperTransitionEnd))),!0}};function UR({swiper:e,runCallbacks:t,direction:n,step:r}){const{activeIndex:a,previousIndex:o}=e;let i=n;i||(i=a>o?"next":a<o?"prev":"reset"),e.emit(`transition${r}`),t&&"reset"===i?e.emit(`slideResetTransition${r}`):t&&a!==o&&(e.emit(`slideChangeTransition${r}`),"next"===i?e.emit(`slideNextTransition${r}`):e.emit(`slidePrevTransition${r}`))}var WR={setTransition:function(e,t){const n=this;n.params.cssMode||(n.wrapperEl.style.transitionDuration=`${e}ms`,n.wrapperEl.style.transitionDelay=0===e?"0ms":""),n.emit("setTransition",e,t)},transitionStart:function(e=!0,t){const n=this,{params:r}=n;r.cssMode||(r.autoHeight&&n.updateAutoHeight(),UR({swiper:n,runCallbacks:e,direction:t,step:"Start"}))},transitionEnd:function(e=!0,t){const n=this,{params:r}=n;n.animating=!1,r.cssMode||(n.setTransition(0),UR({swiper:n,runCallbacks:e,direction:t,step:"End"}))}},QR={slideTo:function(e=0,t,n=!0,r,a){"string"==typeof e&&(e=parseInt(e,10));const o=this;let i=e;i<0&&(i=0);const{params:s,snapGrid:l,slidesGrid:c,previousIndex:u,activeIndex:d,rtlTranslate:p,wrapperEl:f,enabled:m}=o;if(!m&&!r&&!a||o.destroyed||o.animating&&s.preventInteractionOnTransition)return!1;void 0===t&&(t=o.params.speed);const h=Math.min(o.params.slidesPerGroupSkip,i);let g=h+Math.floor((i-h)/o.params.slidesPerGroup);g>=l.length&&(g=l.length-1);const v=-l[g];if(s.normalizeSlideIndex)for(let e=0;e<c.length;e+=1){const t=-Math.floor(100*v),n=Math.floor(100*c[e]),r=Math.floor(100*c[e+1]);void 0!==c[e+1]?t>=n&&t<r-(r-n)/2?i=e:t>=n&&t<r&&(i=e+1):t>=n&&(i=e)}if(o.initialized&&i!==d){if(!o.allowSlideNext&&(p?v>o.translate&&v>o.minTranslate():v<o.translate&&v<o.minTranslate()))return!1;if(!o.allowSlidePrev&&v>o.translate&&v>o.maxTranslate()&&(d||0)!==i)return!1}let b;i!==(u||0)&&n&&o.emit("beforeSlideChangeStart"),o.updateProgress(v),b=i>d?"next":i<d?"prev":"reset";const y=o.virtual&&o.params.virtual.enabled;if((!y||!a)&&(p&&-v===o.translate||!p&&v===o.translate))return o.updateActiveIndex(i),s.autoHeight&&o.updateAutoHeight(),o.updateSlidesClasses(),"slide"!==s.effect&&o.setTranslate(v),"reset"!==b&&(o.transitionStart(n,b),o.transitionEnd(n,b)),!1;if(s.cssMode){const e=o.isHorizontal(),n=p?v:-v;if(0===t)y&&(o.wrapperEl.style.scrollSnapType="none",o._immediateVirtual=!0),y&&!o._cssModeVirtualInitialSet&&o.params.initialSlide>0?(o._cssModeVirtualInitialSet=!0,requestAnimationFrame(()=>{f[e?"scrollLeft":"scrollTop"]=n})):f[e?"scrollLeft":"scrollTop"]=n,y&&requestAnimationFrame(()=>{o.wrapperEl.style.scrollSnapType="",o._immediateVirtual=!1});else{if(!o.support.smoothScroll)return ER({swiper:o,targetPosition:n,side:e?"left":"top"}),!0;f.scrollTo({[e?"left":"top"]:n,behavior:"smooth"})}return!0}const w=DR().isSafari;return y&&!a&&w&&o.isElement&&o.virtual.update(!1,!1,i),o.setTransition(t),o.setTranslate(v),o.updateActiveIndex(i),o.updateSlidesClasses(),o.emit("beforeTransitionStart",t,r),o.transitionStart(n,b),0===t?o.transitionEnd(n,b):o.animating||(o.animating=!0,o.onSlideToWrapperTransitionEnd||(o.onSlideToWrapperTransitionEnd=function(e){o&&!o.destroyed&&e.target===this&&(o.wrapperEl.removeEventListener("transitionend",o.onSlideToWrapperTransitionEnd),o.onSlideToWrapperTransitionEnd=null,delete o.onSlideToWrapperTransitionEnd,o.transitionEnd(n,b))}),o.wrapperEl.addEventListener("transitionend",o.onSlideToWrapperTransitionEnd)),!0},slideToLoop:function(e=0,t,n=!0,r){"string"==typeof e&&(e=parseInt(e,10));const a=this;if(a.destroyed)return;void 0===t&&(t=a.params.speed);const o=a.grid&&a.params.grid&&a.params.grid.rows>1;let i=e;if(a.params.loop)if(a.virtual&&a.params.virtual.enabled)i+=a.virtual.slidesBefore;else{let e;if(o){const t=i*a.params.grid.rows;e=a.slides.find(e=>1*e.getAttribute("data-swiper-slide-index")===t).column}else e=a.getSlideIndexByData(i);const t=o?Math.ceil(a.slides.length/a.params.grid.rows):a.slides.length,{centeredSlides:n,slidesOffsetBefore:s,slidesOffsetAfter:l}=a.params,c=n||!!s||!!l;let u=a.params.slidesPerView;"auto"===u?u=a.slidesPerViewDynamic():(u=Math.ceil(parseFloat(a.params.slidesPerView,10)),c&&u%2==0&&(u+=1));let d=t-e<u;if(c&&(d=d||e<Math.ceil(u/2)),r&&c&&"auto"!==a.params.slidesPerView&&!o&&(d=!1),d){const n=c?e<a.activeIndex?"prev":"next":e-a.activeIndex-1<a.params.slidesPerView?"next":"prev";a.loopFix({direction:n,slideTo:!0,activeSlideIndex:"next"===n?e+1:e-t+1,slideRealIndex:"next"===n?a.realIndex:void 0})}if(o){const e=i*a.params.grid.rows;i=a.slides.find(t=>1*t.getAttribute("data-swiper-slide-index")===e).column}else i=a.getSlideIndexByData(i)}return requestAnimationFrame(()=>{a.slideTo(i,t,n,r)}),a},slideNext:function(e,t=!0,n){const r=this,{enabled:a,params:o,animating:i}=r;if(!a||r.destroyed)return r;void 0===e&&(e=r.params.speed);let s=o.slidesPerGroup;"auto"===o.slidesPerView&&1===o.slidesPerGroup&&o.slidesPerGroupAuto&&(s=Math.max(r.slidesPerViewDynamic("current",!0),1));const l=r.activeIndex<o.slidesPerGroupSkip?1:s,c=r.virtual&&o.virtual.enabled;if(o.loop){if(i&&!c&&o.loopPreventsSliding)return!1;if(r.loopFix({direction:"next"}),r._clientLeft=r.wrapperEl.clientLeft,r.activeIndex===r.slides.length-1&&o.cssMode)return requestAnimationFrame(()=>{r.slideTo(r.activeIndex+l,e,t,n)}),!0}return o.rewind&&r.isEnd?r.slideTo(0,e,t,n):r.slideTo(r.activeIndex+l,e,t,n)},slidePrev:function(e,t=!0,n){const r=this,{params:a,snapGrid:o,slidesGrid:i,rtlTranslate:s,enabled:l,animating:c}=r;if(!l||r.destroyed)return r;void 0===e&&(e=r.params.speed);const u=r.virtual&&a.virtual.enabled;if(a.loop){if(c&&!u&&a.loopPreventsSliding)return!1;r.loopFix({direction:"prev"}),r._clientLeft=r.wrapperEl.clientLeft}function d(e){return e<0?-Math.floor(Math.abs(e)):Math.floor(e)}const p=d(s?r.translate:-r.translate),f=o.map(e=>d(e)),m=a.freeMode&&a.freeMode.enabled;let h=o[f.indexOf(p)-1];if(void 0===h&&(a.cssMode||m)){let e;o.forEach((t,n)=>{p>=t&&(e=n)}),void 0!==e&&(h=m?o[e]:o[e>0?e-1:e])}let g=0;if(void 0!==h&&(g=i.indexOf(h),g<0&&(g=r.activeIndex-1),"auto"===a.slidesPerView&&1===a.slidesPerGroup&&a.slidesPerGroupAuto&&(g=g-r.slidesPerViewDynamic("previous",!0)+1,g=Math.max(g,0))),a.rewind&&r.isBeginning){const a=r.params.virtual&&r.params.virtual.enabled&&r.virtual?r.virtual.slides.length-1:r.slides.length-1;return r.slideTo(a,e,t,n)}return a.loop&&0===r.activeIndex&&a.cssMode?(requestAnimationFrame(()=>{r.slideTo(g,e,t,n)}),!0):r.slideTo(g,e,t,n)},slideReset:function(e,t=!0,n){const r=this;if(!r.destroyed)return void 0===e&&(e=r.params.speed),r.slideTo(r.activeIndex,e,t,n)},slideToClosest:function(e,t=!0,n,r=.5){const a=this;if(a.destroyed)return;void 0===e&&(e=a.params.speed);let o=a.activeIndex;const i=Math.min(a.params.slidesPerGroupSkip,o),s=i+Math.floor((o-i)/a.params.slidesPerGroup),l=a.rtlTranslate?a.translate:-a.translate;if(l>=a.snapGrid[s]){const e=a.snapGrid[s];l-e>(a.snapGrid[s+1]-e)*r&&(o+=a.params.slidesPerGroup)}else{const e=a.snapGrid[s-1];l-e<=(a.snapGrid[s]-e)*r&&(o-=a.params.slidesPerGroup)}return o=Math.max(o,0),o=Math.min(o,a.slidesGrid.length-1),a.slideTo(o,e,t,n)},slideToClickedSlide:function(){const e=this;if(e.destroyed)return;const{params:t,slidesEl:n}=e,r="auto"===t.slidesPerView?e.slidesPerViewDynamic():t.slidesPerView;let a,o=e.getSlideIndexWhenGrid(e.clickedIndex);const i=e.isElement?"swiper-slide":`.${t.slideClass}`,s=e.grid&&e.params.grid&&e.params.grid.rows>1;if(t.loop){if(e.animating)return;a=parseInt(e.clickedSlide.getAttribute("data-swiper-slide-index"),10),t.centeredSlides?e.slideToLoop(a):o>(s?(e.slides.length-r)/2-(e.params.grid.rows-1):e.slides.length-r)?(e.loopFix(),o=e.getSlideIndex(RR(n,`${i}[data-swiper-slide-index="${a}"]`)[0]),hR(()=>{e.slideTo(o)})):e.slideTo(o)}else e.slideTo(o)}},KR={loopCreate:function(e,t){const n=this,{params:r,slidesEl:a}=n;if(!r.loop||n.virtual&&n.params.virtual.enabled)return;const o=()=>{RR(a,`.${r.slideClass}, swiper-slide`).forEach((e,t)=>{e.setAttribute("data-swiper-slide-index",t)})},i=n.grid&&r.grid&&r.grid.rows>1;r.loopAddBlankSlides&&(r.slidesPerGroup>1||i)&&(()=>{const e=RR(a,`.${r.slideBlankClass}`);e.forEach(e=>{e.remove()}),e.length>0&&(n.recalcSlides(),n.updateSlides())})();const s=r.slidesPerGroup*(i?r.grid.rows:1),l=n.slides.length%s!==0,c=i&&n.slides.length%r.grid.rows!==0,u=e=>{for(let t=0;t<e;t+=1){const e=n.isElement?AR("swiper-slide",[r.slideBlankClass]):AR("div",[r.slideClass,r.slideBlankClass]);n.slidesEl.append(e)}};l?(r.loopAddBlankSlides?(u(s-n.slides.length%s),n.recalcSlides(),n.updateSlides()):xR("Swiper Loop Warning: The number of slides is not even to slidesPerGroup, loop mode may not function properly. You need to add more slides (or make duplicates, or empty slides)"),o()):c?(r.loopAddBlankSlides?(u(r.grid.rows-n.slides.length%r.grid.rows),n.recalcSlides(),n.updateSlides()):xR("Swiper Loop Warning: The number of slides is not even to grid.rows, loop mode may not function properly. You need to add more slides (or make duplicates, or empty slides)"),o()):o();const d=r.centeredSlides||!!r.slidesOffsetBefore||!!r.slidesOffsetAfter;n.loopFix({slideRealIndex:e,direction:d?void 0:"next",initial:t})},loopFix:function({slideRealIndex:e,slideTo:t=!0,direction:n,setTranslate:r,activeSlideIndex:a,initial:o,byController:i,byMousewheel:s}={}){const l=this;if(!l.params.loop)return;l.emit("beforeLoopFix");const{slides:c,allowSlidePrev:u,allowSlideNext:d,slidesEl:p,params:f}=l,{centeredSlides:m,slidesOffsetBefore:h,slidesOffsetAfter:g,initialSlide:v}=f,b=m||!!h||!!g;if(l.allowSlidePrev=!0,l.allowSlideNext=!0,l.virtual&&f.virtual.enabled)return t&&(b||0!==l.snapIndex?b&&l.snapIndex<f.slidesPerView?l.slideTo(l.virtual.slides.length+l.snapIndex,0,!1,!0):l.snapIndex===l.snapGrid.length-1&&l.slideTo(l.virtual.slidesBefore,0,!1,!0):l.slideTo(l.virtual.slides.length,0,!1,!0)),l.allowSlidePrev=u,l.allowSlideNext=d,void l.emit("loopFix");let y=f.slidesPerView;"auto"===y?y=l.slidesPerViewDynamic():(y=Math.ceil(parseFloat(f.slidesPerView,10)),b&&y%2==0&&(y+=1));const w=f.slidesPerGroupAuto?y:f.slidesPerGroup;let E=b?Math.max(w,Math.ceil(y/2)):w;E%w!==0&&(E+=w-E%w),E+=f.loopAdditionalSlides,l.loopedSlides=E;const R=l.grid&&f.grid&&f.grid.rows>1;c.length<y+E||"cards"===l.params.effect&&c.length<y+2*E?xR("Swiper Loop Warning: The number of slides is not enough for loop mode, it will be disabled or not function properly. You need to add more slides (or make duplicates) or lower the values of slidesPerView and slidesPerGroup parameters"):R&&"row"===f.grid.fill&&xR("Swiper Loop Warning: Loop mode is not compatible with grid.fill = `row`");const x=[],A=[],C=R?Math.ceil(c.length/f.grid.rows):c.length,S=o&&C-v<y&&!b;let k=S?v:l.activeIndex;void 0===a?a=l.getSlideIndex(c.find(e=>e.classList.contains(f.slideActiveClass))):k=a;const O="next"===n||!n,P="prev"===n||!n;let M=0,I=0;const T=(R?c[a].column:a)+(b&&void 0===r?-y/2+.5:0);if(T<E){M=Math.max(E-T,w);for(let e=0;e<E-T;e+=1){const t=e-Math.floor(e/C)*C;if(R){const e=C-t-1;for(let t=c.length-1;t>=0;t-=1)c[t].column===e&&x.push(t)}else x.push(C-t-1)}}else if(T+y>C-E){I=Math.max(T-(C-2*E),w),S&&(I=Math.max(I,y-C+v+1));for(let e=0;e<I;e+=1){const t=e-Math.floor(e/C)*C;R?c.forEach((e,n)=>{e.column===t&&A.push(n)}):A.push(t)}}if(l.__preventObserver__=!0,requestAnimationFrame(()=>{l.__preventObserver__=!1}),"cards"===l.params.effect&&c.length<y+2*E&&(A.includes(a)&&A.splice(A.indexOf(a),1),x.includes(a)&&x.splice(x.indexOf(a),1)),P&&x.forEach(e=>{c[e].swiperLoopMoveDOM=!0,p.prepend(c[e]),c[e].swiperLoopMoveDOM=!1}),O&&A.forEach(e=>{c[e].swiperLoopMoveDOM=!0,p.append(c[e]),c[e].swiperLoopMoveDOM=!1}),l.recalcSlides(),"auto"===f.slidesPerView?l.updateSlides():R&&(x.length>0&&P||A.length>0&&O)&&l.slides.forEach((e,t)=>{l.grid.updateSlide(t,e,l.slides)}),f.watchSlidesProgress&&l.updateSlidesOffset(),t)if(x.length>0&&P){if(void 0===e){const e=l.slidesGrid[k],t=l.slidesGrid[k+M]-e;s?l.setTranslate(l.translate-t):(l.slideTo(k+Math.ceil(M),0,!1,!0),r&&(l.touchEventsData.startTranslate=l.touchEventsData.startTranslate-t,l.touchEventsData.currentTranslate=l.touchEventsData.currentTranslate-t))}else if(r){const e=R?x.length/f.grid.rows:x.length;l.slideTo(l.activeIndex+e,0,!1,!0),l.touchEventsData.currentTranslate=l.translate}}else if(A.length>0&&O)if(void 0===e){const e=l.slidesGrid[k],t=l.slidesGrid[k-I]-e;s?l.setTranslate(l.translate-t):(l.slideTo(k-I,0,!1,!0),r&&(l.touchEventsData.startTranslate=l.touchEventsData.startTranslate-t,l.touchEventsData.currentTranslate=l.touchEventsData.currentTranslate-t))}else{const e=R?A.length/f.grid.rows:A.length;l.slideTo(l.activeIndex-e,0,!1,!0)}if(l.allowSlidePrev=u,l.allowSlideNext=d,l.controller&&l.controller.control&&!i){const o={slideRealIndex:e,direction:n,setTranslate:r,activeSlideIndex:a,byController:!0};Array.isArray(l.controller.control)?l.controller.control.forEach(e=>{!e.destroyed&&e.params.loop&&e.loopFix({...o,slideTo:e.params.slidesPerView===f.slidesPerView&&t})}):l.controller.control instanceof l.constructor&&l.controller.control.params.loop&&l.controller.control.loopFix({...o,slideTo:l.controller.control.params.slidesPerView===f.slidesPerView&&t})}l.emit("loopFix")},loopDestroy:function(){const e=this,{params:t,slidesEl:n}=e;if(!t.loop||!n||e.virtual&&e.params.virtual.enabled)return;e.recalcSlides();const r=[];e.slides.forEach(e=>{const t=void 0===e.swiperSlideIndex?1*e.getAttribute("data-swiper-slide-index"):e.swiperSlideIndex;r[t]=e}),e.slides.forEach(e=>{e.removeAttribute("data-swiper-slide-index")}),r.forEach(e=>{n.append(e)}),e.recalcSlides(),e.slideTo(e.realIndex,0)}};function ZR(e,t,n){const r=mR(),{params:a}=e,o=a.edgeSwipeDetection,i=a.edgeSwipeThreshold;return!o||!(n<=i||n>=r.innerWidth-i)||"prevent"===o&&(t.preventDefault(),!0)}function JR(e){const t=this,n=pR();let r=e;r.originalEvent&&(r=r.originalEvent);const a=t.touchEventsData;if("pointerdown"===r.type){if(null!==a.pointerId&&a.pointerId!==r.pointerId)return;a.pointerId=r.pointerId}else"touchstart"===r.type&&1===r.targetTouches.length&&(a.touchId=r.targetTouches[0].identifier);if("touchstart"===r.type)return void ZR(t,r,r.targetTouches[0].pageX);const{params:o,touches:i,enabled:s}=t;if(!s)return;if(!o.simulateTouch&&"mouse"===r.pointerType)return;if(t.animating&&o.preventInteractionOnTransition)return;!t.animating&&o.cssMode&&o.loop&&t.loopFix();let l=r.target;if("wrapper"===o.touchEventsTarget&&!function(e,t){const n=mR();let r=t.contains(e);return!r&&n.HTMLSlotElement&&t instanceof HTMLSlotElement&&(r=[...t.assignedElements()].includes(e),r||(r=function(e,t){const n=[t];for(;n.length>0;){const t=n.shift();if(e===t)return!0;n.push(...t.children,...t.shadowRoot?t.shadowRoot.children:[],...t.assignedElements?t.assignedElements():[])}}(e,t))),r}(l,t.wrapperEl))return;if("which"in r&&3===r.which)return;if("button"in r&&r.button>0)return;if(a.isTouched&&a.isMoved)return;const c=!!o.noSwipingClass&&""!==o.noSwipingClass,u=r.composedPath?r.composedPath():r.path;c&&r.target&&r.target.shadowRoot&&u&&(l=u[0]);const d=o.noSwipingSelector?o.noSwipingSelector:`.${o.noSwipingClass}`,p=!(!r.target||!r.target.shadowRoot);if(o.noSwiping&&(p?function(e,t=this){return function t(n){if(!n||n===pR()||n===mR())return null;n.assignedSlot&&(n=n.assignedSlot);const r=n.closest(e);return r||n.getRootNode?r||t(n.getRootNode().host):null}(t)}(d,l):l.closest(d)))return void(t.allowClick=!0);if(o.swipeHandler&&!l.closest(o.swipeHandler))return;i.currentX=r.pageX,i.currentY=r.pageY;const f=i.currentX,m=i.currentY;if(!ZR(t,r,f))return;Object.assign(a,{isTouched:!0,isMoved:!1,allowTouchCallbacks:!0,isScrolling:void 0,startMoving:void 0}),i.startX=f,i.startY=m,a.touchStartTime=gR(),t.allowClick=!0,t.updateSize(),t.swipeDirection=void 0,o.threshold>0&&(a.allowThresholdMove=!1);let h=!0;l.matches(a.focusableElements)&&(h=!1,"SELECT"===l.nodeName&&(a.isTouched=!1)),n.activeElement&&n.activeElement.matches(a.focusableElements)&&n.activeElement!==l&&("mouse"===r.pointerType||"mouse"!==r.pointerType&&!l.matches(a.focusableElements))&&n.activeElement.blur();const g=h&&t.allowTouchMove&&o.touchStartPreventDefault;!o.touchStartForcePreventDefault&&!g||l.isContentEditable||r.preventDefault(),o.freeMode&&o.freeMode.enabled&&t.freeMode&&t.animating&&!o.cssMode&&t.freeMode.onTouchStart(),t.emit("touchStart",r)}function XR(e){const t=pR(),n=this,r=n.touchEventsData,{params:a,touches:o,rtlTranslate:i,enabled:s}=n;if(!s)return;if(!a.simulateTouch&&"mouse"===e.pointerType)return;let l,c=e;if(c.originalEvent&&(c=c.originalEvent),"pointermove"===c.type){if(null!==r.touchId)return;if(c.pointerId!==r.pointerId)return}if("touchmove"===c.type){if(l=[...c.changedTouches].find(e=>e.identifier===r.touchId),!l||l.identifier!==r.touchId)return}else l=c;if(!r.isTouched)return void(r.startMoving&&r.isScrolling&&n.emit("touchMoveOpposite",c));const u=l.pageX,d=l.pageY;if(c.preventedByNestedSwiper)return o.startX=u,void(o.startY=d);if(!n.allowTouchMove)return c.target.matches(r.focusableElements)||(n.allowClick=!1),void(r.isTouched&&(Object.assign(o,{startX:u,startY:d,currentX:u,currentY:d}),r.touchStartTime=gR()));if(a.touchReleaseOnEdges&&!a.loop)if(n.isVertical()){if(d<o.startY&&n.translate<=n.maxTranslate()||d>o.startY&&n.translate>=n.minTranslate())return r.isTouched=!1,void(r.isMoved=!1)}else{if(i&&(u>o.startX&&-n.translate<=n.maxTranslate()||u<o.startX&&-n.translate>=n.minTranslate()))return;if(!i&&(u<o.startX&&n.translate<=n.maxTranslate()||u>o.startX&&n.translate>=n.minTranslate()))return}if(t.activeElement&&t.activeElement.matches(r.focusableElements)&&t.activeElement!==c.target&&"mouse"!==c.pointerType&&t.activeElement.blur(),t.activeElement&&c.target===t.activeElement&&c.target.matches(r.focusableElements))return r.isMoved=!0,void(n.allowClick=!1);r.allowTouchCallbacks&&n.emit("touchMove",c),o.previousX=o.currentX,o.previousY=o.currentY,o.currentX=u,o.currentY=d;const p=o.currentX-o.startX,f=o.currentY-o.startY;if(n.params.threshold&&Math.sqrt(p**2+f**2)<n.params.threshold)return;if(void 0===r.isScrolling){let e;n.isHorizontal()&&o.currentY===o.startY||n.isVertical()&&o.currentX===o.startX?r.isScrolling=!1:p*p+f*f>=25&&(e=180*Math.atan2(Math.abs(f),Math.abs(p))/Math.PI,r.isScrolling=n.isHorizontal()?e>a.touchAngle:90-e>a.touchAngle)}if(r.isScrolling&&n.emit("touchMoveOpposite",c),void 0===r.startMoving&&(o.currentX===o.startX&&o.currentY===o.startY||(r.startMoving=!0)),r.isScrolling||"touchmove"===c.type&&r.preventTouchMoveFromPointerMove)return void(r.isTouched=!1);if(!r.startMoving)return;n.allowClick=!1,!a.cssMode&&c.cancelable&&c.preventDefault(),a.touchMoveStopPropagation&&!a.nested&&c.stopPropagation();let m=n.isHorizontal()?p:f,h=n.isHorizontal()?o.currentX-o.previousX:o.currentY-o.previousY;a.oneWayMovement&&(m=Math.abs(m)*(i?1:-1),h=Math.abs(h)*(i?1:-1)),o.diff=m,m*=a.touchRatio,i&&(m=-m,h=-h);const g=n.touchesDirection;n.swipeDirection=m>0?"prev":"next",n.touchesDirection=h>0?"prev":"next";const v=n.params.loop&&!a.cssMode,b="next"===n.touchesDirection&&n.allowSlideNext||"prev"===n.touchesDirection&&n.allowSlidePrev;if(!r.isMoved){if(v&&b&&n.loopFix({direction:n.swipeDirection}),r.startTranslate=n.getTranslate(),n.setTransition(0),n.animating){const e=new window.CustomEvent("transitionend",{bubbles:!0,cancelable:!0,detail:{bySwiperTouchMove:!0}});n.wrapperEl.dispatchEvent(e)}r.allowMomentumBounce=!1,!a.grabCursor||!0!==n.allowSlideNext&&!0!==n.allowSlidePrev||n.setGrabCursor(!0),n.emit("sliderFirstMove",c)}if((new Date).getTime(),!1!==a._loopSwapReset&&r.isMoved&&r.allowThresholdMove&&g!==n.touchesDirection&&v&&b&&Math.abs(m)>=1)return Object.assign(o,{startX:u,startY:d,currentX:u,currentY:d,startTranslate:r.currentTranslate}),r.loopSwapReset=!0,void(r.startTranslate=r.currentTranslate);n.emit("sliderMove",c),r.isMoved=!0,r.currentTranslate=m+r.startTranslate;let y=!0,w=a.resistanceRatio;if(a.touchReleaseOnEdges&&(w=0),m>0?(v&&b&&r.allowThresholdMove&&r.currentTranslate>(a.centeredSlides?n.minTranslate()-n.slidesSizesGrid[n.activeIndex+1]-("auto"!==a.slidesPerView&&n.slides.length-a.slidesPerView>=2?n.slidesSizesGrid[n.activeIndex+1]+n.params.spaceBetween:0)-n.params.spaceBetween:n.minTranslate())&&n.loopFix({direction:"prev",setTranslate:!0,activeSlideIndex:0}),r.currentTranslate>n.minTranslate()&&(y=!1,a.resistance&&(r.currentTranslate=n.minTranslate()-1+(-n.minTranslate()+r.startTranslate+m)**w))):m<0&&(v&&b&&r.allowThresholdMove&&r.currentTranslate<(a.centeredSlides?n.maxTranslate()+n.slidesSizesGrid[n.slidesSizesGrid.length-1]+n.params.spaceBetween+("auto"!==a.slidesPerView&&n.slides.length-a.slidesPerView>=2?n.slidesSizesGrid[n.slidesSizesGrid.length-1]+n.params.spaceBetween:0):n.maxTranslate())&&n.loopFix({direction:"next",setTranslate:!0,activeSlideIndex:n.slides.length-("auto"===a.slidesPerView?n.slidesPerViewDynamic():Math.ceil(parseFloat(a.slidesPerView,10)))}),r.currentTranslate<n.maxTranslate()&&(y=!1,a.resistance&&(r.currentTranslate=n.maxTranslate()+1-(n.maxTranslate()-r.startTranslate-m)**w))),y&&(c.preventedByNestedSwiper=!0),!n.allowSlideNext&&"next"===n.swipeDirection&&r.currentTranslate<r.startTranslate&&(r.currentTranslate=r.startTranslate),!n.allowSlidePrev&&"prev"===n.swipeDirection&&r.currentTranslate>r.startTranslate&&(r.currentTranslate=r.startTranslate),n.allowSlidePrev||n.allowSlideNext||(r.currentTranslate=r.startTranslate),a.threshold>0){if(!(Math.abs(m)>a.threshold||r.allowThresholdMove))return void(r.currentTranslate=r.startTranslate);if(!r.allowThresholdMove)return r.allowThresholdMove=!0,o.startX=o.currentX,o.startY=o.currentY,r.currentTranslate=r.startTranslate,void(o.diff=n.isHorizontal()?o.currentX-o.startX:o.currentY-o.startY)}a.followFinger&&!a.cssMode&&((a.freeMode&&a.freeMode.enabled&&n.freeMode||a.watchSlidesProgress)&&(n.updateActiveIndex(),n.updateSlidesClasses()),a.freeMode&&a.freeMode.enabled&&n.freeMode&&n.freeMode.onTouchMove(),n.updateProgress(r.currentTranslate),n.setTranslate(r.currentTranslate))}function YR(e){const t=this,n=t.touchEventsData;let r,a=e;if(a.originalEvent&&(a=a.originalEvent),"touchend"===a.type||"touchcancel"===a.type){if(r=[...a.changedTouches].find(e=>e.identifier===n.touchId),!r||r.identifier!==n.touchId)return}else{if(null!==n.touchId)return;if(a.pointerId!==n.pointerId)return;r=a}if(["pointercancel","pointerout","pointerleave","contextmenu"].includes(a.type)&&(!["pointercancel","contextmenu"].includes(a.type)||!t.browser.isSafari&&!t.browser.isWebView))return;n.pointerId=null,n.touchId=null;const{params:o,touches:i,rtlTranslate:s,slidesGrid:l,enabled:c}=t;if(!c)return;if(!o.simulateTouch&&"mouse"===a.pointerType)return;if(n.allowTouchCallbacks&&t.emit("touchEnd",a),n.allowTouchCallbacks=!1,!n.isTouched)return n.isMoved&&o.grabCursor&&t.setGrabCursor(!1),n.isMoved=!1,void(n.startMoving=!1);o.grabCursor&&n.isMoved&&n.isTouched&&(!0===t.allowSlideNext||!0===t.allowSlidePrev)&&t.setGrabCursor(!1);const u=gR(),d=u-n.touchStartTime;if(t.allowClick){const e=a.path||a.composedPath&&a.composedPath();t.updateClickedSlide(e&&e[0]||a.target,e),t.emit("tap click",a),d<300&&u-n.lastClickTime<300&&t.emit("doubleTap doubleClick",a)}if(n.lastClickTime=gR(),hR(()=>{t.destroyed||(t.allowClick=!0)}),!n.isTouched||!n.isMoved||!t.swipeDirection||0===i.diff&&!n.loopSwapReset||n.currentTranslate===n.startTranslate&&!n.loopSwapReset)return n.isTouched=!1,n.isMoved=!1,void(n.startMoving=!1);let p;if(n.isTouched=!1,n.isMoved=!1,n.startMoving=!1,p=o.followFinger?s?t.translate:-t.translate:-n.currentTranslate,o.cssMode)return;if(o.freeMode&&o.freeMode.enabled)return void t.freeMode.onTouchEnd({currentPos:p});const f=p>=-t.maxTranslate()&&!t.params.loop;let m=0,h=t.slidesSizesGrid[0];for(let e=0;e<l.length;e+=e<o.slidesPerGroupSkip?1:o.slidesPerGroup){const t=e<o.slidesPerGroupSkip-1?1:o.slidesPerGroup;void 0!==l[e+t]?(f||p>=l[e]&&p<l[e+t])&&(m=e,h=l[e+t]-l[e]):(f||p>=l[e])&&(m=e,h=l[l.length-1]-l[l.length-2])}let g=null,v=null;o.rewind&&(t.isBeginning?v=o.virtual&&o.virtual.enabled&&t.virtual?t.virtual.slides.length-1:t.slides.length-1:t.isEnd&&(g=0));const b=(p-l[m])/h,y=m<o.slidesPerGroupSkip-1?1:o.slidesPerGroup;if(d>o.longSwipesMs){if(!o.longSwipes)return void t.slideTo(t.activeIndex);"next"===t.swipeDirection&&(b>=o.longSwipesRatio?t.slideTo(o.rewind&&t.isEnd?g:m+y):t.slideTo(m)),"prev"===t.swipeDirection&&(b>1-o.longSwipesRatio?t.slideTo(m+y):null!==v&&b<0&&Math.abs(b)>o.longSwipesRatio?t.slideTo(v):t.slideTo(m))}else{if(!o.shortSwipes)return void t.slideTo(t.activeIndex);!t.navigation||a.target!==t.navigation.nextEl&&a.target!==t.navigation.prevEl?("next"===t.swipeDirection&&t.slideTo(null!==g?g:m+y),"prev"===t.swipeDirection&&t.slideTo(null!==v?v:m)):a.target===t.navigation.nextEl?t.slideTo(m+y):t.slideTo(m)}}function $R(){const e=this,{params:t,el:n}=e;if(n&&0===n.offsetWidth)return;t.breakpoints&&e.setBreakpoint();const{allowSlideNext:r,allowSlidePrev:a,snapGrid:o}=e,i=e.virtual&&e.params.virtual.enabled;e.allowSlideNext=!0,e.allowSlidePrev=!0,e.updateSize(),e.updateSlides(),e.updateSlidesClasses();const s=i&&t.loop;if(!("auto"===t.slidesPerView||t.slidesPerView>1)||!e.isEnd||e.isBeginning||e.params.centeredSlides||s)e.params.loop&&!i?e.slideToLoop(e.realIndex,0,!1,!0):e.slideTo(e.activeIndex,0,!1,!0);else{const t=i?e.virtual.slides:e.slides;e.slideTo(t.length-1,0,!1,!0)}e.autoplay&&e.autoplay.running&&e.autoplay.paused&&(clearTimeout(e.autoplay.resizeTimeout),e.autoplay.resizeTimeout=setTimeout(()=>{e.autoplay&&e.autoplay.running&&e.autoplay.paused&&e.autoplay.resume()},500)),e.allowSlidePrev=a,e.allowSlideNext=r,e.params.watchOverflow&&o!==e.snapGrid&&e.checkOverflow()}function ex(e){const t=this;t.enabled&&(t.allowClick||(t.params.preventClicks&&e.preventDefault(),t.params.preventClicksPropagation&&t.animating&&(e.stopPropagation(),e.stopImmediatePropagation())))}function tx(){const e=this,{wrapperEl:t,rtlTranslate:n,enabled:r}=e;if(!r)return;let a;e.previousTranslate=e.translate,e.isHorizontal()?e.translate=-t.scrollLeft:e.translate=-t.scrollTop,0===e.translate&&(e.translate=0),e.updateActiveIndex(),e.updateSlidesClasses();const o=e.maxTranslate()-e.minTranslate();a=0===o?0:(e.translate-e.minTranslate())/o,a!==e.progress&&e.updateProgress(n?-e.translate:e.translate),e.emit("setTranslate",e.translate,!1)}function nx(e){const t=this;jR(t,e.target),t.params.cssMode||"auto"!==t.params.slidesPerView&&!t.params.autoHeight||t.update()}function rx(){const e=this;e.documentTouchHandlerProceeded||(e.documentTouchHandlerProceeded=!0,e.params.touchReleaseOnEdges&&(e.el.style.touchAction="auto"))}const ax=(e,t)=>{const n=pR(),{params:r,el:a,wrapperEl:o,device:i}=e,s=!!r.nested,l="on"===t?"addEventListener":"removeEventListener",c=t;a&&"string"!=typeof a&&(n[l]("touchstart",e.onDocumentTouchStart,{passive:!1,capture:s}),a[l]("touchstart",e.onTouchStart,{passive:!1}),a[l]("pointerdown",e.onTouchStart,{passive:!1}),n[l]("touchmove",e.onTouchMove,{passive:!1,capture:s}),n[l]("pointermove",e.onTouchMove,{passive:!1,capture:s}),n[l]("touchend",e.onTouchEnd,{passive:!0}),n[l]("pointerup",e.onTouchEnd,{passive:!0}),n[l]("pointercancel",e.onTouchEnd,{passive:!0}),n[l]("touchcancel",e.onTouchEnd,{passive:!0}),n[l]("pointerout",e.onTouchEnd,{passive:!0}),n[l]("pointerleave",e.onTouchEnd,{passive:!0}),n[l]("contextmenu",e.onTouchEnd,{passive:!0}),(r.preventClicks||r.preventClicksPropagation)&&a[l]("click",e.onClick,!0),r.cssMode&&o[l]("scroll",e.onScroll),r.updateOnWindowResize?e[c](i.ios||i.android?"resize orientationchange observerUpdate":"resize observerUpdate",$R,!0):e[c]("observerUpdate",$R,!0),a[l]("load",e.onLoad,{capture:!0}))},ox=(e,t)=>e.grid&&t.grid&&t.grid.rows>1;var ix={setBreakpoint:function(){const e=this,{realIndex:t,initialized:n,params:r,el:a}=e,o=r.breakpoints;if(!o||o&&0===Object.keys(o).length)return;const i=pR(),s="window"!==r.breakpointsBase&&r.breakpointsBase?"container":r.breakpointsBase,l=["window","container"].includes(r.breakpointsBase)||!r.breakpointsBase?e.el:i.querySelector(r.breakpointsBase),c=e.getBreakpoint(o,s,l);if(!c||e.currentBreakpoint===c)return;const u=(c in o?o[c]:void 0)||e.originalParams,d=ox(e,r),p=ox(e,u),f=e.params.grabCursor,m=u.grabCursor,h=r.enabled;d&&!p?(a.classList.remove(`${r.containerModifierClass}grid`,`${r.containerModifierClass}grid-column`),e.emitContainerClasses()):!d&&p&&(a.classList.add(`${r.containerModifierClass}grid`),(u.grid.fill&&"column"===u.grid.fill||!u.grid.fill&&"column"===r.grid.fill)&&a.classList.add(`${r.containerModifierClass}grid-column`),e.emitContainerClasses()),f&&!m?e.unsetGrabCursor():!f&&m&&e.setGrabCursor(),["navigation","pagination","scrollbar"].forEach(t=>{if(void 0===u[t])return;const n=r[t]&&r[t].enabled,a=u[t]&&u[t].enabled;n&&!a&&e[t].disable(),!n&&a&&e[t].enable()});const g=u.direction&&u.direction!==r.direction,v=r.loop&&(u.slidesPerView!==r.slidesPerView||g),b=r.loop;g&&n&&e.changeDirection(),yR(e.params,u);const y=e.params.enabled,w=e.params.loop;Object.assign(e,{allowTouchMove:e.params.allowTouchMove,allowSlideNext:e.params.allowSlideNext,allowSlidePrev:e.params.allowSlidePrev}),h&&!y?e.disable():!h&&y&&e.enable(),e.currentBreakpoint=c,e.emit("_beforeBreakpoint",u),n&&(v?(e.loopDestroy(),e.loopCreate(t),e.updateSlides()):!b&&w?(e.loopCreate(t),e.updateSlides()):b&&!w&&e.loopDestroy()),e.emit("breakpoint",u)},getBreakpoint:function(e,t="window",n){if(!e||"container"===t&&!n)return;let r=!1;const a=mR(),o="window"===t?a.innerHeight:n.clientHeight,i=Object.keys(e).map(e=>{if("string"==typeof e&&0===e.indexOf("@")){const t=parseFloat(e.substr(1));return{value:o*t,point:e}}return{value:e,point:e}});i.sort((e,t)=>parseInt(e.value,10)-parseInt(t.value,10));for(let e=0;e<i.length;e+=1){const{point:o,value:s}=i[e];"window"===t?a.matchMedia(`(min-width: ${s}px)`).matches&&(r=o):s<=n.clientWidth&&(r=o)}return r||"max"}},sx={addClasses:function(){const e=this,{classNames:t,params:n,rtl:r,el:a,device:o}=e,i=function(e,t){const n=[];return e.forEach(e=>{"object"==typeof e?Object.keys(e).forEach(r=>{e[r]&&n.push(t+r)}):"string"==typeof e&&n.push(t+e)}),n}(["initialized",n.direction,{"free-mode":e.params.freeMode&&n.freeMode.enabled},{autoheight:n.autoHeight},{rtl:r},{grid:n.grid&&n.grid.rows>1},{"grid-column":n.grid&&n.grid.rows>1&&"column"===n.grid.fill},{android:o.android},{ios:o.ios},{"css-mode":n.cssMode},{centered:n.cssMode&&n.centeredSlides},{"watch-progress":n.watchSlidesProgress}],n.containerModifierClass);t.push(...i),a.classList.add(...t),e.emitContainerClasses()},removeClasses:function(){const{el:e,classNames:t}=this;e&&"string"!=typeof e&&(e.classList.remove(...t),this.emitContainerClasses())}},lx={init:!0,direction:"horizontal",oneWayMovement:!1,swiperElementNodeName:"SWIPER-CONTAINER",touchEventsTarget:"wrapper",initialSlide:0,speed:300,cssMode:!1,updateOnWindowResize:!0,resizeObserver:!0,nested:!1,createElements:!1,eventsPrefix:"swiper",enabled:!0,focusableElements:"input, select, option, textarea, button, video, label",width:null,height:null,preventInteractionOnTransition:!1,userAgent:null,url:null,edgeSwipeDetection:!1,edgeSwipeThreshold:20,autoHeight:!1,setWrapperSize:!1,virtualTranslate:!1,effect:"slide",breakpoints:void 0,breakpointsBase:"window",spaceBetween:0,slidesPerView:1,slidesPerGroup:1,slidesPerGroupSkip:0,slidesPerGroupAuto:!1,centeredSlides:!1,centeredSlidesBounds:!1,slidesOffsetBefore:0,slidesOffsetAfter:0,normalizeSlideIndex:!0,centerInsufficientSlides:!1,snapToSlideEdge:!1,watchOverflow:!0,roundLengths:!1,touchRatio:1,touchAngle:45,simulateTouch:!0,shortSwipes:!0,longSwipes:!0,longSwipesRatio:.5,longSwipesMs:300,followFinger:!0,allowTouchMove:!0,threshold:5,touchMoveStopPropagation:!1,touchStartPreventDefault:!0,touchStartForcePreventDefault:!1,touchReleaseOnEdges:!1,uniqueNavElements:!0,resistance:!0,resistanceRatio:.85,watchSlidesProgress:!1,grabCursor:!1,preventClicks:!0,preventClicksPropagation:!0,slideToClickedSlide:!1,loop:!1,loopAddBlankSlides:!0,loopAdditionalSlides:0,loopPreventsSliding:!0,rewind:!1,allowSlidePrev:!0,allowSlideNext:!0,swipeHandler:null,noSwiping:!0,noSwipingClass:"swiper-no-swiping",noSwipingSelector:null,passiveListeners:!0,maxBackfaceHiddenSlides:10,containerModifierClass:"swiper-",slideClass:"swiper-slide",slideBlankClass:"swiper-slide-blank",slideActiveClass:"swiper-slide-active",slideVisibleClass:"swiper-slide-visible",slideFullyVisibleClass:"swiper-slide-fully-visible",slideNextClass:"swiper-slide-next",slidePrevClass:"swiper-slide-prev",wrapperClass:"swiper-wrapper",lazyPreloaderClass:"swiper-lazy-preloader",lazyPreloadPrevNext:0,runCallbacksOnInit:!0,_emitClasses:!1};function cx(e,t){return function(n={}){const r=Object.keys(n)[0],a=n[r];"object"==typeof a&&null!==a?(!0===e[r]&&(e[r]={enabled:!0}),"navigation"===r&&e[r]&&e[r].enabled&&!e[r].prevEl&&!e[r].nextEl&&(e[r].auto=!0),["pagination","scrollbar"].indexOf(r)>=0&&e[r]&&e[r].enabled&&!e[r].el&&(e[r].auto=!0),r in e&&"enabled"in a?("object"!=typeof e[r]||"enabled"in e[r]||(e[r].enabled=!0),e[r]||(e[r]={enabled:!1}),yR(t,n)):yR(t,n)):yR(t,n)}}const ux={eventsEmitter:BR,update:GR,translate:qR,transition:WR,slide:QR,loop:KR,grabCursor:{setGrabCursor:function(e){const t=this;if(!t.params.simulateTouch||t.params.watchOverflow&&t.isLocked||t.params.cssMode)return;const n="container"===t.params.touchEventsTarget?t.el:t.wrapperEl;t.isElement&&(t.__preventObserver__=!0),n.style.cursor="move",n.style.cursor=e?"grabbing":"grab",t.isElement&&requestAnimationFrame(()=>{t.__preventObserver__=!1})},unsetGrabCursor:function(){const e=this;e.params.watchOverflow&&e.isLocked||e.params.cssMode||(e.isElement&&(e.__preventObserver__=!0),e["container"===e.params.touchEventsTarget?"el":"wrapperEl"].style.cursor="",e.isElement&&requestAnimationFrame(()=>{e.__preventObserver__=!1}))}},events:{attachEvents:function(){const e=this,{params:t}=e;e.onTouchStart=JR.bind(e),e.onTouchMove=XR.bind(e),e.onTouchEnd=YR.bind(e),e.onDocumentTouchStart=rx.bind(e),t.cssMode&&(e.onScroll=tx.bind(e)),e.onClick=ex.bind(e),e.onLoad=nx.bind(e),ax(e,"on")},detachEvents:function(){ax(this,"off")}},breakpoints:ix,checkOverflow:{checkOverflow:function(){const e=this,{isLocked:t,params:n}=e,{slidesOffsetBefore:r}=n;if(r){const t=e.slides.length-1,n=e.slidesGrid[t]+e.slidesSizesGrid[t]+2*r;e.isLocked=e.size>n}else e.isLocked=1===e.snapGrid.length;!0===n.allowSlideNext&&(e.allowSlideNext=!e.isLocked),!0===n.allowSlidePrev&&(e.allowSlidePrev=!e.isLocked),t&&t!==e.isLocked&&(e.isEnd=!1),t!==e.isLocked&&e.emit(e.isLocked?"lock":"unlock")}},classes:sx},dx={};class px{constructor(...e){let t,n;1===e.length&&e[0].constructor&&"Object"===Object.prototype.toString.call(e[0]).slice(8,-1)?n=e[0]:[t,n]=e,n||(n={}),n=yR({},n),t&&!n.el&&(n.el=t);const r=pR();if(n.el&&"string"==typeof n.el&&r.querySelectorAll(n.el).length>1){const e=[];return r.querySelectorAll(n.el).forEach(t=>{const r=yR({},n,{el:t});e.push(new px(r))}),e}const a=this;a.__swiper__=!0,a.support=NR(),a.device=LR({userAgent:n.userAgent}),a.browser=DR(),a.eventsListeners={},a.eventsAnyListeners=[],a.modules=[...a.__modules__],n.modules&&Array.isArray(n.modules)&&n.modules.forEach(e=>{"function"==typeof e&&a.modules.indexOf(e)<0&&a.modules.push(e)});const o={};a.modules.forEach(e=>{e({params:n,swiper:a,extendParams:cx(n,o),on:a.on.bind(a),once:a.once.bind(a),off:a.off.bind(a),emit:a.emit.bind(a)})});const i=yR({},lx,o);return a.params=yR({},i,dx,n),a.originalParams=yR({},a.params),a.passedParams=yR({},n),a.params&&a.params.on&&Object.keys(a.params.on).forEach(e=>{a.on(e,a.params.on[e])}),a.params&&a.params.onAny&&a.onAny(a.params.onAny),Object.assign(a,{enabled:a.params.enabled,el:t,classNames:[],slides:[],slidesGrid:[],snapGrid:[],slidesSizesGrid:[],isHorizontal:()=>"horizontal"===a.params.direction,isVertical:()=>"vertical"===a.params.direction,activeIndex:0,realIndex:0,isBeginning:!0,isEnd:!1,translate:0,previousTranslate:0,progress:0,velocity:0,animating:!1,cssOverflowAdjustment(){return Math.trunc(this.translate/2**23)*2**23},allowSlideNext:a.params.allowSlideNext,allowSlidePrev:a.params.allowSlidePrev,touchEventsData:{isTouched:void 0,isMoved:void 0,allowTouchCallbacks:void 0,touchStartTime:void 0,isScrolling:void 0,currentTranslate:void 0,startTranslate:void 0,allowThresholdMove:void 0,focusableElements:a.params.focusableElements,lastClickTime:0,clickTimeout:void 0,velocities:[],allowMomentumBounce:void 0,startMoving:void 0,pointerId:null,touchId:null},allowClick:!0,allowTouchMove:a.params.allowTouchMove,touches:{startX:0,startY:0,currentX:0,currentY:0,diff:0},imagesToLoad:[],imagesLoaded:0}),a.emit("_swiper"),a.params.init&&a.init(),a}getDirectionLabel(e){return this.isHorizontal()?e:{width:"height","margin-top":"margin-left","margin-bottom ":"margin-right","margin-left":"margin-top","margin-right":"margin-bottom","padding-left":"padding-top","padding-right":"padding-bottom",marginRight:"marginBottom"}[e]}getSlideIndex(e){const{slidesEl:t,params:n}=this,r=SR(RR(t,`.${n.slideClass}, swiper-slide`)[0]);return SR(e)-r}getSlideIndexByData(e){return this.getSlideIndex(this.slides.find(t=>1*t.getAttribute("data-swiper-slide-index")===e))}getSlideIndexWhenGrid(e){return this.grid&&this.params.grid&&this.params.grid.rows>1&&("column"===this.params.grid.fill?e=Math.floor(e/this.params.grid.rows):"row"===this.params.grid.fill&&(e%=Math.ceil(this.slides.length/this.params.grid.rows))),e}recalcSlides(){const{slidesEl:e,params:t}=this;this.slides=RR(e,`.${t.slideClass}, swiper-slide`)}enable(){const e=this;e.enabled||(e.enabled=!0,e.params.grabCursor&&e.setGrabCursor(),e.emit("enable"))}disable(){const e=this;e.enabled&&(e.enabled=!1,e.params.grabCursor&&e.unsetGrabCursor(),e.emit("disable"))}setProgress(e,t){const n=this;e=Math.min(Math.max(e,0),1);const r=n.minTranslate(),a=(n.maxTranslate()-r)*e+r;n.translateTo(a,void 0===t?0:t),n.updateActiveIndex(),n.updateSlidesClasses()}emitContainerClasses(){const e=this;if(!e.params._emitClasses||!e.el)return;const t=e.el.className.split(" ").filter(t=>0===t.indexOf("swiper")||0===t.indexOf(e.params.containerModifierClass));e.emit("_containerClasses",t.join(" "))}getSlideClasses(e){const t=this;return t.destroyed?"":e.className.split(" ").filter(e=>0===e.indexOf("swiper-slide")||0===e.indexOf(t.params.slideClass)).join(" ")}emitSlidesClasses(){const e=this;if(!e.params._emitClasses||!e.el)return;const t=[];e.slides.forEach(n=>{const r=e.getSlideClasses(n);t.push({slideEl:n,classNames:r}),e.emit("_slideClass",n,r)}),e.emit("_slideClasses",t)}slidesPerViewDynamic(e="current",t=!1){const{params:n,slides:r,slidesGrid:a,slidesSizesGrid:o,size:i,activeIndex:s}=this;let l=1;if("number"==typeof n.slidesPerView)return n.slidesPerView;if(n.centeredSlides){let e,t=r[s]?Math.ceil(r[s].swiperSlideSize):0;for(let n=s+1;n<r.length;n+=1)r[n]&&!e&&(t+=Math.ceil(r[n].swiperSlideSize),l+=1,t>i&&(e=!0));for(let n=s-1;n>=0;n-=1)r[n]&&!e&&(t+=r[n].swiperSlideSize,l+=1,t>i&&(e=!0))}else if("current"===e)for(let e=s+1;e<r.length;e+=1)(t?a[e]+o[e]-a[s]<i:a[e]-a[s]<i)&&(l+=1);else for(let e=s-1;e>=0;e-=1)a[s]-a[e]<i&&(l+=1);return l}update(){const e=this;if(!e||e.destroyed)return;const{snapGrid:t,params:n}=e;function r(){const t=e.rtlTranslate?-1*e.translate:e.translate,n=Math.min(Math.max(t,e.maxTranslate()),e.minTranslate());e.setTranslate(n),e.updateActiveIndex(),e.updateSlidesClasses()}let a;if(n.breakpoints&&e.setBreakpoint(),[...e.el.querySelectorAll('[loading="lazy"]')].forEach(t=>{t.complete&&jR(e,t)}),e.updateSize(),e.updateSlides(),e.updateProgress(),e.updateSlidesClasses(),n.freeMode&&n.freeMode.enabled&&!n.cssMode)r(),n.autoHeight&&e.updateAutoHeight();else{if(("auto"===n.slidesPerView||n.slidesPerView>1)&&e.isEnd&&!n.centeredSlides){const t=e.virtual&&n.virtual.enabled?e.virtual.slides:e.slides;a=e.slideTo(t.length-1,0,!1,!0)}else a=e.slideTo(e.activeIndex,0,!1,!0);a||r()}n.watchOverflow&&t!==e.snapGrid&&e.checkOverflow(),e.emit("update")}changeDirection(e,t=!0){const n=this,r=n.params.direction;return e||(e="horizontal"===r?"vertical":"horizontal"),e===r||"horizontal"!==e&&"vertical"!==e||(n.el.classList.remove(`${n.params.containerModifierClass}${r}`),n.el.classList.add(`${n.params.containerModifierClass}${e}`),n.emitContainerClasses(),n.params.direction=e,n.slides.forEach(t=>{"vertical"===e?t.style.width="":t.style.height=""}),n.emit("changeDirection"),t&&n.update()),n}changeLanguageDirection(e){const t=this;t.rtl&&"rtl"===e||!t.rtl&&"ltr"===e||(t.rtl="rtl"===e,t.rtlTranslate="horizontal"===t.params.direction&&t.rtl,t.rtl?(t.el.classList.add(`${t.params.containerModifierClass}rtl`),t.el.dir="rtl"):(t.el.classList.remove(`${t.params.containerModifierClass}rtl`),t.el.dir="ltr"),t.update())}mount(e){const t=this;if(t.mounted)return!0;let n=e||t.params.el;if("string"==typeof n&&(n=document.querySelector(n)),!n)return!1;n.swiper=t,n.parentNode&&n.parentNode.host&&n.parentNode.host.nodeName===t.params.swiperElementNodeName.toUpperCase()&&(t.isElement=!0);const r=()=>`.${(t.params.wrapperClass||"").trim().split(" ").join(".")}`;let a=n&&n.shadowRoot&&n.shadowRoot.querySelector?n.shadowRoot.querySelector(r()):RR(n,r())[0];return!a&&t.params.createElements&&(a=AR("div",t.params.wrapperClass),n.append(a),RR(n,`.${t.params.slideClass}`).forEach(e=>{a.append(e)})),Object.assign(t,{el:n,wrapperEl:a,slidesEl:t.isElement&&!n.parentNode.host.slideSlots?n.parentNode.host:a,hostEl:t.isElement?n.parentNode.host:n,mounted:!0,rtl:"rtl"===n.dir.toLowerCase()||"rtl"===CR(n,"direction"),rtlTranslate:"horizontal"===t.params.direction&&("rtl"===n.dir.toLowerCase()||"rtl"===CR(n,"direction")),wrongRTL:"-webkit-box"===CR(a,"display")}),!0}init(e){const t=this;if(t.initialized)return t;if(!1===t.mount(e))return t;t.emit("beforeInit"),t.params.breakpoints&&t.setBreakpoint(),t.addClasses(),t.updateSize(),t.updateSlides(),t.params.watchOverflow&&t.checkOverflow(),t.params.grabCursor&&t.enabled&&t.setGrabCursor(),t.params.loop&&t.virtual&&t.params.virtual.enabled?t.slideTo(t.params.initialSlide+t.virtual.slidesBefore,0,t.params.runCallbacksOnInit,!1,!0):t.slideTo(t.params.initialSlide,0,t.params.runCallbacksOnInit,!1,!0),t.params.loop&&t.loopCreate(void 0,!0),t.attachEvents();const n=[...t.el.querySelectorAll('[loading="lazy"]')];return t.isElement&&n.push(...t.hostEl.querySelectorAll('[loading="lazy"]')),n.forEach(e=>{e.complete?jR(t,e):e.addEventListener("load",e=>{jR(t,e.target)})}),VR(t),t.initialized=!0,VR(t),t.emit("init"),t.emit("afterInit"),t}destroy(e=!0,t=!0){const n=this,{params:r,el:a,wrapperEl:o,slides:i}=n;return void 0===n.params||n.destroyed||(n.emit("beforeDestroy"),n.initialized=!1,n.detachEvents(),r.loop&&n.loopDestroy(),t&&(n.removeClasses(),a&&"string"!=typeof a&&a.removeAttribute("style"),o&&o.removeAttribute("style"),i&&i.length&&i.forEach(e=>{e.classList.remove(r.slideVisibleClass,r.slideFullyVisibleClass,r.slideActiveClass,r.slideNextClass,r.slidePrevClass),e.removeAttribute("style"),e.removeAttribute("data-swiper-slide-index")})),n.emit("destroy"),Object.keys(n.eventsListeners).forEach(e=>{n.off(e)}),!1!==e&&(n.el&&"string"!=typeof n.el&&(n.el.swiper=null),function(e){const t=e;Object.keys(t).forEach(e=>{try{t[e]=null}catch(e){}try{delete t[e]}catch(e){}})}(n)),n.destroyed=!0),null}static extendDefaults(e){yR(dx,e)}static get extendedDefaults(){return dx}static get defaults(){return lx}static installModule(e){px.prototype.__modules__||(px.prototype.__modules__=[]);const t=px.prototype.__modules__;"function"==typeof e&&t.indexOf(e)<0&&t.push(e)}static use(e){return Array.isArray(e)?(e.forEach(e=>px.installModule(e)),px):(px.installModule(e),px)}}Object.keys(ux).forEach(e=>{Object.keys(ux[e]).forEach(t=>{px.prototype[t]=ux[e][t]})}),px.use([function({swiper:e,on:t,emit:n}){const r=mR();let a=null,o=null;const i=()=>{e&&!e.destroyed&&e.initialized&&(n("beforeResize"),n("resize"))},s=()=>{e&&!e.destroyed&&e.initialized&&n("orientationchange")};t("init",()=>{e.params.resizeObserver&&void 0!==r.ResizeObserver?e&&!e.destroyed&&e.initialized&&(a=new ResizeObserver(t=>{o=r.requestAnimationFrame(()=>{const{width:n,height:r}=e;let a=n,o=r;t.forEach(({contentBoxSize:t,contentRect:n,target:r})=>{r&&r!==e.el||(a=n?n.width:(t[0]||t).inlineSize,o=n?n.height:(t[0]||t).blockSize)}),a===n&&o===r||i()})}),a.observe(e.el)):(r.addEventListener("resize",i),r.addEventListener("orientationchange",s))}),t("destroy",()=>{o&&r.cancelAnimationFrame(o),a&&a.unobserve&&e.el&&(a.unobserve(e.el),a=null),r.removeEventListener("resize",i),r.removeEventListener("orientationchange",s)})},function({swiper:e,extendParams:t,on:n,emit:r}){const a=[],o=mR(),i=(t,n={})=>{const i=new(o.MutationObserver||o.WebkitMutationObserver)(t=>{if(e.__preventObserver__)return;if(1===t.length)return void r("observerUpdate",t[0]);const n=function(){r("observerUpdate",t[0])};o.requestAnimationFrame?o.requestAnimationFrame(n):o.setTimeout(n,0)});i.observe(t,{attributes:void 0===n.attributes||n.attributes,childList:e.isElement||(void 0===n.childList||n).childList,characterData:void 0===n.characterData||n.characterData}),a.push(i)};t({observer:!1,observeParents:!1,observeSlideChildren:!1}),n("init",()=>{if(e.params.observer){if(e.params.observeParents){const t=kR(e.hostEl);for(let e=0;e<t.length;e+=1)i(t[e])}i(e.hostEl,{childList:e.params.observeSlideChildren}),i(e.wrapperEl,{attributes:!1})}}),n("destroy",()=>{a.forEach(e=>{e.disconnect()}),a.splice(0,a.length)})}]);const fx=["eventsPrefix","injectStyles","injectStylesUrls","modules","init","_direction","oneWayMovement","swiperElementNodeName","touchEventsTarget","initialSlide","_speed","cssMode","updateOnWindowResize","resizeObserver","nested","focusableElements","_enabled","_width","_height","preventInteractionOnTransition","userAgent","url","_edgeSwipeDetection","_edgeSwipeThreshold","_freeMode","_autoHeight","setWrapperSize","virtualTranslate","_effect","breakpoints","breakpointsBase","_spaceBetween","_slidesPerView","maxBackfaceHiddenSlides","_grid","_slidesPerGroup","_slidesPerGroupSkip","_slidesPerGroupAuto","_centeredSlides","_centeredSlidesBounds","_slidesOffsetBefore","_slidesOffsetAfter","normalizeSlideIndex","_centerInsufficientSlides","_snapToSlideEdge","_watchOverflow","roundLengths","touchRatio","touchAngle","simulateTouch","_shortSwipes","_longSwipes","longSwipesRatio","longSwipesMs","_followFinger","allowTouchMove","_threshold","touchMoveStopPropagation","touchStartPreventDefault","touchStartForcePreventDefault","touchReleaseOnEdges","uniqueNavElements","_resistance","_resistanceRatio","_watchSlidesProgress","_grabCursor","preventClicks","preventClicksPropagation","_slideToClickedSlide","_loop","loopAdditionalSlides","loopAddBlankSlides","loopPreventsSliding","_rewind","_allowSlidePrev","_allowSlideNext","_swipeHandler","_noSwiping","noSwipingClass","noSwipingSelector","passiveListeners","containerModifierClass","slideClass","slideActiveClass","slideVisibleClass","slideFullyVisibleClass","slideNextClass","slidePrevClass","slideBlankClass","wrapperClass","lazyPreloaderClass","lazyPreloadPrevNext","runCallbacksOnInit","observer","observeParents","observeSlideChildren","a11y","_autoplay","_controller","coverflowEffect","cubeEffect","fadeEffect","flipEffect","creativeEffect","cardsEffect","hashNavigation","history","keyboard","mousewheel","_navigation","_pagination","parallax","_scrollbar","_thumbs","virtual","zoom","control"];function mx(e){return"object"==typeof e&&null!==e&&e.constructor&&"Object"===Object.prototype.toString.call(e).slice(8,-1)&&!e.__swiper__}function hx(e,t){const n=["__proto__","constructor","prototype"];Object.keys(t).filter(e=>n.indexOf(e)<0).forEach(n=>{void 0===e[n]?e[n]=t[n]:mx(t[n])&&mx(e[n])&&Object.keys(t[n]).length>0?t[n].__swiper__?e[n]=t[n]:hx(e[n],t[n]):e[n]=t[n]})}function gx(e={}){return e.navigation&&void 0===e.navigation.nextEl&&void 0===e.navigation.prevEl}function vx(e={}){return e.pagination&&void 0===e.pagination.el}function bx(e={}){return e.scrollbar&&void 0===e.scrollbar.el}function yx(e=""){const t=e.split(" ").map(e=>e.trim()).filter(e=>!!e),n=[];return t.forEach(e=>{n.indexOf(e)<0&&n.push(e)}),n.join(" ")}function wx(e=""){return e?e.includes("swiper-wrapper")?e:`swiper-wrapper ${e}`:"swiper-wrapper"}function Ex(){return Ex=Object.assign?Object.assign.bind():function(e){for(var t=1;t<arguments.length;t++){var n=arguments[t];for(var r in n)Object.prototype.hasOwnProperty.call(n,r)&&(e[r]=n[r])}return e},Ex.apply(this,arguments)}function Rx(e){return e.type&&e.type.displayName&&e.type.displayName.includes("SwiperSlide")}function xx(e){const t=[];return c.Children.toArray(e).forEach(e=>{Rx(e)?t.push(e):e.props&&e.props.children&&xx(e.props.children).forEach(e=>t.push(e))}),t}function Ax(e){const t=[],n={"container-start":[],"container-end":[],"wrapper-start":[],"wrapper-end":[]};return c.Children.toArray(e).forEach(e=>{if(Rx(e))t.push(e);else if(e.props&&e.props.slot&&n[e.props.slot])n[e.props.slot].push(e);else if(e.props&&e.props.children){const r=xx(e.props.children);r.length>0?r.forEach(e=>t.push(e)):n["container-end"].push(e)}else n["container-end"].push(e)}),{slides:t,slots:n}}function Cx(e,t){return"undefined"==typeof window?(0,c.useEffect)(e,t):(0,c.useLayoutEffect)(e,t)}const Sx=(0,c.createContext)(null),kx=(0,c.createContext)(null),Ox=(0,c.forwardRef)(({className:e,tag:t="div",wrapperTag:n="div",children:r,onSwiper:a,...o}={},i)=>{let s=!1;const[l,u]=(0,c.useState)("swiper"),[d,p]=(0,c.useState)(null),[f,m]=(0,c.useState)(!1),h=(0,c.useRef)(!1),g=(0,c.useRef)(null),v=(0,c.useRef)(null),b=(0,c.useRef)(null),y=(0,c.useRef)(null),w=(0,c.useRef)(null),E=(0,c.useRef)(null),R=(0,c.useRef)(null),x=(0,c.useRef)(null),{params:A,passedParams:C,rest:S,events:k}=function(e={},t=!0){const n={on:{}},r={},a={};hx(n,lx),n._emitClasses=!0,n.init=!1;const o={},i=fx.map(e=>e.replace(/_/,"")),s=Object.assign({},e);return Object.keys(s).forEach(s=>{void 0!==e[s]&&(i.indexOf(s)>=0?mx(e[s])?(n[s]={},a[s]={},hx(n[s],e[s]),hx(a[s],e[s])):(n[s]=e[s],a[s]=e[s]):0===s.search(/on[A-Z]/)&&"function"==typeof e[s]?t?r[`${s[2].toLowerCase()}${s.substr(3)}`]=e[s]:n.on[`${s[2].toLowerCase()}${s.substr(3)}`]=e[s]:o[s]=e[s])}),["navigation","pagination","scrollbar"].forEach(e=>{!0===n[e]&&(n[e]={}),!1===n[e]&&delete n[e]}),{params:n,passedParams:a,rest:o,events:r}}(o),{slides:O,slots:P}=Ax(r),M=()=>{m(!f)};Object.assign(A.on,{_containerClasses(e,t){u(t)}});const I=()=>{Object.assign(A.on,k),s=!0;const e={...A};if(delete e.wrapperClass,v.current=new px(e),v.current.virtual&&v.current.params.virtual.enabled){v.current.virtual.slides=O;const e={cache:!1,slides:O,renderExternal:p,renderExternalUpdate:!1};hx(v.current.params.virtual,e),hx(v.current.originalParams.virtual,e)}};return g.current||I(),v.current&&v.current.on("_beforeBreakpoint",M),(0,c.useEffect)(()=>()=>{v.current&&v.current.off("_beforeBreakpoint",M)}),(0,c.useEffect)(()=>{!h.current&&v.current&&(v.current.emitSlidesClasses(),h.current=!0)}),Cx(()=>{if(i&&(i.current=g.current),g.current)return v.current.destroyed&&I(),function({el:e,nextEl:t,prevEl:n,paginationEl:r,scrollbarEl:a,swiper:o},i){gx(i)&&t&&n&&(o.params.navigation.nextEl=t,o.originalParams.navigation.nextEl=t,o.params.navigation.prevEl=n,o.originalParams.navigation.prevEl=n),vx(i)&&r&&(o.params.pagination.el=r,o.originalParams.pagination.el=r),bx(i)&&a&&(o.params.scrollbar.el=a,o.originalParams.scrollbar.el=a),o.init(e)}({el:g.current,nextEl:w.current,prevEl:E.current,paginationEl:R.current,scrollbarEl:x.current,swiper:v.current},A),a&&!v.current.destroyed&&a(v.current),()=>{v.current&&!v.current.destroyed&&v.current.destroy(!0,!1)}},[]),Cx(()=>{!s&&k&&v.current&&Object.keys(k).forEach(e=>{v.current.on(e,k[e])});const e=function(e,t,n,r,a){const o=[];if(!t)return o;const i=e=>{o.indexOf(e)<0&&o.push(e)};if(n&&r){const e=r.map(a),t=n.map(a);e.join("")!==t.join("")&&i("children"),r.length!==n.length&&i("children")}return fx.filter(e=>"_"===e[0]).map(e=>e.replace(/_/,"")).forEach(n=>{if(n in e&&n in t)if(mx(e[n])&&mx(t[n])){const r=Object.keys(e[n]),a=Object.keys(t[n]);r.length!==a.length?i(n):(r.forEach(r=>{e[n][r]!==t[n][r]&&i(n)}),a.forEach(r=>{e[n][r]!==t[n][r]&&i(n)}))}else e[n]!==t[n]&&i(n)}),o}(C,b.current,O,y.current,e=>e.key);return b.current=C,y.current=O,e.length&&v.current&&!v.current.destroyed&&function({swiper:e,slides:t,passedParams:n,changedParams:r,nextEl:a,prevEl:o,scrollbarEl:i,paginationEl:s}){const l=r.filter(e=>"children"!==e&&"direction"!==e&&"wrapperClass"!==e),{params:c,pagination:u,navigation:d,scrollbar:p,virtual:f,thumbs:m}=e;let h,g,v,b,y,w,E,R;r.includes("thumbs")&&n.thumbs&&n.thumbs.swiper&&!n.thumbs.swiper.destroyed&&c.thumbs&&(!c.thumbs.swiper||c.thumbs.swiper.destroyed)&&(h=!0),r.includes("controller")&&n.controller&&n.controller.control&&c.controller&&!c.controller.control&&(g=!0),r.includes("pagination")&&n.pagination&&(n.pagination.el||s)&&(c.pagination||!1===c.pagination)&&u&&!u.el&&(v=!0),r.includes("scrollbar")&&n.scrollbar&&(n.scrollbar.el||i)&&(c.scrollbar||!1===c.scrollbar)&&p&&!p.el&&(b=!0),r.includes("navigation")&&n.navigation&&(n.navigation.prevEl||o)&&(n.navigation.nextEl||a)&&(c.navigation||!1===c.navigation)&&d&&!d.prevEl&&!d.nextEl&&(y=!0);const x=t=>{e[t]&&(e[t].destroy(),"navigation"===t?(e.isElement&&(e[t].prevEl.remove(),e[t].nextEl.remove()),c[t].prevEl=void 0,c[t].nextEl=void 0,e[t].prevEl=void 0,e[t].nextEl=void 0):(e.isElement&&e[t].el.remove(),c[t].el=void 0,e[t].el=void 0))};r.includes("loop")&&e.isElement&&(c.loop&&!n.loop?w=!0:!c.loop&&n.loop?E=!0:R=!0),l.forEach(e=>{if(mx(c[e])&&mx(n[e]))Object.assign(c[e],n[e]),"navigation"!==e&&"pagination"!==e&&"scrollbar"!==e||!("enabled"in n[e])||n[e].enabled||x(e);else{const t=n[e];!0!==t&&!1!==t||"navigation"!==e&&"pagination"!==e&&"scrollbar"!==e?c[e]=n[e]:!1===t&&x(e)}}),l.includes("controller")&&!g&&e.controller&&e.controller.control&&c.controller&&c.controller.control&&(e.controller.control=c.controller.control),r.includes("children")&&t&&f&&c.virtual.enabled?(f.slides=t,f.update(!0)):r.includes("virtual")&&f&&c.virtual.enabled&&(t&&(f.slides=t),f.update(!0)),r.includes("children")&&t&&c.loop&&(R=!0),h&&m.init()&&m.update(!0),g&&(e.controller.control=c.controller.control),v&&(!e.isElement||s&&"string"!=typeof s||((s=document.createElement("div")).classList.add("swiper-pagination"),s.part.add("pagination"),e.el.appendChild(s)),s&&(c.pagination.el=s),u.init(),u.render(),u.update()),b&&(!e.isElement||i&&"string"!=typeof i||((i=document.createElement("div")).classList.add("swiper-scrollbar"),i.part.add("scrollbar"),e.el.appendChild(i)),i&&(c.scrollbar.el=i),p.init(),p.updateSize(),p.setTranslate()),y&&(e.isElement&&(a&&"string"!=typeof a||((a=document.createElement("div")).classList.add("swiper-button-next"),MR(a,e.navigation.arrowSvg),a.part.add("button-next"),e.el.appendChild(a)),o&&"string"!=typeof o||((o=document.createElement("div")).classList.add("swiper-button-prev"),MR(o,e.navigation.arrowSvg),o.part.add("button-prev"),e.el.appendChild(o))),a&&(c.navigation.nextEl=a),o&&(c.navigation.prevEl=o),d.init(),d.update()),r.includes("allowSlideNext")&&(e.allowSlideNext=n.allowSlideNext),r.includes("allowSlidePrev")&&(e.allowSlidePrev=n.allowSlidePrev),r.includes("direction")&&e.changeDirection(n.direction,!1),(w||R)&&e.loopDestroy(),(E||R)&&e.loopCreate(),e.update()}({swiper:v.current,slides:O,passedParams:C,changedParams:e,nextEl:w.current,prevEl:E.current,scrollbarEl:x.current,paginationEl:R.current}),()=>{k&&v.current&&Object.keys(k).forEach(e=>{v.current.off(e,k[e])})}}),Cx(()=>{var e;!(e=v.current)||e.destroyed||!e.params.virtual||e.params.virtual&&!e.params.virtual.enabled||(e.updateSlides(),e.updateProgress(),e.updateSlidesClasses(),e.emit("_virtualUpdated"),e.parallax&&e.params.parallax&&e.params.parallax.enabled&&e.parallax.setTranslate())},[d]),c.createElement(t,Ex({ref:g,className:yx(`${l}${e?` ${e}`:""}`)},S),c.createElement(kx.Provider,{value:v.current},P["container-start"],c.createElement(n,{className:wx(A.wrapperClass)},P["wrapper-start"],A.virtual?function(e,t,n){if(!n)return null;const r=e=>{let n=e;return e<0?n=t.length+e:n>=t.length&&(n-=t.length),n},a=e.isHorizontal()?{[e.rtlTranslate?"right":"left"]:`${n.offset}px`}:{top:`${n.offset}px`},{from:o,to:i}=n,s=e.params.loop?-t.length:0,l=e.params.loop?2*t.length:t.length,u=[];for(let e=s;e<l;e+=1)e>=o&&e<=i&&u.push(t[r(e)]);return u.map((t,n)=>c.cloneElement(t,{swiper:e,style:a,key:t.props.virtualIndex||t.key||`slide-${n}`}))}(v.current,O,d):O.map((e,t)=>c.cloneElement(e,{swiper:v.current,swiperSlideIndex:t})),P["wrapper-end"]),gx(A)&&c.createElement(c.Fragment,null,c.createElement("div",{ref:E,className:"swiper-button-prev"}),c.createElement("div",{ref:w,className:"swiper-button-next"})),bx(A)&&c.createElement("div",{ref:x,className:"swiper-scrollbar"}),vx(A)&&c.createElement("div",{ref:R,className:"swiper-pagination"}),P["container-end"]))});Ox.displayName="Swiper";const Px=(0,c.forwardRef)(({tag:e="div",children:t,className:n="",swiper:r,zoom:a,lazy:o,virtualIndex:i,swiperSlideIndex:s,...l}={},u)=>{const d=(0,c.useRef)(null),[p,f]=(0,c.useState)("swiper-slide"),[m,h]=(0,c.useState)(!1);function g(e,t,n){t===d.current&&f(n)}Cx(()=>{if(void 0!==s&&(d.current.swiperSlideIndex=s),u&&(u.current=d.current),d.current&&r){if(!r.destroyed)return r.on("_slideClass",g),()=>{r&&r.off("_slideClass",g)};"swiper-slide"!==p&&f("swiper-slide")}}),Cx(()=>{r&&d.current&&!r.destroyed&&f(r.getSlideClasses(d.current))},[r]);const v={isActive:p.indexOf("swiper-slide-active")>=0,isVisible:p.indexOf("swiper-slide-visible")>=0,isPrev:p.indexOf("swiper-slide-prev")>=0,isNext:p.indexOf("swiper-slide-next")>=0},b=()=>"function"==typeof t?t(v):t;return c.createElement(e,Ex({ref:d,className:yx(`${p}${n?` ${n}`:""}`),"data-swiper-slide-index":i,onLoad:()=>{h(!0)}},l),a&&c.createElement(Sx.Provider,{value:v},c.createElement("div",{className:"swiper-zoom-container","data-swiper-zoom":"number"==typeof a?a:void 0},b(),o&&!m&&c.createElement("div",{className:"swiper-lazy-preloader",ref:e=>{e&&(e.lazyPreloaderManaged=!0)}}))),!a&&c.createElement(Sx.Provider,{value:v},b(),o&&!m&&c.createElement("div",{className:"swiper-lazy-preloader",ref:e=>{e&&(e.lazyPreloaderManaged=!0)}})))});function Mx(e,t,n,r){return e.params.createElements&&Object.keys(r).forEach(a=>{if(!n[a]&&!0===n.auto){let o=RR(e.el,`.${r[a]}`)[0];o||(o=AR("div",r[a]),o.className=r[a],e.el.append(o)),n[a]=o,t[a]=o}}),n}Px.displayName="SwiperSlide";const Ix='<svg class="swiper-navigation-icon" width="11" height="20" viewBox="0 0 11 20" fill="none" xmlns="http://www.w3.org/2000/svg"><path d="M0.38296 20.0762C0.111788 19.805 0.111788 19.3654 0.38296 19.0942L9.19758 10.2796L0.38296 1.46497C0.111788 1.19379 0.111788 0.754138 0.38296 0.482966C0.654131 0.211794 1.09379 0.211794 1.36496 0.482966L10.4341 9.55214C10.8359 9.9539 10.8359 10.6053 10.4341 11.007L1.36496 20.0762C1.09379 20.3474 0.654131 20.3474 0.38296 20.0762Z" fill="currentColor"/></svg>';function Tx({swiper:e,extendParams:t,on:n,emit:r}){function a(t){let n;return t&&"string"==typeof t&&e.isElement&&(n=e.el.querySelector(t)||e.hostEl.querySelector(t),n)?n:(t&&("string"==typeof t&&(n=[...document.querySelectorAll(t)]),e.params.uniqueNavElements&&"string"==typeof t&&n&&n.length>1&&1===e.el.querySelectorAll(t).length?n=e.el.querySelector(t):n&&1===n.length&&(n=n[0])),t&&!n?t:n)}function o(t,n){const r=e.params.navigation;(t=PR(t)).forEach(t=>{t&&(t.classList[n?"add":"remove"](...r.disabledClass.split(" ")),"BUTTON"===t.tagName&&(t.disabled=n),e.params.watchOverflow&&e.enabled&&t.classList[e.isLocked?"add":"remove"](r.lockClass))})}function i(){const{nextEl:t,prevEl:n}=e.navigation;if(e.params.loop)return o(n,!1),void o(t,!1);o(n,e.isBeginning&&!e.params.rewind),o(t,e.isEnd&&!e.params.rewind)}function s(t){t.preventDefault(),(!e.isBeginning||e.params.loop||e.params.rewind)&&(e.slidePrev(),r("navigationPrev"))}function l(t){t.preventDefault(),(!e.isEnd||e.params.loop||e.params.rewind)&&(e.slideNext(),r("navigationNext"))}function c(){const t=e.params.navigation;if(e.params.navigation=Mx(e,e.originalParams.navigation,e.params.navigation,{nextEl:"swiper-button-next",prevEl:"swiper-button-prev"}),!t.nextEl&&!t.prevEl)return;let n=a(t.nextEl),r=a(t.prevEl);Object.assign(e.navigation,{nextEl:n,prevEl:r}),n=PR(n),r=PR(r);const o=(n,r)=>{if(n){if(t.addIcons&&n.matches(".swiper-button-next,.swiper-button-prev")&&!n.querySelector("svg")){const e=document.createElement("div");MR(e,Ix),n.appendChild(e.querySelector("svg")),e.remove()}n.addEventListener("click","next"===r?l:s)}!e.enabled&&n&&n.classList.add(...t.lockClass.split(" "))};n.forEach(e=>o(e,"next")),r.forEach(e=>o(e,"prev"))}function u(){let{nextEl:t,prevEl:n}=e.navigation;t=PR(t),n=PR(n);const r=(t,n)=>{t.removeEventListener("click","next"===n?l:s),t.classList.remove(...e.params.navigation.disabledClass.split(" "))};t.forEach(e=>r(e,"next")),n.forEach(e=>r(e,"prev"))}t({navigation:{nextEl:null,prevEl:null,addIcons:!0,hideOnClick:!1,disabledClass:"swiper-button-disabled",hiddenClass:"swiper-button-hidden",lockClass:"swiper-button-lock",navigationDisabledClass:"swiper-navigation-disabled"}}),e.navigation={nextEl:null,prevEl:null,arrowSvg:Ix},n("init",()=>{!1===e.params.navigation.enabled?d():(c(),i())}),n("toEdge fromEdge lock unlock",()=>{i()}),n("destroy",()=>{u()}),n("enable disable",()=>{let{nextEl:t,prevEl:n}=e.navigation;t=PR(t),n=PR(n),e.enabled?i():[...t,...n].filter(e=>!!e).forEach(t=>t.classList.add(e.params.navigation.lockClass))}),n("click",(t,n)=>{let{nextEl:a,prevEl:o}=e.navigation;a=PR(a),o=PR(o);const i=n.target;let s=o.includes(i)||a.includes(i);if(e.isElement&&!s){const e=n.path||n.composedPath&&n.composedPath();e&&(s=e.find(e=>a.includes(e)||o.includes(e)))}if(e.params.navigation.hideOnClick&&!s){if(e.pagination&&e.params.pagination&&e.params.pagination.clickable&&(e.pagination.el===i||e.pagination.el.contains(i)))return;let t;a.length?t=a[0].classList.contains(e.params.navigation.hiddenClass):o.length&&(t=o[0].classList.contains(e.params.navigation.hiddenClass)),r(!0===t?"navigationShow":"navigationHide"),[...a,...o].filter(e=>!!e).forEach(t=>t.classList.toggle(e.params.navigation.hiddenClass))}});const d=()=>{e.el.classList.add(...e.params.navigation.navigationDisabledClass.split(" ")),u()};Object.assign(e.navigation,{enable:()=>{e.el.classList.remove(...e.params.navigation.navigationDisabledClass.split(" ")),c(),i()},disable:d,update:i,init:c,destroy:u})}function Nx(e=""){return`.${e.trim().replace(/([\.:!+\/()[\]#>~*^$|=,'"@{}\\])/g,"\\$1").replace(/ /g,".")}`}function Lx({swiper:e,extendParams:t,on:n,emit:r}){const a="swiper-pagination";let o;t({pagination:{el:null,bulletElement:"span",clickable:!1,hideOnClick:!1,renderBullet:null,renderProgressbar:null,renderFraction:null,renderCustom:null,progressbarOpposite:!1,type:"bullets",dynamicBullets:!1,dynamicMainBullets:1,formatFractionCurrent:e=>e,formatFractionTotal:e=>e,bulletClass:`${a}-bullet`,bulletActiveClass:`${a}-bullet-active`,modifierClass:`${a}-`,currentClass:`${a}-current`,totalClass:`${a}-total`,hiddenClass:`${a}-hidden`,progressbarFillClass:`${a}-progressbar-fill`,progressbarOppositeClass:`${a}-progressbar-opposite`,clickableClass:`${a}-clickable`,lockClass:`${a}-lock`,horizontalClass:`${a}-horizontal`,verticalClass:`${a}-vertical`,paginationDisabledClass:`${a}-disabled`}}),e.pagination={el:null,bullets:[]};let i=0;function s(){return!e.params.pagination.el||!e.pagination.el||Array.isArray(e.pagination.el)&&0===e.pagination.el.length}function l(t,n){const{bulletActiveClass:r}=e.params.pagination;t&&(t=t[("prev"===n?"previous":"next")+"ElementSibling"])&&(t.classList.add(`${r}-${n}`),(t=t[("prev"===n?"previous":"next")+"ElementSibling"])&&t.classList.add(`${r}-${n}-${n}`))}function c(t){const n=t.target.closest(Nx(e.params.pagination.bulletClass));if(!n)return;t.preventDefault();const r=SR(n)*e.params.slidesPerGroup;if(e.params.loop){if(e.realIndex===r)return;const t=(a=e.realIndex,o=r,(o%=i=e.slides.length)===1+(a%=i)?"next":o===a-1?"previous":void 0);"next"===t?e.slideNext():"previous"===t?e.slidePrev():e.slideToLoop(r)}else e.slideTo(r);var a,o,i}function u(){const t=e.rtl,n=e.params.pagination;if(s())return;let a,c,u=e.pagination.el;u=PR(u);const d=e.virtual&&e.params.virtual.enabled?e.virtual.slides.length:e.slides.length,p=e.params.loop?Math.ceil(d/e.params.slidesPerGroup):e.snapGrid.length;if(e.params.loop?(c=e.previousRealIndex||0,a=e.params.slidesPerGroup>1?Math.floor(e.realIndex/e.params.slidesPerGroup):e.realIndex):void 0!==e.snapIndex?(a=e.snapIndex,c=e.previousSnapIndex):(c=e.previousIndex||0,a=e.activeIndex||0),"bullets"===n.type&&e.pagination.bullets&&e.pagination.bullets.length>0){const r=e.pagination.bullets;let s,d,p;if(n.dynamicBullets&&(o=OR(r[0],e.isHorizontal()?"width":"height",!0),u.forEach(t=>{t.style[e.isHorizontal()?"width":"height"]=o*(n.dynamicMainBullets+4)+"px"}),n.dynamicMainBullets>1&&void 0!==c&&(i+=a-(c||0),i>n.dynamicMainBullets-1?i=n.dynamicMainBullets-1:i<0&&(i=0)),s=Math.max(a-i,0),d=s+(Math.min(r.length,n.dynamicMainBullets)-1),p=(d+s)/2),r.forEach(e=>{const t=[...["","-next","-next-next","-prev","-prev-prev","-main"].map(e=>`${n.bulletActiveClass}${e}`)].map(e=>"string"==typeof e&&e.includes(" ")?e.split(" "):e).flat();e.classList.remove(...t)}),u.length>1)r.forEach(t=>{const r=SR(t);r===a?t.classList.add(...n.bulletActiveClass.split(" ")):e.isElement&&t.setAttribute("part","bullet"),n.dynamicBullets&&(r>=s&&r<=d&&t.classList.add(...`${n.bulletActiveClass}-main`.split(" ")),r===s&&l(t,"prev"),r===d&&l(t,"next"))});else{const t=r[a];if(t&&t.classList.add(...n.bulletActiveClass.split(" ")),e.isElement&&r.forEach((e,t)=>{e.setAttribute("part",t===a?"bullet-active":"bullet")}),n.dynamicBullets){const e=r[s],t=r[d];for(let e=s;e<=d;e+=1)r[e]&&r[e].classList.add(...`${n.bulletActiveClass}-main`.split(" "));l(e,"prev"),l(t,"next")}}if(n.dynamicBullets){const a=Math.min(r.length,n.dynamicMainBullets+4),i=(o*a-o)/2-p*o,s=t?"right":"left";r.forEach(t=>{t.style[e.isHorizontal()?s:"top"]=`${i}px`})}}u.forEach((t,o)=>{if("fraction"===n.type&&(t.querySelectorAll(Nx(n.currentClass)).forEach(e=>{e.textContent=n.formatFractionCurrent(a+1)}),t.querySelectorAll(Nx(n.totalClass)).forEach(e=>{e.textContent=n.formatFractionTotal(p)})),"progressbar"===n.type){let r;r=n.progressbarOpposite?e.isHorizontal()?"vertical":"horizontal":e.isHorizontal()?"horizontal":"vertical";const o=(a+1)/p;let i=1,s=1;"horizontal"===r?i=o:s=o,t.querySelectorAll(Nx(n.progressbarFillClass)).forEach(t=>{t.style.transform=`translate3d(0,0,0) scaleX(${i}) scaleY(${s})`,t.style.transitionDuration=`${e.params.speed}ms`})}"custom"===n.type&&n.renderCustom?(MR(t,n.renderCustom(e,a+1,p)),0===o&&r("paginationRender",t)):(0===o&&r("paginationRender",t),r("paginationUpdate",t)),e.params.watchOverflow&&e.enabled&&t.classList[e.isLocked?"add":"remove"](n.lockClass)})}function d(){const t=e.params.pagination;if(s())return;const n=e.virtual&&e.params.virtual.enabled?e.virtual.slides.length:e.grid&&e.params.grid.rows>1?e.slides.length/Math.ceil(e.params.grid.rows):e.slides.length;let a=e.pagination.el;a=PR(a);let o="";if("bullets"===t.type){let r=e.params.loop?Math.ceil(n/e.params.slidesPerGroup):e.snapGrid.length;e.params.freeMode&&e.params.freeMode.enabled&&r>n&&(r=n);for(let n=0;n<r;n+=1)t.renderBullet?o+=t.renderBullet.call(e,n,t.bulletClass):o+=`<${t.bulletElement} ${e.isElement?'part="bullet"':""} class="${t.bulletClass}"></${t.bulletElement}>`}"fraction"===t.type&&(o=t.renderFraction?t.renderFraction.call(e,t.currentClass,t.totalClass):`<span class="${t.currentClass}"></span> / <span class="${t.totalClass}"></span>`),"progressbar"===t.type&&(o=t.renderProgressbar?t.renderProgressbar.call(e,t.progressbarFillClass):`<span class="${t.progressbarFillClass}"></span>`),e.pagination.bullets=[],a.forEach(n=>{"custom"!==t.type&&MR(n,o||""),"bullets"===t.type&&e.pagination.bullets.push(...n.querySelectorAll(Nx(t.bulletClass)))}),"custom"!==t.type&&r("paginationRender",a[0])}function p(){e.params.pagination=Mx(e,e.originalParams.pagination,e.params.pagination,{el:"swiper-pagination"});const t=e.params.pagination;if(!t.el)return;let n;"string"==typeof t.el&&e.isElement&&(n=e.el.querySelector(t.el)),n||"string"!=typeof t.el||(n=[...document.querySelectorAll(t.el)]),n||(n=t.el),n&&0!==n.length&&(e.params.uniqueNavElements&&"string"==typeof t.el&&Array.isArray(n)&&n.length>1&&(n=[...e.el.querySelectorAll(t.el)],n.length>1&&(n=n.find(t=>kR(t,".swiper")[0]===e.el))),Array.isArray(n)&&1===n.length&&(n=n[0]),Object.assign(e.pagination,{el:n}),n=PR(n),n.forEach(n=>{"bullets"===t.type&&t.clickable&&n.classList.add(...(t.clickableClass||"").split(" ")),n.classList.add(t.modifierClass+t.type),n.classList.add(e.isHorizontal()?t.horizontalClass:t.verticalClass),"bullets"===t.type&&t.dynamicBullets&&(n.classList.add(`${t.modifierClass}${t.type}-dynamic`),i=0,t.dynamicMainBullets<1&&(t.dynamicMainBullets=1)),"progressbar"===t.type&&t.progressbarOpposite&&n.classList.add(t.progressbarOppositeClass),t.clickable&&n.addEventListener("click",c),e.enabled||n.classList.add(t.lockClass)}))}function f(){const t=e.params.pagination;if(s())return;let n=e.pagination.el;n&&(n=PR(n),n.forEach(n=>{n.classList.remove(t.hiddenClass),n.classList.remove(t.modifierClass+t.type),n.classList.remove(e.isHorizontal()?t.horizontalClass:t.verticalClass),t.clickable&&(n.classList.remove(...(t.clickableClass||"").split(" ")),n.removeEventListener("click",c))})),e.pagination.bullets&&e.pagination.bullets.forEach(e=>e.classList.remove(...t.bulletActiveClass.split(" ")))}n("changeDirection",()=>{if(!e.pagination||!e.pagination.el)return;const t=e.params.pagination;let{el:n}=e.pagination;n=PR(n),n.forEach(n=>{n.classList.remove(t.horizontalClass,t.verticalClass),n.classList.add(e.isHorizontal()?t.horizontalClass:t.verticalClass)})}),n("init",()=>{!1===e.params.pagination.enabled?m():(p(),d(),u())}),n("activeIndexChange",()=>{void 0===e.snapIndex&&u()}),n("snapIndexChange",()=>{u()}),n("snapGridLengthChange",()=>{d(),u()}),n("destroy",()=>{f()}),n("enable disable",()=>{let{el:t}=e.pagination;t&&(t=PR(t),t.forEach(t=>t.classList[e.enabled?"remove":"add"](e.params.pagination.lockClass)))}),n("lock unlock",()=>{u()}),n("click",(t,n)=>{const a=n.target,o=PR(e.pagination.el);if(e.params.pagination.el&&e.params.pagination.hideOnClick&&o&&o.length>0&&!a.classList.contains(e.params.pagination.bulletClass)){if(e.navigation&&(e.navigation.nextEl&&a===e.navigation.nextEl||e.navigation.prevEl&&a===e.navigation.prevEl))return;const t=o[0].classList.contains(e.params.pagination.hiddenClass);r(!0===t?"paginationShow":"paginationHide"),o.forEach(t=>t.classList.toggle(e.params.pagination.hiddenClass))}});const m=()=>{e.el.classList.add(e.params.pagination.paginationDisabledClass);let{el:t}=e.pagination;t&&(t=PR(t),t.forEach(t=>t.classList.add(e.params.pagination.paginationDisabledClass))),f()};Object.assign(e.pagination,{enable:()=>{e.el.classList.remove(e.params.pagination.paginationDisabledClass);let{el:t}=e.pagination;t&&(t=PR(t),t.forEach(t=>t.classList.remove(e.params.pagination.paginationDisabledClass))),p(),d(),u()},disable:m,render:d,update:u,init:p,destroy:f})}function Dx(e){return Dx="function"==typeof Symbol&&"symbol"==typeof Symbol.iterator?function(e){return typeof e}:function(e){return e&&"function"==typeof Symbol&&e.constructor===Symbol&&e!==Symbol.prototype?"symbol":typeof e},Dx(e)}function Bx(e,t){(null==t||t>e.length)&&(t=e.length);for(var n=0,r=Array(t);n<t;n++)r[n]=e[n];return r}function Fx(e,t,n){return t in e?Object.defineProperty(e,t,{value:n,enumerable:!0,configurable:!0,writable:!0}):e[t]=n,e}function zx(e,t){var n=Object.keys(e);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(e);t&&(r=r.filter(function(t){return Object.getOwnPropertyDescriptor(e,t).enumerable})),n.push.apply(n,r)}return n}function jx(e){for(var t=1;t<arguments.length;t++){var n=null!=arguments[t]?arguments[t]:{};t%2?zx(Object(n),!0).forEach(function(t){Fx(e,t,n[t])}):Object.getOwnPropertyDescriptors?Object.defineProperties(e,Object.getOwnPropertyDescriptors(n)):zx(Object(n)).forEach(function(t){Object.defineProperty(e,t,Object.getOwnPropertyDescriptor(n,t))})}return e}function Hx(e){return function t(){for(var n=this,r=arguments.length,a=new Array(r),o=0;o<r;o++)a[o]=arguments[o];return a.length>=e.length?e.apply(this,a):function(){for(var e=arguments.length,r=new Array(e),o=0;o<e;o++)r[o]=arguments[o];return t.apply(n,[].concat(a,r))}}}function Vx(e){return{}.toString.call(e).includes("Object")}function Gx(e){return"function"==typeof e}(0,i.memo)(function(e){var t=e.items,n=e.label,r=void 0===n?"":n,a=e.attributes,o=e.setAttributes,i=e.attributesKey,s=null==t?void 0:t.findIndex(function(e){return(null==e?void 0:e.value)===a});return React.createElement("div",{className:"sp-eab-layout-preset-slider-component sp-eab-component-mb"},React.createElement("div",{className:"sp-eab-component-title-wrapper sp-mb-8px"},React.createElement("span",{className:"sp-eab-component-title"},r)),React.createElement(Ox,{pagination:{clickable:!0},navigation:!0,modules:[Lx,Tx],className:"mySwiper sp-eab-layout-picker-swiper",initialSlide:s,onSlideChange:function(e){return n=e.activeIndex,"vertical-six"===(a=null===(r=t[n])||void 0===r?void 0:r.value)&&o({toggleIconPosition:"start"}),void o(function(e,t,n){return(t=function(e){var t=function(e){if("object"!=Dx(e)||!e)return e;var t=e[Symbol.toPrimitive];if(void 0!==t){var n=t.call(e,"string");if("object"!=Dx(n))return n;throw new TypeError("@@toPrimitive must return a primitive value.")}return String(e)}(e);return"symbol"==Dx(t)?t:t+""}(t))in e?Object.defineProperty(e,t,{value:n,enumerable:!0,configurable:!0,writable:!0}):e[t]=n,e}({},i,a));var n,r,a},key:s},null==t?void 0:t.map(function(e,t){var n=e.Icon;return React.createElement(Px,{key:t},React.createElement("div",{className:"sp-eab-preset-image sp-d-flex sp-justify-center"},React.createElement(n,null)))})))}),(0,i.memo)(function(e){var t,n,r=e.videoType,a=e.bgVideo,o=e.youtubeVideo,i="";return"youtube"===r&&(i=(n=null==(t=o)?void 0:t.match(/(?:youtube\.com\/(?:.*[?&]v=|v\/|embed\/)|youtu\.be\/)([^"&?\/ ]{11})/))?n[1]:null),React.createElement("div",{className:"sp-eab-video-player sp-w-full"},"html5"===r&&React.createElement("video",{autoPlay:!0,muted:!0,loop:!0,key:null==a?void 0:a.url},React.createElement("source",{src:null==a?void 0:a.url,type:"video/mp4"})),"youtube"===r&&React.createElement("iframe",{key:i,width:"100%",height:"500px",src:"https://www.youtube.com/embed/".concat(i,"?autoplay=1&mute=1"),title:"YouTube video player",frameBorder:"0",allow:"accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture",allowFullScreen:!0}))});var qx=Hx(function(e,t){throw new Error(e[t]||e.default)})({initialIsRequired:"initial state is required",initialType:"initial state should be an object",initialContent:"initial state shouldn't be an empty object",handlerType:"handler should be an object or a function",handlersType:"all handlers should be a functions",selectorType:"selector should be a function",changeType:"provided value of changes should be an object",changeField:'it seams you want to change a field in the state which is not specified in the "initial" state',default:"an unknown error accured in `state-local` package"}),Ux=function(e,t){return Vx(t)||qx("changeType"),Object.keys(t).some(function(t){return n=e,r=t,!Object.prototype.hasOwnProperty.call(n,r);var n,r})&&qx("changeField"),t},Wx=function(e){Gx(e)||qx("selectorType")},Qx=function(e){Gx(e)||Vx(e)||qx("handlerType"),Vx(e)&&Object.values(e).some(function(e){return!Gx(e)})&&qx("handlersType")},Kx=function(e){var t;e||qx("initialIsRequired"),Vx(e)||qx("initialType"),t=e,Object.keys(t).length||qx("initialContent")};function Zx(e,t){return Gx(t)?t(e.current):t}function Jx(e,t){return e.current=jx(jx({},e.current),t),t}function Xx(e,t,n){return Gx(t)?t(e.current):Object.keys(n).forEach(function(n){var r;return null===(r=t[n])||void 0===r?void 0:r.call(t,e.current[n])}),n}var Yx={create:function(e){var t=arguments.length>1&&void 0!==arguments[1]?arguments[1]:{};Kx(e),Qx(t);var n={current:e},r=Hx(Xx)(n,t),a=Hx(Jx)(n),o=Hx(Ux)(e),i=Hx(Zx)(n);return[function(){var e=arguments.length>0&&void 0!==arguments[0]?arguments[0]:function(e){return e};return Wx(e),e(n.current)},function(e){!function(){for(var e=arguments.length,t=new Array(e),n=0;n<e;n++)t[n]=arguments[n];return function(e){return t.reduceRight(function(e,t){return t(e)},e)}}(r,a,o,i)(e)}]}};const $x=Yx;var eA,tA={configIsRequired:"the configuration object is required",configType:"the configuration object should be an object",default:"an unknown error accured in `@monaco-editor/loader` package",deprecation:"Deprecation warning!\n    You are using deprecated way of configuration.\n\n    Instead of using\n      monaco.config({ urls: { monacoBase: '...' } })\n    use\n      monaco.config({ paths: { vs: '...' } })\n\n    For more please check the link https://github.com/suren-atoyan/monaco-loader#config\n  "};(eA=function(e,t){throw new Error(e[t]||e.default)},function e(){for(var t=this,n=arguments.length,r=new Array(n),a=0;a<n;a++)r[a]=arguments[a];return r.length>=eA.length?eA.apply(this,r):function(){for(var n=arguments.length,a=new Array(n),o=0;o<n;o++)a[o]=arguments[o];return e.apply(t,[].concat(r,a))}})(tA);var nA={type:"cancelation",msg:"operation is manually canceled"};function rA(e){var t=!1,n=new Promise(function(n,r){e.then(function(e){return t?r(nA):n(e)}),e.catch(r)});return n.cancel=function(){return t=!0},n}var aA,oA=function(e){if(Array.isArray(e))return e}(aA=$x.create({config:{paths:{vs:"https://cdn.jsdelivr.net/npm/monaco-editor@0.55.1/min/vs"}},isInitialized:!1,resolve:null,reject:null,monaco:null}))||function(e){var t=null==e?null:"undefined"!=typeof Symbol&&e[Symbol.iterator]||e["@@iterator"];if(null!=t){var n,r,a,o,i=[],s=!0,l=!1;try{for(a=(t=t.call(e)).next;!(s=(n=a.call(t)).done)&&(i.push(n.value),2!==i.length);s=!0);}catch(e){l=!0,r=e}finally{try{if(!s&&null!=t.return&&(o=t.return(),Object(o)!==o))return}finally{if(l)throw r}}return i}}(aA)||function(e){if(e){if("string"==typeof e)return Bx(e,2);var t={}.toString.call(e).slice(8,-1);return"Object"===t&&e.constructor&&(t=e.constructor.name),"Map"===t||"Set"===t?Array.from(e):"Arguments"===t||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(t)?Bx(e,2):void 0}}(aA)||function(){throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.")}(),iA=oA[0],sA=oA[1];function lA(e){return document.body.appendChild(e)}function cA(e){var t,n,r=iA(function(e){return{config:e.config,reject:e.reject}}),a=(t="".concat(r.config.paths.vs,"/loader.js"),n=document.createElement("script"),t&&(n.src=t),n);return a.onload=function(){return e()},a.onerror=r.reject,a}function uA(){var e=iA(function(e){return{config:e.config,resolve:e.resolve,reject:e.reject}}),t=window.require;t.config(e.config),t(["vs/editor/editor.main"],function(t){var n=t.m||t;dA(n),e.resolve(n)},function(t){e.reject(t)})}function dA(e){iA().monaco||sA({monaco:e})}var pA=new Promise(function(e,t){return sA({resolve:e,reject:t})}),fA=function(){var e=iA(function(e){return{monaco:e.monaco,isInitialized:e.isInitialized,resolve:e.resolve}});if(!e.isInitialized){if(sA({isInitialized:!0}),e.monaco)return e.resolve(e.monaco),rA(pA);if(window.monaco&&window.monaco.editor)return dA(window.monaco),e.resolve(window.monaco),rA(pA);!function(){for(var e=arguments.length,t=new Array(e),n=0;n<e;n++)t[n]=arguments[n];return function(e){return t.reduceRight(function(e,t){return t(e)},e)}}(lA,cA)(uA)}return rA(pA)},mA={display:"flex",position:"relative",textAlign:"initial"},hA={width:"100%"},gA={display:"none"},vA={container:{display:"flex",height:"100%",width:"100%",justifyContent:"center",alignItems:"center"}},bA=function({children:e}){return c.createElement("div",{style:vA.container},e)},yA=(0,c.memo)(function({width:e,height:t,isEditorReady:n,loading:r,_ref:a,className:o,wrapperProps:i}){return c.createElement("section",{style:{...mA,width:e,height:t},...i},!n&&c.createElement(bA,null,r),c.createElement("div",{ref:a,style:{...hA,...!n&&gA},className:o}))}),wA=function(e){(0,c.useEffect)(e,[])},EA=function(e,t,n=!0){let r=(0,c.useRef)(!0);(0,c.useEffect)(r.current||!n?()=>{r.current=!1}:e,t)};function RA(){}function xA(e,t,n,r){return function(e,t){return e.editor.getModel(AA(e,t))}(e,r)||function(e,t,n,r){return e.editor.createModel(t,n,r?AA(e,r):void 0)}(e,t,n,r)}function AA(e,t){return e.Uri.parse(t)}(0,c.memo)(function({original:e,modified:t,language:n,originalLanguage:r,modifiedLanguage:a,originalModelPath:o,modifiedModelPath:i,keepCurrentOriginalModel:s=!1,keepCurrentModifiedModel:l=!1,theme:u="light",loading:d="Loading...",options:p={},height:f="100%",width:m="100%",className:h,wrapperProps:g={},beforeMount:v=RA,onMount:b=RA}){let[y,w]=(0,c.useState)(!1),[E,R]=(0,c.useState)(!0),x=(0,c.useRef)(null),A=(0,c.useRef)(null),C=(0,c.useRef)(null),S=(0,c.useRef)(b),k=(0,c.useRef)(v),O=(0,c.useRef)(!1);wA(()=>{let e=fA();return e.then(e=>(A.current=e)&&R(!1)).catch(e=>"cancelation"!==e?.type&&console.error("Monaco initialization: error:",e)),()=>x.current?function(){let e=x.current?.getModel();s||e?.original?.dispose(),l||e?.modified?.dispose(),x.current?.dispose()}():e.cancel()}),EA(()=>{if(x.current&&A.current){let t=x.current.getOriginalEditor(),a=xA(A.current,e||"",r||n||"text",o||"");a!==t.getModel()&&t.setModel(a)}},[o],y),EA(()=>{if(x.current&&A.current){let e=x.current.getModifiedEditor(),r=xA(A.current,t||"",a||n||"text",i||"");r!==e.getModel()&&e.setModel(r)}},[i],y),EA(()=>{let e=x.current.getModifiedEditor();e.getOption(A.current.editor.EditorOption.readOnly)?e.setValue(t||""):t!==e.getValue()&&(e.executeEdits("",[{range:e.getModel().getFullModelRange(),text:t||"",forceMoveMarkers:!0}]),e.pushUndoStop())},[t],y),EA(()=>{x.current?.getModel()?.original.setValue(e||"")},[e],y),EA(()=>{let{original:e,modified:t}=x.current.getModel();A.current.editor.setModelLanguage(e,r||n||"text"),A.current.editor.setModelLanguage(t,a||n||"text")},[n,r,a],y),EA(()=>{A.current?.editor.setTheme(u)},[u],y),EA(()=>{x.current?.updateOptions(p)},[p],y);let P=(0,c.useCallback)(()=>{if(!A.current)return;k.current(A.current);let s=xA(A.current,e||"",r||n||"text",o||""),l=xA(A.current,t||"",a||n||"text",i||"");x.current?.setModel({original:s,modified:l})},[n,t,a,e,r,o,i]),M=(0,c.useCallback)(()=>{!O.current&&C.current&&(x.current=A.current.editor.createDiffEditor(C.current,{automaticLayout:!0,...p}),P(),A.current?.editor.setTheme(u),w(!0),O.current=!0)},[p,u,P]);return(0,c.useEffect)(()=>{y&&S.current(x.current,A.current)},[y]),(0,c.useEffect)(()=>{!E&&!y&&M()},[E,y,M]),c.createElement(yA,{width:m,height:f,isEditorReady:y,loading:d,_ref:C,className:h,wrapperProps:g})});var CA=new Map,SA=(0,c.memo)(function({defaultValue:e,defaultLanguage:t,defaultPath:n,value:r,language:a,path:o,theme:i="light",line:s,loading:l="Loading...",options:u={},overrideServices:d={},saveViewState:p=!0,keepCurrentModel:f=!1,width:m="100%",height:h="100%",className:g,wrapperProps:v={},beforeMount:b=RA,onMount:y=RA,onChange:w,onValidate:E=RA}){let[R,x]=(0,c.useState)(!1),[A,C]=(0,c.useState)(!0),S=(0,c.useRef)(null),k=(0,c.useRef)(null),O=(0,c.useRef)(null),P=(0,c.useRef)(y),M=(0,c.useRef)(b),I=(0,c.useRef)(),T=(0,c.useRef)(r),_=function(e){let t=(0,c.useRef)();return(0,c.useEffect)(()=>{t.current=e},[e]),t.current}(o),N=(0,c.useRef)(!1),L=(0,c.useRef)(!1);wA(()=>{let e=fA();return e.then(e=>(S.current=e)&&C(!1)).catch(e=>"cancelation"!==e?.type&&console.error("Monaco initialization: error:",e)),()=>k.current?(I.current?.dispose(),f?p&&CA.set(o,k.current.saveViewState()):k.current.getModel()?.dispose(),void k.current.dispose()):e.cancel()}),EA(()=>{let i=xA(S.current,e||r||"",t||a||"",o||n||"");i!==k.current?.getModel()&&(p&&CA.set(_,k.current?.saveViewState()),k.current?.setModel(i),p&&k.current?.restoreViewState(CA.get(o)))},[o],R),EA(()=>{k.current?.updateOptions(u)},[u],R),EA(()=>{!k.current||void 0===r||(k.current.getOption(S.current.editor.EditorOption.readOnly)?k.current.setValue(r):r!==k.current.getValue()&&(L.current=!0,k.current.executeEdits("",[{range:k.current.getModel().getFullModelRange(),text:r,forceMoveMarkers:!0}]),k.current.pushUndoStop(),L.current=!1))},[r],R),EA(()=>{let e=k.current?.getModel();e&&a&&S.current?.editor.setModelLanguage(e,a)},[a],R),EA(()=>{void 0!==s&&k.current?.revealLine(s)},[s],R),EA(()=>{S.current?.editor.setTheme(i)},[i],R);let D=(0,c.useCallback)(()=>{if(O.current&&S.current&&!N.current){M.current(S.current);let l=o||n,c=xA(S.current,r||e||"",t||a||"",l||"");k.current=S.current?.editor.create(O.current,{model:c,automaticLayout:!0,...u},d),p&&k.current.restoreViewState(CA.get(l)),S.current.editor.setTheme(i),void 0!==s&&k.current.revealLine(s),x(!0),N.current=!0}},[e,t,n,r,a,o,u,d,p,i,s]);return(0,c.useEffect)(()=>{R&&P.current(k.current,S.current)},[R]),(0,c.useEffect)(()=>{!A&&!R&&D()},[A,R,D]),T.current=r,(0,c.useEffect)(()=>{R&&w&&(I.current?.dispose(),I.current=k.current?.onDidChangeModelContent(e=>{L.current||w(k.current.getValue(),e)}))},[R,w]),(0,c.useEffect)(()=>{if(R){let e=S.current.editor.onDidChangeMarkers(e=>{let t=k.current.getModel()?.uri;if(t&&e.find(e=>e.path===t.path)){let e=S.current.editor.getModelMarkers({resource:t});E?.(e)}});return()=>{e?.dispose()}}return()=>{}},[R,E]),c.createElement(yA,{width:m,height:h,isEditorReady:R,loading:l,_ref:O,className:g,wrapperProps:v})});function kA(e){return kA="function"==typeof Symbol&&"symbol"==typeof Symbol.iterator?function(e){return typeof e}:function(e){return e&&"function"==typeof Symbol&&e.constructor===Symbol&&e!==Symbol.prototype?"symbol":typeof e},kA(e)}const OA=function(e){var t=e.label,n=void 0===t?"":t,r=e.attributes,a=void 0===r?"":r,o=e.setAttributes,i=e.attributesKey,s=void 0===i?"":i,l=e.onChange,c=void 0!==l&&l,u=function(e){c?c(e):o(function(e,t,n){return(t=function(e){var t=function(e){if("object"!=kA(e)||!e)return e;var t=e[Symbol.toPrimitive];if(void 0!==t){var n=t.call(e,"string");if("object"!=kA(n))return n;throw new TypeError("@@toPrimitive must return a primitive value.")}return String(e)}(e);return"symbol"==kA(t)?t:t+""}(t))in e?Object.defineProperty(e,t,{value:n,enumerable:!0,configurable:!0,writable:!0}):e[t]=n,e}({},s,e))};return React.createElement("div",{className:"sp-eab-code-editor-component sp-eab-component-mb"},React.createElement("div",{className:"sp-eab-code-editor-label"},React.createElement("p",{className:"sp-eab-component-title"},n)),React.createElement("div",{className:"sp-eab-code-editor"},React.createElement(SA,{height:"180px",defaultLanguage:"css",theme:"vs-dark",defaultValue:"",value:a,onChange:function(e){return u(e)},options:{quickSuggestions:{other:"on",comments:"off",strings:"off"},quickSuggestionsDelay:10,minimap:{enabled:!1},scrollbar:{vertical:"auto",horizontal:"auto",verticalScrollbarSize:5,horizontalScrollbarSize:5,scrollByPage:!1,ignoreHorizontalScrollbarInContentHeight:!1},lineNumbersMinChars:1,folding:!1,wordWrap:"on"}})))};var PA=[{option_name:"eap_data_remove",label:(0,l.__)("Clean-up Data on Deletion","easy-accordion-free"),infoText:(0,l.__)("Check this if you would like Easy Accordion to completely remove all of its data when the plugin is deleted.","easy-accordion-free"),inputType:"checkbox"},{option_name:"eap_focus_style",label:(0,l.__)("Focus Style for Accessibility","easy-accordion-free"),infoText:(0,l.__)("Check this to enable focus style to improve accessibility.","easy-accordion-free"),inputType:"checkbox"},{option_name:"eap_editor_preference",label:(0,l.__)("Default Editor","easy-accordion-free"),infoText:(0,l.__)("Choose which editor opens when you click 'Add New Accordion'. Pick 'Ask each time' to keep the welcome popup.","easy-accordion-free"),inputType:"select",items:[{label:(0,l.__)("Ask each time","easy-accordion-free"),value:""},{label:(0,l.__)("Block Editor","easy-accordion-free"),value:"block_editor"},{label:(0,l.__)("Classic Shortcode","easy-accordion-free"),value:"classic_shortcode"}]}],MA={advanced:{eap_data_remove:"0",eap_focus_style:"0",eap_editor_preference:""},additional:{ea_custom_css:"",custom_js:""},"woocommerce-faqs":{eap_woo_faq:"0",eap_woo_faq_label:"FAQs",eap_woo_faq_label_priority:"50",eap_woo_set_tab:[]},tools:{}},IA=[{label:(0,l.__)("Advanced Controls","easy-accordion-free"),Icon:function(){return React.createElement("svg",{width:16,height:16,viewBox:"0 0 16 16",fill:"none",xmlns:"http://www.w3.org/2000/svg"},React.createElement("path",{d:"M7.83398 13.3335H14.5007",stroke:"#2F2F2F",strokeLinecap:"round",strokeLinejoin:"round"}),React.createElement("path",{d:"M9.16602 3.3335L14.4993 3.3335",stroke:"#2F2F2F",strokeLinecap:"round",strokeLinejoin:"round"}),React.createElement("path",{d:"M2.5 3.3335H5.16667",stroke:"#2F2F2F",strokeLinecap:"round",strokeLinejoin:"round"}),React.createElement("path",{d:"M2.5 8.3335H9.16667",stroke:"#2F2F2F",strokeLinecap:"round",strokeLinejoin:"round"}),React.createElement("path",{d:"M2.5 13.3335H3.83333",stroke:"#2F2F2F",strokeLinecap:"round",strokeLinejoin:"round"}),React.createElement("path",{d:"M13.166 8.3335H14.4993",stroke:"#2F2F2F",strokeLinecap:"round",strokeLinejoin:"round"}),React.createElement("path",{d:"M6.83398 14.6665C6.52336 14.6665 6.36804 14.6665 6.24553 14.6158C6.08218 14.5481 5.95239 14.4183 5.88473 14.255C5.83398 14.1324 5.83398 13.9771 5.83398 13.6665V12.9998C5.83398 12.6892 5.83398 12.5339 5.88473 12.4114C5.95239 12.248 6.08218 12.1182 6.24553 12.0506C6.36804 11.9998 6.52336 11.9998 6.83398 11.9998C7.14461 11.9998 7.29992 11.9998 7.42245 12.0506C7.58578 12.1182 7.71558 12.248 7.78325 12.4114C7.83398 12.5339 7.83398 12.6892 7.83398 12.9998V13.6665C7.83398 13.9771 7.83398 14.1324 7.78325 14.255C7.71558 14.4183 7.58578 14.5481 7.42245 14.6158C7.29992 14.6665 7.14461 14.6665 6.83398 14.6665Z",stroke:"#2F2F2F",strokeLinecap:"round",strokeLinejoin:"round"}),React.createElement("path",{d:"M8.16602 4.6665C7.85542 4.6665 7.70008 4.6665 7.57755 4.61577C7.41422 4.5481 7.28442 4.4183 7.21675 4.25497C7.16602 4.13244 7.16602 3.9771 7.16602 3.6665V2.99984C7.16602 2.68924 7.16602 2.5339 7.21675 2.41137C7.28442 2.24804 7.41422 2.11824 7.57755 2.05057C7.70008 1.99984 7.85542 1.99984 8.16602 1.99984C8.47662 1.99984 8.63195 1.99984 8.75448 2.05057C8.91782 2.11824 9.04762 2.24804 9.11528 2.41137C9.16602 2.5339 9.16602 2.68924 9.16602 2.99984V3.6665C9.16602 3.9771 9.16602 4.13244 9.11528 4.25497C9.04762 4.4183 8.91782 4.5481 8.75448 4.61577C8.63195 4.6665 8.47662 4.6665 8.16602 4.6665Z",stroke:"#2F2F2F",strokeLinecap:"round",strokeLinejoin:"round"}),React.createElement("path",{d:"M10.166 9.6665C9.85542 9.6665 9.70008 9.6665 9.57755 9.61576C9.41422 9.5481 9.28442 9.41831 9.21675 9.25497C9.16602 9.13244 9.16602 8.9771 9.16602 8.6665V7.99984C9.16602 7.68924 9.16602 7.5339 9.21675 7.41137C9.28442 7.24804 9.41422 7.11824 9.57755 7.05057C9.70008 6.99984 9.85542 6.99984 10.166 6.99984C10.4766 6.99984 10.6319 6.99984 10.7545 7.05057C10.9178 7.11824 11.0476 7.24804 11.1153 7.41137C11.166 7.5339 11.166 7.68924 11.166 7.99984V8.6665C11.166 8.9771 11.166 9.13244 11.1153 9.25497C11.0476 9.41831 10.9178 9.5481 10.7545 9.61576C10.6319 9.6665 10.4766 9.6665 10.166 9.6665Z",stroke:"#2F2F2F",strokeLinecap:"round",strokeLinejoin:"round"}))},value:"advanced"},{label:(0,l.__)("WooCommerce FAQs","easy-accordion-free"),Icon:function(){return React.createElement("svg",{width:16,height:16,viewBox:"0 0 16 16",fill:"none",xmlns:"http://www.w3.org/2000/svg"},React.createElement("g",{clipPath:"url(#WooCommerceFAQsTabIcon)",stroke:"#2F2F2F"},React.createElement("path",{d:"m5.334 10.667 5.813-.485c1.82-.151 2.228-.549 2.43-2.363L14 4M4 4h10.667",strokeLinecap:"round"}),React.createElement("path",{d:"M4.001 14.667a1.333 1.333 0 1 0 0-2.667 1.333 1.333 0 0 0 0 2.667Zm7.332 0a1.333 1.333 0 1 0 0-2.667 1.333 1.333 0 0 0 0 2.667Z"}),React.createElement("path",{d:"M5.334 13.334h4.667m-8.667-12h.644c.63 0 1.179.416 1.331 1.01l1.984 7.707c.1.39.014.802-.234 1.124L4.422 12",strokeLinecap:"round"})),React.createElement("defs",null,React.createElement("clipPath",{id:"WooCommerceFAQsTabIcon"},React.createElement("path",{fill:"#fff",d:"M0 0h16v16H0z"}))))},value:"woocommerce-faqs"},{label:(0,l.__)("Additional CSS & JS","easy-accordion-free"),Icon:function(){return React.createElement("svg",{width:16,height:16,viewBox:"0 0 16 16",fill:"none",xmlns:"http://www.w3.org/2000/svg"},React.createElement("path",{d:"M10.5 6.6665L11.3177 7.3713C11.6615 7.66757 11.8333 7.81577 11.8333 7.99984C11.8333 8.1839 11.6615 8.3321 11.3177 8.62837L10.5 9.33317",stroke:"#2F2F2F",strokeLinecap:"round",strokeLinejoin:"round"}),React.createElement("path",{d:"M5.16634 6.6665L4.34865 7.3713C4.00489 7.66757 3.83301 7.81577 3.83301 7.99984C3.83301 8.1839 4.00489 8.3321 4.34865 8.62837L5.16634 9.33317",stroke:"#2F2F2F",strokeLinecap:"round",strokeLinejoin:"round"}),React.createElement("path",{d:"M8.50033 6L7.16699 10",stroke:"#2F2F2F",strokeLinecap:"round",strokeLinejoin:"round"}),React.createElement("path",{d:"M1.5 7.99984C1.5 5.01428 1.5 3.5215 2.42749 2.594C3.35499 1.6665 4.84777 1.6665 7.83333 1.6665C10.8189 1.6665 12.3117 1.6665 13.2392 2.594C14.1667 3.5215 14.1667 5.01428 14.1667 7.99984C14.1667 10.9854 14.1667 12.4782 13.2392 13.4057C12.3117 14.3332 10.8189 14.3332 7.83333 14.3332C4.84777 14.3332 3.35499 14.3332 2.42749 13.4057C1.5 12.4782 1.5 10.9854 1.5 7.99984Z",stroke:"#2F2F2F"}))},value:"additional"},{label:(0,l.__)("Tools","easy-accordion-free"),Icon:function(){return React.createElement("svg",{width:16,height:16,viewBox:"0 0 16 16",fill:"none",xmlns:"http://www.w3.org/2000/svg"},React.createElement("path",{d:"M5.41 9.866h6M9.91 8.25l1.67 1.616-1.67 1.884m.67-5.884h-6m1.5-1.616L4.41 5.866 6.08 7.75",stroke:"#2f2f2f",strokeLinecap:"round",strokeLinejoin:"round"}),React.createElement("path",{d:"M1.5 8c0-2.986 0-4.478.927-5.406.928-.927 2.42-.927 5.406-.927s4.479 0 5.406.927c.928.928.928 2.42.928 5.406s0 4.478-.928 5.406c-.927.927-2.42.927-5.406.927s-4.478 0-5.406-.927C1.5 12.478 1.5 10.986 1.5 8Z",stroke:"#2f2f2f"}))},value:"tools"}],TA=[{id:1,label:(0,l.__)("All Products","easy-accordion-free"),value:"all"},{id:2,label:(0,l.__)("Category (Pro)","easy-accordion-free"),value:"taxonomy",pro:!0},{id:3,label:(0,l.__)("Specific Products (Pro)","easy-accordion-free"),value:"Specific_Products",pro:!0}];function _A(e,t){return function(e){if(Array.isArray(e))return e}(e)||function(e,t){var n=null==e?null:"undefined"!=typeof Symbol&&e[Symbol.iterator]||e["@@iterator"];if(null!=n){var r,a,o,i,s=[],l=!0,c=!1;try{if(o=(n=n.call(e)).next,0===t){if(Object(n)!==n)return;l=!1}else for(;!(l=(r=o.call(n)).done)&&(s.push(r.value),s.length!==t);l=!0);}catch(e){c=!0,a=e}finally{try{if(!l&&null!=n.return&&(i=n.return(),Object(i)!==i))return}finally{if(c)throw a}}return s}}(e,t)||function(e,t){if(e){if("string"==typeof e)return NA(e,t);var n={}.toString.call(e).slice(8,-1);return"Object"===n&&e.constructor&&(n=e.constructor.name),"Map"===n||"Set"===n?Array.from(e):"Arguments"===n||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)?NA(e,t):void 0}}(e,t)||function(){throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.")}()}function NA(e,t){(null==t||t>e.length)&&(t=e.length);for(var n=0,r=Array(t);n<t;n++)r[n]=e[n];return r}var LA=function(e){var t=e.pluginSettings,n=e.updateSettingsOption,r=e.editorPreference,a=e.setEditorPreference,o=_A((0,i.useState)(!1),2),s=o[0],l=o[1];return React.createElement("div",{className:"sp-eap-dashboard-advanced-settings sp-d-flex sp-flex-col"},null==PA?void 0:PA.map(function(e){var o=e.option_name,i=e.label,s=e.infoText,l=e.inputType,c=e.items,u=ld(null==t?void 0:t[o]);return React.createElement("div",{key:o,className:"sp-eap-settings-option sp-d-flex sp-align-center sp-justify-between"},React.createElement("div",{className:"sp-eap-option-label-wrapper sp-d-flex sp-flex-col"},React.createElement("span",{className:"sp-eap-component-title"},i),s&&React.createElement("span",{className:"sp-eap-option-help-text"},s)),"toggle"===l&&React.createElement(xc.A,{icons:!1,key:u,defaultChecked:u,onChange:function(){return n(o,sd(!u))}}),"checkbox"===l&&React.createElement(Uc.CheckboxControl,{checked:u,__nextHasNoMarginBottom:!0,onChange:function(){return n(o,sd(!u))}}),"select"===l&&React.createElement(mh,{attributes:"eap_editor_preference"===o?r:(null==t?void 0:t[o])||"",onChange:function(e){"eap_editor_preference"===o&&a(e),n(o,e)},items:c,showHeading:!1}))}),s&&React.createElement(Jc,{closeModal:function(){return l(!1)}}))},DA=function(e){var t=e.pluginSettings,n=e.updateSettingsOption;return React.createElement("div",{className:"sp-eap-settings-custom-assets sp-d-flex sp-flex-col"},React.createElement(OA,{label:(0,l.__)("Custom CSS","easy-accordion-free"),attributes:null==t?void 0:t.ea_custom_css,onChange:function(e){return n("ea_custom_css",e)},height:"200px"}),React.createElement(OA,{label:(0,l.__)("Custom JS","easy-accordion-free"),attributes:null==t?void 0:t.custom_js,onChange:function(e){return n("custom_js",e)},defaultLanguage:"javascript",height:"200px"}))},BA=function(){var e=_A((0,i.useState)("all-faqs"),2),t=e[0],n=e[1],r=_A((0,i.useState)(null),2),a=r[0],o=r[1],s=_A((0,i.useState)((0,l.__)("No File Chosen","easy-accordion-free")),2),c=s[0],u=s[1],d=_A((0,i.useState)([]),2),p=d[0],f=d[1],m=_A((0,i.useState)([]),2),h=m[0],g=m[1],v=_A((0,i.useState)(!1),2),b=v[0],y=v[1],w=_A((0,i.useState)(!1),2),E=w[0],R=w[1],x=_A((0,i.useState)(!1),2),A=x[0],C=x[1];return(0,i.useEffect)(function(){var e,t=new FormData;t.append("action","eap_get_shortcode_list_for_export"),t.append("nonce",null===(e=sp_eab_admin_dashboard_localize)||void 0===e?void 0:e.nonce),fetch(ajaxurl,{method:"POST",body:t}).then(function(e){return e.json()}).then(function(e){if(e.success&&Array.isArray(e.data)){var t=e.data.map(function(e){return{label:e.title||"#".concat(e.id),value:e.id}});f(t)}else f([])}).catch(function(e){console.error("Error fetching shortcode list:",e),f([])})},[]),React.createElement("div",{className:"sp-eap-settings-tools-controls"},React.createElement("div",{className:"sp-eap-settings-tools-section"},React.createElement("div",{className:"sp-eap-settings-tools-section-header"},React.createElement("h3",{className:"sp-eap-settings-tools-section-title"},(0,l.__)("Export","easy-accordion-free"))),React.createElement("div",{className:"sp-eap-settings-tools-section-content"},React.createElement("p",{className:"sp-eap-settings-tools-subtitle"},(0,l.__)("Choose What to Export","easy-accordion-free")),React.createElement("div",{className:"sp-eap-settings-tools-radio-group"},React.createElement("label",{className:"sp-eap-settings-tools-radio ".concat("all-faqs"===t?"active":"")},React.createElement("input",{type:"radio",name:"export-type",value:"all-faqs",checked:"all-faqs"===t,onChange:function(){return n("all-faqs")}}),React.createElement("span",{className:"sp-eap-settings-tools-radio-label"},(0,l.__)("All FAQs","easy-accordion-free"))),React.createElement("label",{className:"sp-eap-settings-tools-radio ".concat("all-shortcodes"===t?"active":"")},React.createElement("input",{type:"radio",name:"export-type",value:"all-shortcodes",checked:"all-shortcodes"===t,onChange:function(){return n("all-shortcodes")}}),React.createElement("span",{className:"sp-eap-settings-tools-radio-label"},(0,l.__)("All Accordion Groups","easy-accordion-free"))),React.createElement("label",{className:"sp-eap-settings-tools-radio ".concat("selected-shortcodes"===t?"active":"")},React.createElement("input",{type:"radio",name:"export-type",value:"selected-shortcodes",checked:"selected-shortcodes"===t,onChange:function(){return n("selected-shortcodes")}}),React.createElement("span",{className:"sp-eap-settings-tools-radio-label"},(0,l.__)("Selected Accordion Group(s)","easy-accordion-free")))),"selected-shortcodes"===t&&React.createElement("div",{className:"sp-eap-settings-tools-multiselect"},React.createElement(um,{isMulti:!0,value:p.filter(function(e){return h.includes(e.value)}),onChange:function(e){var t=e?e.map(function(e){return e.value}):[];g(t)},options:p,placeholder:(0,l.__)("Choose group(s)","easy-accordion-free"),className:"sp-eap-tools-multi-select",classNamePrefix:"sp-eap-tools",noOptionsMessage:function(){return(0,l.__)("No groups available","easy-accordion-free")}})),React.createElement("button",{className:"sp-eap-settings-tools-btn sp-eap-settings-tools-btn-primary",onClick:function(){var e="all-faqs"===t?"all_faqs":"all-shortcodes"===t?"all_shortcodes":"selected_shortcodes",n="selected_shortcodes"===e?h.join(","):e;if("all_faqs"===e||"all_shortcodes"===e||"selected_shortcodes"===e&&h.length>0){var r,a=new FormData;a.append("action","eap_export_accordions"),a.append("nonce",null===(r=sp_eab_admin_dashboard_localize)||void 0===r?void 0:r.nonce),a.append("eap_ids",n),fetch(ajaxurl,{method:"POST",body:a}).then(function(e){return e.text()}).then(function(e){if(e){var t;try{var n=JSON.parse(e);t=JSON.stringify(n)}catch(n){t=JSON.stringify(e)}var r=new Blob([t],{type:"application/json"}),a=document.createElement("a"),o=Date.now();a.href=window.URL.createObjectURL(r),a.download="easy-accordion-"+o+".json",a.click()}})}}},(0,l.__)("Export File","easy-accordion-free")))),React.createElement("div",{className:"sp-eap-settings-tools-divider"}),React.createElement("div",{className:"sp-eap-settings-tools-section"},React.createElement("div",{className:"sp-eap-settings-tools-section-header"},React.createElement("h3",{className:"sp-eap-settings-tools-section-title"},(0,l.__)("Import","easy-accordion-free"))),React.createElement("div",{className:"sp-eap-settings-tools-section-content"},React.createElement("p",{className:"sp-eap-settings-tools-subtitle"},(0,l.__)("Import JSON File to Upload","easy-accordion-free")),React.createElement("label",{className:"sp-eap-settings-tools-checkbox"},React.createElement("input",{type:"checkbox",checked:E,onChange:function(e){return R(e.target.checked)},style:{marginRight:"8px"}}),React.createElement("span",{className:"sp-eap-settings-tools-checkbox-label"},(0,l.__)("Allow Iframe/Script Tags","easy-accordion-free"))),React.createElement("p",{className:"sp-eap-settings-tools-checkbox-help"},(0,l.__)("Enabling this option, you are allowing to import accordions which contain iframe, script or embed tags.","easy-accordion-free")),React.createElement("div",{className:"sp-eap-settings-tools-file-input".concat(A?" dragging":""),onDragOver:function(e){e.preventDefault(),e.stopPropagation(),C(!0)},onDragLeave:function(e){e.preventDefault(),e.stopPropagation(),C(!1)},onDrop:function(e){e.preventDefault(),e.stopPropagation(),C(!1);var t=e.dataTransfer.files[0];t&&t.name.endsWith(".json")&&(o(t),u(t.name))}},React.createElement("label",{className:"sp-eap-settings-tools-file-btn"},(0,l.__)("Choose File","easy-accordion-free"),React.createElement("input",{type:"file",accept:".json",onChange:function(e){var t=e.target.files[0];t&&(o(t),u(t.name))},style:{display:"none"}})),React.createElement("span",{className:"sp-eap-settings-tools-file-name"},c)),React.createElement("button",{className:"sp-eap-settings-tools-btn sp-eap-settings-tools-btn-secondary".concat(a?" has-file":""),onClick:function(){if(a){y(!0);var e=new FileReader;e.onload=function(e){var t,n=e.target.result,r=new FormData;r.append("action","eap_import_accordions"),r.append("nonce",null===(t=sp_eab_admin_dashboard_localize)||void 0===t?void 0:t.nonce),r.append("accordion",n),r.append("unSanitize",E?"1":"0"),fetch(ajaxurl,{method:"POST",body:r}).then(function(e){return e.json()}).then(function(e){var t;y(!1),e.success?(alert((0,l.__)("Import successful!","easy-accordion-free")),o(null),u((0,l.__)("No File Chosen","easy-accordion-free"))):alert((null===(t=e.data)||void 0===t?void 0:t.message)||(0,l.__)("Import failed.","easy-accordion-free"))}).catch(function(e){y(!1),console.error("Import error:",e),alert((0,l.__)("Import failed.","easy-accordion-free"))})},e.readAsText(a)}},disabled:!a||b},b?(0,l.__)("Importing...","easy-accordion-free"):(0,l.__)("Import File","easy-accordion-free")))))};function FA(e){return FA="function"==typeof Symbol&&"symbol"==typeof Symbol.iterator?function(e){return typeof e}:function(e){return e&&"function"==typeof Symbol&&e.constructor===Symbol&&e!==Symbol.prototype?"symbol":typeof e},FA(e)}function zA(){return zA=Object.assign?Object.assign.bind():function(e){for(var t=1;t<arguments.length;t++){var n=arguments[t];for(var r in n)({}).hasOwnProperty.call(n,r)&&(e[r]=n[r])}return e},zA.apply(null,arguments)}function jA(e,t){var n=Object.keys(e);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(e);t&&(r=r.filter(function(t){return Object.getOwnPropertyDescriptor(e,t).enumerable})),n.push.apply(n,r)}return n}function HA(e){for(var t=1;t<arguments.length;t++){var n=null!=arguments[t]?arguments[t]:{};t%2?jA(Object(n),!0).forEach(function(t){VA(e,t,n[t])}):Object.getOwnPropertyDescriptors?Object.defineProperties(e,Object.getOwnPropertyDescriptors(n)):jA(Object(n)).forEach(function(t){Object.defineProperty(e,t,Object.getOwnPropertyDescriptor(n,t))})}return e}function VA(e,t,n){return(t=function(e){var t=function(e){if("object"!=FA(e)||!e)return e;var t=e[Symbol.toPrimitive];if(void 0!==t){var n=t.call(e,"string");if("object"!=FA(n))return n;throw new TypeError("@@toPrimitive must return a primitive value.")}return String(e)}(e);return"symbol"==FA(t)?t:t+""}(t))in e?Object.defineProperty(e,t,{value:n,enumerable:!0,configurable:!0,writable:!0}):e[t]=n,e}function GA(e,t){return function(e){if(Array.isArray(e))return e}(e)||function(e,t){var n=null==e?null:"undefined"!=typeof Symbol&&e[Symbol.iterator]||e["@@iterator"];if(null!=n){var r,a,o,i,s=[],l=!0,c=!1;try{if(o=(n=n.call(e)).next,0===t){if(Object(n)!==n)return;l=!1}else for(;!(l=(r=o.call(n)).done)&&(s.push(r.value),s.length!==t);l=!0);}catch(e){c=!0,a=e}finally{try{if(!l&&null!=n.return&&(i=n.return(),Object(i)!==i))return}finally{if(c)throw a}}return s}}(e,t)||qA(e,t)||function(){throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.")}()}function qA(e,t){if(e){if("string"==typeof e)return UA(e,t);var n={}.toString.call(e).slice(8,-1);return"Object"===n&&e.constructor&&(n=e.constructor.name),"Map"===n||"Set"===n?Array.from(e):"Arguments"===n||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)?UA(e,t):void 0}}function UA(e,t){(null==t||t>e.length)&&(t=e.length);for(var n=0,r=Array(t);n<t;n++)r[n]=e[n];return r}var WA=function(e){var t=e.id,n=e.item,r=e.shortCodeOptions,a=void 0===r?[]:r,o=e.onUpdateValue,i=e.duplicateItem,s=e.deleteItem,c=e.activeTabId,u=e.setActiveTabId,d=Math.random(),p=n.eap_display_tab_for,f=null==TA?void 0:TA.find(function(e){return e.value===p});return React.createElement("div",{className:"sp-eap-woo-faq-tab-item"},React.createElement("div",{className:"sp-eap-woo-faq-tab-header sp-d-flex sp-algin-center sp-justify-between"},React.createElement("span",{className:"sp-eap-woo-faq-tab-label",onClick:function(){return u(function(e){return e===t?null:t})}},null==f?void 0:f.label),React.createElement("div",{className:"sp-eap-cloneable-helper sp-d-flex sp-align-center sp-gap-8px"},React.createElement("span",{className:"eap-cloneable-clone sp-cursor-pointer",onClick:function(){return i(t)}},React.createElement(ud,null)),React.createElement("span",{className:"eap-cloneable-remove sp-cursor-pointer",onClick:function(){window.confirm("Are you sure you want to delete this item?")&&s(t)}},React.createElement(dd,null)))),c===t&&React.createElement("div",{className:"sp-eap-woo-faq-tab-content sp-d-flex sp-flex-col sp-gap-10px"},React.createElement("div",{className:"sp-eap-woo-faq-type eap-draggable-content sp-d-flex sp-align-center sp-justify-between"},React.createElement("span",{className:"sp-eap-woo-faq-tab-label"},(0,l.__)("Display FAQs on","easy-accordion-free")),React.createElement("select",{name:"eap_woo_set_tab",onChange:function(e){return o(t,"eap_display_tab_for",e.target.value)},value:p},null==TA?void 0:TA.map(function(e){var t=e.label,n=e.value,r=e.pro;return React.createElement("option",{key:n,value:n,disabled:r},t)}))),React.createElement("div",{className:"sp-eap-woo-faq-posts eap-draggable-content sp-d-flex sp-align-center sp-justify-between"},React.createElement("span",{className:"sp-eap-woo-faq-tab-label"},(0,l.__)("Select FAQs Group(s)","easy-accordion-free")),React.createElement(lE,{label:!1,uniqueId:d,items:a,values:function(e,t){return e.filter(function(e){var n;return null==t?void 0:t.includes(null==e||null===(n=e.value)||void 0===n?void 0:n.toString())})}(a,null==n?void 0:n.eap_woo_tab_shortcode),searchable:!0,onChange:function(e){return o(t,"eap_woo_tab_shortcode",null==(n=e)?void 0:n.map(function(e){var t;return null==e||null===(t=e.value)||void 0===t?void 0:t.toString()}));var n}}))))};const QA=(0,i.memo)(function(e){var t,n=e.pluginSettings,r=e.eapShortcodes,a=e.updateSettingsOption,o=ld(null==n?void 0:n.eap_woo_faq),s=ld(null===(t=sp_eab_admin_dashboard_localize)||void 0===t?void 0:t.isActiveWooCommerce),c=!!s&&o,u=GA((0,i.useState)((null==n?void 0:n.eap_woo_set_tab)||[]),2),d=u[0],p=u[1],f=GA((0,i.useState)(),2),m=f[0],h=f[1],g=function(e){p(e),a("eap_woo_set_tab",e)},v=function(e,t,n){var r=null==d?void 0:d.map(function(r,a){return e===a?HA(HA({},r),{},VA({},t,n)):r});g(r)},b=function(e){var t=null==d?void 0:d.flatMap(function(t,n){return n===e?[t,t]:t});g(t)},y=function(e){g(null==d?void 0:d.filter(function(t,n){return n!==e}))};return React.createElement(React.Fragment,null,!s&&React.createElement("div",{className:"sp-eab-dashboard-woo-notice woo-inactive sp-d-flex sp-align-center sp-gap-4px"},React.createElement("i",{className:"dashicons dashicons-info-outline"}),React.createElement("a",{href:"https://wordpress.org/plugins/woocommerce/",target:"_blank",rel:"noreferrer"}," ","WooCommerce"," "),React.createElement("span",null,(0,l.__)("is required to use this feature.","easy-accordion-free"))),React.createElement("div",{className:"sp-eap-dashboard-advanced-settings eap-woocommerce-settings-tab sp-d-flex sp-flex-col"},React.createElement("div",{className:"sp-eap-settings-option sp-d-flex sp-align-center eap-woo-".concat(s?"active":"inactive")},React.createElement("div",{className:"sp-eap-option-label-wrapper sp-d-flex sp-flex-col"},React.createElement("span",{className:"sp-eap-component-title"},(0,l.__)("WooCommerce FAQs Tab","easy-accordion-free")),React.createElement("span",{className:"sp-eap-option-help-text"},(0,l.__)("WooCommerce's FAQs tab gives quick answers to common customer queries about products and services.","easy-accordion-free"))),React.createElement(xc.A,{icons:!1,defaultChecked:c,onChange:function(){return a("eap_woo_faq",sd(!c))}})),c&&React.createElement(React.Fragment,null,React.createElement("div",{className:"sp-eap-settings-option sp-d-flex sp-align-center"},React.createElement("div",{className:"sp-eap-option-label-wrapper sp-d-flex sp-flex-col"},React.createElement("span",{className:"sp-eap-component-title"},(0,l.__)("FAQs Tab Label","easy-accordion-free")),React.createElement("span",{className:"sp-eap-option-help-text"},(0,l.__)("Set custom text for faq tab.","easy-accordion-free"))),React.createElement(yh,{attributes:null==n?void 0:n.eap_woo_faq_label,onChange:function(e){return a("eap_woo_faq_label",e)}})),React.createElement("div",{className:"sp-eap-settings-option sp-d-flex sp-align-center"},React.createElement("div",{className:"sp-eap-option-label-wrapper sp-d-flex sp-flex-col"},React.createElement("span",{className:"sp-eap-component-title"},(0,l.__)("FAQs Tab Priority","easy-accordion-free")),React.createElement("span",{className:"sp-eap-option-help-text"},(0,l.__)("Set WooCommerce FAQs tab priority position. Default value is 50.","easy-accordion-free"))),React.createElement(yh,{inputType:"number",attributes:null==n?void 0:n.eap_woo_faq_label_priority,onChange:function(e){return a("eap_woo_faq_label_priority",e)}})),React.createElement("div",{className:"sp-eap-settings-option sp-d-flex sp-align-start"},React.createElement("span",{className:"sp-eap-component-title sp-d-flex sp-align-center sp-gap-6px"},(0,l.__)("FAQs Tabs","easy-accordion-free")),React.createElement("div",{className:"sp-eap-woo-faq-tab-items"},React.createElement(xw,{onDragEnd:function(e){var t=e.source,n=e.destination;if(n){var r=t.index,a=n.index,o=kh(d,r,a);g(o)}}},React.createElement(rE,{droppableId:"sp-eap-woo-faq-tab-dnd",direction:"vertical"},function(e){return React.createElement("div",zA({ref:e.innerRef},e.droppableProps),null==d?void 0:d.map(function(e,t){return React.createElement(Dw,{key:t+2,draggableId:String(t+2),index:t},function(n){return React.createElement("div",zA({ref:n.innerRef},n.draggableProps,n.dragHandleProps),React.createElement(WA,{id:t,item:e,shortCodeOptions:r,onUpdateValue:v,duplicateItem:b,deleteItem:y,activeTabId:m,setActiveTabId:h}))})}))})),React.createElement("div",{className:"sp-eap-woo-faq-tab-inserter"},React.createElement("button",{className:"sp-eap-woo-faq-tab-inserter-button sp-d-flex sp-align-center sp-gap-4px sp-cursor-pointer",onClick:function(){g([].concat(function(e){return function(e){if(Array.isArray(e))return UA(e)}(e)||function(e){if("undefined"!=typeof Symbol&&null!=e[Symbol.iterator]||null!=e["@@iterator"])return Array.from(e)}(e)||qA(e)||function(){throw new TypeError("Invalid attempt to spread non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.")}()}(d),[{eap_display_tab_for:"all",eap_woo_tab_shortcode:[]}]))}},React.createElement("i",{className:"dashicons dashicons-plus-alt2"}),(0,l.__)("Add New Tabs","easy-accordion-free"))))))))});function KA(e){return KA="function"==typeof Symbol&&"symbol"==typeof Symbol.iterator?function(e){return typeof e}:function(e){return e&&"function"==typeof Symbol&&e.constructor===Symbol&&e!==Symbol.prototype?"symbol":typeof e},KA(e)}var ZA,JA;function XA(e,t){var n=Object.keys(e);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(e);t&&(r=r.filter(function(t){return Object.getOwnPropertyDescriptor(e,t).enumerable})),n.push.apply(n,r)}return n}function YA(e){for(var t=1;t<arguments.length;t++){var n=null!=arguments[t]?arguments[t]:{};t%2?XA(Object(n),!0).forEach(function(t){$A(e,t,n[t])}):Object.getOwnPropertyDescriptors?Object.defineProperties(e,Object.getOwnPropertyDescriptors(n)):XA(Object(n)).forEach(function(t){Object.defineProperty(e,t,Object.getOwnPropertyDescriptor(n,t))})}return e}function $A(e,t,n){return(t=function(e){var t=function(e){if("object"!=KA(e)||!e)return e;var t=e[Symbol.toPrimitive];if(void 0!==t){var n=t.call(e,"string");if("object"!=KA(n))return n;throw new TypeError("@@toPrimitive must return a primitive value.")}return String(e)}(e);return"symbol"==KA(t)?t:t+""}(t))in e?Object.defineProperty(e,t,{value:n,enumerable:!0,configurable:!0,writable:!0}):e[t]=n,e}function eC(e,t){return function(e){if(Array.isArray(e))return e}(e)||function(e,t){var n=null==e?null:"undefined"!=typeof Symbol&&e[Symbol.iterator]||e["@@iterator"];if(null!=n){var r,a,o,i,s=[],l=!0,c=!1;try{if(o=(n=n.call(e)).next,0===t){if(Object(n)!==n)return;l=!1}else for(;!(l=(r=o.call(n)).done)&&(s.push(r.value),s.length!==t);l=!0);}catch(e){c=!0,a=e}finally{try{if(!l&&null!=n.return&&(i=n.return(),Object(i)!==i))return}finally{if(c)throw a}}return s}}(e,t)||function(e,t){if(e){if("string"==typeof e)return tC(e,t);var n={}.toString.call(e).slice(8,-1);return"Object"===n&&e.constructor&&(n=e.constructor.name),"Map"===n||"Set"===n?Array.from(e):"Arguments"===n||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)?tC(e,t):void 0}}(e,t)||function(){throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.")}()}function tC(e,t){(null==t||t>e.length)&&(t=e.length);for(var n=0,r=Array(t);n<t;n++)r[n]=e[n];return r}var nC=function(e,t){return(Object.keys(MA[t])||[]).reduce(function(t,n){return t[n]=e[n],t},{})},rC=(null===(ZA=window.location)||void 0===ZA||null===(ZA=ZA.hash)||void 0===ZA||null===(ZA=ZA.replace("#",""))||void 0===ZA?void 0:ZA.split("=")[1])||"advanced",aC=(null===(JA=sp_eab_admin_dashboard_localize)||void 0===JA?void 0:JA.eap_editor_preference)||"";const oC=(0,i.memo)(function(){var e=(0,s.useSelect)(function(e){return{pluginSettings:e(qc).getPluginSettings(),eapShortcodes:e(qc).getEapShortcodes()}}),t=e.pluginSettings,n=e.eapShortcodes,r=(0,s.useDispatch)(qc).saveSettings,a=eC((0,i.useState)(rC),2),o=a[0],l=a[1],c=eC((0,i.useState)(t),2),u=c[0],d=c[1],p=eC((0,i.useState)(nC(t,o)),2),f=p[0],m=p[1],h=eC((0,i.useState)(!1),2),g=h[0],v=h[1],b=eC((0,i.useState)(aC),2),y=b[0],w=b[1],E=function(e,n){var r=YA(YA({},f),{},$A({},e,n));v(!Qc(r,t)),m(r),d(function(e){return YA(YA({},e),r)})};return React.createElement("div",{className:"sp-eap-settings-page-container sp-d-flex"},React.createElement("div",{className:"sp-eap-setting-tabs-wrapper sp-d-block"},React.createElement("ul",{className:"sp-eap-setting-tabs"},null==IA?void 0:IA.map(function(e){var n=e.label,r=e.value,a=e.Icon;return React.createElement("li",{key:r,className:"sp-eap-setting-tab sp-d-flex sp-cursor-pointer sp-gap-8px".concat(o===r?" active":""),onClick:function(){return function(e){l(e),window.location.hash="#settings=".concat(e);var n=nC(u,e);v(!Qc(n,t)),m(n)}(r)}},React.createElement("span",{className:"sp-eap-setting-icon"},React.createElement(a,null))," ",React.createElement("span",null,n))})),React.createElement("div",{className:"sp-eap-setting-tabs-bottom"})),React.createElement("div",{className:"sp-eap-setting-tab-content"},"advanced"===o&&React.createElement(LA,{pluginSettings:f,updateSettingsOption:E,editorPreference:y,setEditorPreference:w}),"woocommerce-faqs"===o&&React.createElement(QA,{pluginSettings:f,eapShortcodes:n,updateSettingsOption:E}),"additional"===o&&React.createElement(DA,{pluginSettings:f,updateSettingsOption:E}),"tools"===o&&React.createElement(BA,null),"license-key"!==o&&"tools"!==o&&React.createElement(Kc,{onSave:function(){var e=YA(YA({},t),f);r({pluginSettings:e},y),v(!1)},onReset:function(){var e=MA[o]||{},n=YA(YA({},t),e);r({pluginSettings:n})},isChanged:g})))});var iC=[{id:1,Icon:function(){return React.createElement("svg",{width:44,height:44,viewBox:"0 0 44 44",fill:"none",xmlns:"http://www.w3.org/2000/svg"},React.createElement("rect",{width:44,height:44,rx:6,fill:"#fff"}),React.createElement("rect",{x:.5,y:.5,width:43,height:43,rx:5.5,stroke:"#1e1e1e",strokeOpacity:.15}),React.createElement("g",{clipPath:"url(#GeminiIcona)"},React.createElement("mask",{id:"c",style:{maskType:"alpha"},maskUnits:"userSpaceOnUse",x:8,y:8,width:28,height:28},React.createElement("path",{d:"M21.977 8.5c.293 0 .549.193.62.467.219.839.506 1.66.861 2.453a17.3 17.3 0 0 0 3.814 5.452q2.424 2.337 5.654 3.678 1.237.514 2.544.83a.62.62 0 0 1 .484.598c0 .282-.2.529-.484.598q-1.306.316-2.544.83-3.23 1.341-5.654 3.678a17.3 17.3 0 0 0-3.814 5.452 16 16 0 0 0-.861 2.453.6.6 0 0 1-.227.336.66.66 0 0 1-.393.131.635.635 0 0 1-.62-.467 16 16 0 0 0-.86-2.453 17.3 17.3 0 0 0-3.815-5.452q-2.423-2.336-5.654-3.678a17 17 0 0 0-2.543-.83.64.64 0 0 1-.349-.219.6.6 0 0 1-.136-.379c0-.282.2-.528.485-.597q1.307-.317 2.543-.83 3.232-1.341 5.654-3.678a17.3 17.3 0 0 0 3.815-5.452q.532-1.194.86-2.453a.6.6 0 0 1 .227-.337.66.66 0 0 1 .393-.131",fill:"#000"}),React.createElement("path",{d:"M21.977 8.5c.293 0 .549.193.62.467.219.839.506 1.66.861 2.453a17.3 17.3 0 0 0 3.814 5.452q2.424 2.337 5.654 3.678 1.237.514 2.544.83a.62.62 0 0 1 .484.598c0 .282-.2.529-.484.598q-1.306.316-2.544.83-3.23 1.341-5.654 3.678a17.3 17.3 0 0 0-3.814 5.452 16 16 0 0 0-.861 2.453.6.6 0 0 1-.227.336.66.66 0 0 1-.393.131.635.635 0 0 1-.62-.467 16 16 0 0 0-.86-2.453 17.3 17.3 0 0 0-3.815-5.452q-2.423-2.336-5.654-3.678a17 17 0 0 0-2.543-.83.64.64 0 0 1-.349-.219.6.6 0 0 1-.136-.379c0-.282.2-.528.485-.597q1.307-.317 2.543-.83 3.232-1.341 5.654-3.678a17.3 17.3 0 0 0 3.815-5.452q.532-1.194.86-2.453a.6.6 0 0 1 .227-.337.66.66 0 0 1 .393-.131",fill:"url(#b)"})),React.createElement("g",{mask:"url(#c)"},React.createElement("g",{filter:"url(#d)"},React.createElement("path",{d:"M5.476 29.574c3.23 1.106 6.942-.968 8.292-4.632s-.175-7.532-3.405-8.638-6.942.968-8.293 4.632c-1.349 3.665.176 7.532 3.406 8.638",fill:"#ffe432"})),React.createElement("g",{filter:"url(#e)"},React.createElement("path",{d:"M19.817 17.493c4.437 0 8.034-3.546 8.034-7.918 0-4.374-3.597-7.919-8.034-7.919s-8.035 3.546-8.035 7.919 3.597 7.918 8.035 7.918",fill:"#fc413d"})),React.createElement("g",{filter:"url(#f)"},React.createElement("path",{d:"M16.695 42.814c4.632-.218 8.149-5.086 7.855-10.872-.292-5.787-4.286-10.3-8.918-10.082s-8.149 5.086-7.856 10.872c.294 5.787 4.287 10.3 8.919 10.082",fill:"#00b95c"})),React.createElement("g",{filter:"url(#g)"},React.createElement("path",{d:"M16.695 42.814c4.632-.218 8.149-5.086 7.855-10.872-.292-5.787-4.286-10.3-8.918-10.082s-8.149 5.086-7.856 10.872c.294 5.787 4.287 10.3 8.919 10.082",fill:"#00b95c"})),React.createElement("g",{filter:"url(#h)"},React.createElement("path",{d:"M21.334 39.314c3.883-2.279 4.922-7.467 2.321-11.59-2.6-4.122-7.857-5.617-11.74-3.34-3.884 2.28-4.923 7.468-2.322 11.59 2.601 4.123 7.858 5.618 11.741 3.34",fill:"#00b95c"})),React.createElement("g",{filter:"url(#i)"},React.createElement("path",{d:"M37.03 26.359c4.364 0 7.903-3.286 7.903-7.339 0-4.052-3.539-7.338-7.903-7.338-4.365 0-7.903 3.286-7.903 7.338 0 4.053 3.538 7.339 7.903 7.339",fill:"#3186ff"})),React.createElement("g",{filter:"url(#j)"},React.createElement("path",{d:"M2.372 25.508c4.019 2.946 9.89 2.022 13.113-2.066 3.224-4.087 2.58-9.79-1.44-12.737S4.155 8.682.932 12.77c-3.224 4.088-2.579 9.79 1.44 12.738",fill:"#fbbc04"})),React.createElement("g",{filter:"url(#k)"},React.createElement("path",{d:"M22.965 29.863c4.796 3.18 11.155 2.295 14.201-1.979 3.047-4.273 1.628-10.314-3.17-13.495-4.796-3.18-11.154-2.294-14.201 1.979s-1.628 10.315 3.17 13.495",fill:"#3186ff"})),React.createElement("g",{filter:"url(#l)"},React.createElement("path",{d:"M31.685 7.53c1.22 1.6-.348 4.71-3.502 6.948-3.155 2.237-6.702 2.754-7.922 1.155-1.22-1.6.348-4.712 3.502-6.949s6.702-2.754 7.922-1.155",fill:"#749bff"})),React.createElement("g",{filter:"url(#m)"},React.createElement("path",{d:"M21.667 15.19c4.879-4.365 6.553-10.273 3.74-13.197C22.594-.932 16.358.235 11.48 4.599 6.6 8.963 4.926 14.87 7.74 17.796c2.812 2.924 9.048 1.757 13.927-2.607",fill:"#fc413d"})),React.createElement("g",{filter:"url(#n)"},React.createElement("path",{d:"M11.666 30.863c2.9 2.002 6.229 2.306 7.436.68s-.166-4.567-3.066-6.568-6.229-2.306-7.435-.68c-1.207 1.627.165 4.567 3.065 6.568",fill:"#ffee48"})))),React.createElement("defs",null,React.createElement("filter",{id:"d",x:-3.341,y:11.087,width:22.52,height:23.705,filterUnits:"userSpaceOnUse",colorInterpolationFilters:"sRGB"},React.createElement("feFlood",{floodOpacity:0,result:"BackgroundImageFix"}),React.createElement("feBlend",{in:"SourceGraphic",in2:"BackgroundImageFix",result:"shape"}),React.createElement("feGaussianBlur",{stdDeviation:2.46,result:"effect1_foregroundBlur_12983_8187"})),React.createElement("filter",{id:"e",x:-12,y:-22.125,width:63.633,height:63.4,filterUnits:"userSpaceOnUse",colorInterpolationFilters:"sRGB"},React.createElement("feFlood",{floodOpacity:0,result:"BackgroundImageFix"}),React.createElement("feBlend",{in:"SourceGraphic",in2:"BackgroundImageFix",result:"shape"}),React.createElement("feGaussianBlur",{stdDeviation:11.891,result:"effect1_foregroundBlur_12983_8187"})),React.createElement("filter",{id:"f",x:-12.459,y:1.634,width:57.244,height:61.405,filterUnits:"userSpaceOnUse",colorInterpolationFilters:"sRGB"},React.createElement("feFlood",{floodOpacity:0,result:"BackgroundImageFix"}),React.createElement("feBlend",{in:"SourceGraphic",in2:"BackgroundImageFix",result:"shape"}),React.createElement("feGaussianBlur",{stdDeviation:10.109,result:"effect1_foregroundBlur_12983_8187"})),React.createElement("filter",{id:"g",x:-12.459,y:1.634,width:57.244,height:61.405,filterUnits:"userSpaceOnUse",colorInterpolationFilters:"sRGB"},React.createElement("feFlood",{floodOpacity:0,result:"BackgroundImageFix"}),React.createElement("feBlend",{in:"SourceGraphic",in2:"BackgroundImageFix",result:"shape"}),React.createElement("feGaussianBlur",{stdDeviation:10.109,result:"effect1_foregroundBlur_12983_8187"})),React.createElement("filter",{id:"h",x:-12.058,y:3.101,width:57.364,height:57.496,filterUnits:"userSpaceOnUse",colorInterpolationFilters:"sRGB"},React.createElement("feFlood",{floodOpacity:0,result:"BackgroundImageFix"}),React.createElement("feBlend",{in:"SourceGraphic",in2:"BackgroundImageFix",result:"shape"}),React.createElement("feGaussianBlur",{stdDeviation:10.109,result:"effect1_foregroundBlur_12983_8187"})),React.createElement("filter",{id:"i",x:9.915,y:-7.53,width:54.23,height:53.101,filterUnits:"userSpaceOnUse",colorInterpolationFilters:"sRGB"},React.createElement("feFlood",{floodOpacity:0,result:"BackgroundImageFix"}),React.createElement("feBlend",{in:"SourceGraphic",in2:"BackgroundImageFix",result:"shape"}),React.createElement("feGaussianBlur",{stdDeviation:9.606,result:"effect1_foregroundBlur_12983_8187"})),React.createElement("filter",{id:"j",x:-18.532,y:-8.431,width:53.481,height:53.074,filterUnits:"userSpaceOnUse",colorInterpolationFilters:"sRGB"},React.createElement("feFlood",{floodOpacity:0,result:"BackgroundImageFix"}),React.createElement("feBlend",{in:"SourceGraphic",in2:"BackgroundImageFix",result:"shape"}),React.createElement("feGaussianBlur",{stdDeviation:8.706,result:"effect1_foregroundBlur_12983_8187"})),React.createElement("filter",{id:"k",x:2.64,y:-3.069,width:51.681,height:50.391,filterUnits:"userSpaceOnUse",colorInterpolationFilters:"sRGB"},React.createElement("feFlood",{floodOpacity:0,result:"BackgroundImageFix"}),React.createElement("feBlend",{in:"SourceGraphic",in2:"BackgroundImageFix",result:"shape"}),React.createElement("feGaussianBlur",{stdDeviation:7.775,result:"effect1_foregroundBlur_12983_8187"})),React.createElement("filter",{id:"l",x:5.933,y:-7.314,width:40.081,height:37.79,filterUnits:"userSpaceOnUse",colorInterpolationFilters:"sRGB"},React.createElement("feFlood",{floodOpacity:0,result:"BackgroundImageFix"}),React.createElement("feBlend",{in:"SourceGraphic",in2:"BackgroundImageFix",result:"shape"}),React.createElement("feGaussianBlur",{stdDeviation:6.957,result:"effect1_foregroundBlur_12983_8187"})),React.createElement("filter",{id:"m",x:-5.378,y:-11.371,width:43.902,height:42.529,filterUnits:"userSpaceOnUse",colorInterpolationFilters:"sRGB"},React.createElement("feFlood",{floodOpacity:0,result:"BackgroundImageFix"}),React.createElement("feBlend",{in:"SourceGraphic",in2:"BackgroundImageFix",result:"shape"}),React.createElement("feGaussianBlur",{stdDeviation:5.876,result:"effect1_foregroundBlur_12983_8187"})),React.createElement("filter",{id:"n",x:-6.383,y:8.704,width:40.469,height:38.43,filterUnits:"userSpaceOnUse",colorInterpolationFilters:"sRGB"},React.createElement("feFlood",{floodOpacity:0,result:"BackgroundImageFix"}),React.createElement("feBlend",{in:"SourceGraphic",in2:"BackgroundImageFix",result:"shape"}),React.createElement("feGaussianBlur",{stdDeviation:7.273,result:"effect1_foregroundBlur_12983_8187"})),React.createElement("linearGradient",{id:"b",x1:15.946,y1:26.536,x2:30.025,y2:14.228,gradientUnits:"userSpaceOnUse"},React.createElement("stop",{stopColor:"#4893fc"}),React.createElement("stop",{offset:.27,stopColor:"#4893fc"}),React.createElement("stop",{offset:.777,stopColor:"#969dff"}),React.createElement("stop",{offset:1,stopColor:"#bd99fe"})),React.createElement("clipPath",{id:"GeminiIcona"},React.createElement("path",{fill:"#fff",d:"M8 8.5h28v27H8z"}))))},key:"gemini",label:"Google Gemini",desc:(0,l.__)("Configure API key and token to enable AI-powered FAQ generation from your content, keywords, or custom prompts.","easy-accordion-free"),videoLink:"https://www.youtube.com/watch?v=bRVTr1kki1w",docLink:"https://easyaccordion.io/docs/google-gemini/"},{upcoming:!0,id:2,Icon:function(){return React.createElement("svg",{width:44,height:44,viewBox:"0 0 44 44",fill:"none",xmlns:"http://www.w3.org/2000/svg"},React.createElement("rect",{width:44,height:44,rx:6,fill:"#fff"}),React.createElement("rect",{x:.5,y:.5,width:43,height:43,rx:5.5,stroke:"#1e1e1e",strokeOpacity:.15}),React.createElement("g",{clipPath:"url(#GoogleRecaptchaIcona)"},React.createElement("path",{d:"M37.999 21.977q0-.344-.017-.686V8.304l-3.58 3.59C31.475 8.297 27.017 6 22.025 6c-5.195 0-9.81 2.487-12.728 6.339l5.867 5.947a7.8 7.8 0 0 1 2.377-2.675c1.025-.802 2.476-1.457 4.484-1.457q.362 0 .567.082a7.73 7.73 0 0 1 5.914 3.572l-4.153 4.166c5.26-.02 11.203-.033 13.647.003",fill:"#1c3aa9"}),React.createElement("path",{d:"M21.931 6.001q-.344.001-.684.017H8.297l3.581 3.59a16.01 16.01 0 0 0-5.877 12.415c0 5.21 2.48 9.84 6.32 12.766l5.93-5.885a7.8 7.8 0 0 1-2.667-2.383c-.8-1.028-1.453-2.483-1.453-4.497q0-.364.081-.57a7.76 7.76 0 0 1 3.562-5.93l4.154 4.165c-.021-5.276-.033-11.237.002-13.687",fill:"#4285f4"}),React.createElement("path",{d:"M6.001 22.023q.002.345.017.686v12.987l3.58-3.59C12.528 35.703 16.984 38 21.977 38c5.195 0 9.81-2.487 12.728-6.338l-5.868-5.948a7.8 7.8 0 0 1-2.377 2.675c-1.024.802-2.475 1.458-4.483 1.458q-.363-.002-.568-.083a7.73 7.73 0 0 1-5.913-3.572l4.153-4.166c-5.26.021-11.203.033-13.647-.003",fill:"#ababab"})),React.createElement("defs",null,React.createElement("clipPath",{id:"GoogleRecaptchaIcona"},React.createElement("path",{fill:"#fff",d:"M6 6h32v32H6z"}))))},key:"google_recaptcha",label:"Google reCAPTCHA",desc:(0,l.__)("Add site key and secret key to protect forms from spam and ensure secure, verified user submissions.","easy-accordion-free"),videoLink:"https://www.youtube.com/watch?v=O_-HQWS3SnI",docLink:"https://easyaccordion.io/docs/google-recaptcha/"},{upcoming:!0,id:3,Icon:function(){return React.createElement("svg",{width:44,height:44,viewBox:"0 0 44 44",fill:"none",xmlns:"http://www.w3.org/2000/svg"},React.createElement("g",{clipPath:"url(#ChatGPTIcon)"},React.createElement("rect",{width:44,height:44,rx:6,fill:"#10a37f"}),React.createElement("path",{d:"M35.046 0H8.954C4.009 0 0 4.042 0 9.027v25.946C0 39.959 4.009 44 8.954 44h26.092C39.991 44 44 39.959 44 34.973V9.027C44 4.042 39.991 0 35.046 0",fill:"#10a37f"}),React.createElement("path",{d:"M32.543 19.766a6.14 6.14 0 0 0-.527-5.036 6.205 6.205 0 0 0-6.68-2.976 6.13 6.13 0 0 0-4.587-2.062h-.053a6.2 6.2 0 0 0-5.902 4.294 6.13 6.13 0 0 0-4.1 2.975 6.21 6.21 0 0 0 .763 7.272 6.13 6.13 0 0 0 .526 5.037 6.2 6.2 0 0 0 6.68 2.976 6.13 6.13 0 0 0 4.587 2.062h.055a6.2 6.2 0 0 0 5.902-4.297 6.14 6.14 0 0 0 4.1-2.975 6.2 6.2 0 0 0-.764-7.27M23.29 32.698h-.007a4.6 4.6 0 0 1-2.946-1.067l.145-.083 4.901-2.83a.8.8 0 0 0 .403-.693V21.11l2.072 1.196a.07.07 0 0 1 .04.057v5.722a4.62 4.62 0 0 1-4.608 4.613m-9.912-4.233a4.6 4.6 0 0 1-.55-3.09l.146.086 4.9 2.831a.8.8 0 0 0 .806 0l5.984-3.455v2.397a.08.08 0 0 1-.03.059l-4.954 2.86a4.62 4.62 0 0 1-4.612 0 4.6 4.6 0 0 1-1.69-1.688m-1.289-10.7a4.6 4.6 0 0 1 2.401-2.022l-.002.169v5.667a.8.8 0 0 0 .402.692l5.984 3.454-2.072 1.197a.08.08 0 0 1-.07.006l-4.955-2.863a4.62 4.62 0 0 1-1.688-6.3m17.02 3.961-5.983-3.455 2.071-1.195a.08.08 0 0 1 .07-.007l4.955 2.861a4.616 4.616 0 0 1-.713 8.325v-5.838a.8.8 0 0 0-.4-.69m2.062-3.103-.145-.087-4.902-2.83a.8.8 0 0 0-.805 0l-5.983 3.454v-2.396q0-.038.03-.06l4.954-2.858a4.615 4.615 0 0 1 6.918 3.997q0 .392-.067.78M18.21 22.887l-2.072-1.196a.07.07 0 0 1-.04-.057v-5.722a4.614 4.614 0 0 1 7.565-3.543l-.145.083-4.902 2.83a.8.8 0 0 0-.402.693v.005zm1.126-2.426L22 18.92l2.665 1.539v3.077L22 25.076l-2.665-1.539z",fill:"#fff"})),React.createElement("defs",null,React.createElement("clipPath",{id:"ChatGPTIcon"},React.createElement("rect",{width:44,height:44,rx:6,fill:"#fff"}))))},key:"chatgpt",label:"ChatGPT",desc:(0,l.__)("Easy Accordion integrates ChatGPT into the WordPress Dashboard, allowing you to generate content effortlessly.","easy-accordion-free"),videoLink:"#",docLink:"#"}],sC=[{id:1,key:"elementor",label:"Elementor",Icon:function(){return React.createElement("svg",{width:48,height:48,viewBox:"0 0 48 48",fill:"none",xmlns:"http://www.w3.org/2000/svg"},React.createElement("path",{d:"M2 8a6 6 0 0 1 6-6h32a6 6 0 0 1 6 6v32a6 6 0 0 1-6 6H8a6 6 0 0 1-6-6z",fill:"#EF00ED"}),React.createElement("g",{clipPath:"url(#ElementorIntegrationIcona)"},React.createElement("mask",{id:"ElementorIntegrationIconb",style:{maskType:"luminance"},maskUnits:"userSpaceOnUse",x:0,y:0,width:48,height:48},React.createElement("path",{d:"M48 0H0v48h48z",fill:"#fff"})),React.createElement("g",{mask:"url(#ElementorIntegrationIconb)",fill:"#fff"},React.createElement("path",{d:"M18.001 33.997h-3.998V13.999h3.998zm15.996-16H21.999v-3.998h11.998zm0 8H21.999v-3.998h11.998zm0 8H21.999v-3.998h11.998z"}))),React.createElement("defs",null,React.createElement("clipPath",{id:"ElementorIntegrationIcona"},React.createElement("path",{fill:"#fff",d:"M0 0h48v48H0z"}))))},desc:(0,l.__)("This addon lets you use Easy Accordion Gutenberg blocks in Elementor by generating reusable shortcodes from saved templates.","easy-accordion-free"),docLink:"https://easyaccordion.io/docs/page-builder-integrations/easy-accordion-pro-with-elementor-elementor-pro/"},{id:2,key:"divi",label:"Divi",Icon:function(){return React.createElement("svg",{width:44,height:44,viewBox:"0 0 44 44",fill:"none",xmlns:"http://www.w3.org/2000/svg"},React.createElement("rect",{width:44,height:44,rx:6,fill:"url(#DiviIntegrationIcona)"}),React.createElement("path",{fillRule:"evenodd",clipRule:"evenodd",d:"M9.002 9.547H23.27c5.804 0 11.728 4.11 11.728 12.453S29.073 34.453 23.27 34.453H12.751v-13.42h6.166v7.375h4.11c2.66 0 5.804-3.023 5.804-6.408s-3.023-6.408-5.803-6.408h-6.771c-3.023 0-5.441-2.055-7.255-6.045",fill:"#fff"}),React.createElement("defs",null,React.createElement("linearGradient",{id:"DiviIntegrationIcona",x1:44.061,y1:44.06,x2:.001,y2:-.001,gradientUnits:"userSpaceOnUse"},React.createElement("stop",{stopColor:"#4b81eb"}),React.createElement("stop",{offset:1,stopColor:"#6752f4"}))))},desc:(0,l.__)("This addon lets you use Easy Accordion Gutenberg blocks in Divi by generating reusable shortcodes from saved templates.","easy-accordion-free"),docLink:"https://easyaccordion.io/docs/page-builder-integrations/integrate-with-divi/"},{id:3,key:"wpbakery",label:"WPBakery",Icon:function(){return React.createElement("svg",{width:44,height:44,viewBox:"0 0 44 44",fill:"none",xmlns:"http://www.w3.org/2000/svg"},React.createElement("rect",{width:44,height:44,rx:6,fill:"url(#WPBakeryIntegrationIcona)"}),React.createElement("path",{d:"M21.434 27.626c-.925.462-1.85.925-2.929 1.079-.925.154-2.004.308-2.929 0-1.079-.154-2.158-.462-3.083-1.079-2.312-1.233-3.853-3.083-4.47-5.55-.462-1.54-.308-3.236.309-4.778.154-.77.616-1.695 1.233-2.312.925-1.233 2.158-2.312 3.545-2.928a9.4 9.4 0 0 1 7.707.308c.617.308 1.233.925 1.85 1.541l1.387 1.388c.77.77 1.85 1.233 3.083 1.387.925.154 1.85.154 2.774-.154-1.233 0-2.466-.154-3.545-.771h.154l.617-.154 1.541-.308a7.55 7.55 0 0 1 3.7.462c1.387.617 2.466 1.696 3.237 2.929l.616 2.158q.231 3.93-3.237 6.011-1.387.925-3.237.925c-.308 0-.308 0-.462.308l-1.233 4.316c0 .155-.154.309-.309.155l-3.236-.925h-2.93l-2.157.462c-.925.154-1.542-.308-2.004-.925l-.617-1.079.154-.308c.925-.154 1.85-.617 2.775-1.079.617-.308 1.08-.462 1.541-.925z",fill:"#fff"}),React.createElement("defs",null,React.createElement("linearGradient",{id:"WPBakeryIntegrationIcona",x1:38.822,y1:38.818,x2:5.264,y2:5.287,gradientUnits:"userSpaceOnUse"},React.createElement("stop",{stopColor:"#0074af"}),React.createElement("stop",{offset:.2,stopColor:"#0375b1"}),React.createElement("stop",{offset:.4,stopColor:"#0c79b7"}),React.createElement("stop",{offset:.6,stopColor:"#1c80c1"}),React.createElement("stop",{offset:.7,stopColor:"#328acf"}),React.createElement("stop",{offset:.8,stopColor:"#4f96e1"}),React.createElement("stop",{offset:1,stopColor:"#7fabff"}))))},desc:(0,l.__)("This addon lets you use Easy Accordion Gutenberg blocks in WPBakery by generating reusable shortcodes from saved templates.","easy-accordion-free"),docLink:"https://easyaccordion.io/docs/page-builder-integrations/integrate-with-wpbakery/"},{id:5,key:"beaver",label:"Beaver Builder",Icon:function(){return React.createElement("svg",{width:44,height:44,viewBox:"0 0 44 44",fill:"none",xmlns:"http://www.w3.org/2000/svg"},React.createElement("rect",{width:44,height:44,rx:6,fill:"url(#BeaverIntegrationIcona)"}),React.createElement("path",{fillRule:"evenodd",clipRule:"evenodd",d:"m7.662 24.08.462-.461-.77-.617zm1.85-2.465a70 70 0 0 1-1.08-.925l-.77 1.233.925.925zm-1.234 3.39 1.08 1.08.77-.925-1.233-1.08zm1.696-4.161 1.079-1.387-1.08-.771-.924 1.079zm-.617 2.466 1.234 1.08.77-1.388-1.233-.925zm2.93-5.24-1.08-.617-.77.616.924.925zm.461 2.774-1.233-.925-.925 1.387 1.234 1.08z",fill:"#fff"}),React.createElement("path",{fillRule:"evenodd",clipRule:"evenodd",d:"m12.902 17.607-.154.308.925.925-1.079-.616-.77 1.079 1.232.924 1.388-2.003-1.08 2.466.309.154.308.462h-.462l-.309-.154-.924 1.542.462.462.77.617.31-.463-.155.617.617.462a13.6 13.6 0 0 1 .616-4.47l.77-2.004c-1.232-.462-2.311-.616-3.699-.77h-.154l.617.462z",fill:"#fff"}),React.createElement("path",{fillRule:"evenodd",clipRule:"evenodd",d:"M22.305 35.488h.77l3.084.462 1.233.154h2.62v.154l1.85-.77c.308-.463 1.079-1.388.77-1.696-.307-.308-3.082.616-3.39.154-.155-.308 4.778-4.008 5.086-9.248l-.925.154c-1.078 2.774-4.161 5.857-5.086 6.32l-.463.154c-.924.154-2.466 0-3.082-.463-.617-.462-2.467-4.162-2.93-5.703-1.695-.462-3.699-1.387-4.007-2.312-.308-1.233 2.929-4.779 3.391-4.47.154.154-1.079 2.466-.77 3.082.308.617 2.157 1.85 4.007 1.696 1.542 0 3.083-1.079 4.008-1.85l.308-.77c.154-.463-.154-.463-.462-.463-.308.154 0 .617 0 .77.154.155 0 .31-.154 0l-.309-.307H27.7l-.308-.463-.154-.154v-.154l.154-.154v-.154l.308-.155c1.08-.308 3.546-.154 3.083.617l-.617.925c-.462.462 0-.308 0-.463 0-.308-.154-.308-.308-.154l-.154 1.08c.617.616 2.004 1.54 3.237 1.695 1.541 0 3.391-1.08 3.7-1.85.154-.616-2.775-7.09-4.625-8.015-2.004-.925-10.173.616-10.481.462-.463 0-1.08-1.387-1.388-1.541-.462-.154-1.695 1.079-1.695 1.541 0 .154.924.925.924 1.387.155.309-.77.617-3.082 6.474-1.08 2.775-.771 6.937.77 7.554.771.462.617-2.004.925-2.004 1.387 0 1.85 2.928-.154 2.928-1.387 0-2.466-1.079-2.929-2.466l-.616-2.62-.617-.463-.77 1.85c1.079.925 2.003 1.695 1.85 1.85 0 .154-.926-.309-2.159-1.233l-.616 1.54v.155l1.079.77c.308-.616.462-1.387.616-1.232l-.308 1.541c1.541 1.233 3.083 2.312 4.316 2.929.462.154 1.233.462 1.233.925.154.308-.308 1.233-.154 1.541s2.466 1.079 2.62.617l.155-.309-.309-.616h.309l.154.154.616.462zm3.083-17.419v.155h-.154l-.463.154a.924.924 0 1 1 .463-1.542h.154l.154.77c.154.155 0 .31-.154.463m7.861-.154v.154c-.154.309-.462.309-.77.309a.924.924 0 1 1 .308-1.542h.154l.154.154.309.463v.154zm-21.426 8.478-1.078-.77-.617 1.232 1.079 1.08a9.6 9.6 0 0 0 .77-1.388zm.463-.462.925-1.696-.77-.462-.463-.463-.771 1.542.616.616z",fill:"#fff"}),React.createElement("path",{fillRule:"evenodd",clipRule:"evenodd",d:"m28.163 30.71 1.233-1.234c1.233-1.387 2.62-3.545 2.928-4.778l-.924-.617-1.696-1.85-1.08 4.624-.153.463-1.233 3.545zm.308-8.325c-1.233 1.233-3.7 2.775-4.933 2.93.308 1.232.925 2.774 1.542 4.007l1.079 1.233.616.154v-.154l.617-2.158.308-1.08zm-6.628-10.79a3.64 3.64 0 0 1 1.387-1.233l2.158-.308c-.617-1.387-1.08-1.85-1.696-2.312-2.158.308-4.624 1.233-4.932 2.929l1.233-.617c.462 0 1.387 1.079 1.85 1.541m4.624-1.541h2.004l-1.233-1.541c-.463-.463-1.388-.771-2.467-.771.617.616 1.233 1.233 1.696 2.312m-2.929 1.85 3.083-.155h3.545c-.462-1.54-4.778-1.387-6.628.155",fill:"#fff"}),React.createElement("defs",null,React.createElement("linearGradient",{id:"BeaverIntegrationIcona",x1:5.772,y1:5.742,x2:39.103,y2:39.06,gradientUnits:"userSpaceOnUse"},React.createElement("stop",{stopColor:"#aa7a55"}),React.createElement("stop",{offset:1,stopColor:"#8c5934"}))))},desc:(0,l.__)("This addon lets you use Easy Accordion Gutenberg blocks in Beaver by generating reusable shortcodes from saved templates.","easy-accordion-free"),docLink:"https://easyaccordion.io/docs/page-builder-integrations/integrate-with-beaver-builder/"},{id:6,key:"bricks",label:"Bricks",Icon:function(){return React.createElement("svg",{width:44,height:44,viewBox:"0 0 44 44",fill:"none",xmlns:"http://www.w3.org/2000/svg"},React.createElement("rect",{width:44,height:44,rx:6,fill:"#ffd53e"}),React.createElement("path",{d:"M17.267 8.167c.294.31.257.566.248.978v.234q0 .382-.006.766l-.002.532q-.003.699-.01 1.398-.007.713-.009 1.427-.006 1.4-.02 2.8l.256-.138.34-.181.168-.091c1.194-.637 2.57-1.043 3.932-1.091l.273-.01c2.808-.05 5.327.743 7.377 2.7 1.942 1.908 3.14 4.437 3.181 7.177l.002.52q0 .263.003.527c.012 2.892-1.113 5.444-3.122 7.516-1.491 1.447-3.36 2.292-5.4 2.617-.297.043-.297.043-.553.135-2.013.105-3.943-.264-5.703-1.251q-.132-.074-.27-.148c-.415-.238-.415-.238-.568-.353v-.166l-.136-.058c-.265-.145-.472-.332-.703-.526l-.006.175-.03.779-.01.275-.011.261-.01.242c-.017.186-.017.186-.1.27q-.248.011-.494.01H14.12a304 304 0 0 0-1.687 0h-1.127c-.21-.01-.21-.01-.294-.094a8 8 0 0 1-.01-.428L11 34.688v-.647l.001-.915v-.985l.001-1.708.001-2.47a7645 7645 0 0 1 .003-7.9v-1.446l.005-9.987 1.458-.17q.247-.027.493-.057 1.247-.145 2.495-.285l.182-.021c1.25-.14 1.25-.14 1.628.07m1.036 13.614c-1.017 1.186-1.343 2.68-1.226 4.213.144 1.507.761 2.661 1.926 3.635 1.111.816 2.463.98 3.802.811 1.224-.227 2.197-.785 2.97-1.765.916-1.35 1.11-2.957.892-4.55-.174-.883-.6-1.756-1.233-2.403h-.168l-.06-.148c-.343-.59-1.22-.97-1.862-1.147-1.83-.449-3.735-.04-5.041 1.354",fill:"#212121"}))},desc:(0,l.__)("This addon lets you use Easy Accordion Gutenberg blocks in Bricks by generating reusable shortcodes from saved templates.","easy-accordion-free"),docLink:"https://easyaccordion.io/docs/page-builder-integrations/integrate-with-bricks/"},{id:4,key:"oxygen",label:"Oxygen",Icon:function(){return React.createElement("svg",{width:44,height:44,viewBox:"0 0 44 44",fill:"none",xmlns:"http://www.w3.org/2000/svg"},React.createElement("rect",{width:44,height:44,rx:6,fill:"url(#OxygenIntegrationIcona)"}),React.createElement("path",{d:"M35.718 22.078a13.718 13.718 0 1 0-7.553 12.177 4.778 4.778 0 0 0 7.4-4.008q0-1.618-.926-2.774c.771-1.696 1.08-3.545 1.08-5.395m-24.817 0a11.251 11.251 0 0 1 20.93-5.715 11.25 11.25 0 0 1 .959 9.414 4.778 4.778 0 0 0-6.32 6.628 11.252 11.252 0 0 1-15.568-10.327M30.787 33.33a3.238 3.238 0 1 1-1.404-6.321 3.238 3.238 0 0 1 1.404 6.321",fill:"#fff"}),React.createElement("defs",null,React.createElement("linearGradient",{id:"OxygenIntegrationIcona",x1:37.28,y1:40.574,x2:6.96,y2:3.741,gradientUnits:"userSpaceOnUse"},React.createElement("stop",{stopColor:"#2c1870"}),React.createElement("stop",{offset:1,stopColor:"#783fff"}))))},desc:(0,l.__)("This addon lets you use Easy Accordion Gutenberg blocks in Oxygen by generating reusable shortcodes from saved templates.","easy-accordion-free"),docLink:"https://easyaccordion.io/docs/page-builder-integrations/integrate-with-oxygen/"}];const lC=function(){return React.createElement("div",{className:"sp-eap-integrations-page"},React.createElement("div",{className:"eap-dashboard-page-header sp-d-flex sp-flex-col sp-gap-10px"},React.createElement("span",{className:"eap-dashboard-page-header__label"},(0,l.__)("Manage Integrations","easy-accordion-free")),React.createElement("span",{className:"eap-dashboard-page-header__desc"},"Enable only what you need. Keep your site lean, fast, and clutter-free.")),React.createElement(Nu,{items:iC,optionKey:"integrations"}),React.createElement("div",{className:"eap-dashboard-page-header eap-upcoming-modules"}),React.createElement(Nu,{items:sC,optionKey:"integrations",type:"page-builder"}))};var cC=function(){return React.createElement("svg",{xmlns:"http://www.w3.org/2000/svg",width:20,height:13,viewBox:"0 0 5 9",fill:"none"},React.createElement("path",{fillRule:"evenodd",clipRule:"evenodd",d:"M1.15403 0.865234L4.74524 4.81555L1.15403 8.76588L0.423828 8.10206L3.41156 4.81555L0.423829 1.52906L1.15403 0.865234Z",fill:"#757575"}))},uC=function(){return React.createElement("svg",{xmlns:"http://www.w3.org/2000/svg",width:20,height:13,viewBox:"0 0 5 9",fill:"none"},React.createElement("path",{fillRule:"evenodd",clipRule:"evenodd",d:"M4.26589 0.865234L0.674678 4.81555L4.26589 8.76588L4.99609 8.10206L2.00836 4.81555L4.99609 1.52906L4.26589 0.865234Z",fill:"#757575"}))},dC=function(){return React.createElement("svg",{xmlns:"http://www.w3.org/2000/svg",width:35,height:12,viewBox:"0 0 35 12",fill:"none"},React.createElement("path",{d:"M1.5 5.25a.75.75 0 0 0 0 1.5zm32.53 1.28a.75.75 0 0 0 0-1.06L29.257.697a.75.75 0 0 0-1.06 1.06L32.439 6l-4.242 4.243a.75.75 0 0 0 1.06 1.06zM1.5 6v.75h32v-1.5h-32z",fill:"#838487"}))},pC=function(){return React.createElement("svg",{width:16,height:15,viewBox:"0 0 16 15",fill:"none",xmlns:"http://www.w3.org/2000/svg"},React.createElement("path",{d:"M0 7.733 4.968 15h2.129L16 1.533 13.935 0l-8 9.467L2 5.733z",fill:"#fff"}))};function fC(e,t){(null==t||t>e.length)&&(t=e.length);for(var n=0,r=Array(t);n<t;n++)r[n]=e[n];return r}var mC=function(){return React.createElement("svg",{width:14,height:14,viewBox:"0 0 14 14",fill:"none",xmlns:"http://www.w3.org/2000/svg"},React.createElement("path",{d:"M11.376 6.139a.62.62 0 0 0-.622.622v4.5a.474.474 0 0 1-.474.473H2.156a.474.474 0 0 1-.474-.473V3.136c0-.261.213-.473.474-.473H8.82a.622.622 0 0 0 0-1.245H2.156A1.72 1.72 0 0 0 .437 3.136v8.125a1.72 1.72 0 0 0 1.719 1.718h8.124A1.72 1.72 0 0 0 12 11.26v-4.5a.62.62 0 0 0-.623-.622",fill:"#ff5b2e"}),React.createElement("path",{d:"M12.5 1.204 5.576 8.153l-1.78-1.786a.622.622 0 0 0-.881.88L4.893 9.23a.96.96 0 0 0 .684.285.96.96 0 0 0 .684-.285l7.12-7.147a.622.622 0 1 0-.882-.879",fill:"#ff5b2e"}))};const hC=function(){var e,t,n,r=function(e,t){return function(e){if(Array.isArray(e))return e}(e)||function(e,t){var n=null==e?null:"undefined"!=typeof Symbol&&e[Symbol.iterator]||e["@@iterator"];if(null!=n){var r,a,o,i,s=[],l=!0,c=!1;try{if(o=(n=n.call(e)).next,0===t){if(Object(n)!==n)return;l=!1}else for(;!(l=(r=o.call(n)).done)&&(s.push(r.value),s.length!==t);l=!0);}catch(e){c=!0,a=e}finally{try{if(!l&&null!=n.return&&(i=n.return(),Object(i)!==i))return}finally{if(c)throw a}}return s}}(e,t)||function(e,t){if(e){if("string"==typeof e)return fC(e,t);var n={}.toString.call(e).slice(8,-1);return"Object"===n&&e.constructor&&(n=e.constructor.name),"Map"===n||"Set"===n?Array.from(e):"Arguments"===n||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)?fC(e,t):void 0}}(e,t)||function(){throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.")}()}((0,i.useState)(!1),2),a=r[0],o=r[1],s=[{title:(0,l.__)("Vertical & Horizontal Accordion","easy-accordion-free")},{title:(0,l.__)("FAQ Search & Pagination","easy-accordion-free"),hot:!0},{title:(0,l.__)("Image and Accordion Slider","easy-accordion-free"),hot:!0},{title:(0,l.__)("FAQ Analytics & FAQ Form","easy-accordion-free")},{title:(0,l.__)("Post and Product Accordion","easy-accordion-free")},{title:(0,l.__)("Generate FAQs with AI","easy-accordion-free"),hot:!0},{title:(0,l.__)("Menu and Category Accordion","easy-accordion-free")},{title:(0,l.__)("Easy Customization Options","easy-accordion-free")}],c=(new Date).getHours(),u="Good Night";c>=5&&c<12?u="Good Morning":c>=12&&c<17?u="Good Afternoon":c>=17&&c<21&&(u="Good Evening");var d=null===(e=sp_eab_admin_dashboard_localize)||void 0===e?void 0:e.userName;return React.createElement("div",{className:"sp-eap-setup-welcome-page sp-d-flex sp-align-center"},React.createElement("div",{className:"sp-eap-setup-welcome-page-left sp-d-flex sp-flex-col"},React.createElement("div",{className:"sp-eap-setup-welcome-page-greeting"},u,", ",d),React.createElement("h3",{className:"sp-eap-setup-page-title sp-welcome-title"},"Welcome to ",React.createElement("span",null,"Easy Accordion!")),React.createElement("p",{className:"sp-eap-setup-page-desc"},"Thanks for installing Easy Accordion — This plugin gives you everything you need to create clean and interactive accordion sections, without touching a line of code."),React.createElement("p",{className:"sp-eap-setup-page-desc"},"Get set up in minutes and start showcasing accordions using",React.createElement("b",null," 15+ flexible blocks and 100+ ready-made patterns.")," Packed with features, including:"),React.createElement("div",{className:"sp-eap-setup-feature-lists sp-d-grid sp-grid-cols-2 sp-gap-10px"},null==s?void 0:s.map(function(e,t){return React.createElement("div",{key:t,className:"sp-eap-setup-feature-list sp-d-flex sp-align-center sp-gap-8px"},React.createElement("span",{className:"sp-eap-setup-feature-check-icon"},React.createElement(mC,null)),React.createElement("span",{className:"sp-eap-feature-list-title"},e.title,e.hot&&React.createElement("span",{className:"sp-eap-badge-hot"},"HOT"),e.upcoming&&React.createElement("span",{className:"sp-eap-badge-upcoming"},"Upcoming")))}))),React.createElement("div",{className:"sp-eap-setup-welcome-page-right sp-d-flex",style:{backgroundImage:"url(".concat(null===(t=sp_eab_admin_dashboard_localize)||void 0===t?void 0:t.pluginUrl,"admin/img/setup-wizard/video-thumbnail.png)")}},a?React.createElement("iframe",{width:"510",height:"410",src:"https://www.youtube.com/embed/videoseries?list=PLoUb-7uG-5jPNXkpGII8cTTfB-L4TCaqv&autoplay=1",title:"YouTube video player",allow:"autoplay; encrypted-media"}):React.createElement("div",{className:"sp-eap-setup-video-overlay sp-d-flex sp-align-center sp-justify-center"},React.createElement("button",{id:"sp-eap-play-btn",className:"sp-eap-play-btn-sonar sp-d-flex sp-align-center sp-justify-center sp-cursor-pointer",onClick:function(){return o(!0)}},React.createElement("img",{src:"".concat(null===(n=sp_eab_admin_dashboard_localize)||void 0===n?void 0:n.pluginUrl,"admin/img/setup-wizard/video-play.svg"),alt:"video-play"})))))},gC=function(){return React.createElement("div",{className:"sp-eap-setup-blocks-page"},React.createElement("div",{className:"sp-eap-setup-blocks-page-header sp-d-flex sp-align-center sp-justify-between sp-gap-10px sp-flex-col"},React.createElement("h3",{className:"sp-eap-setup-page-title"},(0,l.__)("Enable the Blocks You Need","easy-accordion-free")),React.createElement("p",{className:"sp-eap-setup-page-desc"},(0,l.__)("Turn on the blocks that match your workflow. You can update your selection anytime.","easy-accordion-free"))),React.createElement(ed,{showHeading:!1}))};var vC=function(e){var t=e.closeModal;return React.createElement(Uc.Modal,{title:(0,l.__)("What We Collect?","easy-accordion-free"),onRequestClose:t,className:"splw-setup-page-modal"},React.createElement("hr",null),React.createElement("p",{className:"modal-description"},(0,l.__)("We collect only non-sensitive diagnostic data and basic plugin usage information. This may include:","easy-accordion-free")),React.createElement("ul",null,React.createElement("li",{className:"modal-description"},(0,l.__)("WordPress & PHP version","easy-accordion-free")),React.createElement("li",{className:"modal-description"},(0,l.__)("Active theme and plugins","easy-accordion-free")),React.createElement("li",{className:"modal-description"},(0,l.__)("General system details","easy-accordion-free")),React.createElement("li",{className:"modal-description"},(0,l.__)("Email address only for sending helpful updates or optional offers.","easy-accordion-free"))),React.createElement("p",{className:"modal-description"},(0,l.__)("This information helps us improve performance, fix issues faster, and ensure Easy Accordion stays compatible with the popular plugins and themes.","easy-accordion-free")),React.createElement("p",{className:"modal-description sp-d-flex sp-align-center sp-gap-4px"},(0,l.__)("We","easy-accordion-free"),React.createElement("b",null,(0,l.__)("do not collect sensitive personal data,","easy-accordion-free")),(0,l.__)("and","easy-accordion-free"),React.createElement("b",null,(0,l.__)("never send spam","easy-accordion-free")),(0,l.__)("promise.","easy-accordion-free")),React.createElement("p",{className:"modal-description"},React.createElement("b",null,(0,l.__)("Your privacy comes first.","easy-accordion-free"))),React.createElement("a",{href:"https://easyaccordion.io/information-we-collect/",target:"_blank",className:"modal-description sp-d-flex sp-align-center sp-gap-4px",rel:"noreferrer"},(0,l.__)("Learn More","easy-accordion-free"),React.createElement(cc,null)))};function bC(){var e,t,n="function"==typeof Symbol?Symbol:{},r=n.iterator||"@@iterator",a=n.toStringTag||"@@toStringTag";function o(n,r,a,o){var l=r&&r.prototype instanceof s?r:s,c=Object.create(l.prototype);return yC(c,"_invoke",function(n,r,a){var o,s,l,c=0,u=a||[],d=!1,p={p:0,n:0,v:e,a:f,f:f.bind(e,4),d:function(t,n){return o=t,s=0,l=e,p.n=n,i}};function f(n,r){for(s=n,l=r,t=0;!d&&c&&!a&&t<u.length;t++){var a,o=u[t],f=p.p,m=o[2];n>3?(a=m===r)&&(l=o[(s=o[4])?5:(s=3,3)],o[4]=o[5]=e):o[0]<=f&&((a=n<2&&f<o[1])?(s=0,p.v=r,p.n=o[1]):f<m&&(a=n<3||o[0]>r||r>m)&&(o[4]=n,o[5]=r,p.n=m,s=0))}if(a||n>1)return i;throw d=!0,r}return function(a,u,m){if(c>1)throw TypeError("Generator is already running");for(d&&1===u&&f(u,m),s=u,l=m;(t=s<2?e:l)||!d;){o||(s?s<3?(s>1&&(p.n=-1),f(s,l)):p.n=l:p.v=l);try{if(c=2,o){if(s||(a="next"),t=o[a]){if(!(t=t.call(o,l)))throw TypeError("iterator result is not an object");if(!t.done)return t;l=t.value,s<2&&(s=0)}else 1===s&&(t=o.return)&&t.call(o),s<2&&(l=TypeError("The iterator does not provide a '"+a+"' method"),s=1);o=e}else if((t=(d=p.n<0)?l:n.call(r,p))!==i)break}catch(t){o=e,s=1,l=t}finally{c=1}}return{value:t,done:d}}}(n,a,o),!0),c}var i={};function s(){}function l(){}function c(){}t=Object.getPrototypeOf;var u=[][r]?t(t([][r]())):(yC(t={},r,function(){return this}),t),d=c.prototype=s.prototype=Object.create(u);function p(e){return Object.setPrototypeOf?Object.setPrototypeOf(e,c):(e.__proto__=c,yC(e,a,"GeneratorFunction")),e.prototype=Object.create(d),e}return l.prototype=c,yC(d,"constructor",c),yC(c,"constructor",l),l.displayName="GeneratorFunction",yC(c,a,"GeneratorFunction"),yC(d),yC(d,a,"Generator"),yC(d,r,function(){return this}),yC(d,"toString",function(){return"[object Generator]"}),(bC=function(){return{w:o,m:p}})()}function yC(e,t,n,r){var a=Object.defineProperty;try{a({},"",{})}catch(e){a=0}yC=function(e,t,n,r){function o(t,n){yC(e,t,function(e){return this._invoke(t,n,e)})}t?a?a(e,t,{value:n,enumerable:!r,configurable:!r,writable:!r}):e[t]=n:(o("next",0),o("throw",1),o("return",2))},yC(e,t,n,r)}function wC(e,t,n,r,a,o,i){try{var s=e[o](i),l=s.value}catch(e){return void n(e)}s.done?t(l):Promise.resolve(l).then(r,a)}function EC(e){return function(){var t=this,n=arguments;return new Promise(function(r,a){var o=e.apply(t,n);function i(e){wC(o,r,a,i,s,"next",e)}function s(e){wC(o,r,a,i,s,"throw",e)}i(void 0)})}}function RC(e,t){return function(e){if(Array.isArray(e))return e}(e)||function(e,t){var n=null==e?null:"undefined"!=typeof Symbol&&e[Symbol.iterator]||e["@@iterator"];if(null!=n){var r,a,o,i,s=[],l=!0,c=!1;try{if(o=(n=n.call(e)).next,0===t){if(Object(n)!==n)return;l=!1}else for(;!(l=(r=o.call(n)).done)&&(s.push(r.value),s.length!==t);l=!0);}catch(e){c=!0,a=e}finally{try{if(!l&&null!=n.return&&(i=n.return(),Object(i)!==i))return}finally{if(c)throw a}}return s}}(e,t)||function(e,t){if(e){if("string"==typeof e)return xC(e,t);var n={}.toString.call(e).slice(8,-1);return"Object"===n&&e.constructor&&(n=e.constructor.name),"Map"===n||"Set"===n?Array.from(e):"Arguments"===n||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)?xC(e,t):void 0}}(e,t)||function(){throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.")}()}function xC(e,t){(null==t||t>e.length)&&(t=e.length);for(var n=0,r=Array(t);n<t;n++)r[n]=e[n];return r}const AC=function(){var e,t,n,r,a="undefined"===(null===(e=sp_eab_admin_dashboard_localize)||void 0===e?void 0:e.eab_user_consent)||{0:!1,1:!0}[null===(t=sp_eab_admin_dashboard_localize)||void 0===t?void 0:t.eab_user_consent],o=RC((0,i.useState)(a),2),s=o[0],c=o[1],u=RC((0,i.useState)(!1),2),d=u[0],p=u[1],f=RC((0,i.useState)(!1),2),m=f[0],h=f[1],g=function(){var e=EC(bC().m(function e(){var t,n,r;return bC().w(function(e){for(;;)switch(e.p=e.n){case 0:return h(!0),e.p=1,t={shareData:s},(n=new FormData).append("action","sp_eap_get_user_consent"),n.append("nonce",sp_eab_admin_dashboard_localize.nonce),n.append("queryData",JSON.stringify(t)),e.n=2,Zl.post(ajaxurl,n);case 2:return e.a(2,{success:!0});case 3:return e.p=3,r=e.v,od((0,l.__)("Something Went Wrong","easy-accordion-free")),e.a(2,{success:!1,error:r});case 4:return e.p=4,h(!1),e.f(4);case 5:return e.a(2)}},e,null,[[1,3,4,5]])}));return function(){return e.apply(this,arguments)}}(),v=function(){var e=EC(bC().m(function e(){var t,n;return bC().w(function(e){for(;;)switch(e.n){case 0:return e.n=1,g();case 1:(t=e.v)&&t.success&&(window.location.href="".concat(null===(n=sp_eab_admin_dashboard_localize)||void 0===n?void 0:n.homeUrl,"wp-admin/admin.php?page=eap_dashboard"));case 2:return e.a(2)}},e)}));return function(){return e.apply(this,arguments)}}();return React.createElement("div",{className:"sp-eap-setup-finish-page sp-d-flex sp-flex-col sp-align-center sp-justify-center"},React.createElement("img",{src:"".concat(null===(n=sp_eab_admin_dashboard_localize)||void 0===n?void 0:n.pluginUrl,"/admin/img/setup-wizard/congratulations.svg"),alt:"Congratulations"}),React.createElement("h3",{className:"sp-eap-setup-page-title"},(0,l.__)("You’re Ready to Create FAQs & Accordions!","easy-accordion-free")),React.createElement("p",{className:"sp-eap-setup-page-desc",style:{width:"636px",textAlign:"center"}},(0,l.__)("Start building beautiful FAQs and dynamic accordions with Easy Accordion—no coding, just a smooth and efficient experience.","easy-accordion-free")),React.createElement("button",{className:"sp-eap-setup-wizard-nav-btn next-btn eap-setup-wizard-finish",onClick:v,disabled:m,"aria-busy":m},m?React.createElement(React.Fragment,null,React.createElement(Uc.Spinner,null)," ",(0,l.__)("Finishing…","easy-accordion-free")):(0,l.__)("Finish & Let’s Get Started","easy-accordion-free")),React.createElement("div",{className:"sp-eap-setup-finish-page-banner sp-d-flex sp-align-center sp-justify-between"},React.createElement("div",{className:"sp-eap-setup-finish-page-banner-left sp-d-flex sp-flex-col"},React.createElement("h3",{className:"sp-eap-setup-page-title"},(0,l.__)("Easily Create Beautiful FAQs and Accordions for Your Website","easy-accordion-free")),React.createElement("p",{className:"sp-eap-setup-page-desc"},React.createElement("span",{className:"sp-d-flex sp-align-center sp-gap-4px"},(0,l.__)("Trusted by","easy-accordion-free"),React.createElement("b",null,"100,000+"),(0,l.__)("users — Easy Accordion helps you","easy-accordion-free")),React.createElement("span",{className:"sp-d-block"},(0,l.__)("create clean, flexible layouts effortlessly.","easy-accordion-free"))),React.createElement("div",{className:"sp-eap-setup-wizard-button sp-d-flex sp-align-center sp-gap-8px"},React.createElement("a",{className:"sp-eap-setup-wizard-nav-btn prev-btn eab-pro-btn",href:"https://easyaccordion.io/pricing/?ref=1",target:"_blank",rel:"noreferrer"},React.createElement(gc,null),(0,l.__)("Upgrade to Pro!","easy-accordion-free")),React.createElement("a",{className:"sp-eap-setup-wizard-nav-btn prev-btn explore-button",href:"https://easyaccordion.io/patterns/",target:"_blank",rel:"noreferrer"},(0,l.__)("Explore All Patterns","easy-accordion-free"),React.createElement(pd,null)))),React.createElement("img",{src:"".concat(null===(r=sp_eab_admin_dashboard_localize)||void 0===r?void 0:r.pluginUrl,"/admin/img/setup-wizard/finish-page-banner.png"),alt:"finish-page-banner"})),React.createElement("div",{className:"spl-weather-checkbox-component-wrapper sp-d-flex sp-align-center"},React.createElement("p",{className:"sp-eap-setup-page-desc sp-d-flex sp-align-center sp-gap-4px"},(0,l.__)("Help us improve Easy Accordion and get useful tips by sharing non-sensitive diagnostic data. See","easy-accordion-free"),React.createElement("span",{className:"sp-eap-modal-btn",style:{fontWeight:"600",textDecoration:"underline"},onClick:function(){return p(!0)}},(0,l.__)("what we collect.","easy-accordion-free"))),React.createElement(Uc.CheckboxControl,{checked:s,onChange:function(){return c(!s)},__nextHasNoMarginBottom:!0})),d&&React.createElement(vC,{closeModal:function(){return p(!1)}}))};function CC(e,t){return function(e){if(Array.isArray(e))return e}(e)||function(e,t){var n=null==e?null:"undefined"!=typeof Symbol&&e[Symbol.iterator]||e["@@iterator"];if(null!=n){var r,a,o,i,s=[],l=!0,c=!1;try{if(o=(n=n.call(e)).next,0===t){if(Object(n)!==n)return;l=!1}else for(;!(l=(r=o.call(n)).done)&&(s.push(r.value),s.length!==t);l=!0);}catch(e){c=!0,a=e}finally{try{if(!l&&null!=n.return&&(i=n.return(),Object(i)!==i))return}finally{if(c)throw a}}return s}}(e,t)||function(e,t){if(e){if("string"==typeof e)return SC(e,t);var n={}.toString.call(e).slice(8,-1);return"Object"===n&&e.constructor&&(n=e.constructor.name),"Map"===n||"Set"===n?Array.from(e):"Arguments"===n||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)?SC(e,t):void 0}}(e,t)||function(){throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.")}()}function SC(e,t){(null==t||t>e.length)&&(t=e.length);for(var n=0,r=Array(t);n<t;n++)r[n]=e[n];return r}const kC=function(){var e,t,n=document.querySelector("#wpfooter");n&&(n.style.display="none");var r=(0,i.useRef)(null),a=CC((0,i.useState)(0),2),o=a[0],s=a[1],c=CC((0,i.useState)(!1),2),u=c[0],d=c[1],p=CC((0,i.useState)("left"),2),f=p[0],m=p[1],h=CC((0,i.useState)(""),2),g=h[0],v=h[1],b=["Welcome","Blocks","Finish"];return React.createElement("div",{className:"sp-eab-admin-dashboard-container"},React.createElement("div",{className:"sp-eap-setup-wizard-wrapper sp-d-flex sp-flex-col sp-align-center sp-justify-center"},React.createElement("div",{className:"sp-eap-setup-wizard-content sp-d-flex sp-flex-col sp-align-center sp-justify-center"},React.createElement("div",{className:"sp-eap-setup-steps"},null==b?void 0:b.map(function(e,t){return React.createElement("div",{key:t,className:"sp-eap-setup-step sp-d-flex sp-align-center"},React.createElement("span",{className:"sp-eap-setup-step-number sp-d-flex sp-align-center sp-justify-center".concat("".concat(t===o?" active":""),"".concat(t<o?" previous":""))},t<o?React.createElement(pC,null):"0"+(t+1)),React.createElement("span",{className:"sp-eap-setup-step-title"},e),t!==b.length-1&&React.createElement(dC,null))})),React.createElement("div",{className:"sp-eap-setup-step-page ".concat(g),onAnimationEnd:function(){u&&(s("left"===f?function(e){return e+1}:function(e){return e-1}),v("is-entering"),d(!1))}},"Welcome"===b[o]&&React.createElement(hC,null),"Blocks"===b[o]&&React.createElement(gC,null),"Finish"===b[o]&&React.createElement(AC,null)),React.createElement("div",{className:"sp-eap-setup-wizard-btn-wrapper sp-d-flex"},0!==o&&o!==b.length-1&&React.createElement("button",{className:"sp-eap-setup-wizard-nav-btn prev-btn",onClick:function(){m("right"),d(!0),v("is-exiting")}},React.createElement(uC,null),(0,l.__)("Previous","easy-accordion-free")),0===o&&React.createElement("a",{className:"sp-eap-setup-wizard-nav-btn prev-btn",href:"".concat(null===(e=sp_eab_admin_dashboard_localize)||void 0===e?void 0:e.homeUrl,"wp-admin/admin.php?page=eap_dashboard")},"Skip it"),o!==b.length-1&&React.createElement("button",{className:"sp-eap-setup-wizard-nav-btn next-btn",onClick:function(){m("left"),d(!0),v("is-exiting")},ref:r},(0,l.__)("Next Step","easy-accordion-free"),React.createElement(cC,null)))),React.createElement("img",{className:"setup-wizard-bg",src:"".concat(null===(t=sp_eab_admin_dashboard_localize)||void 0===t?void 0:t.pluginUrl,"admin/img/setup-wizard/setup-wizard-bg.svg"),alt:"setup wizard"}),React.createElement(se,{position:"top-right",toastOptions:{style:{padding:"16px 24px",fontSize:"18px",borderRadius:"10px",maxWidth:"400px"}}})))};var OC=function(){return React.createElement("svg",{xmlns:"http://www.w3.org/2000/svg",width:17,height:16,fill:"none"},React.createElement("path",{fill:"#6E6A69",d:"M16.5 8c0-4.408-3.592-8-8-8-4.416 0-8 3.592-8 8 0 4.416 3.584 8 8 8 4.408 0 8-3.584 8-8Zm-9.776 4.296-2.728-7.32c.44-.016.936-.064.936-.064.4-.048.352-.904-.048-.888 0 0-1.16.088-1.896.088-.144 0-.296 0-.464-.008A7.097 7.097 0 0 1 8.5.888c1.864 0 3.56.696 4.84 1.872-.544-.088-1.32.312-1.32 1.264 0 .592.36 1.088.72 1.68.28.488.44 1.088.44 1.968 0 1.192-1.12 4-1.12 4L9.636 4.976c.432-.016.656-.136.656-.136.4-.04.352-1-.048-.976 0 0-1.152.096-1.904.096-.696 0-1.864-.096-1.864-.096-.4-.024-.448.96-.048.976l.736.064 1.008 2.728-1.448 4.664ZM14.428 8c.192-.512.592-1.496.344-3.4.56 1.032.84 2.168.84 3.4 0 2.632-1.384 4.992-3.52 6.224.776-2.072 1.552-4.16 2.336-6.224ZM5.38 14.472C2.996 13.32 1.388 10.824 1.388 8c0-1.04.184-1.984.576-2.872C3.1 8.24 4.236 11.36 5.38 14.472Zm3.224-5.304 2.064 5.584a6.734 6.734 0 0 1-2.168.36 6.301 6.301 0 0 1-1.832-.264c.648-1.904 1.296-3.792 1.936-5.68Z"}))},PC=function(e){var t=e.color,n=void 0===t?"#F4674D":t;return React.createElement("svg",{width:16,height:15,viewBox:"0 0 16 15",fill:"none",xmlns:"http://www.w3.org/2000/svg"},React.createElement("path",{d:"M7.70547 0L9.84795 5.15113L15.409 5.59696L11.1721 9.22637L12.4665 14.653L7.70547 11.745L2.94441 14.653L4.23887 9.22637L0.00191116 5.59696L5.56299 5.15113L7.70547 0Z",fill:n}))},MC=function(){return React.createElement("svg",{width:17,height:17,viewBox:"0 0 17 17",fill:"none",xmlns:"http://www.w3.org/2000/svg"},React.createElement("path",{d:"m8.1 0 2.143 5.151 5.56.446-4.236 3.63 1.294 5.426L8.1 11.745l-4.761 2.908 1.294-5.427L.396 5.597l5.562-.446z",fill:"#e0e0e0"}),React.createElement("path",{d:"m8.1 0-2.142 5.151-5.562.446 4.236 3.63-1.294 5.426L8.1 11.745V0z",fill:"#f4674d"}))},IC=function(){return React.createElement("svg",{width:"21",height:"20",viewBox:"0 0 21 20",fill:"none",xmlns:"http://www.w3.org/2000/svg"},React.createElement("path",{d:"m10.5 15.252 4.563-1.164L16.969 20zM21 7.61h-8.031L10.5 0 8.031 7.61H0l6.5 4.717-2.469 7.61 6.5-4.717 4-2.893z",fill:"#00b57a"}))},TC=[{title:(0,l.__)("All Core Plugin Features","easy-accordion-free"),free:"yes",pro:"yes"},{title:(0,l.__)("Advanced Gutenberg Accordion Blocks","easy-accordion-free"),free:7,pro:15,new:!0,hot:!0},{title:(0,l.__)("Pre-Made Templates (Vertical, Horizontal, Slider, etc.)","easy-accordion-free"),free:7,pro:25},{title:(0,l.__)("Ready-to-use Rich Accordion Patterns Library","easy-accordion-free"),free:"yes",pro:"yes"},{title:(0,l.__)("Reusable Saved Templates","easy-accordion-free"),free:"yes",pro:"yes"},{title:(0,l.__)("WooCommerce Custom FAQ Tab (Per Product & Category)","easy-accordion-free"),free:"no",pro:"yes"},{title:(0,l.__)("Stunning Vertical Q & A, Timeline, Numbered & Multi Shaped Templates ","easy-accordion-free"),free:"no",pro:"yes",hot:!0},{title:(0,l.__)("Striking Horizontal & Vertical Image Accordion","easy-accordion-free"),free:"yes",pro:"yes"},{title:(0,l.__)("Dynamic Accordion Slider with Image Hover Effects","easy-accordion-free"),free:"no",pro:"yes",new:!0,hot:!0},{title:(0,l.__)("Display Posts and Products in FAQ Accordion Blocks","easy-accordion-free"),free:"yes",pro:"yes",hot:!0},{title:(0,l.__)("Create FAQs in compact Sidebar Tab Accordion","easy-accordion-free"),free:"yes",pro:"yes"},{title:(0,l.__)("Create an Accordion with Taxonomy or WordPress Menu  (Upcoming)","easy-accordion-free"),free:"yes",pro:"yes"},{title:(0,l.__)("Collect Queries using FAQ Forms (Upcoming)","easy-accordion-free"),free:"yes",pro:"yes",new:!0},{title:(0,l.__)("Create Unlimited Multi-level / Nested Accordion","easy-accordion-free"),free:"yes",pro:"yes",hot:!0},{title:(0,l.__)("Create, Edit & Delete FAQs as Needed","easy-accordion-free"),free:"yes",pro:"yes"},{title:(0,l.__)("Schema FAQs Markup Supported","easy-accordion-free"),free:"yes",pro:"yes",hot:!0},{title:(0,l.__)("Get Real-time FAQs Analytics Data","easy-accordion-free"),free:"no",pro:"yes",hot:!0},{title:(0,l.__)("Accordion Expand & Collapse Toggle Icon Styles","easy-accordion-free"),free:8,pro:16},{title:(0,l.__)("Accordion Expand/Collapse All Button","easy-accordion-free"),free:"no",pro:"yes",hot:!0},{title:(0,l.__)("Live AJAX FAQs Search Bar","easy-accordion-free"),free:"no",pro:"yes",hot:!0},{title:(0,l.__)("Dynamic Navigation Arrow (10 Styles)","easy-accordion-free"),free:"no",pro:"yes"},{title:(0,l.__)("Multiple AJAX Paginations (Load More, Infinite Scroll, Number, etc.)","easy-accordion-free"),free:"no",pro:"yes"},{title:(0,l.__)("Image Flip & Custom Focal Point","easy-accordion-free"),free:"no",pro:"yes",new:!0,hot:!0},{title:(0,l.__)("Advanced Image Lightbox (15+ Icon Styles)","easy-accordion-free"),free:"no",pro:"yes"},{title:(0,l.__)("Upload Custom or Featured Icon from Rich Icon Library","easy-accordion-free"),free:"no",pro:"yes"},{title:(0,l.__)("Control Accordion Items Expanded Area Width","easy-accordion-free"),free:"no",pro:"yes",new:!0},{title:(0,l.__)("Dynamic Activator Events (On Click, Hover, AutoPlay)","easy-accordion-free"),free:"yes",pro:"yes"},{title:(0,l.__)("Initial Accordion Display (Single, Multiple, Selected)","easy-accordion-free"),free:"yes",pro:"yes"},{title:(0,l.__)("20+ Animation Effects for Accordion Content","easy-accordion-free"),free:"no",pro:"yes"},{title:(0,l.__)("25+ Entrance Animations Effects","easy-accordion-free"),free:"no",pro:"yes"},{title:(0,l.__)("Interactive Vertical Scrolling Effects","easy-accordion-free"),free:"no",pro:"yes"},{title:(0,l.__)("Accordion Item Anchor Links (Title / ID)","easy-accordion-free"),free:"no",pro:"yes",hot:!0},{title:(0,l.__)("Make Horizontal Accordion in Vertical on Mobile","easy-accordion-free"),free:"no",pro:"yes",new:!0},{title:(0,l.__)("Reduce Long Scrolling with Close Button","easy-accordion-free"),free:"no",pro:"yes",hot:!0},{title:(0,l.__)("Disable / Inactive Specific Accordion Item","easy-accordion-free"),free:"no",pro:"yes"},{title:(0,l.__)("Add Subtitle & Featured Icon","easy-accordion-free"),free:"no",pro:"yes",new:!0},{title:(0,l.__)("Add Prefix & Suffix to Accordion Title","easy-accordion-free"),free:"no",pro:"yes",hot:!0},{title:(0,l.__)("Enable Custom Title Linking","easy-accordion-free"),free:"no",pro:"yes"},{title:(0,l.__)("Display posts from Posts, Pages, Media & Custom Post Types","easy-accordion-free"),free:"no",pro:"yes"},{title:(0,l.__)("Advanced Post and Product Query Builder","easy-accordion-free"),free:"no",pro:"yes"},{title:(0,l.__)("Powerful Frontend Taxonomy Filter (Button, List)","easy-accordion-free"),free:"no",pro:"yes",new:!0},{title:(0,l.__)("Show WooCommerce Product Meta Data","easy-accordion-free"),free:"no",pro:"yes"},{title:(0,l.__)("Show Post Meta Data","easy-accordion-free"),free:"yes",pro:"yes"},{title:(0,l.__)("Link Posts and Products to the Single Pages","easy-accordion-free"),free:"no",pro:"yes"},{title:(0,l.__)("Import / Export Accordion FAQs","easy-accordion-free"),free:"yes",pro:"yes"},{title:(0,l.__)("All Premium Features, Security Enhancements & Compatibility","easy-accordion-free"),free:"no",pro:"yes"},{title:(0,l.__)("Multisite Compatible","easy-accordion-free"),free:"yes",pro:"yes"},{title:(0,l.__)("Priority Top-Notch Support","easy-accordion-free"),free:"no",pro:"yes"}],_C=[{text:(0,l.__)("Just wanted to drop a quick note to confirm that not only does the plugin operate as well as – if not better then – you’d expect from the description and other reviews here, but also they have o...","easy-accordion-free"),user:"wordpress",name:"Michael Kastler",role:"Managing Director, Newbe Marketing",img:"/admin/img/michael.png"},{text:(0,l.__)("My colleagues are very impressed with the result of the multiple accordion. Just what we needed:-) Very useful having the video tutorial, many alternatives don’t. However there is a piece missing from...","easy-accordion-free"),user:"wordpress",name:"Joel Roberts",role:"Web Developer",img:"/admin/img/joel.png"},{text:(0,l.__)("Nice, simple plugin with a few useful extra options in the Pro version. However, it is the service/support that needs a special mention. I got prompt and helpful replies within a few hours (allowing for...","easy-accordion-free"),user:"trustpilot",name:"Richard Joss",role:"Freelancer, Upwork",img:"/admin/img/richard.png"}],NC=function(e){return"number"==typeof e?React.createElement("b",null,e):"yes"===e?React.createElement("i",{className:"dashicons dashicons-saved"}):"no"===e?React.createElement("i",{className:"dashicons dashicons-no-alt"}):e};const LC=function(){return React.createElement("section",{className:"sp-eab-pro-page",id:"lite-pro-tab"},React.createElement("div",{className:"sp-eab-pro-table"},React.createElement("div",{className:"sp-eab-pro-header"},React.createElement("div",null,React.createElement("h2",{className:"sp-eab-section-title"},(0,l.__)("Lite vs Pro Comparison","easy-accordion-free")),React.createElement("span",{className:"sp-eab-pro-subtitle"},(0,l.__)("Get Easy Accordion Pro Today and Unlock all the Powerful Features","easy-accordion-free"))),React.createElement("a",{target:"_blank",rel:"noreferrer",href:"https://easyaccordion.io/pricing/?ref=1",className:"sp-eab-upgrade-to-pro-btn"},(0,l.__)("Upgrade to Pro Now!","easy-accordion-free"))),React.createElement("div",{className:"sp-eab-pro-table-list"},React.createElement("ul",null,React.createElement("li",{className:"sp-eab-pro-table-row sp-eab-header"},React.createElement("span",{className:"sp-eab-title"},(0,l.__)("FEATURES","easy-accordion-free")),React.createElement("span",{className:"sp-eab-free"},(0,l.__)("LITE","easy-accordion-free")),React.createElement("span",{className:"sp-eab-pro sp-eab-pro-icon"},React.createElement(gc,null),(0,l.__)("PRO","easy-accordion-free"))),TC.map(function(e,t){return React.createElement("li",{className:"sp-eab-pro-table-row",key:t},React.createElement("span",{className:"sp-eab-title"},null==e?void 0:e.title,(null==e?void 0:e.info)&&React.createElement(Zc,{text:null==e?void 0:e.info}),(null==e?void 0:e.video)&&React.createElement("span",{className:"sp-eab-settings-info"},React.createElement("span",{className:"sp-eab-settings-info-text"})),(null==e?void 0:e.new)&&React.createElement("span",{className:"sp-eab-new"},(0,l.__)("new","easy-accordion-free")),(null==e?void 0:e.hot)&&React.createElement("span",{className:"sp-eab-hot"},(0,l.__)("hot","easy-accordion-free"))),React.createElement("span",{className:"sp-eab-free"},NC(null==e?void 0:e.free)),React.createElement("span",{className:"sp-eab-pro"},NC(null==e?void 0:e.pro)))})))),React.createElement("div",{className:"sp-eab-upgrade-to-pro-promotion"},React.createElement("h2",{className:"sp-eab-section-title"},(0,l.__)("Upgrade To PRO & Enjoy Advanced Features!","easy-accordion-free")),React.createElement("span",{className:"sp-eab-section-subtitle"},(0,l.__)("Already, ","easy-accordion-free"),React.createElement("b",null,(0,l.__)("100,000+","easy-accordion-free")),(0,l.__)(" people are using Easy Accordion on their websites to create beautiful showcase, why won't you!","easy-accordion-free")),React.createElement("div",{className:"sp-eab-upgrade-to-pro-btn-wrapper"},React.createElement("a",{target:"_blank",rel:"noreferrer",href:"https://easyaccordion.io/pricing/?ref=1",className:"sp-eab-upgrade-to-pro-btn"},(0,l.__)("Upgrade to Pro Now!","easy-accordion-free")),React.createElement("a",{target:"_blank",rel:"noreferrer",href:"https://easyaccordion.io/",className:"sp-eab-upgrade-to-pro-btn"},(0,l.__)("See All Features","easy-accordion-free")))),React.createElement("div",{className:"sp-eab-testimonial"},React.createElement("div",{className:"sp-eab-testimonial-header"},React.createElement("div",{className:"sp-eab-testimonial-ratings"},React.createElement("a",{href:"https://wordpress.org/support/plugin/easy-accordion-free/reviews/",target:"_blank",rel:"noreferrer",className:"sp-eab-testimonial-rating-item",title:"Reviews on WordPress"},React.createElement("div",{className:"sp-eab-testimonial-rating-wordpress"},React.createElement("div",{className:"sp-eab-wp-mark"},React.createElement(OC,null)),React.createElement("div",{className:"sp-eab-wp-text"},React.createElement(PC,null),React.createElement(PC,null),React.createElement(PC,null),React.createElement(PC,null),React.createElement(MC,null))),React.createElement("span",{className:"sp-eab-testimonial-rating-score"},"4.5/5"),React.createElement("span",{className:"sp-eab-testimonial-review-count"},"350+ Reviews")),React.createElement("a",{href:"https://www.trustpilot.com/review/shapedplugin.com",target:"_blank",rel:"noreferrer",className:"sp-eab-testimonial-rating-item",title:"Reviews on Trustpilot"},React.createElement("div",{className:"sp-eab-testimonial-rating-trustpilot"},React.createElement("div",{className:"sp-eab-trustpilot-mark"},React.createElement(IC,null))),React.createElement("div",{className:"sp-eab-trustpilot-stars"},React.createElement(PC,{color:"#fff"}),React.createElement(PC,{color:"#fff"}),React.createElement(PC,{color:"#fff"}),React.createElement(PC,{color:"#fff"}),React.createElement(PC,{color:"#fff"})),React.createElement("span",{className:"sp-eab-testimonial-rating-score"},"4.9/5"),React.createElement("span",{className:"sp-eab-testimonial-review-count"},"130+ Reviews"))),React.createElement("h2",{className:"sp-eab-testimonial-title"},(0,l.__)("Don't Just Take Our Word for It — See What Users Say!","easy-accordion-free"))),React.createElement("div",{className:"sp-eab-testimonial-wrap"},null==_C?void 0:_C.map(function(e,t){var n;return React.createElement("div",{className:"sp-eab-testimonial-card ".concat("trustpilot"===(null==e?void 0:e.user)?"sp-eab-testimonial-card-trustpilot":""),key:t},React.createElement("div",{className:"sp-eab-testimonial-card-header"},React.createElement("div",{className:"sp-eab-testimonial-reviewer"},React.createElement("div",{className:"sp-eab-testimonial-avatar"},"trustpilot"===(null==e?void 0:e.user)?React.createElement("div",{className:"sp-eab-testimonial-avatar-initials"},React.createElement("span",null,e.name.slice(0,2).toUpperCase())):React.createElement("img",{src:"".concat(null===(n=sp_eab_admin_dashboard_localize)||void 0===n?void 0:n.pluginUrl).concat(null==e?void 0:e.img),alt:null==e?void 0:e.name}),React.createElement("div",{className:"sp-eab-testimonial-source-badge"},"trustpilot"===(null==e?void 0:e.user)?React.createElement(IC,null):React.createElement(OC,null))),React.createElement("div",{className:"sp-eab-testimonial-reviewer-info"},React.createElement("h3",null,e.name),React.createElement("p",null,e.role)))),React.createElement("div",{className:"sp-eab-testimonial-rating-stars"},"trustpilot"===(null==e?void 0:e.user)?React.createElement("div",{className:"sp-eab-testimonial-rating-trustpilot-stars"},React.createElement("span",{className:"sp-eab-trustpilot-star-item"},React.createElement(PC,{color:"#fff"})),React.createElement("span",{className:"sp-eab-trustpilot-star-item"},React.createElement(PC,{color:"#fff"})),React.createElement("span",{className:"sp-eab-trustpilot-star-item"},React.createElement(PC,{color:"#fff"})),React.createElement("span",{className:"sp-eab-trustpilot-star-item"},React.createElement(PC,{color:"#fff"})),React.createElement("span",{className:"sp-eab-trustpilot-star-item"},React.createElement(PC,{color:"#fff"}))):React.createElement("span",null,"★★★★★")),React.createElement("div",{className:"sp-eab-testimonial-card-content"},React.createElement("p",null,null==e?void 0:e.text)))}))))};var DC=function(){return React.createElement("svg",{width:48,height:48,viewBox:"0 0 48 48",fill:"none",xmlns:"http://www.w3.org/2000/svg"},React.createElement("path",{fill:"#641dd7",d:"M0 0h48v48H0z"}),React.createElement("path",{d:"M8.4 27.997a2.44 2.44 0 0 1 2.438-2.437h9.165a2.437 2.437 0 0 1 2.437 2.437v9.165a2.437 2.437 0 0 1-2.437 2.438h-9.165A2.44 2.44 0 0 1 8.4 37.162zM25.56 15.42a7.02 7.02 0 1 1 14.04 0 7.02 7.02 0 0 1-14.04 0M8.4 10.837A2.44 2.44 0 0 1 10.838 8.4h9.165a2.437 2.437 0 0 1 2.437 2.437v9.165a2.437 2.437 0 0 1-2.437 2.438h-9.165A2.44 2.44 0 0 1 8.4 20.002z",fill:"#fff"}),React.createElement("rect",{x:25.561,y:36.48,width:14.04,height:2.08,rx:1.04,fill:"#fff"}),React.createElement("rect",{x:25.561,y:26.6,width:14.04,height:2.08,rx:1.04,fill:"#fff"}),React.createElement("rect",{x:25.561,y:31.28,width:14.04,height:2.08,rx:1.04,fill:"#fff"}))},BC=function(){return React.createElement("svg",{width:48,height:48,viewBox:"0 0 48 48",fill:"none",xmlns:"http://www.w3.org/2000/svg"},React.createElement("path",{fill:"url(#tabsLogoIcon)",d:"M0 0h48v48H0z"}),React.createElement("path",{d:"M40.077 10.5H7.875c-.498 0-.9.402-.9.9v25.194c0 .504.402.9.9.9h32.202c.504 0 .9-.402.9-.9V11.4c0-.504-.402-.9-.9-.9m-3.198 8.19H31.28v-4.098h5.598zm-14.508 0v-4.098h4.902v4.098zM11.079 33.396V14.598h7.302v7.194c0 .504.402.9.9.9h17.604v10.71H11.079z",fill:"#fff"}),React.createElement("defs",null,React.createElement("linearGradient",{id:"tabsLogoIcon",x1:-1.225,y1:0,x2:51.903,y2:9.999,gradientUnits:"userSpaceOnUse"},React.createElement("stop",{stopColor:"#1a689c"}),React.createElement("stop",{offset:.837,stopColor:"#2eba90"}))))},FC=function(){return React.createElement("svg",{width:48,height:48,viewBox:"0 0 48 48",fill:"none",xmlns:"http://www.w3.org/2000/svg"},React.createElement("path",{d:"M44.97 0H3.03A3.03 3.03 0 0 0 0 3.03v41.94A3.03 3.03 0 0 0 3.03 48h41.94A3.03 3.03 0 0 0 48 44.97V3.03A3.03 3.03 0 0 0 44.97 0",fill:"url(#wp-carousel)"}),React.createElement("g",{opacity:.9,fill:"#fff"},React.createElement("path",{opacity:.9,d:"m32.178 25.533-3.898-4.865 2.385-1.867 3.898 4.824z"}),React.createElement("path",{opacity:.9,d:"m30.665 28.463-2.344-1.88 3.898-4.866 2.344 1.908zm-14.527-2.93-2.385-1.908L17.65 18.8l2.37 1.867z"}),React.createElement("path",{opacity:.9,d:"m17.65 28.463-3.897-4.838 2.344-1.908 3.884 4.865z"}),React.createElement("path",{opacity:.9,d:"M41.568 37.171H6.748V10.065h34.82zm-30.895-3.925h26.97V14.004h-26.97z"})),React.createElement("defs",null,React.createElement("linearGradient",{id:"wp-carousel",x1:.891,y1:47.108,x2:47.122,y2:.878,gradientUnits:"userSpaceOnUse"},React.createElement("stop",{stopColor:"#197893"}),React.createElement("stop",{offset:1,stopColor:"#1fa8b5"}))))},zC=function(){return React.createElement("svg",{width:48,height:48,viewBox:"0 0 48 48",fill:"none",xmlns:"http://www.w3.org/2000/svg",xmlnsXlink:"http://www.w3.org/1999/xlink"},React.createElement("path",{fill:"url(#woo-gallery-logo-icon)",d:"M0 0h48v48H0z"}),React.createElement("defs",null,React.createElement("pattern",{id:"woo-gallery-logo-icon",patternContentUnits:"objectBoundingBox",width:1,height:1},React.createElement("use",{xlinkHref:"#woo-gallery",transform:"scale(.0039)"})),React.createElement("image",{id:"woo-gallery",width:256,height:256,preserveAspectRatio:"none",xlinkHref:"data:image/png;base64, "})))},jC=function(){return React.createElement("svg",{width:48,height:48,viewBox:"0 0 48 48",fill:"none",xmlns:"http://www.w3.org/2000/svg",xmlnsXlink:"http://www.w3.org/1999/xlink"},React.createElement("path",{fill:"url(#logo-carousel)",d:"M0 0h48v48H0z"}),React.createElement("defs",null,React.createElement("pattern",{id:"logo-carousel",patternContentUnits:"objectBoundingBox",width:1,height:1},React.createElement("use",{xlinkHref:"#logo-carousel-b",transform:"scale(.0039)"})),React.createElement("image",{id:"logo-carousel-b",width:256,height:256,preserveAspectRatio:"none",xlinkHref:"data:image/png;base64, "})))},HC=function(){return React.createElement("img",{src:"https://shapedplugin.com/wp-content/uploads/edd/2022/08/real-testimonials.png"})},VC=function(){return React.createElement("img",{src:"https://shapedplugin.com/wp-content/uploads/edd/2022/08/woo-product-slider.png"})},GC=function(){return React.createElement("img",{src:"https://shapedplugin.com/wp-content/uploads/edd/2022/08/woo-category-slider.png"})},qC=function(){return React.createElement("img",{src:"https://shapedplugin.com/wp-content/uploads/edd/2024/07/Smart-Swatch-Icon.png"})},UC=function(){return React.createElement("img",{src:"https://shapedplugin.com/wp-content/uploads/edd/2022/08/wp-team.png"})},WC=function(){return React.createElement("img",{src:"https://shapedplugin.com/wp-content/uploads/edd/2023/05/smart-brands.png"})},QC=function(){return React.createElement("img",{alt:"Location Weather",src:"https://shapedplugin.com/wp-content/uploads/edd/2022/08/Location-Weather.png"})},KC=[{name:"WP Carousel",description:"The most powerful and user-friendly multi-purpose carousel, slider, & gallery plugin for WordPress.",url:"https://wpcarousel.io/",icon:React.createElement(FC,null)},{name:"Real Testimonial",description:"Simply collect, manage, and display Testimonials on your website and boost conversions.",url:"https://realtestimonials.io/",icon:React.createElement(HC,null)},{name:"Smart Tabs",description:"Best WooCommerce Custom Product Tabs & WordPress Tabs Builder Plugin to create responsive tabs.",url:"https://wptabs.com/",icon:React.createElement(BC,null)},{name:"Smart Post",description:"Filter and display posts (any post types), pages, taxonomy, custom taxonomy, and custom field, in beautiful layouts.",url:"https://wpsmartpost.com/",icon:React.createElement(DC,null)},{name:"Smart Team",description:"Simply collect, manage, and display Testimonials on your website and boost conversions.",url:"https://getwpteam.com/",icon:React.createElement(UC,null)},{name:"Logo Carousel",description:"Showcase a group of logo images with Title, Description, Tooltips, Links, and Popup as a grid or in a carousel.",url:"https://logocarousel.com/",icon:React.createElement(jC,null)},{name:"Location Weather",description:"Display beautiful weather update widgets to your WordPress site in a minute without coding skills!",url:"https://locationweather.io/",icon:React.createElement(QC,null)},{name:"WooGallery",description:"Product gallery slider and additional variation images gallery for WooCommerce and boost your sales.",url:"https://woogallery.io/",icon:React.createElement(zC,null)},{name:"Product Slider for WooCommerce",description:"Boost sales by interactive product Slider, Grid, and Table in your WooCommerce website or store.",url:"https://wooproductslider.io/",icon:React.createElement(VC,null)},{name:"WooCategory",description:"Display by filtering the list of categories aesthetically and boosting sales.",url:"https://shapedplugin.com/woocategory/",icon:React.createElement(GC,null)},{name:"Smart Swatches",description:"Smart Swatches is a Best Product Variation Swatches for WooCommerce to Boost Your Store Sales.",url:"https://shapedplugin.com/smart-swatches-for-woocommerce",icon:React.createElement(qC,null)},{name:"Smart Brands",description:"Smart Brands for WooCommerce Pro helps you display product brands in an attractive way on your online store.",url:"https://shapedplugin.com/smart-brands/",icon:React.createElement(WC,null)}];const ZC=function(){var e;return React.createElement("section",{id:"about-us-tab",className:"sp-eab-about-page"},React.createElement("div",{className:"sp-eab-about-box"},React.createElement("div",{className:"sp-eab-about-info"},React.createElement("h3",null,(0,l.__)("The Most Powerful Accordion and FAQs Builder plugin for WordPress from the ","easy-accordion-free"),React.createElement("span",{className:"sp-eab-highlight-text"},(0,l.__)("ShapedPlugin Team","easy-accordion-free"))),React.createElement("p",null,(0,l.__)("At","easy-accordion-free")," ",React.createElement("b",null,(0,l.__)("ShapedPlugin LLC,","easy-accordion-free"))," ",(0,l.__)("we have been looking for the best way to create FAQ pages or sections on WordPress sites. Unfortunately, we couldn't find any suitable plugin that met our needs. Hence, we set a simple goal: to develop a highly customizable and full-featured Accordion and FAQs builder plugin to minimize customer support costs.","easy-accordion-free")," ",(0,l.__)("The Easy Accordion plugin provides a convenient way to create visually appealing FAQ pages to reduce customer costs. Check it out now and experience the difference!","easy-accordion-free")),React.createElement("div",{className:"sp-eab-video-section-btn"},React.createElement("ul",null,React.createElement("li",null,React.createElement("a",{target:"_blank",rel:"noreferrer",href:"https://easyaccordion.io/",className:"sp-eab-medium-btn"},(0,l.__)("Explore Easy Accordion","easy-accordion-free"))),React.createElement("li",null,React.createElement("a",{target:"_blank",rel:"noreferrer",href:"https://shapedplugin.com/about-us/",className:"sp-eab-medium-btn sp-eab-arrow-btn"},(0,l.__)("More About Us ","easy-accordion-free")," ",React.createElement(cc,null)))))),React.createElement("div",{className:"sp-eab-about-img"},React.createElement("img",{src:"".concat(null===(e=sp_eab_admin_dashboard_localize)||void 0===e?void 0:e.pluginUrl,"admin/img/shapedplugin-team.jpg"),alt:"Team",height:"402",width:"610"}),React.createElement("span",null,(0,l.__)("The Creative Minds Behind the Easy Accordion Plugin","easy-accordion-free")))),React.createElement("div",{className:"sp-eab-more-plugins-section"},React.createElement("div",{className:"sp-eab-more-plugins-header"},React.createElement("h2",{className:"sp-eab-more-plugins-title"},(0,l.__)("Your Website Deserves More Than Typical — Go Premium Today!","easy-accordion-free")),React.createElement("p",{className:"sp-eab-more-plugins-subtitle"},(0,l.__)("Unlock powerful plugins built to boost performance, elevate design, and grow your business.","easy-accordion-free"))),React.createElement("div",{className:"sp-eab-more-plugins-grid"},KC.map(function(e){return React.createElement("a",{key:e.name,href:e.url,target:"_blank",rel:"noopener noreferrer",className:"sp-eab-plugin-card"},React.createElement("div",{className:"sp-eab-plugin-card-icon"},e.icon),React.createElement("div",{className:"sp-eab-plugin-card-content"},React.createElement("h3",{className:"sp-eab-plugin-card-title"},e.name),React.createElement("p",{className:"sp-eab-plugin-card-desc"},e.description)),React.createElement("span",{className:"sp-eab-plugin-card-arrow"},React.createElement(uc,null)))}))))};function JC(e,t){(null==t||t>e.length)&&(t=e.length);for(var n=0,r=Array(t);n<t;n++)r[n]=e[n];return r}const XC=function(){var e,t=null===(e=window.location)||void 0===e||null===(e=e.hash)||void 0===e||null===(e=e.replace("#",""))||void 0===e?void 0:e.split("=")[0],n=document.querySelector(".eab-recommended-plugins-wrapper");!function(e){var t,n=document.getElementById("menu-posts-sp_easy_accordion");if(n){n.querySelectorAll("li").forEach(function(e){return e.classList.remove("current")});var r="getting-start"===e||""===e?'li a[href="edit.php?post_type=sp_easy_accordion&page=eap_dashboard"]':'li a[href*="#'.concat(e,'"]');null===(t=n.querySelector(r))||void 0===t||null===(t=t.closest("li"))||void 0===t||t.classList.add("current")}}(t);var r=function(e,t){return function(e){if(Array.isArray(e))return e}(e)||function(e,t){var n=null==e?null:"undefined"!=typeof Symbol&&e[Symbol.iterator]||e["@@iterator"];if(null!=n){var r,a,o,i,s=[],l=!0,c=!1;try{if(o=(n=n.call(e)).next,0===t){if(Object(n)!==n)return;l=!1}else for(;!(l=(r=o.call(n)).done)&&(s.push(r.value),s.length!==t);l=!0);}catch(e){c=!0,a=e}finally{try{if(!l&&null!=n.return&&(i=n.return(),Object(i)!==i))return}finally{if(c)throw a}}return s}}(e,t)||function(e,t){if(e){if("string"==typeof e)return JC(e,t);var n={}.toString.call(e).slice(8,-1);return"Object"===n&&e.constructor&&(n=e.constructor.name),"Map"===n||"Set"===n?Array.from(e):"Arguments"===n||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)?JC(e,t):void 0}}(e,t)||function(){throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.")}()}((0,i.useState)(t||"getting-start"),2),a=r[0],o=r[1];(0,i.useEffect)(function(){"our_plugins"===t&&n&&(n.style.display="block");var e=document.getElementById("menu-posts-sp_easy_accordion"),r=e.querySelectorAll("li"),a=function(e){var t=e.target.closest("li");r.forEach(function(e){e.classList.remove("current")}),t.classList.add("current"),setTimeout(function(){o(window.location.hash.replace("#",""))},0)};return e.addEventListener("click",a),function(){return e.removeEventListener("click",a)}},[]);var c=function(e){o(e),"our_plugins"===e&&n?n.style.display="block":n&&(n.style.display="none"),window.location.hash=e},u=(0,s.useSelect)(function(e){return{pluginSettings:e(qc).getPluginSettings(),blockVisibility:e(qc).getBlockVisibility(),dashboardSettings:e(qc).getDashboardSettings()}}),d=u.pluginSettings,p=u.blockVisibility,f=u.dashboardSettings,m=(0,s.useDispatch)(qc).fetchApiData;(0,i.useEffect)(function(){m()},[m]),(0,i.useEffect)(function(){window.$crisp||(window.$crisp=[],window.CRISP_WEBSITE_ID="3770a55e-947f-424d-87b8-d93a86f2cd7b",function(){var e=document,t=e.createElement("script");t.src="https://client.crisp.chat/l.js",t.async=1,e.getElementsByTagName("head")[0].appendChild(t)}())},[]);var h=(0,i.useMemo)(function(){var e,t;if(!f)return[];var n,r=[{label:"Getting Started",value:"getting-start",hash:"#"},{label:"Blocks",value:"blocks",hash:"#blocks",badge:"new"},{label:"Modules",value:"modules",hash:"#modules"},{label:"Saved Templates",value:"saved_templates",hash:"#saved_templates"},{label:"Integrations",value:"integrations",hash:"#integrations"},{label:"Settings",value:"settings",hash:"#settings"},{label:"Lite vs Pro",value:"lite_vs_pro",hash:"#lite_vs_pro"},{label:"About Us",value:"about_us",hash:"#about_us"},{label:"Our Plugins",value:"our_plugins",hash:"#our_plugins",icon:React.createElement(dc,null)}];return null==f||null===(e=f.modules)||void 0===e||!e.saved_templates||(null==f||null===(t=f.modules)||void 0===t||null===(t=t.saved_templates)||void 0===t?void 0:t.is_active)||(r=null===(n=r)||void 0===n?void 0:n.filter(function(e){return"saved_templates"!==e.value})),r},[f]);return d?"setupwizard"===a?React.createElement(kC,null):React.createElement(React.Fragment,null,React.createElement("div",{className:"sp-eab-admin-dashboard-container"},React.createElement(wc,null),React.createElement("div",{className:"sp-eab-admin-dashboard-body"},React.createElement("div",{className:"sp-eab-admin-dashboard-nav"},React.createElement("ul",{className:"our_plugins"===a||"about_us"===a?"sp-eab-hide-our-plugins-border sp-d-flex":"sp-d-flex"},null==h?void 0:h.map(function(e){return React.createElement("li",{key:e.value,className:"our_plugins"===e.value?"sp-eab-nav-our-plugins":""},React.createElement("a",{href:e.hash,className:a.includes(e.value)?"active":"",onClick:function(){return c(e.value)}},e.icon,e.label,e.badge&&React.createElement("span",{className:"sp-eab-nav-badge"},(0,l.__)("NEW!","easy-accordion-free"))))}))),React.createElement("div",{className:"sp-eab-admin-dashboard-content"},"getting-start"===a&&React.createElement(Ku,{setPageAndHash:c}),"blocks"===a&&p&&React.createElement(ed,null),"modules"===a&&React.createElement(Bu,null),"integrations"===a&&f&&React.createElement(lC,null),"saved_templates"===a&&React.createElement(Sd,null),"settings"===a&&React.createElement(oC,null),"lite_vs_pro"===a&&React.createElement(LC,null),"about_us"===a&&React.createElement(ZC,null)))),React.createElement(se,{position:"top-right",toastOptions:{style:{padding:"16px 24px",fontSize:"18px",borderRadius:"10px",maxWidth:"400px"}}})):null};window.addEventListener("DOMContentLoaded",function(){var e=document.getElementById("sp-eab-admin-dashboard-wrapper");if(e){var t=document.querySelector(".sp-eab-admin-dashboard-container");t||((t=document.createElement("div")).className="sp-eab-admin-dashboard-container",e.insertBefore(t,e.firstChild)),"function"==typeof i.createRoot?i.createRoot(t).render(React.createElement(XC,null)):"function"==typeof i.render&&i.render(React.createElement(XC,null),t)}})},146(e,t,n){"use strict";var r=n(404),a={childContextTypes:!0,contextType:!0,contextTypes:!0,defaultProps:!0,displayName:!0,getDefaultProps:!0,getDerivedStateFromError:!0,getDerivedStateFromProps:!0,mixins:!0,propTypes:!0,type:!0},o={name:!0,length:!0,prototype:!0,caller:!0,callee:!0,arguments:!0,arity:!0},i={$$typeof:!0,compare:!0,defaultProps:!0,displayName:!0,propTypes:!0,type:!0},s={};function l(e){return r.isMemo(e)?i:s[e.$$typeof]||a}s[r.ForwardRef]={$$typeof:!0,render:!0,defaultProps:!0,displayName:!0,propTypes:!0},s[r.Memo]=i;var c=Object.defineProperty,u=Object.getOwnPropertyNames,d=Object.getOwnPropertySymbols,p=Object.getOwnPropertyDescriptor,f=Object.getPrototypeOf,m=Object.prototype;e.exports=function e(t,n,r){if("string"!=typeof n){if(m){var a=f(n);a&&a!==m&&e(t,a,r)}var i=u(n);d&&(i=i.concat(d(n)));for(var s=l(t),h=l(n),g=0;g<i.length;++g){var v=i[g];if(!(o[v]||r&&r[v]||h&&h[v]||s&&s[v])){var b=p(n,v);try{c(t,v,b)}catch(e){}}}}return t}},72(e,t){"use strict";var n="function"==typeof Symbol&&Symbol.for,r=n?Symbol.for("react.element"):60103,a=n?Symbol.for("react.portal"):60106,o=n?Symbol.for("react.fragment"):60107,i=n?Symbol.for("react.strict_mode"):60108,s=n?Symbol.for("react.profiler"):60114,l=n?Symbol.for("react.provider"):60109,c=n?Symbol.for("react.context"):60110,u=n?Symbol.for("react.async_mode"):60111,d=n?Symbol.for("react.concurrent_mode"):60111,p=n?Symbol.for("react.forward_ref"):60112,f=n?Symbol.for("react.suspense"):60113,m=n?Symbol.for("react.suspense_list"):60120,h=n?Symbol.for("react.memo"):60115,g=n?Symbol.for("react.lazy"):60116,v=n?Symbol.for("react.block"):60121,b=n?Symbol.for("react.fundamental"):60117,y=n?Symbol.for("react.responder"):60118,w=n?Symbol.for("react.scope"):60119;function E(e){if("object"==typeof e&&null!==e){var t=e.$$typeof;switch(t){case r:switch(e=e.type){case u:case d:case o:case s:case i:case f:return e;default:switch(e=e&&e.$$typeof){case c:case p:case g:case h:case l:return e;default:return t}}case a:return t}}}function R(e){return E(e)===d}t.AsyncMode=u,t.ConcurrentMode=d,t.ContextConsumer=c,t.ContextProvider=l,t.Element=r,t.ForwardRef=p,t.Fragment=o,t.Lazy=g,t.Memo=h,t.Portal=a,t.Profiler=s,t.StrictMode=i,t.Suspense=f,t.isAsyncMode=function(e){return R(e)||E(e)===u},t.isConcurrentMode=R,t.isContextConsumer=function(e){return E(e)===c},t.isContextProvider=function(e){return E(e)===l},t.isElement=function(e){return"object"==typeof e&&null!==e&&e.$$typeof===r},t.isForwardRef=function(e){return E(e)===p},t.isFragment=function(e){return E(e)===o},t.isLazy=function(e){return E(e)===g},t.isMemo=function(e){return E(e)===h},t.isPortal=function(e){return E(e)===a},t.isProfiler=function(e){return E(e)===s},t.isStrictMode=function(e){return E(e)===i},t.isSuspense=function(e){return E(e)===f},t.isValidElementType=function(e){return"string"==typeof e||"function"==typeof e||e===o||e===d||e===s||e===i||e===f||e===m||"object"==typeof e&&null!==e&&(e.$$typeof===g||e.$$typeof===h||e.$$typeof===l||e.$$typeof===c||e.$$typeof===p||e.$$typeof===b||e.$$typeof===y||e.$$typeof===w||e.$$typeof===v)},t.typeOf=E},404(e,t,n){"use strict";e.exports=n(72)},694(e,t,n){"use strict";var r=n(925);function a(){}function o(){}o.resetWarningCache=a,e.exports=function(){function e(e,t,n,a,o,i){if(i!==r){var s=new Error("Calling PropTypes validators directly is not supported by the `prop-types` package. Use PropTypes.checkPropTypes() to call them. Read more at http://fb.me/use-check-prop-types");throw s.name="Invariant Violation",s}}function t(){return e}e.isRequired=e;var n={array:e,bigint:e,bool:e,func:e,number:e,object:e,string:e,symbol:e,any:e,arrayOf:t,element:e,elementType:e,instanceOf:t,node:e,objectOf:t,oneOf:t,oneOfType:t,shape:t,exact:t,checkPropTypes:o,resetWarningCache:a};return n.PropTypes=n,n}},556(e,t,n){e.exports=n(694)()},925(e){"use strict";e.exports="SECRET_DO_NOT_PASS_THIS_OR_YOU_WILL_BE_FIRED"},405(e,t){"use strict";Symbol.for("react.transitional.element"),Symbol.for("react.portal");var n=Symbol.for("react.fragment"),r=Symbol.for("react.strict_mode"),a=Symbol.for("react.profiler"),o=Symbol.for("react.consumer"),i=Symbol.for("react.context"),s=Symbol.for("react.forward_ref"),l=Symbol.for("react.suspense"),c=Symbol.for("react.suspense_list"),u=Symbol.for("react.memo"),d=Symbol.for("react.lazy"),p=(Symbol.for("react.view_transition"),Symbol.for("react.client.reference"));t.Hy=function(e){return"string"==typeof e||"function"==typeof e||e===n||e===a||e===r||e===l||e===c||"object"==typeof e&&null!==e&&(e.$$typeof===d||e.$$typeof===u||e.$$typeof===i||e.$$typeof===o||e.$$typeof===s||e.$$typeof===p||void 0!==e.getModuleId)}},212(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0});var r,a=(r=n(609))&&r.__esModule?r:{default:r};t.default=function(){return a.default.createElement("svg",{width:"14",height:"11",viewBox:"0 0 14 11"},a.default.createElement("path",{d:"M11.264 0L5.26 6.004 2.103 2.847 0 4.95l5.26 5.26 8.108-8.107L11.264 0",fill:"#fff",fillRule:"evenodd"}))}},384(e,t,n){"use strict";var r=Object.assign||function(e){for(var t=1;t<arguments.length;t++){var n=arguments[t];for(var r in n)Object.prototype.hasOwnProperty.call(n,r)&&(e[r]=n[r])}return e},a=function(){function e(e,t){for(var n=0;n<t.length;n++){var r=t[n];r.enumerable=r.enumerable||!1,r.configurable=!0,"value"in r&&(r.writable=!0),Object.defineProperty(e,r.key,r)}}return function(t,n,r){return n&&e(t.prototype,n),r&&e(t,r),t}}(),o=n(609),i=p(o),s=p(n(942)),l=p(n(556)),c=p(n(212)),u=p(n(28)),d=n(394);function p(e){return e&&e.__esModule?e:{default:e}}var f=function(e){function t(e){!function(e,t){if(!(e instanceof t))throw new TypeError("Cannot call a class as a function")}(this,t);var n=function(e,t){if(!e)throw new ReferenceError("this hasn't been initialised - super() hasn't been called");return!t||"object"!=typeof t&&"function"!=typeof t?e:t}(this,(t.__proto__||Object.getPrototypeOf(t)).call(this,e));return n.handleClick=n.handleClick.bind(n),n.handleTouchStart=n.handleTouchStart.bind(n),n.handleTouchMove=n.handleTouchMove.bind(n),n.handleTouchEnd=n.handleTouchEnd.bind(n),n.handleFocus=n.handleFocus.bind(n),n.handleBlur=n.handleBlur.bind(n),n.previouslyChecked=!(!e.checked&&!e.defaultChecked),n.state={checked:!(!e.checked&&!e.defaultChecked),hasFocus:!1},n}return function(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Super expression must either be null or a function, not "+typeof t);e.prototype=Object.create(t&&t.prototype,{constructor:{value:e,enumerable:!1,writable:!0,configurable:!0}}),t&&(Object.setPrototypeOf?Object.setPrototypeOf(e,t):e.__proto__=t)}(t,e),a(t,[{key:"componentDidUpdate",value:function(e){e.checked!==this.props.checked&&this.setState({checked:!!this.props.checked})}},{key:"handleClick",value:function(e){if(!this.props.disabled){var t=this.input;if(e.target!==t&&!this.moved)return this.previouslyChecked=t.checked,e.preventDefault(),t.focus(),void t.click();var n=this.props.hasOwnProperty("checked")?this.props.checked:t.checked;this.setState({checked:n})}}},{key:"handleTouchStart",value:function(e){this.props.disabled||(this.startX=(0,d.pointerCoord)(e).x,this.activated=!0)}},{key:"handleTouchMove",value:function(e){if(this.activated&&(this.moved=!0,this.startX)){var t=(0,d.pointerCoord)(e).x;this.state.checked&&t+15<this.startX?(this.setState({checked:!1}),this.startX=t,this.activated=!0):t-15>this.startX&&(this.setState({checked:!0}),this.startX=t,this.activated=t<this.startX+5)}}},{key:"handleTouchEnd",value:function(e){if(this.moved){var t=this.input;if(e.preventDefault(),this.startX){var n=(0,d.pointerCoord)(e).x;!0===this.previouslyChecked&&this.startX+4>n?this.previouslyChecked!==this.state.checked&&(this.setState({checked:!1}),this.previouslyChecked=this.state.checked,t.click()):this.startX-4<n&&this.previouslyChecked!==this.state.checked&&(this.setState({checked:!0}),this.previouslyChecked=this.state.checked,t.click()),this.activated=!1,this.startX=null,this.moved=!1}}}},{key:"handleFocus",value:function(e){var t=this.props.onFocus;t&&t(e),this.setState({hasFocus:!0})}},{key:"handleBlur",value:function(e){var t=this.props.onBlur;t&&t(e),this.setState({hasFocus:!1})}},{key:"getIcon",value:function(e){var n=this.props.icons;return n?void 0===n[e]?t.defaultProps.icons[e]:n[e]:null}},{key:"render",value:function(){var e=this,t=this.props,n=t.className,a=(t.icons,function(e,t){var n={};for(var r in e)t.indexOf(r)>=0||Object.prototype.hasOwnProperty.call(e,r)&&(n[r]=e[r]);return n}(t,["className","icons"])),o=(0,s.default)("react-toggle",{"react-toggle--checked":this.state.checked,"react-toggle--focus":this.state.hasFocus,"react-toggle--disabled":this.props.disabled},n);return i.default.createElement("div",{className:o,onClick:this.handleClick,onTouchStart:this.handleTouchStart,onTouchMove:this.handleTouchMove,onTouchEnd:this.handleTouchEnd},i.default.createElement("div",{className:"react-toggle-track"},i.default.createElement("div",{className:"react-toggle-track-check"},this.getIcon("checked")),i.default.createElement("div",{className:"react-toggle-track-x"},this.getIcon("unchecked"))),i.default.createElement("div",{className:"react-toggle-thumb"}),i.default.createElement("input",r({},a,{ref:function(t){e.input=t},onFocus:this.handleFocus,onBlur:this.handleBlur,className:"react-toggle-screenreader-only",type:"checkbox"})))}}]),t}(o.PureComponent);t.A=f,f.displayName="Toggle",f.defaultProps={icons:{checked:i.default.createElement(c.default,null),unchecked:i.default.createElement(u.default,null)}},f.propTypes={checked:l.default.bool,disabled:l.default.bool,defaultChecked:l.default.bool,onChange:l.default.func,onFocus:l.default.func,onBlur:l.default.func,className:l.default.string,name:l.default.string,value:l.default.string,id:l.default.string,"aria-labelledby":l.default.string,"aria-label":l.default.string,icons:l.default.oneOfType([l.default.bool,l.default.shape({checked:l.default.node,unchecked:l.default.node})])}},394(e,t){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.pointerCoord=function(e){if(e){var t=e.changedTouches;if(t&&t.length>0){var n=t[0];return{x:n.clientX,y:n.clientY}}var r=e.pageX;if(void 0!==r)return{x:r,y:e.pageY}}return{x:0,y:0}}},28(e,t,n){"use strict";Object.defineProperty(t,"__esModule",{value:!0});var r,a=(r=n(609))&&r.__esModule?r:{default:r};t.default=function(){return a.default.createElement("svg",{width:"10",height:"10",viewBox:"0 0 10 10"},a.default.createElement("path",{d:"M9.9 2.12L7.78 0 4.95 2.828 2.12 0 0 2.12l2.83 2.83L0 7.776 2.123 9.9 4.95 7.07 7.78 9.9 9.9 7.776 7.072 4.95 9.9 2.12",fill:"#fff",fillRule:"evenodd"}))}},160(e,t,n){"use strict";var r=n(609);"function"==typeof Object.is&&Object.is,r.useSyncExternalStore,r.useRef,r.useEffect,r.useMemo,r.useDebugValue},418(e,t,n){"use strict";n(160)},609(e){"use strict";e.exports=window.React},942(e,t){var n;!function(){"use strict";var r={}.hasOwnProperty;function a(){for(var e="",t=0;t<arguments.length;t++){var n=arguments[t];n&&(e=i(e,o(n)))}return e}function o(e){if("string"==typeof e||"number"==typeof e)return e;if("object"!=typeof e)return"";if(Array.isArray(e))return a.apply(null,e);if(e.toString!==Object.prototype.toString&&!e.toString.toString().includes("[native code]"))return e.toString();var t="";for(var n in e)r.call(e,n)&&e[n]&&(t=i(t,n));return t}function i(e,t){return t?e?e+" "+t:e+t:e}e.exports?(a.default=a,e.exports=a):void 0===(n=function(){return a}.apply(t,[]))||(e.exports=n)}()}},n={};function r(e){var a=n[e];if(void 0!==a)return a.exports;var o=n[e]={exports:{}};return t[e](o,o.exports,r),o.exports}r.m=t,e=[],r.O=(t,n,a,o)=>{if(!n){var i=1/0;for(u=0;u<e.length;u++){for(var[n,a,o]=e[u],s=!0,l=0;l<n.length;l++)(!1&o||i>=o)&&Object.keys(r.O).every(e=>r.O[e](n[l]))?n.splice(l--,1):(s=!1,o<i&&(i=o));if(s){e.splice(u--,1);var c=a();void 0!==c&&(t=c)}}return t}o=o||0;for(var u=e.length;u>0&&e[u-1][2]>o;u--)e[u]=e[u-1];e[u]=[n,a,o]},r.n=e=>{var t=e&&e.__esModule?()=>e.default:()=>e;return r.d(t,{a:t}),t},r.d=(e,t)=>{for(var n in t)r.o(t,n)&&!r.o(e,n)&&Object.defineProperty(e,n,{enumerable:!0,get:t[n]})},r.o=(e,t)=>Object.prototype.hasOwnProperty.call(e,t),r.r=e=>{"undefined"!=typeof Symbol&&Symbol.toStringTag&&Object.defineProperty(e,Symbol.toStringTag,{value:"Module"}),Object.defineProperty(e,"__esModule",{value:!0})},(()=>{var e={422:0,283:0};r.O.j=t=>0===e[t];var t=(t,n)=>{var a,o,[i,s,l]=n,c=0;if(i.some(t=>0!==e[t])){for(a in s)r.o(s,a)&&(r.m[a]=s[a]);if(l)var u=l(r)}for(t&&t(n);c<i.length;c++)o=i[c],r.o(e,o)&&e[o]&&e[o][0](),e[o]=0;return r.O(u)},n=globalThis.webpackChunkeasy_accordion_free=globalThis.webpackChunkeasy_accordion_free||[];n.forEach(t.bind(null,0)),n.push=t.bind(null,n.push.bind(n))})();var a=r.O(void 0,[283],()=>r(998));a=r.O(a)})();